from __future__ import (absolute_import, division, print_function)
# Copyright (c) 2022 Fortinet
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

__metaclass__ = type

import json


SCHEMA_DATA = '''
{
    "adom_options": {
        "stated": false,
        "options": {
            "assign_excluded": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "specify_assign_pkg_list": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "assign_name": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "antivirus_mmschecksum": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "entries": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "checksum": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "antivirus_mmschecksum_entries": {
        "stated": true,
        "options": {
            "checksum": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "antivirus_notification": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "entries": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "prefix": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "antivirus_notification_entries": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "prefix": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "antivirus_profile": {
        "stated": true,
        "options": {
            "analytics-bl-filetype": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "analytics-db": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "analytics-max-upload": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "analytics-wl-filetype": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "av-block-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "av-virus-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "extended-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ftgd-analytics": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "suspicious",
                    "everything"
                ],
                "type": "str"
            },
            "inspection-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "proxy",
                    "flow-based"
                ],
                "type": "str"
            },
            "mobile-malware-db": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "replacemsg-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "scan-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "quick",
                    "full",
                    "legacy",
                    "default"
                ],
                "type": "str"
            },
            "feature-set": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "proxy",
                    "flow"
                ],
                "type": "str"
            },
            "cifs": {
                "required": false,
                "type": "dict",
                "options": {
                    "archive-block": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "encrypted",
                            "corrupted",
                            "multipart",
                            "nested",
                            "mailbomb",
                            "unhandled",
                            "partiallycorrupted",
                            "fileslimit",
                            "timeout"
                        ],
                        "elements": "str"
                    },
                    "archive-log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "encrypted",
                            "corrupted",
                            "multipart",
                            "nested",
                            "mailbomb",
                            "unhandled",
                            "partiallycorrupted",
                            "fileslimit",
                            "timeout"
                        ],
                        "elements": "str"
                    },
                    "emulator": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "options": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "scan",
                            "quarantine",
                            "avmonitor"
                        ],
                        "elements": "str"
                    },
                    "outbreak-prevention": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disabled",
                            "files",
                            "full-archive",
                            "disable",
                            "block",
                            "monitor"
                        ],
                        "type": "str"
                    },
                    "av-scan": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "monitor",
                            "block"
                        ],
                        "type": "str"
                    },
                    "external-blocklist": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "monitor",
                            "block"
                        ],
                        "type": "str"
                    },
                    "quarantine": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "fortindr": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "block",
                            "monitor"
                        ],
                        "type": "str"
                    },
                    "fortisandbox": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "block",
                            "monitor"
                        ],
                        "type": "str"
                    },
                    "fortiai": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "monitor",
                            "block"
                        ],
                        "type": "str"
                    }
                }
            },
            "content-disarm": {
                "required": false,
                "type": "dict",
                "options": {
                    "cover-page": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "detect-only": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "error-action": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "block",
                            "log-only",
                            "ignore"
                        ],
                        "type": "str"
                    },
                    "office-action": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "office-dde": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "office-embed": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "office-hylink": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "office-linked": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "office-macro": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "original-file-destination": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "fortisandbox",
                            "quarantine",
                            "discard"
                        ],
                        "type": "str"
                    },
                    "pdf-act-form": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "pdf-act-gotor": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "pdf-act-java": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "pdf-act-launch": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "pdf-act-movie": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "pdf-act-sound": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "pdf-embedfile": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "pdf-hyperlink": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "pdf-javacode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "ftp": {
                "required": false,
                "type": "dict",
                "options": {
                    "archive-block": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "encrypted",
                            "corrupted",
                            "multipart",
                            "nested",
                            "mailbomb",
                            "unhandled",
                            "partiallycorrupted",
                            "fileslimit",
                            "timeout"
                        ],
                        "elements": "str"
                    },
                    "archive-log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "encrypted",
                            "corrupted",
                            "multipart",
                            "nested",
                            "mailbomb",
                            "unhandled",
                            "partiallycorrupted",
                            "fileslimit",
                            "timeout"
                        ],
                        "elements": "str"
                    },
                    "emulator": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "options": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "scan",
                            "file-filter",
                            "quarantine",
                            "avquery",
                            "avmonitor"
                        ],
                        "elements": "str"
                    },
                    "outbreak-prevention": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disabled",
                            "files",
                            "full-archive",
                            "disable",
                            "block",
                            "monitor"
                        ],
                        "type": "str"
                    },
                    "av-scan": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "monitor",
                            "block"
                        ],
                        "type": "str"
                    },
                    "external-blocklist": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "monitor",
                            "block"
                        ],
                        "type": "str"
                    },
                    "quarantine": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "fortindr": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "block",
                            "monitor"
                        ],
                        "type": "str"
                    },
                    "fortisandbox": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "block",
                            "monitor"
                        ],
                        "type": "str"
                    },
                    "fortiai": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "monitor",
                            "block"
                        ],
                        "type": "str"
                    }
                }
            },
            "http": {
                "required": false,
                "type": "dict",
                "options": {
                    "archive-block": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "encrypted",
                            "corrupted",
                            "multipart",
                            "nested",
                            "mailbomb",
                            "unhandled",
                            "partiallycorrupted",
                            "fileslimit",
                            "timeout"
                        ],
                        "elements": "str"
                    },
                    "archive-log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "encrypted",
                            "corrupted",
                            "multipart",
                            "nested",
                            "mailbomb",
                            "unhandled",
                            "partiallycorrupted",
                            "fileslimit",
                            "timeout"
                        ],
                        "elements": "str"
                    },
                    "content-disarm": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "emulator": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "options": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "scan",
                            "file-filter",
                            "quarantine",
                            "avquery",
                            "avmonitor",
                            "strict-file"
                        ],
                        "elements": "str"
                    },
                    "outbreak-prevention": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disabled",
                            "files",
                            "full-archive",
                            "disable",
                            "block",
                            "monitor"
                        ],
                        "type": "str"
                    },
                    "av-optimize": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "av-scan": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "monitor",
                            "block"
                        ],
                        "type": "str"
                    },
                    "external-blocklist": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "monitor",
                            "block"
                        ],
                        "type": "str"
                    },
                    "quarantine": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "fortindr": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "block",
                            "monitor"
                        ],
                        "type": "str"
                    },
                    "fortisandbox": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "block",
                            "monitor"
                        ],
                        "type": "str"
                    },
                    "fortiai": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "monitor",
                            "block"
                        ],
                        "type": "str"
                    },
                    "unknown-content-encoding": {
                        "required": false,
                        "revision": {
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "block",
                            "inspect",
                            "bypass"
                        ],
                        "type": "str"
                    }
                }
            },
            "imap": {
                "required": false,
                "type": "dict",
                "options": {
                    "archive-block": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "encrypted",
                            "corrupted",
                            "multipart",
                            "nested",
                            "mailbomb",
                            "unhandled",
                            "partiallycorrupted",
                            "fileslimit",
                            "timeout"
                        ],
                        "elements": "str"
                    },
                    "archive-log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "encrypted",
                            "corrupted",
                            "multipart",
                            "nested",
                            "mailbomb",
                            "unhandled",
                            "partiallycorrupted",
                            "fileslimit",
                            "timeout"
                        ],
                        "elements": "str"
                    },
                    "content-disarm": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "emulator": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "executables": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "default",
                            "virus"
                        ],
                        "type": "str"
                    },
                    "options": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "scan",
                            "file-filter",
                            "quarantine",
                            "avquery",
                            "avmonitor"
                        ],
                        "elements": "str"
                    },
                    "outbreak-prevention": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disabled",
                            "files",
                            "full-archive",
                            "disable",
                            "block",
                            "monitor"
                        ],
                        "type": "str"
                    },
                    "av-scan": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "monitor",
                            "block"
                        ],
                        "type": "str"
                    },
                    "external-blocklist": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "monitor",
                            "block"
                        ],
                        "type": "str"
                    },
                    "quarantine": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "fortindr": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "block",
                            "monitor"
                        ],
                        "type": "str"
                    },
                    "fortisandbox": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "block",
                            "monitor"
                        ],
                        "type": "str"
                    },
                    "fortiai": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "monitor",
                            "block"
                        ],
                        "type": "str"
                    }
                }
            },
            "mapi": {
                "required": false,
                "type": "dict",
                "options": {
                    "archive-block": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "encrypted",
                            "corrupted",
                            "multipart",
                            "nested",
                            "mailbomb",
                            "unhandled",
                            "partiallycorrupted",
                            "fileslimit",
                            "timeout"
                        ],
                        "elements": "str"
                    },
                    "archive-log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "encrypted",
                            "corrupted",
                            "multipart",
                            "nested",
                            "mailbomb",
                            "unhandled",
                            "partiallycorrupted",
                            "fileslimit",
                            "timeout"
                        ],
                        "elements": "str"
                    },
                    "emulator": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "executables": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "default",
                            "virus"
                        ],
                        "type": "str"
                    },
                    "options": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "scan",
                            "quarantine",
                            "avquery",
                            "avmonitor"
                        ],
                        "elements": "str"
                    },
                    "outbreak-prevention": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disabled",
                            "files",
                            "full-archive",
                            "disable",
                            "block",
                            "monitor"
                        ],
                        "type": "str"
                    },
                    "av-scan": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "monitor",
                            "block"
                        ],
                        "type": "str"
                    },
                    "external-blocklist": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "monitor",
                            "block"
                        ],
                        "type": "str"
                    },
                    "quarantine": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "fortindr": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "block",
                            "monitor"
                        ],
                        "type": "str"
                    },
                    "fortisandbox": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "block",
                            "monitor"
                        ],
                        "type": "str"
                    },
                    "fortiai": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "monitor",
                            "block"
                        ],
                        "type": "str"
                    }
                }
            },
            "nac-quar": {
                "required": false,
                "type": "dict",
                "options": {
                    "expiry": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "infected": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "quar-src-ip",
                            "quar-interface"
                        ],
                        "type": "str"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "nntp": {
                "required": false,
                "type": "dict",
                "options": {
                    "archive-block": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "encrypted",
                            "corrupted",
                            "multipart",
                            "nested",
                            "mailbomb",
                            "unhandled",
                            "partiallycorrupted",
                            "fileslimit",
                            "timeout"
                        ],
                        "elements": "str"
                    },
                    "archive-log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "encrypted",
                            "corrupted",
                            "multipart",
                            "nested",
                            "mailbomb",
                            "unhandled",
                            "partiallycorrupted",
                            "fileslimit",
                            "timeout"
                        ],
                        "elements": "str"
                    },
                    "emulator": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "options": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "scan",
                            "file-filter",
                            "quarantine",
                            "avquery",
                            "avmonitor"
                        ],
                        "elements": "str"
                    },
                    "outbreak-prevention": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disabled",
                            "files",
                            "full-archive",
                            "disable",
                            "block",
                            "monitor"
                        ],
                        "type": "str"
                    },
                    "av-scan": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "monitor",
                            "block"
                        ],
                        "type": "str"
                    },
                    "external-blocklist": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "monitor",
                            "block"
                        ],
                        "type": "str"
                    },
                    "quarantine": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "fortindr": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "block",
                            "monitor"
                        ],
                        "type": "str"
                    },
                    "fortisandbox": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "block",
                            "monitor"
                        ],
                        "type": "str"
                    },
                    "fortiai": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "monitor",
                            "block"
                        ],
                        "type": "str"
                    }
                }
            },
            "outbreak-prevention": {
                "required": false,
                "type": "dict",
                "options": {
                    "external-blocklist": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ftgd-service": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "pop3": {
                "required": false,
                "type": "dict",
                "options": {
                    "archive-block": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "encrypted",
                            "corrupted",
                            "multipart",
                            "nested",
                            "mailbomb",
                            "unhandled",
                            "partiallycorrupted",
                            "fileslimit",
                            "timeout"
                        ],
                        "elements": "str"
                    },
                    "archive-log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "encrypted",
                            "corrupted",
                            "multipart",
                            "nested",
                            "mailbomb",
                            "unhandled",
                            "partiallycorrupted",
                            "fileslimit",
                            "timeout"
                        ],
                        "elements": "str"
                    },
                    "content-disarm": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "emulator": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "executables": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "default",
                            "virus"
                        ],
                        "type": "str"
                    },
                    "options": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "scan",
                            "file-filter",
                            "quarantine",
                            "avquery",
                            "avmonitor"
                        ],
                        "elements": "str"
                    },
                    "outbreak-prevention": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disabled",
                            "files",
                            "full-archive",
                            "disable",
                            "block",
                            "monitor"
                        ],
                        "type": "str"
                    },
                    "av-scan": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "monitor",
                            "block"
                        ],
                        "type": "str"
                    },
                    "external-blocklist": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "monitor",
                            "block"
                        ],
                        "type": "str"
                    },
                    "quarantine": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "fortindr": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "block",
                            "monitor"
                        ],
                        "type": "str"
                    },
                    "fortisandbox": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "block",
                            "monitor"
                        ],
                        "type": "str"
                    },
                    "fortiai": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "monitor",
                            "block"
                        ],
                        "type": "str"
                    }
                }
            },
            "smtp": {
                "required": false,
                "type": "dict",
                "options": {
                    "archive-block": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "encrypted",
                            "corrupted",
                            "multipart",
                            "nested",
                            "mailbomb",
                            "unhandled",
                            "partiallycorrupted",
                            "fileslimit",
                            "timeout"
                        ],
                        "elements": "str"
                    },
                    "archive-log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "encrypted",
                            "corrupted",
                            "multipart",
                            "nested",
                            "mailbomb",
                            "unhandled",
                            "partiallycorrupted",
                            "fileslimit",
                            "timeout"
                        ],
                        "elements": "str"
                    },
                    "content-disarm": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "emulator": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "executables": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "default",
                            "virus"
                        ],
                        "type": "str"
                    },
                    "options": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "scan",
                            "file-filter",
                            "quarantine",
                            "avquery",
                            "avmonitor"
                        ],
                        "elements": "str"
                    },
                    "outbreak-prevention": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disabled",
                            "files",
                            "full-archive",
                            "disable",
                            "block",
                            "monitor"
                        ],
                        "type": "str"
                    },
                    "av-scan": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "monitor",
                            "block"
                        ],
                        "type": "str"
                    },
                    "external-blocklist": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "monitor",
                            "block"
                        ],
                        "type": "str"
                    },
                    "quarantine": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "fortindr": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "block",
                            "monitor"
                        ],
                        "type": "str"
                    },
                    "fortisandbox": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "block",
                            "monitor"
                        ],
                        "type": "str"
                    },
                    "fortiai": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "monitor",
                            "block"
                        ],
                        "type": "str"
                    }
                }
            },
            "ssh": {
                "required": false,
                "type": "dict",
                "options": {
                    "archive-block": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "encrypted",
                            "corrupted",
                            "multipart",
                            "nested",
                            "mailbomb",
                            "unhandled",
                            "partiallycorrupted",
                            "fileslimit",
                            "timeout"
                        ],
                        "elements": "str"
                    },
                    "archive-log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "encrypted",
                            "corrupted",
                            "multipart",
                            "nested",
                            "mailbomb",
                            "unhandled",
                            "partiallycorrupted",
                            "fileslimit",
                            "timeout"
                        ],
                        "elements": "str"
                    },
                    "emulator": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "options": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "avmonitor",
                            "quarantine",
                            "scan"
                        ],
                        "elements": "str"
                    },
                    "outbreak-prevention": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disabled",
                            "files",
                            "full-archive",
                            "disable",
                            "block",
                            "monitor"
                        ],
                        "type": "str"
                    },
                    "av-scan": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "monitor",
                            "block"
                        ],
                        "type": "str"
                    },
                    "external-blocklist": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "monitor",
                            "block"
                        ],
                        "type": "str"
                    },
                    "quarantine": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "fortindr": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "block",
                            "monitor"
                        ],
                        "type": "str"
                    },
                    "fortisandbox": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "block",
                            "monitor"
                        ],
                        "type": "str"
                    },
                    "fortiai": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "monitor",
                            "block"
                        ],
                        "type": "str"
                    }
                }
            },
            "smb": {
                "required": false,
                "type": "dict",
                "options": {
                    "archive-block": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "list",
                        "choices": [
                            "encrypted",
                            "corrupted",
                            "multipart",
                            "nested",
                            "mailbomb",
                            "unhandled",
                            "partiallycorrupted",
                            "fileslimit",
                            "timeout"
                        ],
                        "elements": "str"
                    },
                    "archive-log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "list",
                        "choices": [
                            "encrypted",
                            "corrupted",
                            "multipart",
                            "nested",
                            "mailbomb",
                            "unhandled",
                            "partiallycorrupted",
                            "fileslimit",
                            "timeout"
                        ],
                        "elements": "str"
                    },
                    "emulator": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "options": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "list",
                        "choices": [
                            "scan",
                            "quarantine",
                            "avquery",
                            "avmonitor"
                        ],
                        "elements": "str"
                    },
                    "outbreak-prevention": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disabled",
                            "files",
                            "full-archive"
                        ],
                        "type": "str"
                    }
                }
            },
            "analytics-accept-filetype": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "analytics-ignore-filetype": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ems-threat-feed": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "external-blocklist": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "external-blocklist-archive-scan": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "external-blocklist-enable-all": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "outbreak-prevention-archive-scan": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fortindr-error-action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "log-only",
                    "block",
                    "ignore"
                ],
                "type": "str"
            },
            "fortindr-timeout-action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "log-only",
                    "block",
                    "ignore"
                ],
                "type": "str"
            },
            "fortisandbox-error-action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "log-only",
                    "block",
                    "ignore"
                ],
                "type": "str"
            },
            "fortisandbox-max-upload": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fortisandbox-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "inline",
                    "analytics-suspicious",
                    "analytics-everything"
                ],
                "type": "str"
            },
            "fortisandbox-timeout-action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "log-only",
                    "block",
                    "ignore"
                ],
                "type": "str"
            },
            "fortiai-error-action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "block",
                    "log-only",
                    "ignore"
                ],
                "type": "str"
            },
            "fortiai-timeout-action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "block",
                    "log-only",
                    "ignore"
                ],
                "type": "str"
            }
        }
    },
    "antivirus_profile_cifs": {
        "stated": false,
        "options": {
            "archive-block": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "encrypted",
                    "corrupted",
                    "multipart",
                    "nested",
                    "mailbomb",
                    "unhandled",
                    "partiallycorrupted",
                    "fileslimit",
                    "timeout"
                ],
                "elements": "str"
            },
            "archive-log": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "encrypted",
                    "corrupted",
                    "multipart",
                    "nested",
                    "mailbomb",
                    "unhandled",
                    "partiallycorrupted",
                    "fileslimit",
                    "timeout"
                ],
                "elements": "str"
            },
            "emulator": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "options": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "scan",
                    "quarantine",
                    "avmonitor"
                ],
                "elements": "str"
            },
            "outbreak-prevention": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disabled",
                    "files",
                    "full-archive",
                    "disable",
                    "block",
                    "monitor"
                ],
                "type": "str"
            },
            "av-scan": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "monitor",
                    "block"
                ],
                "type": "str"
            },
            "external-blocklist": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "monitor",
                    "block"
                ],
                "type": "str"
            },
            "quarantine": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fortindr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "block",
                    "monitor"
                ],
                "type": "str"
            },
            "fortisandbox": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "block",
                    "monitor"
                ],
                "type": "str"
            },
            "fortiai": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "monitor",
                    "block"
                ],
                "type": "str"
            }
        }
    },
    "antivirus_profile_contentdisarm": {
        "stated": false,
        "options": {
            "cover-page": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "detect-only": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "office-embed": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "office-hylink": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "office-linked": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "office-macro": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "original-file-destination": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "fortisandbox",
                    "quarantine",
                    "discard"
                ],
                "type": "str"
            },
            "pdf-act-form": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "pdf-act-gotor": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "pdf-act-java": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "pdf-act-launch": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "pdf-act-movie": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "pdf-act-sound": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "pdf-embedfile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "pdf-hyperlink": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "pdf-javacode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "office-action": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "office-dde": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "error-action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "block",
                    "log-only",
                    "ignore"
                ],
                "type": "str"
            }
        }
    },
    "antivirus_profile_ftp": {
        "stated": false,
        "options": {
            "archive-block": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "encrypted",
                    "corrupted",
                    "multipart",
                    "nested",
                    "mailbomb",
                    "unhandled",
                    "partiallycorrupted",
                    "fileslimit",
                    "timeout"
                ],
                "elements": "str"
            },
            "archive-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "encrypted",
                    "corrupted",
                    "multipart",
                    "nested",
                    "mailbomb",
                    "unhandled",
                    "partiallycorrupted",
                    "fileslimit",
                    "timeout"
                ],
                "elements": "str"
            },
            "emulator": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "options": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "scan",
                    "file-filter",
                    "quarantine",
                    "avquery",
                    "avmonitor"
                ],
                "elements": "str"
            },
            "outbreak-prevention": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disabled",
                    "files",
                    "full-archive",
                    "disable",
                    "block",
                    "monitor"
                ],
                "type": "str"
            },
            "av-scan": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "monitor",
                    "block"
                ],
                "type": "str"
            },
            "external-blocklist": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "monitor",
                    "block"
                ],
                "type": "str"
            },
            "quarantine": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fortindr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "block",
                    "monitor"
                ],
                "type": "str"
            },
            "fortisandbox": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "block",
                    "monitor"
                ],
                "type": "str"
            },
            "fortiai": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "monitor",
                    "block"
                ],
                "type": "str"
            }
        }
    },
    "antivirus_profile_http": {
        "stated": false,
        "options": {
            "archive-block": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "encrypted",
                    "corrupted",
                    "multipart",
                    "nested",
                    "mailbomb",
                    "unhandled",
                    "partiallycorrupted",
                    "fileslimit",
                    "timeout"
                ],
                "elements": "str"
            },
            "archive-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "encrypted",
                    "corrupted",
                    "multipart",
                    "nested",
                    "mailbomb",
                    "unhandled",
                    "partiallycorrupted",
                    "fileslimit",
                    "timeout"
                ],
                "elements": "str"
            },
            "content-disarm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "emulator": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "options": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "scan",
                    "file-filter",
                    "quarantine",
                    "avquery",
                    "avmonitor",
                    "strict-file"
                ],
                "elements": "str"
            },
            "outbreak-prevention": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disabled",
                    "files",
                    "full-archive",
                    "disable",
                    "block",
                    "monitor"
                ],
                "type": "str"
            },
            "av-optimize": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "av-scan": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "monitor",
                    "block"
                ],
                "type": "str"
            },
            "external-blocklist": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "monitor",
                    "block"
                ],
                "type": "str"
            },
            "quarantine": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fortindr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "block",
                    "monitor"
                ],
                "type": "str"
            },
            "fortisandbox": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "block",
                    "monitor"
                ],
                "type": "str"
            },
            "fortiai": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "monitor",
                    "block"
                ],
                "type": "str"
            },
            "unknown-content-encoding": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "block",
                    "inspect",
                    "bypass"
                ],
                "type": "str"
            }
        }
    },
    "antivirus_profile_imap": {
        "stated": false,
        "options": {
            "archive-block": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "encrypted",
                    "corrupted",
                    "multipart",
                    "nested",
                    "mailbomb",
                    "unhandled",
                    "partiallycorrupted",
                    "fileslimit",
                    "timeout"
                ],
                "elements": "str"
            },
            "archive-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "encrypted",
                    "corrupted",
                    "multipart",
                    "nested",
                    "mailbomb",
                    "unhandled",
                    "partiallycorrupted",
                    "fileslimit",
                    "timeout"
                ],
                "elements": "str"
            },
            "content-disarm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "emulator": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "executables": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "default",
                    "virus"
                ],
                "type": "str"
            },
            "options": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "scan",
                    "file-filter",
                    "quarantine",
                    "avquery",
                    "avmonitor"
                ],
                "elements": "str"
            },
            "outbreak-prevention": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disabled",
                    "files",
                    "full-archive",
                    "disable",
                    "block",
                    "monitor"
                ],
                "type": "str"
            },
            "av-scan": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "monitor",
                    "block"
                ],
                "type": "str"
            },
            "external-blocklist": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "monitor",
                    "block"
                ],
                "type": "str"
            },
            "quarantine": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fortindr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "block",
                    "monitor"
                ],
                "type": "str"
            },
            "fortisandbox": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "block",
                    "monitor"
                ],
                "type": "str"
            },
            "fortiai": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "monitor",
                    "block"
                ],
                "type": "str"
            }
        }
    },
    "antivirus_profile_mapi": {
        "stated": false,
        "options": {
            "archive-block": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "encrypted",
                    "corrupted",
                    "multipart",
                    "nested",
                    "mailbomb",
                    "unhandled",
                    "partiallycorrupted",
                    "fileslimit",
                    "timeout"
                ],
                "elements": "str"
            },
            "archive-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "encrypted",
                    "corrupted",
                    "multipart",
                    "nested",
                    "mailbomb",
                    "unhandled",
                    "partiallycorrupted",
                    "fileslimit",
                    "timeout"
                ],
                "elements": "str"
            },
            "emulator": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "executables": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "default",
                    "virus"
                ],
                "type": "str"
            },
            "options": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "scan",
                    "quarantine",
                    "avquery",
                    "avmonitor"
                ],
                "elements": "str"
            },
            "outbreak-prevention": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disabled",
                    "files",
                    "full-archive",
                    "disable",
                    "block",
                    "monitor"
                ],
                "type": "str"
            },
            "av-scan": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "monitor",
                    "block"
                ],
                "type": "str"
            },
            "external-blocklist": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "monitor",
                    "block"
                ],
                "type": "str"
            },
            "quarantine": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fortindr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "block",
                    "monitor"
                ],
                "type": "str"
            },
            "fortisandbox": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "block",
                    "monitor"
                ],
                "type": "str"
            },
            "fortiai": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "monitor",
                    "block"
                ],
                "type": "str"
            }
        }
    },
    "antivirus_profile_nacquar": {
        "stated": false,
        "options": {
            "expiry": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "infected": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "quar-src-ip",
                    "quar-interface"
                ],
                "type": "str"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "antivirus_profile_nntp": {
        "stated": false,
        "options": {
            "archive-block": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "encrypted",
                    "corrupted",
                    "multipart",
                    "nested",
                    "mailbomb",
                    "unhandled",
                    "partiallycorrupted",
                    "fileslimit",
                    "timeout"
                ],
                "elements": "str"
            },
            "archive-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "encrypted",
                    "corrupted",
                    "multipart",
                    "nested",
                    "mailbomb",
                    "unhandled",
                    "partiallycorrupted",
                    "fileslimit",
                    "timeout"
                ],
                "elements": "str"
            },
            "emulator": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "options": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "scan",
                    "file-filter",
                    "quarantine",
                    "avquery",
                    "avmonitor"
                ],
                "elements": "str"
            },
            "outbreak-prevention": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disabled",
                    "files",
                    "full-archive",
                    "disable",
                    "block",
                    "monitor"
                ],
                "type": "str"
            },
            "av-scan": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "monitor",
                    "block"
                ],
                "type": "str"
            },
            "external-blocklist": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "monitor",
                    "block"
                ],
                "type": "str"
            },
            "quarantine": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fortindr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "block",
                    "monitor"
                ],
                "type": "str"
            },
            "fortisandbox": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "block",
                    "monitor"
                ],
                "type": "str"
            },
            "fortiai": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "monitor",
                    "block"
                ],
                "type": "str"
            }
        }
    },
    "antivirus_profile_outbreakprevention": {
        "stated": false,
        "options": {
            "external-blocklist": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ftgd-service": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "antivirus_profile_pop3": {
        "stated": false,
        "options": {
            "archive-block": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "encrypted",
                    "corrupted",
                    "multipart",
                    "nested",
                    "mailbomb",
                    "unhandled",
                    "partiallycorrupted",
                    "fileslimit",
                    "timeout"
                ],
                "elements": "str"
            },
            "archive-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "encrypted",
                    "corrupted",
                    "multipart",
                    "nested",
                    "mailbomb",
                    "unhandled",
                    "partiallycorrupted",
                    "fileslimit",
                    "timeout"
                ],
                "elements": "str"
            },
            "content-disarm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "emulator": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "executables": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "default",
                    "virus"
                ],
                "type": "str"
            },
            "options": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "scan",
                    "file-filter",
                    "quarantine",
                    "avquery",
                    "avmonitor"
                ],
                "elements": "str"
            },
            "outbreak-prevention": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disabled",
                    "files",
                    "full-archive",
                    "disable",
                    "block",
                    "monitor"
                ],
                "type": "str"
            },
            "av-scan": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "monitor",
                    "block"
                ],
                "type": "str"
            },
            "external-blocklist": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "monitor",
                    "block"
                ],
                "type": "str"
            },
            "quarantine": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fortindr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "block",
                    "monitor"
                ],
                "type": "str"
            },
            "fortisandbox": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "block",
                    "monitor"
                ],
                "type": "str"
            },
            "fortiai": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "monitor",
                    "block"
                ],
                "type": "str"
            }
        }
    },
    "antivirus_profile_smb": {
        "stated": false,
        "options": {
            "archive-block": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "choices": [
                    "encrypted",
                    "corrupted",
                    "multipart",
                    "nested",
                    "mailbomb",
                    "unhandled",
                    "partiallycorrupted",
                    "fileslimit",
                    "timeout"
                ],
                "elements": "str"
            },
            "archive-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "choices": [
                    "encrypted",
                    "corrupted",
                    "multipart",
                    "nested",
                    "mailbomb",
                    "unhandled",
                    "partiallycorrupted",
                    "fileslimit",
                    "timeout"
                ],
                "elements": "str"
            },
            "emulator": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "options": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "choices": [
                    "scan",
                    "quarantine",
                    "avquery",
                    "avmonitor"
                ],
                "elements": "str"
            },
            "outbreak-prevention": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disabled",
                    "files",
                    "full-archive"
                ],
                "type": "str"
            }
        }
    },
    "antivirus_profile_smtp": {
        "stated": false,
        "options": {
            "archive-block": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "encrypted",
                    "corrupted",
                    "multipart",
                    "nested",
                    "mailbomb",
                    "unhandled",
                    "partiallycorrupted",
                    "fileslimit",
                    "timeout"
                ],
                "elements": "str"
            },
            "archive-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "encrypted",
                    "corrupted",
                    "multipart",
                    "nested",
                    "mailbomb",
                    "unhandled",
                    "partiallycorrupted",
                    "fileslimit",
                    "timeout"
                ],
                "elements": "str"
            },
            "content-disarm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "emulator": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "executables": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "default",
                    "virus"
                ],
                "type": "str"
            },
            "options": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "scan",
                    "file-filter",
                    "quarantine",
                    "avquery",
                    "avmonitor"
                ],
                "elements": "str"
            },
            "outbreak-prevention": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disabled",
                    "files",
                    "full-archive",
                    "disable",
                    "block",
                    "monitor"
                ],
                "type": "str"
            },
            "av-scan": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "monitor",
                    "block"
                ],
                "type": "str"
            },
            "external-blocklist": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "monitor",
                    "block"
                ],
                "type": "str"
            },
            "quarantine": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fortindr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "block",
                    "monitor"
                ],
                "type": "str"
            },
            "fortisandbox": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "block",
                    "monitor"
                ],
                "type": "str"
            },
            "fortiai": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "monitor",
                    "block"
                ],
                "type": "str"
            }
        }
    },
    "antivirus_profile_ssh": {
        "stated": false,
        "options": {
            "archive-block": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "encrypted",
                    "corrupted",
                    "multipart",
                    "nested",
                    "mailbomb",
                    "unhandled",
                    "partiallycorrupted",
                    "fileslimit",
                    "timeout"
                ],
                "elements": "str"
            },
            "archive-log": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "encrypted",
                    "corrupted",
                    "multipart",
                    "nested",
                    "mailbomb",
                    "unhandled",
                    "partiallycorrupted",
                    "fileslimit",
                    "timeout"
                ],
                "elements": "str"
            },
            "emulator": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "options": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "avmonitor",
                    "quarantine",
                    "scan"
                ],
                "elements": "str"
            },
            "outbreak-prevention": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disabled",
                    "files",
                    "full-archive",
                    "disable",
                    "block",
                    "monitor"
                ],
                "type": "str"
            },
            "av-scan": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "monitor",
                    "block"
                ],
                "type": "str"
            },
            "external-blocklist": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "monitor",
                    "block"
                ],
                "type": "str"
            },
            "quarantine": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fortindr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "block",
                    "monitor"
                ],
                "type": "str"
            },
            "fortisandbox": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "block",
                    "monitor"
                ],
                "type": "str"
            },
            "fortiai": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "monitor",
                    "block"
                ],
                "type": "str"
            }
        }
    },
    "apcfgprofile": {
        "stated": true,
        "options": {
            "ac-ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ac-port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ac-timer": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ac-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "default",
                    "specify",
                    "apcfg"
                ],
                "type": "str"
            },
            "command-list": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "passwd-value": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "non-password",
                            "password"
                        ],
                        "type": "str"
                    },
                    "value": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ap-family": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "fap",
                    "fap-u",
                    "fap-c"
                ],
                "type": "str"
            }
        }
    },
    "apcfgprofile_commandlist": {
        "stated": true,
        "options": {
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "passwd-value": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "non-password",
                    "password"
                ],
                "type": "str"
            },
            "value": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "application_casi_profile": {
        "stated": true,
        "options": {
            "app-replacemsg": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "entries": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "pass",
                            "block",
                            "reset"
                        ],
                        "type": "str"
                    },
                    "application": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "raw"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "replacemsg-group": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "application_casi_profile_entries": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "pass",
                    "block",
                    "reset"
                ],
                "type": "str"
            },
            "application": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "application_categories": {
        "stated": true,
        "options": {
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "application_custom": {
        "stated": true,
        "options": {
            "behavior": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "category": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "signature": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tag": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "technology": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vendor": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "application_group": {
        "stated": true,
        "options": {
            "application": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "category": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "application",
                    "category",
                    "filter"
                ],
                "type": "str"
            },
            "behavior": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "popularity": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "1",
                    "2",
                    "3",
                    "4",
                    "5"
                ],
                "elements": "str"
            },
            "protocols": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "risk": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "technology": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "vendor": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "application_internetservice": {
        "stated": false,
        "options": {
            "entry": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "ip-number": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "ip-range-number": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "port": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "raw"
                    },
                    "protocol": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "id": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "offset": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "reputation": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            }
        }
    },
    "application_internetservice_entry": {
        "stated": true,
        "options": {
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "ip-number": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "ip-range-number": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            }
        }
    },
    "application_internetservicecustom": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "disable-entry": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "ip-range": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "list",
                        "options": {
                            "end-ip": {
                                "required": false,
                                "revision": {
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": false,
                                    "6.4.1": false,
                                    "6.4.2": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.0": false,
                                    "7.0.1": false,
                                    "7.0.2": false,
                                    "7.0.3": false,
                                    "7.0.4": false,
                                    "7.0.5": false,
                                    "7.0.6": false,
                                    "7.0.7": false,
                                    "7.0.8": false,
                                    "7.0.9": false,
                                    "7.2.0": false,
                                    "7.2.1": false,
                                    "7.2.2": false,
                                    "7.2.3": false,
                                    "7.2.4": false,
                                    "7.4.0": false,
                                    "7.4.1": false
                                },
                                "type": "str"
                            },
                            "id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": false,
                                    "6.4.1": false,
                                    "6.4.2": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.0": false,
                                    "7.0.1": false,
                                    "7.0.2": false,
                                    "7.0.3": false,
                                    "7.0.4": false,
                                    "7.0.5": false,
                                    "7.0.6": false,
                                    "7.0.7": false,
                                    "7.0.8": false,
                                    "7.0.9": false,
                                    "7.2.0": false,
                                    "7.2.1": false,
                                    "7.2.2": false,
                                    "7.2.3": false,
                                    "7.2.4": false,
                                    "7.4.0": false,
                                    "7.4.1": false
                                },
                                "type": "int"
                            },
                            "start-ip": {
                                "required": false,
                                "revision": {
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": false,
                                    "6.4.1": false,
                                    "6.4.2": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.0": false,
                                    "7.0.1": false,
                                    "7.0.2": false,
                                    "7.0.3": false,
                                    "7.0.4": false,
                                    "7.0.5": false,
                                    "7.0.6": false,
                                    "7.0.7": false,
                                    "7.0.8": false,
                                    "7.0.9": false,
                                    "7.2.0": false,
                                    "7.2.1": false,
                                    "7.2.2": false,
                                    "7.2.3": false,
                                    "7.2.4": false,
                                    "7.4.0": false,
                                    "7.4.1": false
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "port": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "raw"
                    },
                    "protocol": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "entry": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "dst": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "port-range": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "list",
                        "options": {
                            "end-port": {
                                "required": false,
                                "revision": {
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": false,
                                    "6.4.1": false,
                                    "6.4.2": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.0": false,
                                    "7.0.1": false,
                                    "7.0.2": false,
                                    "7.0.3": false,
                                    "7.0.4": false,
                                    "7.0.5": false,
                                    "7.0.6": false,
                                    "7.0.7": false,
                                    "7.0.8": false,
                                    "7.0.9": false,
                                    "7.2.0": false,
                                    "7.2.1": false,
                                    "7.2.2": false,
                                    "7.2.3": false,
                                    "7.2.4": false,
                                    "7.4.0": false,
                                    "7.4.1": false
                                },
                                "type": "int"
                            },
                            "id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": false,
                                    "6.4.1": false,
                                    "6.4.2": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.0": false,
                                    "7.0.1": false,
                                    "7.0.2": false,
                                    "7.0.3": false,
                                    "7.0.4": false,
                                    "7.0.5": false,
                                    "7.0.6": false,
                                    "7.0.7": false,
                                    "7.0.8": false,
                                    "7.0.9": false,
                                    "7.2.0": false,
                                    "7.2.1": false,
                                    "7.2.2": false,
                                    "7.2.3": false,
                                    "7.2.4": false,
                                    "7.4.0": false,
                                    "7.4.1": false
                                },
                                "type": "int"
                            },
                            "start-port": {
                                "required": false,
                                "revision": {
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": false,
                                    "6.4.1": false,
                                    "6.4.2": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.0": false,
                                    "7.0.1": false,
                                    "7.0.2": false,
                                    "7.0.3": false,
                                    "7.0.4": false,
                                    "7.0.5": false,
                                    "7.0.6": false,
                                    "7.0.7": false,
                                    "7.0.8": false,
                                    "7.0.9": false,
                                    "7.2.0": false,
                                    "7.2.1": false,
                                    "7.2.2": false,
                                    "7.2.3": false,
                                    "7.2.4": false,
                                    "7.4.0": false,
                                    "7.4.1": false
                                },
                                "type": "int"
                            }
                        },
                        "elements": "dict"
                    },
                    "protocol": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "master-service-id": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "application_internetservicecustom_disableentry": {
        "stated": true,
        "options": {
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "ip-range": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "end-ip": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "start-ip": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            }
        }
    },
    "application_internetservicecustom_disableentry_iprange": {
        "stated": true,
        "options": {
            "end-ip": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "start-ip": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "application_internetservicecustom_entry": {
        "stated": true,
        "options": {
            "dst": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "port-range": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "end-port": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "start-port": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            }
        }
    },
    "application_internetservicecustom_entry_portrange": {
        "stated": true,
        "options": {
            "end-port": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "start-port": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            }
        }
    },
    "application_list": {
        "stated": true,
        "options": {
            "app-replacemsg": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "deep-app-inspection": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "entries": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "pass",
                            "block",
                            "reset"
                        ],
                        "type": "str"
                    },
                    "application": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "behavior": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "category": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "log-packet": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "parameters": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "id": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "value": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "members": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "options": {
                                    "id": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": false,
                                            "6.2.9": false,
                                            "6.2.10": false,
                                            "6.2.11": false,
                                            "6.2.12": false,
                                            "6.4.0": true,
                                            "6.4.1": true,
                                            "6.4.2": true,
                                            "6.4.3": true,
                                            "6.4.4": true,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "name": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": false,
                                            "6.2.9": false,
                                            "6.2.10": false,
                                            "6.2.11": false,
                                            "6.2.12": false,
                                            "6.4.0": true,
                                            "6.4.1": true,
                                            "6.4.2": true,
                                            "6.4.3": true,
                                            "6.4.4": true,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "value": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": false,
                                            "6.2.9": false,
                                            "6.2.10": false,
                                            "6.2.11": false,
                                            "6.2.12": false,
                                            "6.4.0": true,
                                            "6.4.1": true,
                                            "6.4.2": true,
                                            "6.4.3": true,
                                            "6.4.4": true,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    }
                                },
                                "elements": "dict"
                            }
                        },
                        "elements": "dict"
                    },
                    "per-ip-shaper": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "popularity": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "1",
                            "2",
                            "3",
                            "4",
                            "5"
                        ],
                        "elements": "str"
                    },
                    "protocols": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "quarantine": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "attacker"
                        ],
                        "type": "str"
                    },
                    "quarantine-expiry": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "quarantine-log": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "rate-count": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "rate-duration": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "rate-mode": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "periodical",
                            "continuous"
                        ],
                        "type": "str"
                    },
                    "rate-track": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "src-ip",
                            "dest-ip",
                            "dhcp-client-mac",
                            "dns-domain"
                        ],
                        "type": "str"
                    },
                    "risk": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "session-ttl": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "shaper": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "shaper-reverse": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sub-category": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "technology": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "vendor": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "tags": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "exclusion": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    }
                },
                "elements": "dict"
            },
            "extended-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "options": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "allow-dns",
                    "allow-icmp",
                    "allow-http",
                    "allow-ssl",
                    "allow-quic"
                ],
                "elements": "str"
            },
            "other-application-action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "block"
                ],
                "type": "str"
            },
            "other-application-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "p2p-black-list": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "skype",
                    "edonkey",
                    "bittorrent"
                ],
                "elements": "str"
            },
            "replacemsg-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "unknown-application-action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "block"
                ],
                "type": "str"
            },
            "unknown-application-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "control-default-network-services": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "default-network-services": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "port": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "services": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "http",
                            "ssh",
                            "telnet",
                            "ftp",
                            "dns",
                            "smtp",
                            "pop3",
                            "imap",
                            "snmp",
                            "nntp",
                            "https"
                        ],
                        "elements": "str"
                    },
                    "violation-action": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "block",
                            "monitor",
                            "pass"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "enforce-default-app-port": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "force-inclusion-ssl-di-sigs": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "p2p-block-list": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "skype",
                    "edonkey",
                    "bittorrent"
                ],
                "elements": "str"
            }
        }
    },
    "application_list_defaultnetworkservices": {
        "stated": true,
        "options": {
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "services": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "http",
                    "ssh",
                    "telnet",
                    "ftp",
                    "dns",
                    "smtp",
                    "pop3",
                    "imap",
                    "snmp",
                    "nntp",
                    "https"
                ],
                "elements": "str"
            },
            "violation-action": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "block",
                    "monitor",
                    "pass"
                ],
                "type": "str"
            }
        }
    },
    "application_list_entries": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "block",
                    "reset"
                ],
                "type": "str"
            },
            "application": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "behavior": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "category": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "log-packet": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "parameters": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "value": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "members": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "value": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    }
                },
                "elements": "dict"
            },
            "per-ip-shaper": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "popularity": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "1",
                    "2",
                    "3",
                    "4",
                    "5"
                ],
                "elements": "str"
            },
            "protocols": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "quarantine": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "attacker"
                ],
                "type": "str"
            },
            "quarantine-expiry": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "quarantine-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "rate-count": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "rate-duration": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "rate-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "periodical",
                    "continuous"
                ],
                "type": "str"
            },
            "rate-track": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "src-ip",
                    "dest-ip",
                    "dhcp-client-mac",
                    "dns-domain"
                ],
                "type": "str"
            },
            "risk": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "session-ttl": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "shaper": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "shaper-reverse": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sub-category": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "technology": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "vendor": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "tags": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "exclusion": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "application_list_entries_parameters": {
        "stated": true,
        "options": {
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "value": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "members": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "value": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "application_list_entries_parameters_members": {
        "stated": true,
        "options": {
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "value": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "arrpprofile": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "darrp-optimize": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "darrp-optimize-schedules": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "include-dfs-channel": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "no",
                    "disable",
                    "yes",
                    "enable"
                ],
                "type": "str"
            },
            "include-weather-channel": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "no",
                    "disable",
                    "yes",
                    "enable"
                ],
                "type": "str"
            },
            "monitor-period": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "override-darrp-optimize": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "selection-period": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "threshold-ap": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "threshold-channel-load": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "threshold-noise-floor": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "threshold-rx-errors": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "threshold-spectral-rssi": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "threshold-tx-retries": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "weight-channel-load": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "weight-dfs-channel": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "weight-managed-ap": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "weight-noise-floor": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "weight-rogue-ap": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "weight-spectral-rssi": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "weight-weather-channel": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "authentication_scheme": {
        "stated": true,
        "options": {
            "domain-controller": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "fsso-agent-for-ntlm": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "fsso-guest": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "kerberos-keytab": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "str"
            },
            "method": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "ntlm",
                    "basic",
                    "digest",
                    "form",
                    "negotiate",
                    "fsso",
                    "rsso",
                    "ssh-publickey",
                    "saml",
                    "cert",
                    "x-auth-user",
                    "saml-sp"
                ],
                "elements": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "negotiate-ntlm": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "require-tfa": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssh-ca": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "user-database": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ems-device-owner": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "saml-server": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "saml-timeout": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "user-cert": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "bleprofile": {
        "stated": true,
        "options": {
            "advertising": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "ibeacon",
                    "eddystone-uid",
                    "eddystone-url"
                ],
                "elements": "str"
            },
            "beacon-interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ble-scanning": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "eddystone-instance": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "eddystone-namespace": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "eddystone-url": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "eddystone-url-encode-hex": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ibeacon-uuid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "major-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "minor-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "txpower": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "0",
                    "1",
                    "2",
                    "3",
                    "4",
                    "5",
                    "6",
                    "7",
                    "8",
                    "9",
                    "10",
                    "11",
                    "12"
                ],
                "type": "str"
            },
            "scan-interval": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "scan-period": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "scan-threshold": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "scan-time": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "scan-type": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "active",
                    "passive"
                ],
                "type": "str"
            },
            "scan-window": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "bonjourprofile": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "policy-list": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "description": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "from-vlan": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "policy-id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "services": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "airplay",
                            "afp",
                            "bit-torrent",
                            "ftp",
                            "ichat",
                            "itunes",
                            "printers",
                            "samba",
                            "scanners",
                            "ssh",
                            "chromecast",
                            "all",
                            "miracast"
                        ],
                        "elements": "str"
                    },
                    "to-vlan": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "bonjourprofile_policylist": {
        "stated": true,
        "options": {
            "description": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "from-vlan": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "policy-id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "services": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "airplay",
                    "afp",
                    "bit-torrent",
                    "ftp",
                    "ichat",
                    "itunes",
                    "printers",
                    "samba",
                    "scanners",
                    "ssh",
                    "chromecast",
                    "all",
                    "miracast"
                ],
                "elements": "str"
            },
            "to-vlan": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "casb_profile": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "saas-application": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "access-rule": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "action": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "choices": [
                                    "block",
                                    "bypass",
                                    "monitor"
                                ],
                                "type": "str"
                            },
                            "bypass": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "list",
                                "choices": [
                                    "av",
                                    "dlp",
                                    "web-filter",
                                    "file-filter",
                                    "video-filter"
                                ],
                                "elements": "str"
                            },
                            "name": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "custom-control": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "name": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "option": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "list",
                                "options": {
                                    "name": {
                                        "required": false,
                                        "revision": {
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "user-input": {
                                        "required": false,
                                        "revision": {
                                            "7.4.1": true
                                        },
                                        "type": "list",
                                        "elements": "str"
                                    }
                                },
                                "elements": "dict"
                            }
                        },
                        "elements": "dict"
                    },
                    "domain-control": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "domain-control-domains": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "list",
                        "elements": "str"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "safe-search": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "safe-search-control": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "list",
                        "elements": "str"
                    },
                    "tenant-control": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "tenant-control-tenants": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "list",
                        "elements": "str"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "casb_profile_saasapplication": {
        "stated": true,
        "options": {
            "access-rule": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "block",
                            "bypass",
                            "monitor"
                        ],
                        "type": "str"
                    },
                    "bypass": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "av",
                            "dlp",
                            "web-filter",
                            "file-filter",
                            "video-filter"
                        ],
                        "elements": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "custom-control": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "option": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "name": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "user-input": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "list",
                                "elements": "str"
                            }
                        },
                        "elements": "dict"
                    }
                },
                "elements": "dict"
            },
            "domain-control": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "domain-control-domains": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "list",
                "elements": "str"
            },
            "log": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "safe-search": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "safe-search-control": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "list",
                "elements": "str"
            },
            "tenant-control": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tenant-control-tenants": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "list",
                "elements": "str"
            }
        }
    },
    "casb_profile_saasapplication_accessrule": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "block",
                    "bypass",
                    "monitor"
                ],
                "type": "str"
            },
            "bypass": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "av",
                    "dlp",
                    "web-filter",
                    "file-filter",
                    "video-filter"
                ],
                "elements": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "casb_profile_saasapplication_customcontrol": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "option": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "user-input": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "list",
                        "elements": "str"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "casb_profile_saasapplication_customcontrol_option": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "user-input": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "list",
                "elements": "str"
            }
        }
    },
    "casb_saasapplication": {
        "stated": true,
        "options": {
            "casb-name": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "description": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "domains": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "list",
                "elements": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "built-in",
                    "customized"
                ],
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "casb_useractivity": {
        "stated": true,
        "options": {
            "application": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "casb-name": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "category": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "activity-control",
                    "tenant-control",
                    "domain-control",
                    "safe-search-control",
                    "other"
                ],
                "type": "str"
            },
            "control-options": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "operations": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "action": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "choices": [
                                    "append",
                                    "prepend",
                                    "replace",
                                    "new",
                                    "new-on-not-found",
                                    "delete"
                                ],
                                "type": "str"
                            },
                            "case-sensitive": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "direction": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "choices": [
                                    "request"
                                ],
                                "type": "str"
                            },
                            "header-name": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "name": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "search-key": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "no_log": true,
                                "type": "str"
                            },
                            "search-pattern": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "choices": [
                                    "simple",
                                    "substr",
                                    "regexp"
                                ],
                                "type": "str"
                            },
                            "target": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "choices": [
                                    "header",
                                    "path"
                                ],
                                "type": "str"
                            },
                            "value-from-input": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "values": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "list",
                                "elements": "str"
                            }
                        },
                        "elements": "dict"
                    }
                },
                "elements": "dict"
            },
            "description": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "match": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "id": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "rules": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "case-sensitive": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "domains": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "list",
                                "elements": "str"
                            },
                            "header-name": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "id": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "match-pattern": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "choices": [
                                    "simple",
                                    "substr",
                                    "regexp"
                                ],
                                "type": "str"
                            },
                            "match-value": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "methods": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "list",
                                "elements": "str"
                            },
                            "negate": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "type": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "choices": [
                                    "domains",
                                    "host",
                                    "path",
                                    "header",
                                    "header-value",
                                    "method"
                                ],
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "strategy": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "or",
                            "and"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "match-strategy": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "or",
                    "and"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "built-in",
                    "customized"
                ],
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "casb_useractivity_controloptions": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "operations": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "append",
                            "prepend",
                            "replace",
                            "new",
                            "new-on-not-found",
                            "delete"
                        ],
                        "type": "str"
                    },
                    "case-sensitive": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "direction": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "request"
                        ],
                        "type": "str"
                    },
                    "header-name": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "search-key": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "str"
                    },
                    "search-pattern": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "simple",
                            "substr",
                            "regexp"
                        ],
                        "type": "str"
                    },
                    "target": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "header",
                            "path"
                        ],
                        "type": "str"
                    },
                    "value-from-input": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "values": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "list",
                        "elements": "str"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "casb_useractivity_controloptions_operations": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "append",
                    "prepend",
                    "replace",
                    "new",
                    "new-on-not-found",
                    "delete"
                ],
                "type": "str"
            },
            "case-sensitive": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "direction": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "request"
                ],
                "type": "str"
            },
            "header-name": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "search-key": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "no_log": true,
                "type": "str"
            },
            "search-pattern": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "simple",
                    "substr",
                    "regexp"
                ],
                "type": "str"
            },
            "target": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "header",
                    "path"
                ],
                "type": "str"
            },
            "value-from-input": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "values": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "list",
                "elements": "str"
            }
        }
    },
    "casb_useractivity_match": {
        "stated": true,
        "options": {
            "id": {
                "required": true,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "rules": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "case-sensitive": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "domains": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "list",
                        "elements": "str"
                    },
                    "header-name": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "match-pattern": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "simple",
                            "substr",
                            "regexp"
                        ],
                        "type": "str"
                    },
                    "match-value": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "methods": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "list",
                        "elements": "str"
                    },
                    "negate": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "domains",
                            "host",
                            "path",
                            "header",
                            "header-value",
                            "method"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "strategy": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "or",
                    "and"
                ],
                "type": "str"
            }
        }
    },
    "casb_useractivity_match_rules": {
        "stated": true,
        "options": {
            "case-sensitive": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "domains": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "list",
                "elements": "str"
            },
            "header-name": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "match-pattern": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "simple",
                    "substr",
                    "regexp"
                ],
                "type": "str"
            },
            "match-value": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "methods": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "list",
                "elements": "str"
            },
            "negate": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "domains",
                    "host",
                    "path",
                    "header",
                    "header-value",
                    "method"
                ],
                "type": "str"
            }
        }
    },
    "certificate_template": {
        "stated": true,
        "options": {
            "city": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "country": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "digest-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "sha1",
                    "sha256"
                ],
                "type": "str"
            },
            "email": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "host-ip",
                    "domain-name",
                    "email"
                ],
                "type": "str"
            },
            "key-size": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "512",
                    "1024",
                    "1536",
                    "2048",
                    "4096"
                ],
                "type": "str"
            },
            "key-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "rsa",
                    "ec"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "organization": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "organization-unit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "scep-password": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "scep-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "state": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "subject-name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "external",
                    "local"
                ],
                "type": "str"
            },
            "curve-name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "secp256r1",
                    "secp384r1",
                    "secp521r1"
                ],
                "type": "str"
            },
            "scep-ca-identifier": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "cifs_domaincontroller": {
        "stated": true,
        "options": {
            "domain-name": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ip": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ip6": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "password": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "server-name": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "username": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "cifs_profile": {
        "stated": true,
        "options": {
            "domain-controller": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "server-credential-type": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "credential-replication",
                    "credential-keytab"
                ],
                "type": "str"
            },
            "server-keytab": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "list",
                "options": {
                    "keytab": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "str"
                    },
                    "principal": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "password": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    }
                },
                "elements": "dict"
            },
            "file-filter": {
                "required": false,
                "type": "dict",
                "options": {
                    "entries": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "action": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "block",
                                    "log"
                                ],
                                "type": "str"
                            },
                            "comment": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "direction": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "incoming",
                                    "outgoing",
                                    "any"
                                ],
                                "type": "str"
                            },
                            "file-type": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            },
                            "filter": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "protocol": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "choices": [
                                    "cifs"
                                ],
                                "elements": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            }
        }
    },
    "cifs_profile_filefilter": {
        "stated": false,
        "options": {
            "entries": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "block",
                            "log"
                        ],
                        "type": "str"
                    },
                    "comment": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "direction": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "incoming",
                            "outgoing",
                            "any"
                        ],
                        "type": "str"
                    },
                    "file-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "filter": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "protocol": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "cifs"
                        ],
                        "elements": "str"
                    }
                },
                "elements": "dict"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "cifs_profile_filefilter_entries": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "block",
                    "log"
                ],
                "type": "str"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "direction": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "incoming",
                    "outgoing",
                    "any"
                ],
                "type": "str"
            },
            "file-type": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "filter": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "cifs"
                ],
                "elements": "str"
            }
        }
    },
    "cifs_profile_serverkeytab": {
        "stated": true,
        "options": {
            "keytab": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "str"
            },
            "principal": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "password": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            }
        }
    },
    "cloud_orchestaws": {
        "stated": true,
        "options": {
            "connector": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "region-name": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "us-east-1",
                    "us-east-2",
                    "us-west-1",
                    "us-west-2",
                    "eu-west-1",
                    "eu-west-2",
                    "eu-west-3",
                    "eu-north-1",
                    "eu-south-1",
                    "eu-south-2",
                    "eu-central-1",
                    "eu-central-2",
                    "ca-central-1",
                    "ap-southeast-1",
                    "ap-southeast-2",
                    "ap-southeast-3",
                    "ap-southeast-4",
                    "ap-south-1",
                    "ap-south-2",
                    "ap-northeast-1",
                    "ap-northeast-2",
                    "ap-northeast-3",
                    "af-south-1",
                    "me-central-1",
                    "me-south-1",
                    "sa-east-1",
                    "ap-east-1",
                    "us-gov-east-1",
                    "us-gov-west-1"
                ],
                "type": "str"
            },
            "template-configuration": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "cloud_orchestawsconnector": {
        "stated": true,
        "options": {
            "access-key-id": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "str"
            },
            "access-key-secret": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "name": {
                "required": true,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "use-metadata-iam": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "cloud_orchestawstemplate_autoscaleexistingvpc": {
        "stated": true,
        "options": {
            "custom-asset-container": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "custom-asset-directory": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "custom-identifier": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "faz-autoscale-admin-password": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "faz-autoscale-admin-username": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "faz-custom-private-ipaddress": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "faz-instance-type": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "h1.2xlarge",
                    "h1.4xlarge",
                    "h1.8xlarge",
                    "m5.large",
                    "m5.xlarge",
                    "m5.2xlarge",
                    "m5.4xlarge",
                    "m5.12xlarge",
                    "t2.medium",
                    "t2.large",
                    "t2.xlarge"
                ],
                "type": "str"
            },
            "faz-integration-options": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "no",
                    "yes"
                ],
                "type": "str"
            },
            "faz-version": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "fgt-admin-cidr": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "fgt-admin-port": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fgt-instance-type": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "t2.small",
                    "c5.large",
                    "c5.xlarge",
                    "c5.2xlarge",
                    "c5.4xlarge",
                    "c5.9xlarge"
                ],
                "type": "str"
            },
            "fgt-psk-secret": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "str"
            },
            "fgtasg-cool-down": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fgtasg-desired-capacity-byol": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fgtasg-desired-capacity-payg": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fgtasg-health-check-grace-period": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fgtasg-max-size-byol": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fgtasg-max-size-payg": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fgtasg-min-size-byol": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fgtasg-min-size-payg": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fgtasg-scale-in-threshold": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fgtasg-scale-out-threshold": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fos-version": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "get-license-grace-period": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "heartbeat-delay-allowance": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "heartbeat-interval": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "heartbeat-loss-count": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "internal-balancer-dns-name": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "internal-balancing-options": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "add a new internal load balancer",
                    "use a load balancer specified below",
                    "do not need one"
                ],
                "type": "str"
            },
            "internal-target-group-health-check-path": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "key-pair-name": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "str"
            },
            "lifecycle-hook-timeout": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "loadbalancing-health-check-threshold": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "loadbalancing-traffic-port": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "loadbalancing-traffic-protocol": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "HTTPS",
                    "HTTP",
                    "TCP"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "notification-email": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "primary-election-timeout": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "private-subnet-route-table": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "private-subnet1": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "private-subnet2": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "public-subnet1": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "public-subnet2": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "resource-tag-prefix": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "s3-bucket-name": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "s3-key-prefix": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "str"
            },
            "sync-recovery-count": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "terminate-unhealthy-vm": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "no",
                    "yes"
                ],
                "type": "str"
            },
            "use-custom-asset-location": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "no",
                    "yes"
                ],
                "type": "str"
            },
            "vpc-cidr": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vpc-endpoint-id": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vpc-id": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "cloud_orchestawstemplate_autoscalenewvpc": {
        "stated": true,
        "options": {
            "availability-zones": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "custom-asset-container": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "custom-asset-directory": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "custom-identifier": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "faz-autoscale-admin-password": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "faz-autoscale-admin-username": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "faz-custom-private-ipaddress": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "faz-instance-type": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "h1.2xlarge",
                    "h1.4xlarge",
                    "h1.8xlarge",
                    "m5.large",
                    "m5.xlarge",
                    "m5.2xlarge",
                    "m5.4xlarge",
                    "m5.12xlarge",
                    "t2.medium",
                    "t2.large",
                    "t2.xlarge"
                ],
                "type": "str"
            },
            "faz-integration-options": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "no",
                    "yes"
                ],
                "type": "str"
            },
            "faz-version": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "fgt-admin-cidr": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "fgt-admin-port": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fgt-instance-type": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "t2.small",
                    "c5.large",
                    "c5.xlarge",
                    "c5.2xlarge",
                    "c5.4xlarge",
                    "c5.9xlarge"
                ],
                "type": "str"
            },
            "fgt-psk-secret": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "str"
            },
            "fgtasg-cool-down": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fgtasg-desired-capacity-byol": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fgtasg-desired-capacity-payg": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fgtasg-health-check-grace-period": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fgtasg-max-size-byol": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fgtasg-max-size-payg": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fgtasg-min-size-byol": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fgtasg-min-size-payg": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fgtasg-scale-in-threshold": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fgtasg-scale-out-threshold": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fos-version": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "get-license-grace-period": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "heartbeat-delay-allowance": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "heartbeat-interval": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "heartbeat-loss-count": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "internal-balancer-dns-name": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "internal-balancing-options": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "add a new internal load balancer",
                    "use a load balancer specified below",
                    "do not need one"
                ],
                "type": "str"
            },
            "internal-target-group-health-check-path": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "key-pair-name": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "str"
            },
            "lifecycle-hook-timeout": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "loadbalancing-health-check-threshold": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "loadbalancing-traffic-port": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "loadbalancing-traffic-protocol": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "HTTPS",
                    "HTTP",
                    "TCP"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "notification-email": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "primary-election-timeout": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "private-subnet1-cidr": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "private-subnet2-cidr": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "public-subnet1-cidr": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "public-subnet2-cidr": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "resource-tag-prefix": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "s3-bucket-name": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "s3-key-prefix": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "str"
            },
            "sync-recovery-count": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "terminate-unhealthy-vm": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "no",
                    "yes"
                ],
                "type": "str"
            },
            "use-custom-asset-location": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "no",
                    "yes"
                ],
                "type": "str"
            },
            "vpc-cidr": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "cloud_orchestawstemplate_autoscaletgwnewvpc": {
        "stated": true,
        "options": {
            "availability-zones": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "bgp-asn": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "custom-asset-container": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "custom-asset-directory": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "custom-identifier": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "faz-autoscale-admin-password": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "faz-autoscale-admin-username": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "faz-custom-private-ipaddress": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "faz-instance-type": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "h1.2xlarge",
                    "h1.4xlarge",
                    "h1.8xlarge",
                    "m5.large",
                    "m5.xlarge",
                    "m5.2xlarge",
                    "m5.4xlarge",
                    "m5.12xlarge",
                    "t2.medium",
                    "t2.large",
                    "t2.xlarge"
                ],
                "type": "str"
            },
            "faz-integration-options": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "no",
                    "yes"
                ],
                "type": "str"
            },
            "faz-version": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "fgt-admin-cidr": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "fgt-admin-port": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fgt-instance-type": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "t2.small",
                    "c5.large",
                    "c5.xlarge",
                    "c5.2xlarge",
                    "c5.4xlarge",
                    "c5.9xlarge"
                ],
                "type": "str"
            },
            "fgt-psk-secret": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "str"
            },
            "fgtasg-cool-down": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fgtasg-desired-capacity-byol": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fgtasg-desired-capacity-payg": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fgtasg-health-check-grace-period": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fgtasg-max-size-byol": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fgtasg-max-size-payg": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fgtasg-min-size-byol": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fgtasg-min-size-payg": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fgtasg-scale-in-threshold": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fgtasg-scale-out-threshold": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fos-version": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "get-license-grace-period": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "heartbeat-delay-allowance": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "heartbeat-interval": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "heartbeat-loss-count": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "key-pair-name": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "str"
            },
            "lifecycle-hook-timeout": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": true,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "notification-email": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "primary-election-timeout": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "public-subnet1-cidr": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "public-subnet2-cidr": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "resource-tag-prefix": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "s3-bucket-name": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "s3-key-prefix": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "str"
            },
            "sync-recovery-count": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "terminate-unhealthy-vm": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "no",
                    "yes"
                ],
                "type": "str"
            },
            "transit-gateway-id": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "transit-gateway-support-options": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "create one",
                    "use an existing one"
                ],
                "type": "str"
            },
            "use-custom-asset-location": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "no",
                    "yes"
                ],
                "type": "str"
            },
            "vpc-cidr": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "cloud_orchestration": {
        "stated": true,
        "options": {
            "configuration": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "description": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "aws"
                ],
                "type": "str"
            }
        }
    },
    "credentialstore_domaincontroller": {
        "stated": true,
        "options": {
            "domain-name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ip6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "password": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "server-name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "username": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "hostname": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "devprof_device_profile_fortianalyzer": {
        "stated": false,
        "options": {
            "managed-sn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "target": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "this-fmg",
                    "managed",
                    "others"
                ],
                "type": "str"
            },
            "target-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "target-sn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "devprof_device_profile_fortiguard": {
        "stated": false,
        "options": {
            "target": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "direct",
                    "this-fmg"
                ],
                "type": "str"
            },
            "target-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "auto-firmware-upgrade": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "auto-firmware-upgrade-day": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "sunday",
                    "monday",
                    "tuesday",
                    "wednesday",
                    "thursday",
                    "friday",
                    "saturday"
                ],
                "elements": "str"
            },
            "auto-firmware-upgrade-delay": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "auto-firmware-upgrade-end-hour": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "auto-firmware-upgrade-start-hour": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "devprof_import": {
        "stated": true,
        "options": {
            "device": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "devprof": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "devprof_log_fortianalyzer_setting": {
        "stated": false,
        "options": {
            "certificate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "conn-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "enc-algorithm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "default",
                    "high",
                    "low",
                    "disable",
                    "high-medium",
                    "low-medium"
                ],
                "type": "str"
            },
            "hmac-algorithm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "sha256",
                    "sha1"
                ],
                "type": "str"
            },
            "ips-archive": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "monitor-failure-retry-period": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "monitor-keepalive-period": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "reliable": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-min-proto-version": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "default",
                    "TLSv1",
                    "TLSv1-1",
                    "TLSv1-2",
                    "SSLv3",
                    "TLSv1-3"
                ],
                "type": "str"
            },
            "upload-day": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "upload-interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "daily",
                    "weekly",
                    "monthly"
                ],
                "type": "str"
            },
            "upload-option": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "store-and-upload",
                    "realtime",
                    "1-minute",
                    "5-minute"
                ],
                "type": "str"
            },
            "upload-time": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "access-config": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "certificate-verification": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "max-log-rate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "priority": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "low",
                    "default"
                ],
                "type": "str"
            },
            "interface": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "interface-select-method": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auto",
                    "sdwan",
                    "specify"
                ],
                "type": "str"
            },
            "preshared-key": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "str"
            },
            "alt-server": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "fallback-to-primary": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "devprof_log_fortianalyzercloud_setting": {
        "stated": false,
        "options": {
            "__change_ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "access-config": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "certificate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "conn-timeout": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "enc-algorithm": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "high",
                    "low",
                    "high-medium",
                    "low-medium"
                ],
                "type": "str"
            },
            "hmac-algorithm": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "sha256",
                    "sha1"
                ],
                "type": "str"
            },
            "ips-archive": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "monitor-failure-retry-period": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "monitor-keepalive-period": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "source-ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ssl-min-proto-version": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "default",
                    "TLSv1-1",
                    "TLSv1-2",
                    "SSLv3",
                    "TLSv1",
                    "TLSv1-3"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "upload-day": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "upload-interval": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "daily",
                    "weekly",
                    "monthly"
                ],
                "type": "str"
            },
            "upload-option": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "store-and-upload",
                    "realtime",
                    "1-minute",
                    "5-minute"
                ],
                "type": "str"
            },
            "upload-time": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "max-log-rate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "priority": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "low",
                    "default"
                ],
                "type": "str"
            },
            "interface": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "interface-select-method": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auto",
                    "sdwan",
                    "specify"
                ],
                "type": "str"
            },
            "preshared-key": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "str"
            },
            "certificate-verification": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "serial": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "devprof_log_syslogd_filter": {
        "stated": false,
        "options": {
            "severity": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "emergency",
                    "alert",
                    "critical",
                    "error",
                    "warning",
                    "notification",
                    "information",
                    "debug"
                ],
                "type": "str"
            },
            "anomaly": {
                "required": false,
                "revision": {
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "exclude-list": {
                "required": false,
                "revision": {
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "category": {
                        "required": false,
                        "revision": {
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "app-ctrl",
                            "attack",
                            "dlp",
                            "event",
                            "traffic",
                            "virus",
                            "voip",
                            "webfilter",
                            "netscan",
                            "spam",
                            "anomaly",
                            "waf"
                        ],
                        "type": "str"
                    },
                    "fields": {
                        "required": false,
                        "revision": {
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "list",
                        "options": {
                            "args": {
                                "required": false,
                                "revision": {
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.1": false,
                                    "7.2.2": false,
                                    "7.2.3": false,
                                    "7.2.4": false,
                                    "7.4.0": false,
                                    "7.4.1": false
                                },
                                "type": "raw"
                            },
                            "field": {
                                "required": false,
                                "revision": {
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.1": false,
                                    "7.2.2": false,
                                    "7.2.3": false,
                                    "7.2.4": false,
                                    "7.4.0": false,
                                    "7.4.1": false
                                },
                                "type": "str"
                            },
                            "negate": {
                                "required": false,
                                "revision": {
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.1": false,
                                    "7.2.2": false,
                                    "7.2.3": false,
                                    "7.2.4": false,
                                    "7.4.0": false,
                                    "7.4.1": false
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "forward-traffic": {
                "required": false,
                "revision": {
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "free-style": {
                "required": false,
                "revision": {
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "category": {
                        "required": false,
                        "revision": {
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "traffic",
                            "event",
                            "virus",
                            "webfilter",
                            "attack",
                            "spam",
                            "voip",
                            "dlp",
                            "app-ctrl",
                            "anomaly",
                            "waf",
                            "gtp",
                            "dns",
                            "ssh",
                            "ssl",
                            "file-filter",
                            "icap",
                            "ztna",
                            "virtual-patch"
                        ],
                        "type": "str"
                    },
                    "filter": {
                        "required": false,
                        "revision": {
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "filter-type": {
                        "required": false,
                        "revision": {
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "include",
                            "exclude"
                        ],
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "gtp": {
                "required": false,
                "revision": {
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "local-traffic": {
                "required": false,
                "revision": {
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "multicast-traffic": {
                "required": false,
                "revision": {
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sniffer-traffic": {
                "required": false,
                "revision": {
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "voip": {
                "required": false,
                "revision": {
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ztna-traffic": {
                "required": false,
                "revision": {
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "filter-type": {
                "required": false,
                "revision": {
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "include",
                    "exclude"
                ],
                "type": "str"
            },
            "filter": {
                "required": false,
                "revision": {
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cifs": {
                "required": false,
                "revision": {
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl": {
                "required": false,
                "revision": {
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dns": {
                "required": false,
                "revision": {
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssh": {
                "required": false,
                "revision": {
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "netscan-discovery": {
                "required": false,
                "revision": {
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "netscan-vulnerability": {
                "required": false,
                "revision": {
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "devprof_log_syslogd_filter_excludelist": {
        "stated": true,
        "options": {
            "category": {
                "required": false,
                "revision": {
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "app-ctrl",
                    "attack",
                    "dlp",
                    "event",
                    "traffic",
                    "virus",
                    "voip",
                    "webfilter",
                    "netscan",
                    "spam",
                    "anomaly",
                    "waf"
                ],
                "type": "str"
            },
            "fields": {
                "required": false,
                "revision": {
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "args": {
                        "required": false,
                        "revision": {
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "raw"
                    },
                    "field": {
                        "required": false,
                        "revision": {
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "negate": {
                        "required": false,
                        "revision": {
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "id": {
                "required": true,
                "revision": {
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            }
        }
    },
    "devprof_log_syslogd_filter_excludelist_fields": {
        "stated": true,
        "options": {
            "args": {
                "required": false,
                "revision": {
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "field": {
                "required": false,
                "revision": {
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "negate": {
                "required": false,
                "revision": {
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "devprof_log_syslogd_filter_freestyle": {
        "stated": true,
        "options": {
            "category": {
                "required": false,
                "revision": {
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "traffic",
                    "event",
                    "virus",
                    "webfilter",
                    "attack",
                    "spam",
                    "voip",
                    "dlp",
                    "app-ctrl",
                    "anomaly",
                    "waf",
                    "gtp",
                    "dns",
                    "ssh",
                    "ssl",
                    "file-filter",
                    "icap",
                    "ztna",
                    "virtual-patch"
                ],
                "type": "str"
            },
            "filter": {
                "required": false,
                "revision": {
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "filter-type": {
                "required": false,
                "revision": {
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "include",
                    "exclude"
                ],
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "devprof_log_syslogd_setting": {
        "stated": false,
        "options": {
            "certificate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "enc-algorithm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "high",
                    "low",
                    "disable",
                    "high-medium"
                ],
                "type": "str"
            },
            "facility": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "kernel",
                    "user",
                    "mail",
                    "daemon",
                    "auth",
                    "syslog",
                    "lpr",
                    "news",
                    "uucp",
                    "cron",
                    "authpriv",
                    "ftp",
                    "ntp",
                    "audit",
                    "alert",
                    "clock",
                    "local0",
                    "local1",
                    "local2",
                    "local3",
                    "local4",
                    "local5",
                    "local6",
                    "local7"
                ],
                "type": "str"
            },
            "mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "udp",
                    "legacy-reliable",
                    "reliable"
                ],
                "type": "str"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ssl-min-proto-version": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "default",
                    "TLSv1-1",
                    "TLSv1-2",
                    "SSLv3",
                    "TLSv1",
                    "TLSv1-3"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "reliable": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "csv": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "max-log-rate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "priority": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "low",
                    "default"
                ],
                "type": "str"
            },
            "interface": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "interface-select-method": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auto",
                    "sdwan",
                    "specify"
                ],
                "type": "str"
            },
            "format": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "default",
                    "csv",
                    "cef",
                    "rfc5424",
                    "json"
                ],
                "type": "str"
            },
            "syslog-type": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "custom-field-name": {
                "required": false,
                "revision": {
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "custom": {
                        "required": false,
                        "revision": {
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "devprof_log_syslogd_setting_customfieldname": {
        "stated": true,
        "options": {
            "custom": {
                "required": false,
                "revision": {
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "devprof_system_centralmanagement": {
        "stated": false,
        "options": {
            "include-default-servers": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "server-list": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "addr-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": false,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": false,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "fqdn",
                            "ipv4",
                            "ipv6"
                        ],
                        "type": "str"
                    },
                    "fqdn": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": false,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": false,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": false,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": false,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "server-address": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": false,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": false,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "server-address6": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": false,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": false,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "server-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": false,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": false,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "update",
                            "rating",
                            "iot-query",
                            "iot-collect"
                        ],
                        "elements": "str"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "devprof_system_centralmanagement_serverlist": {
        "stated": true,
        "options": {
            "addr-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "fqdn",
                    "ipv4",
                    "ipv6"
                ],
                "type": "str"
            },
            "fqdn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "server-address": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "server-address6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "server-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "update",
                    "rating",
                    "iot-query",
                    "iot-collect"
                ],
                "elements": "str"
            }
        }
    },
    "devprof_system_dns": {
        "stated": false,
        "options": {
            "cache-notfound-responses": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dns-cache-limit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "dns-cache-ttl": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "domain": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "ip6-primary": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "ip6-secondary": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "primary": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "secondary": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "dns-over-tls": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable",
                    "enforce"
                ],
                "type": "str"
            },
            "retry": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "server-hostname": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "ssl-certificate": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "timeout": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "interface": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "interface-select-method": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "auto",
                    "sdwan",
                    "specify"
                ],
                "type": "str"
            }
        }
    },
    "devprof_system_emailserver": {
        "stated": false,
        "options": {
            "authenticate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "password": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "reply-to": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "security": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "starttls",
                    "smtps"
                ],
                "type": "str"
            },
            "server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "source-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "source-ip6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ssl-min-proto-version": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "default",
                    "TLSv1",
                    "TLSv1-1",
                    "TLSv1-2",
                    "SSLv3",
                    "TLSv1-3"
                ],
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "custom"
                ],
                "type": "str"
            },
            "username": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "validate-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "interface": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "interface-select-method": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auto",
                    "sdwan",
                    "specify"
                ],
                "type": "str"
            }
        }
    },
    "devprof_system_global": {
        "stated": false,
        "options": {
            "admin-https-redirect": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "admin-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "admin-scp": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "admin-sport": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "admin-ssh-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "admin-ssh-v1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "admin-telnet-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "admintimeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "gui-ipv6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "gui-lines-per-page": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "gui-theme": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "blue",
                    "green",
                    "melongene",
                    "red",
                    "mariner",
                    "neutrino",
                    "jade",
                    "graphite",
                    "dark-matter",
                    "onyx",
                    "eclipse",
                    "retro",
                    "fpx",
                    "jet-stream",
                    "security-fabric"
                ],
                "type": "str"
            },
            "language": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "english",
                    "simch",
                    "japanese",
                    "korean",
                    "spanish",
                    "trach",
                    "french",
                    "portuguese"
                ],
                "type": "str"
            },
            "switch-controller": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "devprof_system_ntp": {
        "stated": false,
        "options": {
            "ntpserver": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "authentication": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": false,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": false,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": false,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": false,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "key": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": false,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": false,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "key-id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": false,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": false,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "int"
                    },
                    "ntpv3": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": false,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": false,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "server": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": false,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": false,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "interface": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "interface-select-method": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "auto",
                            "sdwan",
                            "specify"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "ntpsync": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "source-ip6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "syncinterval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "fortiguard",
                    "custom"
                ],
                "type": "str"
            },
            "authentication": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "key": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "key-id": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "int"
            },
            "key-type": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "MD5",
                    "SHA1"
                ],
                "type": "str"
            }
        }
    },
    "devprof_system_ntp_ntpserver": {
        "stated": true,
        "options": {
            "authentication": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "key": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "key-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "int"
            },
            "ntpv3": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "interface": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "interface-select-method": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "auto",
                    "sdwan",
                    "specify"
                ],
                "type": "str"
            }
        }
    },
    "devprof_system_replacemsg_admin": {
        "stated": false,
        "options": {
            "buffer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "format": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "text",
                    "html",
                    "wml"
                ],
                "type": "str"
            },
            "header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http",
                    "8bit"
                ],
                "type": "str"
            },
            "msg-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "devprof_system_replacemsg_alertmail": {
        "stated": false,
        "options": {
            "buffer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "format": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "text",
                    "html",
                    "wml"
                ],
                "type": "str"
            },
            "header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http",
                    "8bit"
                ],
                "type": "str"
            },
            "msg-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "devprof_system_replacemsg_auth": {
        "stated": false,
        "options": {
            "buffer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "format": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "text",
                    "html",
                    "wml"
                ],
                "type": "str"
            },
            "header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http",
                    "8bit"
                ],
                "type": "str"
            },
            "msg-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "devprof_system_replacemsg_devicedetectionportal": {
        "stated": false,
        "options": {
            "buffer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "format": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "text",
                    "html",
                    "wml"
                ],
                "type": "str"
            },
            "header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http",
                    "8bit"
                ],
                "type": "str"
            },
            "msg-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "devprof_system_replacemsg_ec": {
        "stated": false,
        "options": {
            "buffer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "format": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "none",
                    "text",
                    "html",
                    "wml"
                ],
                "type": "str"
            },
            "header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "none",
                    "http",
                    "8bit"
                ],
                "type": "str"
            },
            "msg-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "devprof_system_replacemsg_fortiguardwf": {
        "stated": false,
        "options": {
            "buffer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "format": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "text",
                    "html",
                    "wml"
                ],
                "type": "str"
            },
            "header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http",
                    "8bit"
                ],
                "type": "str"
            },
            "msg-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "devprof_system_replacemsg_ftp": {
        "stated": false,
        "options": {
            "buffer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "format": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "text",
                    "html",
                    "wml"
                ],
                "type": "str"
            },
            "header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http",
                    "8bit"
                ],
                "type": "str"
            },
            "msg-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "devprof_system_replacemsg_http": {
        "stated": false,
        "options": {
            "buffer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "format": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "text",
                    "html",
                    "wml"
                ],
                "type": "str"
            },
            "header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http",
                    "8bit"
                ],
                "type": "str"
            },
            "msg-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "devprof_system_replacemsg_mail": {
        "stated": false,
        "options": {
            "buffer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "format": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "text",
                    "html",
                    "wml"
                ],
                "type": "str"
            },
            "header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http",
                    "8bit"
                ],
                "type": "str"
            },
            "msg-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "devprof_system_replacemsg_mms": {
        "stated": false,
        "options": {
            "buffer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "charset": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "us-ascii",
                    "utf-8"
                ],
                "type": "str"
            },
            "format": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "text",
                    "html",
                    "wml"
                ],
                "type": "str"
            },
            "header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http",
                    "8bit"
                ],
                "type": "str"
            },
            "image": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "msg-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "devprof_system_replacemsg_nacquar": {
        "stated": false,
        "options": {
            "buffer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "format": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "text",
                    "html",
                    "wml"
                ],
                "type": "str"
            },
            "header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http",
                    "8bit"
                ],
                "type": "str"
            },
            "msg-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "devprof_system_replacemsg_nntp": {
        "stated": false,
        "options": {
            "buffer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "format": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "text",
                    "html",
                    "wml"
                ],
                "type": "str"
            },
            "header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http",
                    "8bit"
                ],
                "type": "str"
            },
            "msg-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "devprof_system_replacemsg_spam": {
        "stated": false,
        "options": {
            "buffer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "format": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "text",
                    "html",
                    "wml"
                ],
                "type": "str"
            },
            "header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http",
                    "8bit"
                ],
                "type": "str"
            },
            "msg-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "devprof_system_replacemsg_sslvpn": {
        "stated": false,
        "options": {
            "buffer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "format": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "text",
                    "html",
                    "wml"
                ],
                "type": "str"
            },
            "header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http",
                    "8bit"
                ],
                "type": "str"
            },
            "msg-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "devprof_system_replacemsg_trafficquota": {
        "stated": false,
        "options": {
            "buffer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "format": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "text",
                    "html",
                    "wml"
                ],
                "type": "str"
            },
            "header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http",
                    "8bit"
                ],
                "type": "str"
            },
            "msg-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "devprof_system_replacemsg_utm": {
        "stated": false,
        "options": {
            "buffer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "format": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "text",
                    "html",
                    "wml"
                ],
                "type": "str"
            },
            "header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http",
                    "8bit"
                ],
                "type": "str"
            },
            "msg-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "devprof_system_replacemsg_webproxy": {
        "stated": false,
        "options": {
            "buffer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "format": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "text",
                    "html",
                    "wml"
                ],
                "type": "str"
            },
            "header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http",
                    "8bit"
                ],
                "type": "str"
            },
            "msg-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "devprof_system_snmp_community": {
        "stated": true,
        "options": {
            "events": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "cpu-high",
                    "mem-low",
                    "log-full",
                    "intf-ip",
                    "vpn-tun-up",
                    "vpn-tun-down",
                    "ha-switch",
                    "ha-hb-failure",
                    "ips-signature",
                    "ips-anomaly",
                    "av-virus",
                    "av-oversize",
                    "av-pattern",
                    "av-fragmented",
                    "fm-if-change",
                    "fm-conf-change",
                    "temperature-high",
                    "voltage-alert",
                    "ha-member-up",
                    "ha-member-down",
                    "ent-conf-change",
                    "av-conserve",
                    "av-bypass",
                    "av-oversize-passed",
                    "av-oversize-blocked",
                    "ips-pkg-update",
                    "power-supply-failure",
                    "amc-bypass",
                    "faz-disconnect",
                    "fan-failure",
                    "bgp-established",
                    "bgp-backward-transition",
                    "wc-ap-up",
                    "wc-ap-down",
                    "fswctl-session-up",
                    "fswctl-session-down",
                    "ips-fail-open",
                    "load-balance-real-server-down",
                    "device-new",
                    "enter-intf-bypass",
                    "exit-intf-bypass",
                    "per-cpu-high",
                    "power-blade-down",
                    "confsync_failure",
                    "dhcp",
                    "pool-usage",
                    "power-redundancy-degrade",
                    "power-redundancy-failure",
                    "ospf-nbr-state-change",
                    "ospf-virtnbr-state-change",
                    "disk-failure",
                    "disk-overload",
                    "faz-main-failover",
                    "faz-alt-failover",
                    "slbc",
                    "faz"
                ],
                "elements": "str"
            },
            "hosts": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "ha-direct": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": false,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": false,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "host-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": false,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": false,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "any",
                            "query",
                            "trap"
                        ],
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": false,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": false,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": false,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": false,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "source-ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": false,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": false,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "hosts6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "ha-direct": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": false,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": false,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "host-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": false,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": false,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "any",
                            "query",
                            "trap"
                        ],
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": false,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": false,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ipv6": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": false,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": false,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "source-ipv6": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": false,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": false,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "query-v1-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "query-v1-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "query-v2c-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "query-v2c-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "trap-v1-lport": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "trap-v1-rport": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "trap-v1-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "trap-v2c-lport": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "trap-v2c-rport": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "trap-v2c-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mib-view": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vdoms": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "devprof_system_snmp_community_hosts": {
        "stated": true,
        "options": {
            "ha-direct": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "host-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "any",
                    "query",
                    "trap"
                ],
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "source-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "devprof_system_snmp_community_hosts6": {
        "stated": true,
        "options": {
            "ha-direct": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "host-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "any",
                    "query",
                    "trap"
                ],
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ipv6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "source-ipv6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "devprof_system_snmp_sysinfo": {
        "stated": false,
        "options": {
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "devprof_system_snmp_user": {
        "stated": true,
        "options": {
            "auth-proto": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "md5",
                    "sha",
                    "sha224",
                    "sha256",
                    "sha384",
                    "sha512"
                ],
                "type": "str"
            },
            "auth-pwd": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "events": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "cpu-high",
                    "mem-low",
                    "log-full",
                    "intf-ip",
                    "vpn-tun-up",
                    "vpn-tun-down",
                    "ha-switch",
                    "fm-conf-change",
                    "ips-signature",
                    "ips-anomaly",
                    "temperature-high",
                    "voltage-alert",
                    "av-virus",
                    "av-oversize",
                    "av-pattern",
                    "av-fragmented",
                    "ha-hb-failure",
                    "fan-failure",
                    "ha-member-up",
                    "ha-member-down",
                    "ent-conf-change",
                    "av-conserve",
                    "av-bypass",
                    "av-oversize-passed",
                    "av-oversize-blocked",
                    "ips-pkg-update",
                    "fm-if-change",
                    "power-supply-failure",
                    "amc-bypass",
                    "faz-disconnect",
                    "bgp-established",
                    "bgp-backward-transition",
                    "wc-ap-up",
                    "wc-ap-down",
                    "fswctl-session-up",
                    "fswctl-session-down",
                    "ips-fail-open",
                    "load-balance-real-server-down",
                    "device-new",
                    "enter-intf-bypass",
                    "exit-intf-bypass",
                    "per-cpu-high",
                    "power-blade-down",
                    "confsync_failure",
                    "dhcp",
                    "pool-usage",
                    "power-redundancy-degrade",
                    "power-redundancy-failure",
                    "ospf-nbr-state-change",
                    "ospf-virtnbr-state-change",
                    "disk-failure",
                    "disk-overload",
                    "faz-main-failover",
                    "faz-alt-failover",
                    "slbc",
                    "faz"
                ],
                "elements": "str"
            },
            "ha-direct": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "notify-hosts": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "notify-hosts6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "priv-proto": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "aes",
                    "des",
                    "aes256",
                    "aes256cisco"
                ],
                "type": "str"
            },
            "priv-pwd": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "queries": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "query-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "security-level": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "no-auth-no-priv",
                    "auth-no-priv",
                    "auth-priv"
                ],
                "type": "str"
            },
            "source-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "source-ipv6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "trap-lport": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "trap-rport": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "trap-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mib-view": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vdoms": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "dlp_datatype": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "look-ahead": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "look-back": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "pattern": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "transform": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "verify": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "verify-transformed-pattern": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "match-around": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "dlp_dictionary": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "entries": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "comment": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ignore-case": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "pattern": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "repeat": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "match-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "match-all",
                    "match-any"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "match-around": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "dlp_dictionary_entries": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ignore-case": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "pattern": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "repeat": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "dlp_filepattern": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "entries": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "file-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "unknown",
                            "ignored",
                            "exe",
                            "elf",
                            "bat",
                            "javascript",
                            "html",
                            "hta",
                            "msoffice",
                            "gzip",
                            "rar",
                            "tar",
                            "lzh",
                            "upx",
                            "zip",
                            "cab",
                            "bzip2",
                            "bzip",
                            "activemime",
                            "mime",
                            "hlp",
                            "arj",
                            "base64",
                            "binhex",
                            "uue",
                            "fsg",
                            "aspack",
                            "msc",
                            "petite",
                            "jpeg",
                            "gif",
                            "tiff",
                            "png",
                            "bmp",
                            "msi",
                            "mpeg",
                            "mov",
                            "mp3",
                            "wma",
                            "wav",
                            "pdf",
                            "avi",
                            "rm",
                            "torrent",
                            "hibun",
                            "7z",
                            "xz",
                            "msofficex",
                            "mach-o",
                            "dmg",
                            ".net",
                            "xar",
                            "chm",
                            "iso",
                            "crx",
                            "sis",
                            "prc",
                            "class",
                            "jad",
                            "cod",
                            "flac"
                        ],
                        "type": "str"
                    },
                    "filter-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "pattern",
                            "type"
                        ],
                        "type": "str"
                    },
                    "pattern": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "dlp_filepattern_entries": {
        "stated": true,
        "options": {
            "file-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "unknown",
                    "ignored",
                    "exe",
                    "elf",
                    "bat",
                    "javascript",
                    "html",
                    "hta",
                    "msoffice",
                    "gzip",
                    "rar",
                    "tar",
                    "lzh",
                    "upx",
                    "zip",
                    "cab",
                    "bzip2",
                    "bzip",
                    "activemime",
                    "mime",
                    "hlp",
                    "arj",
                    "base64",
                    "binhex",
                    "uue",
                    "fsg",
                    "aspack",
                    "msc",
                    "petite",
                    "jpeg",
                    "gif",
                    "tiff",
                    "png",
                    "bmp",
                    "msi",
                    "mpeg",
                    "mov",
                    "mp3",
                    "wma",
                    "wav",
                    "pdf",
                    "avi",
                    "rm",
                    "torrent",
                    "hibun",
                    "7z",
                    "xz",
                    "msofficex",
                    "mach-o",
                    "dmg",
                    ".net",
                    "xar",
                    "chm",
                    "iso",
                    "crx",
                    "sis",
                    "prc",
                    "class",
                    "jad",
                    "cod",
                    "flac"
                ],
                "type": "str"
            },
            "filter-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pattern",
                    "type"
                ],
                "type": "str"
            },
            "pattern": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "dlp_fpsensitivity": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "dlp_profile": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dlp-log": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "extended-log": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "feature-set": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "flow",
                    "proxy"
                ],
                "type": "str"
            },
            "full-archive-proto": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "smtp",
                    "pop3",
                    "imap",
                    "http-post",
                    "http-get",
                    "ftp",
                    "nntp",
                    "mapi",
                    "ssh",
                    "cifs"
                ],
                "elements": "str"
            },
            "nac-quar-log": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "replacemsg-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "rule": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "log-only",
                            "block",
                            "quarantine-ip",
                            "allow"
                        ],
                        "type": "str"
                    },
                    "archive": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "expiry": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "file-size": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "file-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "filter-by": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "fingerprint",
                            "sensor",
                            "encrypted",
                            "none",
                            "mip"
                        ],
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "label": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "match-percentage": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "proto": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "smtp",
                            "pop3",
                            "imap",
                            "http-post",
                            "http-get",
                            "ftp",
                            "nntp",
                            "mapi",
                            "ssh",
                            "cifs"
                        ],
                        "elements": "str"
                    },
                    "sensitivity": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "sensor": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "severity": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "info",
                            "low",
                            "medium",
                            "high",
                            "critical"
                        ],
                        "type": "str"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "file",
                            "message"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "summary-proto": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "smtp",
                    "pop3",
                    "imap",
                    "http-post",
                    "http-get",
                    "ftp",
                    "nntp",
                    "mapi",
                    "ssh",
                    "cifs"
                ],
                "elements": "str"
            }
        }
    },
    "dlp_profile_rule": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "log-only",
                    "block",
                    "quarantine-ip",
                    "allow"
                ],
                "type": "str"
            },
            "archive": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "expiry": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "file-size": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "file-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "filter-by": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "fingerprint",
                    "sensor",
                    "encrypted",
                    "none",
                    "mip"
                ],
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "label": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "match-percentage": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "proto": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "smtp",
                    "pop3",
                    "imap",
                    "http-post",
                    "http-get",
                    "ftp",
                    "nntp",
                    "mapi",
                    "ssh",
                    "cifs"
                ],
                "elements": "str"
            },
            "sensitivity": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "sensor": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "severity": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "info",
                    "low",
                    "medium",
                    "high",
                    "critical"
                ],
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "file",
                    "message"
                ],
                "type": "str"
            }
        }
    },
    "dlp_sensitivity": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "dlp_sensor": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dlp-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "extended-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "filter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "log-only",
                            "block",
                            "exempt",
                            "ban",
                            "ban-sender",
                            "quarantine-ip",
                            "quarantine-port",
                            "none",
                            "allow"
                        ],
                        "type": "str"
                    },
                    "archive": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable",
                            "summary-only"
                        ],
                        "type": "str"
                    },
                    "company-identifier": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "expiry": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "file-size": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "file-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "filter-by": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "credit-card",
                            "ssn",
                            "regexp",
                            "file-type",
                            "file-size",
                            "fingerprint",
                            "watermark",
                            "encrypted",
                            "file-type-and-size"
                        ],
                        "type": "str"
                    },
                    "fp-sensitivity": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "raw"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "match-percentage": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "proto": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "imap",
                            "smtp",
                            "pop3",
                            "ftp",
                            "nntp",
                            "mm1",
                            "mm3",
                            "mm4",
                            "mm7",
                            "mapi",
                            "aim",
                            "icq",
                            "msn",
                            "yahoo",
                            "http-get",
                            "http-post",
                            "ssh",
                            "cifs"
                        ],
                        "elements": "str"
                    },
                    "regexp": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "severity": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "info",
                            "low",
                            "medium",
                            "high",
                            "critical"
                        ],
                        "type": "str"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "file",
                            "message"
                        ],
                        "type": "str"
                    },
                    "sensitivity": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    }
                },
                "elements": "dict"
            },
            "flow-based": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "full-archive-proto": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "imap",
                    "smtp",
                    "pop3",
                    "ftp",
                    "nntp",
                    "mm1",
                    "mm3",
                    "mm4",
                    "mm7",
                    "mapi",
                    "aim",
                    "icq",
                    "msn",
                    "yahoo",
                    "http-get",
                    "http-post",
                    "ssh",
                    "cifs"
                ],
                "elements": "str"
            },
            "nac-quar-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "options": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "strict-file"
                ],
                "type": "str"
            },
            "replacemsg-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "summary-proto": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "imap",
                    "smtp",
                    "pop3",
                    "ftp",
                    "nntp",
                    "mm1",
                    "mm3",
                    "mm4",
                    "mm7",
                    "mapi",
                    "aim",
                    "icq",
                    "msn",
                    "yahoo",
                    "http-get",
                    "http-post",
                    "ssh",
                    "cifs"
                ],
                "elements": "str"
            },
            "feature-set": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "proxy",
                    "flow"
                ],
                "type": "str"
            },
            "entries": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "count": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "dictionary": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "eval": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "match-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "match-all",
                    "match-any",
                    "match-eval"
                ],
                "type": "str"
            }
        }
    },
    "dlp_sensor_entries": {
        "stated": true,
        "options": {
            "count": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "dictionary": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "dlp_sensor_filter": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "log-only",
                    "block",
                    "exempt",
                    "ban",
                    "ban-sender",
                    "quarantine-ip",
                    "quarantine-port",
                    "none",
                    "allow"
                ],
                "type": "str"
            },
            "archive": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "summary-only"
                ],
                "type": "str"
            },
            "company-identifier": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "expiry": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "file-size": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "file-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "filter-by": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "credit-card",
                    "ssn",
                    "regexp",
                    "file-type",
                    "file-size",
                    "fingerprint",
                    "watermark",
                    "encrypted",
                    "file-type-and-size"
                ],
                "type": "str"
            },
            "fp-sensitivity": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "match-percentage": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "proto": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "imap",
                    "smtp",
                    "pop3",
                    "ftp",
                    "nntp",
                    "mm1",
                    "mm3",
                    "mm4",
                    "mm7",
                    "mapi",
                    "aim",
                    "icq",
                    "msn",
                    "yahoo",
                    "http-get",
                    "http-post",
                    "ssh",
                    "cifs"
                ],
                "elements": "str"
            },
            "regexp": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "severity": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "info",
                    "low",
                    "medium",
                    "high",
                    "critical"
                ],
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "file",
                    "message"
                ],
                "type": "str"
            },
            "sensitivity": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "dnsfilter_domainfilter": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "entries": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "block",
                            "allow",
                            "monitor"
                        ],
                        "type": "str"
                    },
                    "domain": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "simple",
                            "regex",
                            "wildcard"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "dnsfilter_domainfilter_entries": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "block",
                    "allow",
                    "monitor"
                ],
                "type": "str"
            },
            "domain": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "simple",
                    "regex",
                    "wildcard"
                ],
                "type": "str"
            }
        }
    },
    "dnsfilter_profile": {
        "stated": true,
        "options": {
            "block-action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "block",
                    "redirect",
                    "block-sevrfail"
                ],
                "type": "str"
            },
            "block-botnet": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "external-ip-blocklist": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "log-all-domain": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "redirect-portal": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "safe-search": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sdns-domain-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sdns-ftgd-err-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "youtube-restrict": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "strict",
                    "moderate"
                ],
                "type": "str"
            },
            "dns-translation": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "dst": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "netmask": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "src": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "addr-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ipv4",
                            "ipv6"
                        ],
                        "type": "str"
                    },
                    "dst6": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "prefix": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "src6": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "redirect-portal6": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "log-all-url": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sdns-url-log": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "domain-filter": {
                "required": false,
                "type": "dict",
                "options": {
                    "domain-filter-table": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                }
            },
            "ftgd-dns": {
                "required": false,
                "type": "dict",
                "options": {
                    "filters": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "action": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "monitor",
                                    "block"
                                ],
                                "type": "str"
                            },
                            "category": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "log": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "options": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "error-allow",
                            "ftgd-disable"
                        ],
                        "elements": "str"
                    }
                }
            },
            "urlfilter": {
                "required": false,
                "type": "dict",
                "options": {
                    "urlfilter-table": {
                        "required": false,
                        "revision": {
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    }
                }
            },
            "transparent-dns-database": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "dnsfilter_profile_dnstranslation": {
        "stated": true,
        "options": {
            "dst": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "netmask": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "src": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "addr-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ipv4",
                    "ipv6"
                ],
                "type": "str"
            },
            "dst6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "prefix": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "src6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "dnsfilter_profile_domainfilter": {
        "stated": false,
        "options": {
            "domain-filter-table": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "dnsfilter_profile_ftgddns": {
        "stated": false,
        "options": {
            "filters": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "monitor",
                            "block"
                        ],
                        "type": "str"
                    },
                    "category": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "options": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "error-allow",
                    "ftgd-disable"
                ],
                "elements": "str"
            }
        }
    },
    "dnsfilter_profile_ftgddns_filters": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "monitor",
                    "block"
                ],
                "type": "str"
            },
            "category": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "dnsfilter_profile_urlfilter": {
        "stated": false,
        "options": {
            "urlfilter-table": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            }
        }
    },
    "dnsfilter_urlfilter": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "entries": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "allow",
                            "monitor",
                            "block"
                        ],
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "wildcard",
                            "regex",
                            "simple"
                        ],
                        "type": "str"
                    },
                    "url": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "dnsfilter_urlfilter_entries": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "allow",
                    "monitor",
                    "block"
                ],
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "wildcard",
                    "regex",
                    "simple"
                ],
                "type": "str"
            },
            "url": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "dvm_cmd_add_device": {
        "stated": true,
        "options": {
            "adom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "device": {
                "required": false,
                "type": "dict",
                "options": {
                    "adm_pass": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "adm_usr": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "desc": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "device action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "faz.quota": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "meta fields": {
                        "required": false,
                        "type": "raw"
                    },
                    "mgmt_mode": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "unreg",
                            "fmg",
                            "faz",
                            "fmgfaz"
                        ],
                        "type": "str"
                    },
                    "mr": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "os_type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "unknown",
                            "fos",
                            "fsw",
                            "foc",
                            "fml",
                            "faz",
                            "fwb",
                            "fch",
                            "fct",
                            "log",
                            "fmg",
                            "fsa",
                            "fdd",
                            "fac",
                            "fpx",
                            "fna"
                        ],
                        "type": "str"
                    },
                    "os_ver": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "unknown",
                            "0.0",
                            "1.0",
                            "2.0",
                            "3.0",
                            "4.0",
                            "5.0",
                            "6.0",
                            "7.0",
                            "8.0"
                        ],
                        "type": "str"
                    },
                    "patch": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "platform_str": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sn": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "device blueprint": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "authorization template": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                }
            },
            "flags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "none",
                    "create_task",
                    "nonblocking",
                    "log_dev"
                ],
                "elements": "str"
            },
            "groups": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "dvm_cmd_add_devlist": {
        "stated": true,
        "options": {
            "add-dev-list": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "adm_pass": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "adm_usr": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "desc": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "device action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "faz.quota": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "meta fields": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "mgmt_mode": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "unreg",
                            "fmg",
                            "faz",
                            "fmgfaz"
                        ],
                        "type": "str"
                    },
                    "mr": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "os_type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "unknown",
                            "fos",
                            "fsw",
                            "foc",
                            "fml",
                            "faz",
                            "fwb",
                            "fch",
                            "fct",
                            "log",
                            "fmg",
                            "fsa",
                            "fdd",
                            "fac",
                            "fpx",
                            "fna"
                        ],
                        "type": "str"
                    },
                    "os_ver": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "unknown",
                            "0.0",
                            "1.0",
                            "2.0",
                            "3.0",
                            "4.0",
                            "5.0",
                            "6.0",
                            "7.0",
                            "8.0"
                        ],
                        "type": "str"
                    },
                    "patch": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "platform_str": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sn": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "device blueprint": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "authorization template": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "adom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "flags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "none",
                    "create_task",
                    "nonblocking",
                    "log_dev"
                ],
                "elements": "str"
            }
        }
    },
    "dvm_cmd_changehaseq": {
        "stated": true,
        "options": {
            "adom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "device": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "flags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "none",
                    "create_task",
                    "nonblocking",
                    "log_dev"
                ],
                "elements": "str"
            },
            "new_master": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "dvm_cmd_del_device": {
        "stated": true,
        "options": {
            "adom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "device": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "flags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "none",
                    "create_task",
                    "nonblocking",
                    "log_dev"
                ],
                "elements": "str"
            }
        }
    },
    "dvm_cmd_del_devlist": {
        "stated": true,
        "options": {
            "adom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "del-dev-member-list": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "flags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "none",
                    "create_task",
                    "nonblocking",
                    "log_dev"
                ],
                "elements": "str"
            }
        }
    },
    "dvm_cmd_discover_device": {
        "stated": true,
        "options": {
            "device": {
                "required": false,
                "type": "dict",
                "options": {
                    "adm_pass": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "str"
                    },
                    "adm_usr": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                }
            }
        }
    },
    "dvm_cmd_import_devlist": {
        "stated": true,
        "options": {
            "adom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "flags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "none",
                    "create_task",
                    "nonblocking",
                    "log_dev"
                ],
                "elements": "str"
            },
            "import-adom-members": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "adom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "dev": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "import-adoms": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "desc": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "flags": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "migration",
                            "db_export",
                            "no_vpn_console",
                            "backup",
                            "other_devices",
                            "central_sdwan",
                            "is_autosync",
                            "per_device_wtp",
                            "policy_check_on_install",
                            "install_on_policy_check_fail",
                            "auto_push_cfg",
                            "per_device_fsw",
                            "install_deselect_all"
                        ],
                        "elements": "str"
                    },
                    "log_db_retention_hours": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "log_disk_quota": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "log_disk_quota_alert_thres": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "log_disk_quota_split_ratio": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "log_file_retention_hours": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "meta fields": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "dict"
                    },
                    "mig_mr": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "mig_os_ver": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "unknown",
                            "0.0",
                            "1.0",
                            "2.0",
                            "3.0",
                            "4.0",
                            "5.0",
                            "6.0",
                            "7.0",
                            "8.0",
                            "9.0"
                        ],
                        "type": "str"
                    },
                    "mode": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ems",
                            "gms",
                            "provider"
                        ],
                        "type": "str"
                    },
                    "mr": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "os_ver": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "unknown",
                            "0.0",
                            "1.0",
                            "2.0",
                            "3.0",
                            "4.0",
                            "5.0",
                            "6.0",
                            "7.0",
                            "8.0",
                            "9.0"
                        ],
                        "type": "str"
                    },
                    "restricted_prds": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw",
                        "choices": [
                            "fos",
                            "foc",
                            "fml",
                            "fch",
                            "fwb",
                            "log",
                            "fct",
                            "faz",
                            "fsa",
                            "fsw",
                            "fmg",
                            "fdd",
                            "fac",
                            "fpx",
                            "fna",
                            "fdc",
                            "ffw",
                            "fsr",
                            "fad",
                            "fap",
                            "fxt",
                            "fts",
                            "fai",
                            "fwc"
                        ]
                    },
                    "state": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "uuid": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "create_time": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "workspace_mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "tz": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "lock_override": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "import-devices": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "adm_pass": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "adm_usr": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "app_ver": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "av_ver": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "beta": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "branch_pt": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "build": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "checksum": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "conf_status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "unknown",
                            "insync",
                            "outofsync"
                        ],
                        "type": "str"
                    },
                    "conn_mode": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "active",
                            "passive"
                        ],
                        "type": "str"
                    },
                    "conn_status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "UNKNOWN",
                            "up",
                            "down"
                        ],
                        "type": "str"
                    },
                    "db_status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "unknown",
                            "nomod",
                            "mod"
                        ],
                        "type": "str"
                    },
                    "desc": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "dev_status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "unknown",
                            "checkedin",
                            "inprogress",
                            "installed",
                            "aborted",
                            "sched",
                            "retry",
                            "canceled",
                            "pending",
                            "retrieved",
                            "changed_conf",
                            "sync_fail",
                            "timeout",
                            "rev_revert",
                            "auto_updated"
                        ],
                        "type": "str"
                    },
                    "fap_cnt": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "faz.full_act": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "faz.perm": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "faz.quota": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "faz.used": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "fex_cnt": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "flags": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "has_hdd",
                            "vdom_enabled",
                            "discover",
                            "reload",
                            "interim_build",
                            "offline_mode",
                            "is_model",
                            "fips_mode",
                            "linked_to_model",
                            "ip-conflict",
                            "faz-autosync",
                            "need_reset",
                            "backup_mode",
                            "azure_vwan_nva",
                            "fgsp_configured",
                            "cnf_mode",
                            "sase_managed"
                        ],
                        "elements": "str"
                    },
                    "foslic_cpu": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "foslic_dr_site": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "foslic_inst_time": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "foslic_last_sync": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "foslic_ram": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "foslic_type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "temporary",
                            "trial",
                            "regular",
                            "trial_expired"
                        ],
                        "type": "str"
                    },
                    "foslic_utm": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "fw",
                            "av",
                            "ips",
                            "app",
                            "url",
                            "utm",
                            "fwb"
                        ],
                        "elements": "str"
                    },
                    "fsw_cnt": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ha_group_id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ha_group_name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ha_mode": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "standalone",
                            "AP",
                            "AA",
                            "ELBC",
                            "DUAL",
                            "enabled",
                            "unknown",
                            "fmg-enabled",
                            "autoscale"
                        ],
                        "type": "str"
                    },
                    "ha_slave": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "idx": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "prio": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "role": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "slave",
                                    "master"
                                ],
                                "type": "str"
                            },
                            "sn": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "status": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "conf_status": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            }
                        },
                        "elements": "dict"
                    },
                    "hdisk_size": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "hostname": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "hw_rev_major": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "hw_rev_minor": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ips_ext": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ips_ver": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "last_checked": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "last_resync": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "latitude": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "lic_flags": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "lic_region": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "location_from": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "logdisk_size": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "longitude": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "maxvdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "meta fields": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "dict"
                    },
                    "mgmt_id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "mgmt_if": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "mgmt_mode": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "unreg",
                            "fmg",
                            "faz",
                            "fmgfaz"
                        ],
                        "type": "str"
                    },
                    "mgt_vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "mr": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "os_type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "unknown",
                            "fos",
                            "fsw",
                            "foc",
                            "fml",
                            "faz",
                            "fwb",
                            "fch",
                            "fct",
                            "log",
                            "fmg",
                            "fsa",
                            "fdd",
                            "fac",
                            "fpx",
                            "fna",
                            "fdc",
                            "ffw",
                            "fsr",
                            "fad",
                            "fap",
                            "fxt",
                            "fts",
                            "fai",
                            "fwc",
                            "fis",
                            "fed",
                            "fpa",
                            "fca",
                            "ftc"
                        ],
                        "type": "str"
                    },
                    "os_ver": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "unknown",
                            "0.0",
                            "1.0",
                            "2.0",
                            "3.0",
                            "4.0",
                            "5.0",
                            "6.0",
                            "7.0",
                            "8.0",
                            "9.0"
                        ],
                        "type": "str"
                    },
                    "patch": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "platform_str": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "psk": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sn": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "comments": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "opmode": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "nat",
                                    "transparent"
                                ],
                                "type": "str"
                            },
                            "rtm_prof_id": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "status": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "vpn_id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "meta fields": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "dict"
                            },
                            "vdom_type": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": false,
                                    "7.0.3": false,
                                    "7.0.4": false,
                                    "7.0.5": false,
                                    "7.0.6": false,
                                    "7.0.7": false,
                                    "7.0.8": false,
                                    "7.0.9": false,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "traffic",
                                    "admin"
                                ],
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "version": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "vm_cpu": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "vm_cpu_limit": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "vm_lic_expire": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "vm_mem": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "vm_mem_limit": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "vm_status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "module_sn": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "prefer_img_ver": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "prio": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "role": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "master",
                            "ha-slave",
                            "autoscale-slave"
                        ],
                        "type": "str"
                    },
                    "hyperscale": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "nsxt_service_name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "private_key": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "str"
                    },
                    "private_key_status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "int"
                    },
                    "vm_lic_overdue_since": {
                        "required": false,
                        "revision": {
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "first_tunnel_up": {
                        "required": false,
                        "revision": {
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "eip": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "mgmt_uuid": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "hw_generation": {
                        "required": false,
                        "revision": {
                            "7.2.4": true,
                            "7.4.0": false,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "import-group-members": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "adom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "dev": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "grp": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "dvm_cmd_reload_devlist": {
        "stated": true,
        "options": {
            "adom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "flags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "none",
                    "create_task",
                    "nonblocking",
                    "log_dev"
                ],
                "elements": "str"
            },
            "from": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "um",
                    "fgfm",
                    "apache",
                    "dvm",
                    "fwm",
                    "xml",
                    "json"
                ],
                "type": "str"
            },
            "reload-dev-member-list": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "tag": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "dvm_cmd_update_device": {
        "stated": true,
        "options": {
            "adom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "device": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "flags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "none",
                    "create_task",
                    "nonblocking",
                    "log_dev"
                ],
                "elements": "str"
            }
        }
    },
    "dvm_cmd_update_devlist": {
        "stated": true,
        "options": {
            "adom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "flags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "none",
                    "create_task",
                    "nonblocking",
                    "log_dev"
                ],
                "elements": "str"
            },
            "update-dev-member-list": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "dvmdb_adom": {
        "stated": true,
        "options": {
            "desc": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "flags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "migration",
                    "db_export",
                    "no_vpn_console",
                    "backup",
                    "other_devices",
                    "central_sdwan",
                    "is_autosync",
                    "per_device_wtp",
                    "policy_check_on_install",
                    "install_on_policy_check_fail",
                    "auto_push_cfg",
                    "per_device_fsw",
                    "install_deselect_all"
                ],
                "elements": "str"
            },
            "log_db_retention_hours": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "log_disk_quota": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "log_disk_quota_alert_thres": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "log_disk_quota_split_ratio": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "log_file_retention_hours": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "meta fields": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "dict"
            },
            "mig_mr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mig_os_ver": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "unknown",
                    "0.0",
                    "1.0",
                    "2.0",
                    "3.0",
                    "4.0",
                    "5.0",
                    "6.0",
                    "7.0",
                    "8.0",
                    "9.0"
                ],
                "type": "str"
            },
            "mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ems",
                    "gms",
                    "provider"
                ],
                "type": "str"
            },
            "mr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "os_ver": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "unknown",
                    "0.0",
                    "1.0",
                    "2.0",
                    "3.0",
                    "4.0",
                    "5.0",
                    "6.0",
                    "7.0",
                    "8.0",
                    "9.0"
                ],
                "type": "str"
            },
            "restricted_prds": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw",
                "choices": [
                    "fos",
                    "foc",
                    "fml",
                    "fch",
                    "fwb",
                    "log",
                    "fct",
                    "faz",
                    "fsa",
                    "fsw",
                    "fmg",
                    "fdd",
                    "fac",
                    "fpx",
                    "fna",
                    "fdc",
                    "ffw",
                    "fsr",
                    "fad",
                    "fap",
                    "fxt",
                    "fts",
                    "fai",
                    "fwc"
                ]
            },
            "state": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "create_time": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "workspace_mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tz": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "lock_override": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "dvmdb_adom_objectmember": {
        "stated": true,
        "options": {
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vdom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "dvmdb_device": {
        "stated": false,
        "options": {
            "adm_pass": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "adm_usr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "app_ver": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "av_ver": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "beta": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "branch_pt": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "build": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "checksum": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "conf_status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "unknown",
                    "insync",
                    "outofsync"
                ],
                "type": "str"
            },
            "conn_mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "active",
                    "passive"
                ],
                "type": "str"
            },
            "conn_status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "UNKNOWN",
                    "up",
                    "down"
                ],
                "type": "str"
            },
            "db_status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "unknown",
                    "nomod",
                    "mod"
                ],
                "type": "str"
            },
            "desc": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dev_status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "unknown",
                    "checkedin",
                    "inprogress",
                    "installed",
                    "aborted",
                    "sched",
                    "retry",
                    "canceled",
                    "pending",
                    "retrieved",
                    "changed_conf",
                    "sync_fail",
                    "timeout",
                    "rev_revert",
                    "auto_updated"
                ],
                "type": "str"
            },
            "fap_cnt": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "faz.full_act": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "faz.perm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "faz.quota": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "faz.used": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fex_cnt": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "flags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "has_hdd",
                    "vdom_enabled",
                    "discover",
                    "reload",
                    "interim_build",
                    "offline_mode",
                    "is_model",
                    "fips_mode",
                    "linked_to_model",
                    "ip-conflict",
                    "faz-autosync",
                    "need_reset",
                    "backup_mode",
                    "azure_vwan_nva",
                    "fgsp_configured",
                    "cnf_mode",
                    "sase_managed"
                ],
                "elements": "str"
            },
            "foslic_cpu": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "foslic_dr_site": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "foslic_inst_time": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "foslic_last_sync": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "foslic_ram": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "foslic_type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "temporary",
                    "trial",
                    "regular",
                    "trial_expired"
                ],
                "type": "str"
            },
            "foslic_utm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "fw",
                    "av",
                    "ips",
                    "app",
                    "url",
                    "utm",
                    "fwb"
                ],
                "elements": "str"
            },
            "fsw_cnt": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ha_group_id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ha_group_name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ha_mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "standalone",
                    "AP",
                    "AA",
                    "ELBC",
                    "DUAL",
                    "enabled",
                    "unknown",
                    "fmg-enabled",
                    "autoscale"
                ],
                "type": "str"
            },
            "ha_slave": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "idx": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "prio": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "role": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "slave",
                            "master"
                        ],
                        "type": "str"
                    },
                    "sn": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "conf_status": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "hdisk_size": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "hostname": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "hw_rev_major": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "hw_rev_minor": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ips_ext": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ips_ver": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "last_checked": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "last_resync": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "latitude": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "lic_flags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "lic_region": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "location_from": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "logdisk_size": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "longitude": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "maxvdom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "meta fields": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "dict"
            },
            "mgmt_id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "mgmt_if": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "mgmt_mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "unreg",
                    "fmg",
                    "faz",
                    "fmgfaz"
                ],
                "type": "str"
            },
            "mgt_vdom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "mr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "os_type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "unknown",
                    "fos",
                    "fsw",
                    "foc",
                    "fml",
                    "faz",
                    "fwb",
                    "fch",
                    "fct",
                    "log",
                    "fmg",
                    "fsa",
                    "fdd",
                    "fac",
                    "fpx",
                    "fna",
                    "fdc",
                    "ffw",
                    "fsr",
                    "fad",
                    "fap",
                    "fxt",
                    "fts",
                    "fai",
                    "fwc",
                    "fis",
                    "fed",
                    "fpa",
                    "fca",
                    "ftc"
                ],
                "type": "str"
            },
            "os_ver": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "unknown",
                    "0.0",
                    "1.0",
                    "2.0",
                    "3.0",
                    "4.0",
                    "5.0",
                    "6.0",
                    "7.0",
                    "8.0",
                    "9.0"
                ],
                "type": "str"
            },
            "patch": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "platform_str": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "psk": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vdom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "comments": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "opmode": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "nat",
                            "transparent"
                        ],
                        "type": "str"
                    },
                    "rtm_prof_id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vpn_id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "meta fields": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "dict"
                    },
                    "vdom_type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "traffic",
                            "admin"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "version": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "vm_cpu": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "vm_cpu_limit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "vm_lic_expire": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "vm_mem": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "vm_mem_limit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "vm_status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "module_sn": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "prefer_img_ver": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "prio": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "role": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "master",
                    "ha-slave",
                    "autoscale-slave"
                ],
                "type": "str"
            },
            "hyperscale": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "nsxt_service_name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "private_key": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "str"
            },
            "private_key_status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "int"
            },
            "vm_lic_overdue_since": {
                "required": false,
                "revision": {
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "first_tunnel_up": {
                "required": false,
                "revision": {
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "eip": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "mgmt_uuid": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "hw_generation": {
                "required": false,
                "revision": {
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "dvmdb_device_replace_sn": {
        "stated": true,
        "options": {
            "sn": {
                "required": false,
                "revision": {
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "dvmdb_device_vdom": {
        "stated": true,
        "options": {
            "comments": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "opmode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "nat",
                    "transparent"
                ],
                "type": "str"
            },
            "rtm_prof_id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vpn_id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "meta fields": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "dict"
            },
            "vdom_type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "traffic",
                    "admin"
                ],
                "type": "str"
            }
        }
    },
    "dvmdb_folder": {
        "stated": true,
        "options": {
            "desc": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "parent": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "dvmdb_group": {
        "stated": true,
        "options": {
            "desc": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "meta fields": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "dict"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "os_type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "unknown",
                    "fos",
                    "fsw",
                    "foc",
                    "fml",
                    "faz",
                    "fwb",
                    "fch",
                    "fct",
                    "log",
                    "fmg",
                    "fsa",
                    "fdd",
                    "fac",
                    "fpx",
                    "fna",
                    "fdc",
                    "ffw",
                    "fsr",
                    "fad",
                    "fap",
                    "fxt",
                    "fts",
                    "fai",
                    "fwc",
                    "fis",
                    "fed",
                    "fpa",
                    "fca",
                    "ftc"
                ],
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "normal",
                    "default",
                    "auto",
                    "cluster",
                    "fabric"
                ],
                "type": "str"
            },
            "id": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cluster_type": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "unknown",
                    "vwan",
                    "sase"
                ],
                "type": "str"
            }
        }
    },
    "dvmdb_group_objectmember": {
        "stated": true,
        "options": {
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vdom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "dvmdb_metafields_adom": {
        "stated": false,
        "options": {
            "importance": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "optional",
                    "required"
                ],
                "type": "str"
            },
            "length": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "dvmdb_metafields_device": {
        "stated": false,
        "options": {
            "importance": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "optional",
                    "required"
                ],
                "type": "str"
            },
            "length": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "dvmdb_metafields_group": {
        "stated": false,
        "options": {
            "importance": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "optional",
                    "required"
                ],
                "type": "str"
            },
            "length": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "dvmdb_revision": {
        "stated": true,
        "options": {
            "created_by": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "created_time": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "desc": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "locked": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "version": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "dvmdb_script": {
        "stated": true,
        "options": {
            "content": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "desc": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "filter_build": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "filter_device": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "filter_hostname": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "filter_ostype": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "unknown",
                    "fos"
                ],
                "type": "str"
            },
            "filter_osver": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "unknown",
                    "4.00",
                    "5.00",
                    "6.00"
                ],
                "type": "str"
            },
            "filter_platform": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "filter_serial": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "modification_time": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "script_schedule": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "datetime": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "day_of_week": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "unknown",
                            "sun",
                            "mon",
                            "tue",
                            "wed",
                            "thu",
                            "fri",
                            "sat"
                        ],
                        "type": "str"
                    },
                    "device": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "run_on_db": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "auto",
                            "onetime",
                            "daily",
                            "weekly",
                            "monthly"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "target": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "device_database",
                    "remote_device",
                    "adom_database"
                ],
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "cli",
                    "tcl",
                    "cligrp"
                ],
                "type": "str"
            }
        }
    },
    "dvmdb_script_execute": {
        "stated": true,
        "options": {
            "adom": {
                "required": false,
                "revision": {
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "package": {
                "required": false,
                "revision": {
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "scope": {
                "required": false,
                "revision": {
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "script": {
                "required": false,
                "revision": {
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "dvmdb_script_objectmember": {
        "stated": true,
        "options": {
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vdom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "dvmdb_script_scriptschedule": {
        "stated": true,
        "options": {
            "datetime": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "day_of_week": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "unknown",
                    "sun",
                    "mon",
                    "tue",
                    "wed",
                    "thu",
                    "fri",
                    "sat"
                ],
                "type": "str"
            },
            "device": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "run_on_db": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auto",
                    "onetime",
                    "daily",
                    "weekly",
                    "monthly"
                ],
                "type": "str"
            }
        }
    },
    "dvmdb_upgrade": {
        "stated": true,
        "options": {
            "scope member": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "dvmdb_workflow_approve": {
        "stated": true,
        "options": {
            "desc": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "dvmdb_workflow_discard": {
        "stated": true,
        "options": {}
    },
    "dvmdb_workflow_drop": {
        "stated": true,
        "options": {}
    },
    "dvmdb_workflow_reject": {
        "stated": true,
        "options": {
            "desc": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "dvmdb_workflow_repair": {
        "stated": true,
        "options": {
            "desc": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "dvmdb_workflow_revert": {
        "stated": true,
        "options": {
            "desc": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "fmgip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "mail_user": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "no_diff": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "no_mail": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "dvmdb_workflow_review": {
        "stated": true,
        "options": {}
    },
    "dvmdb_workflow_save": {
        "stated": true,
        "options": {}
    },
    "dvmdb_workflow_start": {
        "stated": true,
        "options": {
            "desc": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "dvmdb_workflow_submit": {
        "stated": true,
        "options": {
            "desc": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "fmgip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "mail_user": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "no_diff": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "no_mail": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "dvmdb_workspace_commit": {
        "stated": true,
        "options": {}
    },
    "dvmdb_workspace_commit_dev": {
        "stated": true,
        "options": {}
    },
    "dvmdb_workspace_commit_obj": {
        "stated": true,
        "options": {}
    },
    "dvmdb_workspace_commit_pkg": {
        "stated": true,
        "options": {}
    },
    "dvmdb_workspace_lock": {
        "stated": true,
        "options": {}
    },
    "dvmdb_workspace_lock_dev": {
        "stated": true,
        "options": {}
    },
    "dvmdb_workspace_lock_obj": {
        "stated": true,
        "options": {}
    },
    "dvmdb_workspace_lock_pkg": {
        "stated": true,
        "options": {}
    },
    "dvmdb_workspace_unlock": {
        "stated": true,
        "options": {}
    },
    "dvmdb_workspace_unlock_dev": {
        "stated": true,
        "options": {}
    },
    "dvmdb_workspace_unlock_obj": {
        "stated": true,
        "options": {}
    },
    "dvmdb_workspace_unlock_pkg": {
        "stated": true,
        "options": {}
    },
    "dynamic_address": {
        "stated": true,
        "options": {
            "default": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "description": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dynamic_addr_mapping": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "addr": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "dynamic_address_dynamicaddrmapping": {
        "stated": true,
        "options": {
            "addr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "dynamic_certificate_local": {
        "stated": true,
        "options": {
            "description": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dynamic_mapping": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "_scope": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "vdom": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "local-cert": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "dynamic_certificate_local_dynamicmapping": {
        "stated": true,
        "options": {
            "_scope": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "local-cert": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "dynamic_input_interface": {
        "stated": true,
        "options": {
            "default-mapping": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "defmap-intf": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "description": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "dynamic_mapping": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "_scope": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "list",
                        "options": {
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": false,
                                    "6.4.2": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.0": false,
                                    "7.0.1": false,
                                    "7.0.2": false,
                                    "7.0.3": false,
                                    "7.0.4": false,
                                    "7.0.5": false,
                                    "7.0.6": false,
                                    "7.0.7": false,
                                    "7.0.8": false,
                                    "7.0.9": false,
                                    "7.2.0": false,
                                    "7.2.1": false,
                                    "7.2.2": false,
                                    "7.2.3": false,
                                    "7.2.4": false,
                                    "7.4.0": false,
                                    "7.4.1": false
                                },
                                "type": "str"
                            },
                            "vdom": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": false,
                                    "6.4.2": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.0": false,
                                    "7.0.1": false,
                                    "7.0.2": false,
                                    "7.0.3": false,
                                    "7.0.4": false,
                                    "7.0.5": false,
                                    "7.0.6": false,
                                    "7.0.7": false,
                                    "7.0.8": false,
                                    "7.0.9": false,
                                    "7.2.0": false,
                                    "7.2.1": false,
                                    "7.2.2": false,
                                    "7.2.3": false,
                                    "7.2.4": false,
                                    "7.4.0": false,
                                    "7.4.1": false
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "local-intf": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "skip-unmapped": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "dynamic_input_interface_dynamicmapping": {
        "stated": true,
        "options": {
            "_scope": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "local-intf": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "dynamic_interface": {
        "stated": true,
        "options": {
            "color": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "default-mapping": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "defmap-intf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "defmap-intrazone-deny": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "defmap-zonemember": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "description": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dynamic_mapping": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "_scope": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "vdom": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "egress-shaping-profile": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "intrazone-deny": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "local-intf": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "ingress-shaping-profile": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    }
                },
                "elements": "dict"
            },
            "egress-shaping-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "single-intf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ingress-shaping-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "platform_mapping": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "egress-shaping-profile": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "ingress-shaping-profile": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "intf-zone": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "intrazone-deny": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "wildcard": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "wildcard-intf": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "zone-only": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "dynamic_interface_dynamicmapping": {
        "stated": true,
        "options": {
            "_scope": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "egress-shaping-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "intrazone-deny": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "local-intf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ingress-shaping-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "dynamic_interface_platformmapping": {
        "stated": true,
        "options": {
            "egress-shaping-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ingress-shaping-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "intf-zone": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "intrazone-deny": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "dynamic_ippool": {
        "stated": true,
        "options": {
            "description": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "dynamic_multicast_interface": {
        "stated": true,
        "options": {
            "default-mapping": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "defmap-intf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "description": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dynamic_mapping": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "_scope": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "vdom": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "local-intf": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "zone-only": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "dynamic_multicast_interface_dynamicmapping": {
        "stated": true,
        "options": {
            "_scope": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "local-intf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "dynamic_vip": {
        "stated": true,
        "options": {
            "description": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "dynamic_virtualwanlink_members": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "cost": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "detect-failtime": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "detect-http-get": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "detect-http-match": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "detect-http-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "detect-interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "detect-protocol": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "ping",
                    "tcp-echo",
                    "udp-echo",
                    "http"
                ],
                "type": "str"
            },
            "detect-recoverytime": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "detect-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "detect-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "dynamic_mapping": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "_scope": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "list",
                        "options": {
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": false,
                                    "7.0.1": false,
                                    "7.0.2": false,
                                    "7.0.3": false,
                                    "7.0.4": false,
                                    "7.0.5": false,
                                    "7.0.6": false,
                                    "7.0.7": false,
                                    "7.0.8": false,
                                    "7.0.9": false,
                                    "7.2.0": false,
                                    "7.2.1": false,
                                    "7.2.2": false,
                                    "7.2.3": false,
                                    "7.2.4": false,
                                    "7.4.0": false,
                                    "7.4.1": false
                                },
                                "type": "str"
                            },
                            "vdom": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": false,
                                    "7.0.1": false,
                                    "7.0.2": false,
                                    "7.0.3": false,
                                    "7.0.4": false,
                                    "7.0.5": false,
                                    "7.0.6": false,
                                    "7.0.7": false,
                                    "7.0.8": false,
                                    "7.0.9": false,
                                    "7.2.0": false,
                                    "7.2.1": false,
                                    "7.2.2": false,
                                    "7.2.3": false,
                                    "7.2.4": false,
                                    "7.4.0": false,
                                    "7.4.1": false
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "comment": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "cost": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "detect-failtime": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "detect-http-get": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "detect-http-match": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "detect-http-port": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "detect-interval": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "detect-protocol": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "ping",
                            "tcp-echo",
                            "udp-echo",
                            "http"
                        ],
                        "type": "str"
                    },
                    "detect-recoverytime": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "detect-server": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "detect-timeout": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "gateway": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "gateway6": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "ingress-spillover-threshold": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "interface": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "priority": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "source": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "source6": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "spillover-threshold": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "volume-ratio": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "weight": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "gateway": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "gateway6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "ingress-spillover-threshold": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "interface": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "priority": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "source": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "source6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "spillover-threshold": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "volume-ratio": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "weight": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            }
        }
    },
    "dynamic_virtualwanlink_members_dynamicmapping": {
        "stated": true,
        "options": {
            "_scope": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "cost": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "detect-failtime": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "detect-http-get": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "detect-http-match": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "detect-http-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "detect-interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "detect-protocol": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "ping",
                    "tcp-echo",
                    "udp-echo",
                    "http"
                ],
                "type": "str"
            },
            "detect-recoverytime": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "detect-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "detect-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "gateway": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "gateway6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "ingress-spillover-threshold": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "interface": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "priority": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "source": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "source6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "spillover-threshold": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "volume-ratio": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "weight": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            }
        }
    },
    "dynamic_virtualwanlink_neighbor": {
        "stated": true,
        "options": {
            "description": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "dynamic_mapping": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "_scope": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "list",
                        "options": {
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": false,
                                    "7.0.1": false,
                                    "7.0.2": false,
                                    "7.0.3": false,
                                    "7.0.4": false,
                                    "7.0.5": false,
                                    "7.0.6": false,
                                    "7.0.7": false,
                                    "7.0.8": false,
                                    "7.0.9": false,
                                    "7.2.0": false,
                                    "7.2.1": false,
                                    "7.2.2": false,
                                    "7.2.3": false,
                                    "7.2.4": false,
                                    "7.4.0": false,
                                    "7.4.1": false
                                },
                                "type": "str"
                            },
                            "vdom": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": false,
                                    "7.0.1": false,
                                    "7.0.2": false,
                                    "7.0.3": false,
                                    "7.0.4": false,
                                    "7.0.5": false,
                                    "7.0.6": false,
                                    "7.0.7": false,
                                    "7.0.8": false,
                                    "7.0.9": false,
                                    "7.2.0": false,
                                    "7.2.1": false,
                                    "7.2.2": false,
                                    "7.2.3": false,
                                    "7.2.4": false,
                                    "7.4.0": false,
                                    "7.4.1": false
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "description": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "ip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "role": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "primary",
                            "secondary",
                            "standalone"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "role": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "primary",
                    "secondary",
                    "standalone"
                ],
                "type": "str"
            }
        }
    },
    "dynamic_virtualwanlink_neighbor_dynamicmapping": {
        "stated": true,
        "options": {
            "_scope": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "description": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "role": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "primary",
                    "secondary",
                    "standalone"
                ],
                "type": "str"
            }
        }
    },
    "dynamic_virtualwanlink_server": {
        "stated": true,
        "options": {
            "description": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "dynamic_mapping": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "_scope": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "list",
                        "options": {
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": false,
                                    "7.0.1": false,
                                    "7.0.2": false,
                                    "7.0.3": false,
                                    "7.0.4": false,
                                    "7.0.5": false,
                                    "7.0.6": false,
                                    "7.0.7": false,
                                    "7.0.8": false,
                                    "7.0.9": false,
                                    "7.2.0": false,
                                    "7.2.1": false,
                                    "7.2.2": false,
                                    "7.2.3": false,
                                    "7.2.4": false,
                                    "7.4.0": false,
                                    "7.4.1": false
                                },
                                "type": "str"
                            },
                            "vdom": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": false,
                                    "7.0.1": false,
                                    "7.0.2": false,
                                    "7.0.3": false,
                                    "7.0.4": false,
                                    "7.0.5": false,
                                    "7.0.6": false,
                                    "7.0.7": false,
                                    "7.0.8": false,
                                    "7.0.9": false,
                                    "7.2.0": false,
                                    "7.2.1": false,
                                    "7.2.2": false,
                                    "7.2.3": false,
                                    "7.2.4": false,
                                    "7.4.0": false,
                                    "7.4.1": false
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "server": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "raw"
                    }
                },
                "elements": "dict"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            }
        }
    },
    "dynamic_virtualwanlink_server_dynamicmapping": {
        "stated": true,
        "options": {
            "_scope": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            }
        }
    },
    "dynamic_vpntunnel": {
        "stated": true,
        "options": {
            "description": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dynamic_mapping": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "_scope": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "vdom": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "local-ipsec": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "dynamic_vpntunnel_dynamicmapping": {
        "stated": true,
        "options": {
            "_scope": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "local-ipsec": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "emailfilter_blockallowlist": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "entries": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "spam",
                            "clear",
                            "reject"
                        ],
                        "type": "str"
                    },
                    "addr-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ipv4",
                            "ipv6"
                        ],
                        "type": "str"
                    },
                    "email-pattern": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ip4-subnet": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ip6-subnet": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "pattern-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "wildcard",
                            "regexp"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ip",
                            "email",
                            "email-to",
                            "email-from",
                            "subject"
                        ],
                        "type": "str"
                    },
                    "pattern": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "emailfilter_blockallowlist_entries": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "spam",
                    "clear",
                    "reject"
                ],
                "type": "str"
            },
            "addr-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ipv4",
                    "ipv6"
                ],
                "type": "str"
            },
            "email-pattern": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip4-subnet": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ip6-subnet": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "pattern-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "wildcard",
                    "regexp"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ip",
                    "email",
                    "email-to",
                    "email-from",
                    "subject"
                ],
                "type": "str"
            },
            "pattern": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "emailfilter_bwl": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "entries": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "spam",
                            "clear",
                            "reject"
                        ],
                        "type": "str"
                    },
                    "addr-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ipv4",
                            "ipv6"
                        ],
                        "type": "str"
                    },
                    "email-pattern": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ip4-subnet": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ip6-subnet": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "pattern-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "wildcard",
                            "regexp"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ip",
                            "email"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "emailfilter_bwl_entries": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "spam",
                    "clear",
                    "reject"
                ],
                "type": "str"
            },
            "addr-type": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ipv4",
                    "ipv6"
                ],
                "type": "str"
            },
            "email-pattern": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip4-subnet": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ip6-subnet": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "pattern-type": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "wildcard",
                    "regexp"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ip",
                    "email"
                ],
                "type": "str"
            }
        }
    },
    "emailfilter_bword": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "entries": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "spam",
                            "clear"
                        ],
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "language": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "western",
                            "simch",
                            "trach",
                            "japanese",
                            "korean",
                            "french",
                            "thai",
                            "spanish"
                        ],
                        "type": "str"
                    },
                    "pattern": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "pattern-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "wildcard",
                            "regexp"
                        ],
                        "type": "str"
                    },
                    "score": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "where": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "all",
                            "subject",
                            "body"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "emailfilter_bword_entries": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "spam",
                    "clear"
                ],
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "language": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "western",
                    "simch",
                    "trach",
                    "japanese",
                    "korean",
                    "french",
                    "thai",
                    "spanish"
                ],
                "type": "str"
            },
            "pattern": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "pattern-type": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "wildcard",
                    "regexp"
                ],
                "type": "str"
            },
            "score": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "where": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "all",
                    "subject",
                    "body"
                ],
                "type": "str"
            }
        }
    },
    "emailfilter_dnsbl": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "entries": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "spam",
                            "reject"
                        ],
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "server": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "emailfilter_dnsbl_entries": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "spam",
                    "reject"
                ],
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "server": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "emailfilter_fortishield": {
        "stated": false,
        "options": {
            "spam-submit-force": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "spam-submit-srv": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "spam-submit-txt2htm": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "emailfilter_iptrust": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "entries": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "addr-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ipv4",
                            "ipv6"
                        ],
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ip4-subnet": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ip6-subnet": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "emailfilter_iptrust_entries": {
        "stated": true,
        "options": {
            "addr-type": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ipv4",
                    "ipv6"
                ],
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip4-subnet": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ip6-subnet": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "emailfilter_mheader": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "entries": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "spam",
                            "clear"
                        ],
                        "type": "str"
                    },
                    "fieldbody": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "fieldname": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "pattern-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "wildcard",
                            "regexp"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "emailfilter_mheader_entries": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "spam",
                    "clear"
                ],
                "type": "str"
            },
            "fieldbody": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "fieldname": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "pattern-type": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "wildcard",
                    "regexp"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "emailfilter_options": {
        "stated": false,
        "options": {
            "dns-timeout": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "emailfilter_profile": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "external": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "options": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "bannedword",
                    "spambwl",
                    "spamfsip",
                    "spamfssubmit",
                    "spamfschksum",
                    "spamfsurl",
                    "spamhelodns",
                    "spamraddrdns",
                    "spamrbl",
                    "spamhdrcheck",
                    "spamfsphish",
                    "spambal",
                    "spamfgip",
                    "spamfgsubmit",
                    "spamfgchksum",
                    "spamfgurl",
                    "spamfgphish"
                ],
                "elements": "str"
            },
            "replacemsg-group": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "spam-bwl-table": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "spam-bword-table": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "spam-bword-threshold": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "spam-filtering": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "spam-iptrust-table": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "spam-log": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "spam-log-fortiguard-response": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "spam-mheader-table": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "spam-rbl-table": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "feature-set": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "proxy",
                    "flow"
                ],
                "type": "str"
            },
            "gmail": {
                "required": false,
                "type": "dict",
                "options": {
                    "log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "log-all": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "imap": {
                "required": false,
                "type": "dict",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "pass",
                            "tag"
                        ],
                        "type": "str"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "log-all": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "tag-msg": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "tag-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "subject",
                            "header",
                            "spaminfo"
                        ],
                        "elements": "str"
                    }
                }
            },
            "mapi": {
                "required": false,
                "type": "dict",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "pass",
                            "discard"
                        ],
                        "type": "str"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "log-all": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "msn-hotmail": {
                "required": false,
                "type": "dict",
                "options": {
                    "log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "log-all": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "other-webmails": {
                "required": false,
                "type": "dict",
                "options": {
                    "log-all": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "pop3": {
                "required": false,
                "type": "dict",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "pass",
                            "tag"
                        ],
                        "type": "str"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "log-all": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "tag-msg": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "tag-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "subject",
                            "header",
                            "spaminfo"
                        ],
                        "elements": "str"
                    }
                }
            },
            "smtp": {
                "required": false,
                "type": "dict",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "pass",
                            "tag",
                            "discard"
                        ],
                        "type": "str"
                    },
                    "hdrip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "local-override": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "log-all": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "tag-msg": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "tag-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "subject",
                            "header",
                            "spaminfo"
                        ],
                        "elements": "str"
                    }
                }
            },
            "file-filter": {
                "required": false,
                "type": "dict",
                "options": {
                    "entries": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "action": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "log",
                                    "block"
                                ],
                                "type": "str"
                            },
                            "comment": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "encryption": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": false,
                                    "7.2.2": false,
                                    "7.2.3": false,
                                    "7.2.4": false,
                                    "7.4.0": false,
                                    "7.4.1": false
                                },
                                "choices": [
                                    "any",
                                    "yes"
                                ],
                                "type": "str"
                            },
                            "file-type": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            },
                            "filter": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "password-protected": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "any",
                                    "yes"
                                ],
                                "type": "str"
                            },
                            "protocol": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "choices": [
                                    "smtp",
                                    "imap",
                                    "pop3"
                                ],
                                "elements": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "scan-archive-contents": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "spam-bal-table": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "emailfilter_profile_filefilter": {
        "stated": false,
        "options": {
            "entries": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "log",
                            "block"
                        ],
                        "type": "str"
                    },
                    "comment": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "encryption": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "any",
                            "yes"
                        ],
                        "type": "str"
                    },
                    "file-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "filter": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "password-protected": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "any",
                            "yes"
                        ],
                        "type": "str"
                    },
                    "protocol": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "smtp",
                            "imap",
                            "pop3"
                        ],
                        "elements": "str"
                    }
                },
                "elements": "dict"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "scan-archive-contents": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "emailfilter_profile_filefilter_entries": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "log",
                    "block"
                ],
                "type": "str"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "encryption": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "any",
                    "yes"
                ],
                "type": "str"
            },
            "file-type": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "filter": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "password-protected": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "any",
                    "yes"
                ],
                "type": "str"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "smtp",
                    "imap",
                    "pop3"
                ],
                "elements": "str"
            }
        }
    },
    "emailfilter_profile_gmail": {
        "stated": false,
        "options": {
            "log": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "log-all": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "emailfilter_profile_imap": {
        "stated": false,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "tag"
                ],
                "type": "str"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tag-msg": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tag-type": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "subject",
                    "header",
                    "spaminfo"
                ],
                "elements": "str"
            },
            "log-all": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "emailfilter_profile_mapi": {
        "stated": false,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "discard"
                ],
                "type": "str"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "log-all": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "emailfilter_profile_msnhotmail": {
        "stated": false,
        "options": {
            "log": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "log-all": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "emailfilter_profile_otherwebmails": {
        "stated": false,
        "options": {
            "log-all": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "emailfilter_profile_pop3": {
        "stated": false,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "tag"
                ],
                "type": "str"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tag-msg": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tag-type": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "subject",
                    "header",
                    "spaminfo"
                ],
                "elements": "str"
            },
            "log-all": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "emailfilter_profile_smtp": {
        "stated": false,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "tag",
                    "discard"
                ],
                "type": "str"
            },
            "hdrip": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "local-override": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tag-msg": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tag-type": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "subject",
                    "header",
                    "spaminfo"
                ],
                "elements": "str"
            },
            "log-all": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "emailfilter_profile_yahoomail": {
        "stated": false,
        "options": {
            "log": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "endpointcontrol_fctems": {
        "stated": true,
        "options": {
            "call-timeout": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "capabilities": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "fabric-auth",
                    "silent-approval",
                    "websocket",
                    "websocket-malware",
                    "push-ca-certs",
                    "common-tags-api",
                    "tenant-id",
                    "single-vdom-connector",
                    "client-avatars"
                ],
                "elements": "str"
            },
            "certificate-fingerprint": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cloud-server-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "production",
                    "alpha",
                    "beta"
                ],
                "type": "str"
            },
            "fortinetone-cloud-authentication": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "https-port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "out-of-sync-threshold": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "preserve-ssl-session": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "pull-avatars": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "pull-malware-hash": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "pull-sysinfo": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "pull-tags": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "pull-vulnerabilities": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "server": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "source-ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "websocket-override": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "status-check-interval": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "certificate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "admin-username": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "serial-number": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "admin-password": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "interface": {
                "required": false,
                "revision": {
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "interface-select-method": {
                "required": false,
                "revision": {
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auto",
                    "sdwan",
                    "specify"
                ],
                "type": "str"
            },
            "dirty-reason": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "mismatched-ems-sn"
                ],
                "type": "str"
            },
            "ems-id": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ca-cn-info": {
                "required": false,
                "revision": {
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "trust-ca-cn": {
                "required": false,
                "revision": {
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tenant-id": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "exec_fgfm_reclaimdevtunnel": {
        "stated": true,
        "options": {
            "flags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "force",
                    "get_info"
                ],
                "elements": "str"
            }
        }
    },
    "extendercontroller_dataplan": {
        "stated": true,
        "options": {
            "apn": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "auth-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "pap",
                    "chap"
                ],
                "type": "str"
            },
            "billing-date": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "capacity": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "carrier": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "iccid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "modem-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "all",
                    "modem1",
                    "modem2"
                ],
                "type": "str"
            },
            "monthly-fee": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "overage": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "password": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "pdn": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ipv4-only",
                    "ipv6-only",
                    "ipv4-ipv6"
                ],
                "type": "str"
            },
            "preferred-subnet": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "private-network": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "signal-period": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "signal-threshold": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "slot": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "sim1",
                    "sim2"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "carrier",
                    "slot",
                    "iccid",
                    "generic"
                ],
                "type": "str"
            },
            "username": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "extendercontroller_extenderprofile": {
        "stated": true,
        "options": {
            "allowaccess": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "https",
                    "ping",
                    "ssh",
                    "snmp",
                    "http",
                    "telnet"
                ],
                "elements": "str"
            },
            "bandwidth-limit": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "cellular": {
                "required": false,
                "type": "dict",
                "options": {
                    "controller-report": {
                        "required": false,
                        "type": "dict",
                        "options": {
                            "interval": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "signal-threshold": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "status": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            }
                        }
                    },
                    "dataplan": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "modem1": {
                        "required": false,
                        "type": "dict",
                        "options": {
                            "auto-switch": {
                                "required": false,
                                "type": "dict",
                                "options": {
                                    "dataplan": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": false,
                                            "6.2.9": false,
                                            "6.2.10": false,
                                            "6.2.11": false,
                                            "6.2.12": false,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.6": false,
                                            "6.4.7": false,
                                            "6.4.8": false,
                                            "6.4.9": false,
                                            "6.4.10": false,
                                            "6.4.11": false,
                                            "6.4.12": false,
                                            "6.4.13": false,
                                            "7.0.1": false,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "disconnect": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": false,
                                            "6.2.9": false,
                                            "6.2.10": false,
                                            "6.2.11": false,
                                            "6.2.12": false,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.6": false,
                                            "6.4.7": false,
                                            "6.4.8": false,
                                            "6.4.9": false,
                                            "6.4.10": false,
                                            "6.4.11": false,
                                            "6.4.12": false,
                                            "6.4.13": false,
                                            "7.0.1": false,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "disconnect-period": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": false,
                                            "6.2.9": false,
                                            "6.2.10": false,
                                            "6.2.11": false,
                                            "6.2.12": false,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.6": false,
                                            "6.4.7": false,
                                            "6.4.8": false,
                                            "6.4.9": false,
                                            "6.4.10": false,
                                            "6.4.11": false,
                                            "6.4.12": false,
                                            "6.4.13": false,
                                            "7.0.1": false,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "disconnect-threshold": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": false,
                                            "6.2.9": false,
                                            "6.2.10": false,
                                            "6.2.11": false,
                                            "6.2.12": false,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.6": false,
                                            "6.4.7": false,
                                            "6.4.8": false,
                                            "6.4.9": false,
                                            "6.4.10": false,
                                            "6.4.11": false,
                                            "6.4.12": false,
                                            "6.4.13": false,
                                            "7.0.1": false,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "signal": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": false,
                                            "6.2.9": false,
                                            "6.2.10": false,
                                            "6.2.11": false,
                                            "6.2.12": false,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.6": false,
                                            "6.4.7": false,
                                            "6.4.8": false,
                                            "6.4.9": false,
                                            "6.4.10": false,
                                            "6.4.11": false,
                                            "6.4.12": false,
                                            "6.4.13": false,
                                            "7.0.1": false,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "switch-back": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": false,
                                            "6.2.9": false,
                                            "6.2.10": false,
                                            "6.2.11": false,
                                            "6.2.12": false,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.6": false,
                                            "6.4.7": false,
                                            "6.4.8": false,
                                            "6.4.9": false,
                                            "6.4.10": false,
                                            "6.4.11": false,
                                            "6.4.12": false,
                                            "6.4.13": false,
                                            "7.0.1": false,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "list",
                                        "choices": [
                                            "time",
                                            "timer"
                                        ],
                                        "elements": "str"
                                    },
                                    "switch-back-time": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": false,
                                            "6.2.9": false,
                                            "6.2.10": false,
                                            "6.2.11": false,
                                            "6.2.12": false,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.6": false,
                                            "6.4.7": false,
                                            "6.4.8": false,
                                            "6.4.9": false,
                                            "6.4.10": false,
                                            "6.4.11": false,
                                            "6.4.12": false,
                                            "6.4.13": false,
                                            "7.0.1": false,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "switch-back-timer": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": false,
                                            "6.2.9": false,
                                            "6.2.10": false,
                                            "6.2.11": false,
                                            "6.2.12": false,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.6": false,
                                            "6.4.7": false,
                                            "6.4.8": false,
                                            "6.4.9": false,
                                            "6.4.10": false,
                                            "6.4.11": false,
                                            "6.4.12": false,
                                            "6.4.13": false,
                                            "7.0.1": false,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    }
                                }
                            },
                            "conn-status": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "default-sim": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "sim1",
                                    "sim2",
                                    "carrier",
                                    "cost"
                                ],
                                "type": "str"
                            },
                            "gps": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "modem-id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "preferred-carrier": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "redundant-intf": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "redundant-mode": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "sim1-pin": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "sim1-pin-code": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            },
                            "sim2-pin": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "sim2-pin-code": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            }
                        }
                    },
                    "modem2": {
                        "required": false,
                        "type": "dict",
                        "options": {
                            "auto-switch": {
                                "required": false,
                                "type": "dict",
                                "options": {
                                    "dataplan": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": false,
                                            "6.2.9": false,
                                            "6.2.10": false,
                                            "6.2.11": false,
                                            "6.2.12": false,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.6": false,
                                            "6.4.7": false,
                                            "6.4.8": false,
                                            "6.4.9": false,
                                            "6.4.10": false,
                                            "6.4.11": false,
                                            "6.4.12": false,
                                            "6.4.13": false,
                                            "7.0.1": false,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "disconnect": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": false,
                                            "6.2.9": false,
                                            "6.2.10": false,
                                            "6.2.11": false,
                                            "6.2.12": false,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.6": false,
                                            "6.4.7": false,
                                            "6.4.8": false,
                                            "6.4.9": false,
                                            "6.4.10": false,
                                            "6.4.11": false,
                                            "6.4.12": false,
                                            "6.4.13": false,
                                            "7.0.1": false,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "disconnect-period": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": false,
                                            "6.2.9": false,
                                            "6.2.10": false,
                                            "6.2.11": false,
                                            "6.2.12": false,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.6": false,
                                            "6.4.7": false,
                                            "6.4.8": false,
                                            "6.4.9": false,
                                            "6.4.10": false,
                                            "6.4.11": false,
                                            "6.4.12": false,
                                            "6.4.13": false,
                                            "7.0.1": false,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "disconnect-threshold": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": false,
                                            "6.2.9": false,
                                            "6.2.10": false,
                                            "6.2.11": false,
                                            "6.2.12": false,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.6": false,
                                            "6.4.7": false,
                                            "6.4.8": false,
                                            "6.4.9": false,
                                            "6.4.10": false,
                                            "6.4.11": false,
                                            "6.4.12": false,
                                            "6.4.13": false,
                                            "7.0.1": false,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "signal": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": false,
                                            "6.2.9": false,
                                            "6.2.10": false,
                                            "6.2.11": false,
                                            "6.2.12": false,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.6": false,
                                            "6.4.7": false,
                                            "6.4.8": false,
                                            "6.4.9": false,
                                            "6.4.10": false,
                                            "6.4.11": false,
                                            "6.4.12": false,
                                            "6.4.13": false,
                                            "7.0.1": false,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "switch-back": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": false,
                                            "6.2.9": false,
                                            "6.2.10": false,
                                            "6.2.11": false,
                                            "6.2.12": false,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.6": false,
                                            "6.4.7": false,
                                            "6.4.8": false,
                                            "6.4.9": false,
                                            "6.4.10": false,
                                            "6.4.11": false,
                                            "6.4.12": false,
                                            "6.4.13": false,
                                            "7.0.1": false,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "list",
                                        "choices": [
                                            "time",
                                            "timer"
                                        ],
                                        "elements": "str"
                                    },
                                    "switch-back-time": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": false,
                                            "6.2.9": false,
                                            "6.2.10": false,
                                            "6.2.11": false,
                                            "6.2.12": false,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.6": false,
                                            "6.4.7": false,
                                            "6.4.8": false,
                                            "6.4.9": false,
                                            "6.4.10": false,
                                            "6.4.11": false,
                                            "6.4.12": false,
                                            "6.4.13": false,
                                            "7.0.1": false,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "switch-back-timer": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": false,
                                            "6.2.9": false,
                                            "6.2.10": false,
                                            "6.2.11": false,
                                            "6.2.12": false,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.6": false,
                                            "6.4.7": false,
                                            "6.4.8": false,
                                            "6.4.9": false,
                                            "6.4.10": false,
                                            "6.4.11": false,
                                            "6.4.12": false,
                                            "6.4.13": false,
                                            "7.0.1": false,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    }
                                }
                            },
                            "conn-status": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "default-sim": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "sim1",
                                    "sim2",
                                    "carrier",
                                    "cost"
                                ],
                                "type": "str"
                            },
                            "gps": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "modem-id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "preferred-carrier": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "redundant-intf": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "redundant-mode": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "sim1-pin": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "sim1-pin-code": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            },
                            "sim2-pin": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "sim2-pin-code": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            }
                        }
                    },
                    "sms-notification": {
                        "required": false,
                        "type": "dict",
                        "options": {
                            "alert": {
                                "required": false,
                                "type": "dict",
                                "options": {
                                    "data-exhausted": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": false,
                                            "6.2.9": false,
                                            "6.2.10": false,
                                            "6.2.11": false,
                                            "6.2.12": false,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.6": false,
                                            "6.4.7": false,
                                            "6.4.8": false,
                                            "6.4.9": false,
                                            "6.4.10": false,
                                            "6.4.11": false,
                                            "6.4.12": false,
                                            "6.4.13": false,
                                            "7.0.1": false,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "fgt-backup-mode-switch": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": false,
                                            "6.2.9": false,
                                            "6.2.10": false,
                                            "6.2.11": false,
                                            "6.2.12": false,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.6": false,
                                            "6.4.7": false,
                                            "6.4.8": false,
                                            "6.4.9": false,
                                            "6.4.10": false,
                                            "6.4.11": false,
                                            "6.4.12": false,
                                            "6.4.13": false,
                                            "7.0.1": false,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "low-signal-strength": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": false,
                                            "6.2.9": false,
                                            "6.2.10": false,
                                            "6.2.11": false,
                                            "6.2.12": false,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.6": false,
                                            "6.4.7": false,
                                            "6.4.8": false,
                                            "6.4.9": false,
                                            "6.4.10": false,
                                            "6.4.11": false,
                                            "6.4.12": false,
                                            "6.4.13": false,
                                            "7.0.1": false,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "mode-switch": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": false,
                                            "6.2.9": false,
                                            "6.2.10": false,
                                            "6.2.11": false,
                                            "6.2.12": false,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.6": false,
                                            "6.4.7": false,
                                            "6.4.8": false,
                                            "6.4.9": false,
                                            "6.4.10": false,
                                            "6.4.11": false,
                                            "6.4.12": false,
                                            "6.4.13": false,
                                            "7.0.1": false,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "os-image-fallback": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": false,
                                            "6.2.9": false,
                                            "6.2.10": false,
                                            "6.2.11": false,
                                            "6.2.12": false,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.6": false,
                                            "6.4.7": false,
                                            "6.4.8": false,
                                            "6.4.9": false,
                                            "6.4.10": false,
                                            "6.4.11": false,
                                            "6.4.12": false,
                                            "6.4.13": false,
                                            "7.0.1": false,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "session-disconnect": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": false,
                                            "6.2.9": false,
                                            "6.2.10": false,
                                            "6.2.11": false,
                                            "6.2.12": false,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.6": false,
                                            "6.4.7": false,
                                            "6.4.8": false,
                                            "6.4.9": false,
                                            "6.4.10": false,
                                            "6.4.11": false,
                                            "6.4.12": false,
                                            "6.4.13": false,
                                            "7.0.1": false,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "system-reboot": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": false,
                                            "6.2.9": false,
                                            "6.2.10": false,
                                            "6.2.11": false,
                                            "6.2.12": false,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.6": false,
                                            "6.4.7": false,
                                            "6.4.8": false,
                                            "6.4.9": false,
                                            "6.4.10": false,
                                            "6.4.11": false,
                                            "6.4.12": false,
                                            "6.4.13": false,
                                            "7.0.1": false,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    }
                                }
                            },
                            "receiver": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "options": {
                                    "alert": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": false,
                                            "6.2.9": false,
                                            "6.2.10": false,
                                            "6.2.11": false,
                                            "6.2.12": false,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.6": false,
                                            "6.4.7": false,
                                            "6.4.8": false,
                                            "6.4.9": false,
                                            "6.4.10": false,
                                            "6.4.11": false,
                                            "6.4.12": false,
                                            "6.4.13": false,
                                            "7.0.1": false,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "list",
                                        "choices": [
                                            "system-reboot",
                                            "data-exhausted",
                                            "session-disconnect",
                                            "low-signal-strength",
                                            "mode-switch",
                                            "os-image-fallback",
                                            "fgt-backup-mode-switch"
                                        ],
                                        "elements": "str"
                                    },
                                    "name": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": false,
                                            "6.2.9": false,
                                            "6.2.10": false,
                                            "6.2.11": false,
                                            "6.2.12": false,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.6": false,
                                            "6.4.7": false,
                                            "6.4.8": false,
                                            "6.4.9": false,
                                            "6.4.10": false,
                                            "6.4.11": false,
                                            "6.4.12": false,
                                            "6.4.13": false,
                                            "7.0.1": false,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "phone-number": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": false,
                                            "6.2.9": false,
                                            "6.2.10": false,
                                            "6.2.11": false,
                                            "6.2.12": false,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.6": false,
                                            "6.4.7": false,
                                            "6.4.8": false,
                                            "6.4.9": false,
                                            "6.4.10": false,
                                            "6.4.11": false,
                                            "6.4.12": false,
                                            "6.4.13": false,
                                            "7.0.1": false,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "status": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": false,
                                            "6.2.9": false,
                                            "6.2.10": false,
                                            "6.2.11": false,
                                            "6.2.12": false,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.6": false,
                                            "6.4.7": false,
                                            "6.4.8": false,
                                            "6.4.9": false,
                                            "6.4.10": false,
                                            "6.4.11": false,
                                            "6.4.12": false,
                                            "6.4.13": false,
                                            "7.0.1": false,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    }
                                },
                                "elements": "dict"
                            },
                            "status": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            }
                        }
                    }
                }
            },
            "enforce-bandwidth": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "extension": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "wan-extension",
                    "lan-extension"
                ],
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "lan-extension": {
                "required": false,
                "type": "dict",
                "options": {
                    "backhaul": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "port": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "wan",
                                    "lte1",
                                    "lte2",
                                    "port1",
                                    "port2",
                                    "port3",
                                    "port4",
                                    "port5",
                                    "sfp"
                                ],
                                "type": "str"
                            },
                            "role": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "primary",
                                    "secondary"
                                ],
                                "type": "str"
                            },
                            "weight": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            }
                        },
                        "elements": "dict"
                    },
                    "backhaul-interface": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "backhaul-ip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ipsec-tunnel": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "link-loadbalance": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "activebackup",
                            "loadbalance"
                        ],
                        "type": "str"
                    }
                }
            },
            "login-password": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "login-password-change": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "no",
                    "yes",
                    "default"
                ],
                "type": "str"
            },
            "model": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "FX201E",
                    "FX211E",
                    "FX200F",
                    "FXA11F",
                    "FXE11F",
                    "FXA21F",
                    "FXE21F",
                    "FXA22F",
                    "FXE22F",
                    "FX212F",
                    "FX311F",
                    "FX312F",
                    "FX511F",
                    "FVG21F",
                    "FVA21F",
                    "FVG22F",
                    "FVA22F",
                    "FX04DA",
                    "FX04DN",
                    "FX04DI"
                ],
                "type": "str"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "extendercontroller_extenderprofile_cellular": {
        "stated": false,
        "options": {
            "controller-report": {
                "required": false,
                "type": "dict",
                "options": {
                    "interval": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "signal-threshold": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "dataplan": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "modem1": {
                "required": false,
                "type": "dict",
                "options": {
                    "auto-switch": {
                        "required": false,
                        "type": "dict",
                        "options": {
                            "dataplan": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "disconnect": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "disconnect-period": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "disconnect-threshold": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "signal": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "switch-back": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "choices": [
                                    "time",
                                    "timer"
                                ],
                                "elements": "str"
                            },
                            "switch-back-time": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "switch-back-timer": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            }
                        }
                    },
                    "conn-status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "default-sim": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "sim1",
                            "sim2",
                            "carrier",
                            "cost"
                        ],
                        "type": "str"
                    },
                    "gps": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "modem-id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "preferred-carrier": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "redundant-intf": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "redundant-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "sim1-pin": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "sim1-pin-code": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "sim2-pin": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "sim2-pin-code": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    }
                }
            },
            "modem2": {
                "required": false,
                "type": "dict",
                "options": {
                    "auto-switch": {
                        "required": false,
                        "type": "dict",
                        "options": {
                            "dataplan": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "disconnect": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "disconnect-period": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "disconnect-threshold": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "signal": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "switch-back": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "choices": [
                                    "time",
                                    "timer"
                                ],
                                "elements": "str"
                            },
                            "switch-back-time": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "switch-back-timer": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            }
                        }
                    },
                    "conn-status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "default-sim": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "sim1",
                            "sim2",
                            "carrier",
                            "cost"
                        ],
                        "type": "str"
                    },
                    "gps": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "modem-id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "preferred-carrier": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "redundant-intf": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "redundant-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "sim1-pin": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "sim1-pin-code": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "sim2-pin": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "sim2-pin-code": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    }
                }
            },
            "sms-notification": {
                "required": false,
                "type": "dict",
                "options": {
                    "alert": {
                        "required": false,
                        "type": "dict",
                        "options": {
                            "data-exhausted": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "fgt-backup-mode-switch": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "low-signal-strength": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "mode-switch": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "os-image-fallback": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "session-disconnect": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "system-reboot": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        }
                    },
                    "receiver": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "alert": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "choices": [
                                    "system-reboot",
                                    "data-exhausted",
                                    "session-disconnect",
                                    "low-signal-strength",
                                    "mode-switch",
                                    "os-image-fallback",
                                    "fgt-backup-mode-switch"
                                ],
                                "elements": "str"
                            },
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "phone-number": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "status": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            }
        }
    },
    "extendercontroller_extenderprofile_cellular_controllerreport": {
        "stated": false,
        "options": {
            "interval": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "signal-threshold": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "extendercontroller_extenderprofile_cellular_modem1": {
        "stated": false,
        "options": {
            "auto-switch": {
                "required": false,
                "type": "dict",
                "options": {
                    "dataplan": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "disconnect": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "disconnect-period": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "disconnect-threshold": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "signal": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "switch-back": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "time",
                            "timer"
                        ],
                        "elements": "str"
                    },
                    "switch-back-time": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "switch-back-timer": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                }
            },
            "conn-status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "default-sim": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "sim1",
                    "sim2",
                    "carrier",
                    "cost"
                ],
                "type": "str"
            },
            "gps": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "modem-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "preferred-carrier": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "redundant-intf": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "redundant-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sim1-pin": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sim1-pin-code": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "sim2-pin": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sim2-pin-code": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "extendercontroller_extenderprofile_cellular_modem1_autoswitch": {
        "stated": false,
        "options": {
            "dataplan": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "disconnect": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "disconnect-period": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "disconnect-threshold": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "signal": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "switch-back": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "time",
                    "timer"
                ],
                "elements": "str"
            },
            "switch-back-time": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "switch-back-timer": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "extendercontroller_extenderprofile_cellular_modem2": {
        "stated": false,
        "options": {
            "auto-switch": {
                "required": false,
                "type": "dict",
                "options": {
                    "dataplan": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "disconnect": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "disconnect-period": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "disconnect-threshold": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "signal": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "switch-back": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "time",
                            "timer"
                        ],
                        "elements": "str"
                    },
                    "switch-back-time": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "switch-back-timer": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                }
            },
            "conn-status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "default-sim": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "sim1",
                    "sim2",
                    "carrier",
                    "cost"
                ],
                "type": "str"
            },
            "gps": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "modem-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "preferred-carrier": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "redundant-intf": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "redundant-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sim1-pin": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sim1-pin-code": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "sim2-pin": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sim2-pin-code": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "extendercontroller_extenderprofile_cellular_modem2_autoswitch": {
        "stated": false,
        "options": {
            "dataplan": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "disconnect": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "disconnect-period": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "disconnect-threshold": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "signal": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "switch-back": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "time",
                    "timer"
                ],
                "elements": "str"
            },
            "switch-back-time": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "switch-back-timer": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "extendercontroller_extenderprofile_cellular_smsnotification": {
        "stated": false,
        "options": {
            "alert": {
                "required": false,
                "type": "dict",
                "options": {
                    "data-exhausted": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "fgt-backup-mode-switch": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "low-signal-strength": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "mode-switch": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "os-image-fallback": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "session-disconnect": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "system-reboot": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                }
            },
            "receiver": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "alert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "system-reboot",
                            "data-exhausted",
                            "session-disconnect",
                            "low-signal-strength",
                            "mode-switch",
                            "os-image-fallback",
                            "fgt-backup-mode-switch"
                        ],
                        "elements": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "phone-number": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "extendercontroller_extenderprofile_cellular_smsnotification_alert": {
        "stated": false,
        "options": {
            "data-exhausted": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "fgt-backup-mode-switch": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "low-signal-strength": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "mode-switch": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "os-image-fallback": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "session-disconnect": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "system-reboot": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "extendercontroller_extenderprofile_cellular_smsnotification_receiver": {
        "stated": true,
        "options": {
            "alert": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "system-reboot",
                    "data-exhausted",
                    "session-disconnect",
                    "low-signal-strength",
                    "mode-switch",
                    "os-image-fallback",
                    "fgt-backup-mode-switch"
                ],
                "elements": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "phone-number": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "extendercontroller_extenderprofile_lanextension": {
        "stated": false,
        "options": {
            "backhaul": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "port": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "wan",
                            "lte1",
                            "lte2",
                            "port1",
                            "port2",
                            "port3",
                            "port4",
                            "port5",
                            "sfp"
                        ],
                        "type": "str"
                    },
                    "role": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "primary",
                            "secondary"
                        ],
                        "type": "str"
                    },
                    "weight": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "backhaul-interface": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "backhaul-ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipsec-tunnel": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "link-loadbalance": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "activebackup",
                    "loadbalance"
                ],
                "type": "str"
            }
        }
    },
    "extendercontroller_extenderprofile_lanextension_backhaul": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "wan",
                    "lte1",
                    "lte2",
                    "port1",
                    "port2",
                    "port3",
                    "port4",
                    "port5",
                    "sfp"
                ],
                "type": "str"
            },
            "role": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "primary",
                    "secondary"
                ],
                "type": "str"
            },
            "weight": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "extendercontroller_simprofile": {
        "stated": true,
        "options": {
            "auto-switch_profile": {
                "required": false,
                "type": "dict",
                "options": {
                    "dataplan": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "disconnect": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "disconnect-period": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "disconnect-threshold": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "signal": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "switch-back": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "time",
                            "timer"
                        ],
                        "elements": "str"
                    },
                    "switch-back-time": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "switch-back-timer": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                }
            },
            "conn-status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "default-sim": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "sim1",
                    "sim2",
                    "carrier",
                    "cost"
                ],
                "type": "str"
            },
            "description": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "gps": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "modem-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "preferred-carrier": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "redundant-intf": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "redundant-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sim1-pin": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sim1-pin-code": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "sim2-pin": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sim2-pin-code": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "extendercontroller_simprofile_autoswitchprofile": {
        "stated": false,
        "options": {
            "dataplan": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "disconnect": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "disconnect-period": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "disconnect-threshold": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "signal": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "switch-back": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "time",
                    "timer"
                ],
                "elements": "str"
            },
            "switch-back-time": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "switch-back-timer": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "extendercontroller_template": {
        "stated": true,
        "options": {
            "dataplan": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "description": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "modem1_ifname": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "modem1_sim_profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "modem2_ifname": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "modem2_sim_profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "extensioncontroller_dataplan": {
        "stated": true,
        "options": {
            "apn": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "auth-type": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "pap",
                    "chap"
                ],
                "type": "str"
            },
            "billing-date": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "capacity": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "carrier": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "iccid": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "modem-id": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "all",
                    "modem1",
                    "modem2"
                ],
                "type": "str"
            },
            "monthly-fee": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": true,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "overage": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "password": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "pdn": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ipv4-only",
                    "ipv6-only",
                    "ipv4-ipv6"
                ],
                "type": "str"
            },
            "preferred-subnet": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "private-network": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "signal-period": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "signal-threshold": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "slot": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "sim1",
                    "sim2"
                ],
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "carrier",
                    "slot",
                    "iccid",
                    "generic"
                ],
                "type": "str"
            },
            "username": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "extensioncontroller_extenderprofile": {
        "stated": true,
        "options": {
            "allowaccess": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "https",
                    "ping",
                    "ssh",
                    "snmp",
                    "http",
                    "telnet"
                ],
                "elements": "str"
            },
            "bandwidth-limit": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "cellular": {
                "required": false,
                "type": "dict",
                "options": {
                    "controller-report": {
                        "required": false,
                        "type": "dict",
                        "options": {
                            "interval": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "signal-threshold": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "status": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            }
                        }
                    },
                    "dataplan": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "modem1": {
                        "required": false,
                        "type": "dict",
                        "options": {
                            "auto-switch": {
                                "required": false,
                                "type": "dict",
                                "options": {
                                    "dataplan": {
                                        "required": false,
                                        "revision": {
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "disconnect": {
                                        "required": false,
                                        "revision": {
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "disconnect-period": {
                                        "required": false,
                                        "revision": {
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "disconnect-threshold": {
                                        "required": false,
                                        "revision": {
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "signal": {
                                        "required": false,
                                        "revision": {
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "switch-back": {
                                        "required": false,
                                        "revision": {
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "list",
                                        "choices": [
                                            "time",
                                            "timer"
                                        ],
                                        "elements": "str"
                                    },
                                    "switch-back-time": {
                                        "required": false,
                                        "revision": {
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "switch-back-timer": {
                                        "required": false,
                                        "revision": {
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    }
                                }
                            },
                            "conn-status": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "default-sim": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "sim1",
                                    "sim2",
                                    "carrier",
                                    "cost"
                                ],
                                "type": "str"
                            },
                            "gps": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "modem-id": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "preferred-carrier": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "redundant-intf": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "redundant-mode": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "sim1-pin": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "sim1-pin-code": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            },
                            "sim2-pin": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "sim2-pin-code": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            }
                        }
                    },
                    "modem2": {
                        "required": false,
                        "type": "dict",
                        "options": {
                            "auto-switch": {
                                "required": false,
                                "type": "dict",
                                "options": {
                                    "dataplan": {
                                        "required": false,
                                        "revision": {
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "disconnect": {
                                        "required": false,
                                        "revision": {
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "disconnect-period": {
                                        "required": false,
                                        "revision": {
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "disconnect-threshold": {
                                        "required": false,
                                        "revision": {
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "signal": {
                                        "required": false,
                                        "revision": {
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "switch-back": {
                                        "required": false,
                                        "revision": {
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "list",
                                        "choices": [
                                            "time",
                                            "timer"
                                        ],
                                        "elements": "str"
                                    },
                                    "switch-back-time": {
                                        "required": false,
                                        "revision": {
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "switch-back-timer": {
                                        "required": false,
                                        "revision": {
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    }
                                }
                            },
                            "conn-status": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "default-sim": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "sim1",
                                    "sim2",
                                    "carrier",
                                    "cost"
                                ],
                                "type": "str"
                            },
                            "gps": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "modem-id": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "preferred-carrier": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "redundant-intf": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "redundant-mode": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "sim1-pin": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "sim1-pin-code": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            },
                            "sim2-pin": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "sim2-pin-code": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            }
                        }
                    },
                    "sms-notification": {
                        "required": false,
                        "type": "dict",
                        "options": {
                            "alert": {
                                "required": false,
                                "type": "dict",
                                "options": {
                                    "data-exhausted": {
                                        "required": false,
                                        "revision": {
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "fgt-backup-mode-switch": {
                                        "required": false,
                                        "revision": {
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "low-signal-strength": {
                                        "required": false,
                                        "revision": {
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "mode-switch": {
                                        "required": false,
                                        "revision": {
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "os-image-fallback": {
                                        "required": false,
                                        "revision": {
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "session-disconnect": {
                                        "required": false,
                                        "revision": {
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "system-reboot": {
                                        "required": false,
                                        "revision": {
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    }
                                }
                            },
                            "receiver": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "options": {
                                    "alert": {
                                        "required": false,
                                        "revision": {
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "list",
                                        "choices": [
                                            "system-reboot",
                                            "data-exhausted",
                                            "session-disconnect",
                                            "low-signal-strength",
                                            "mode-switch",
                                            "os-image-fallback",
                                            "fgt-backup-mode-switch"
                                        ],
                                        "elements": "str"
                                    },
                                    "name": {
                                        "required": false,
                                        "revision": {
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "phone-number": {
                                        "required": false,
                                        "revision": {
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "status": {
                                        "required": false,
                                        "revision": {
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    }
                                },
                                "elements": "dict"
                            },
                            "status": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            }
                        }
                    }
                }
            },
            "enforce-bandwidth": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "extension": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "wan-extension",
                    "lan-extension"
                ],
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "lan-extension": {
                "required": false,
                "type": "dict",
                "options": {
                    "backhaul": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "name": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "port": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "wan",
                                    "lte1",
                                    "lte2",
                                    "port1",
                                    "port2",
                                    "port3",
                                    "port4",
                                    "port5",
                                    "sfp"
                                ],
                                "type": "str"
                            },
                            "role": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "primary",
                                    "secondary"
                                ],
                                "type": "str"
                            },
                            "weight": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            }
                        },
                        "elements": "dict"
                    },
                    "backhaul-interface": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "backhaul-ip": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ipsec-tunnel": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "link-loadbalance": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "activebackup",
                            "loadbalance"
                        ],
                        "type": "str"
                    }
                }
            },
            "login-password": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "login-password-change": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "no",
                    "yes",
                    "default"
                ],
                "type": "str"
            },
            "model": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "FX201E",
                    "FX211E",
                    "FX200F",
                    "FXA11F",
                    "FXE11F",
                    "FXA21F",
                    "FXE21F",
                    "FXA22F",
                    "FXE22F",
                    "FX212F",
                    "FX311F",
                    "FX312F",
                    "FX511F",
                    "FVG21F",
                    "FVA21F",
                    "FVG22F",
                    "FVA22F",
                    "FX04DA",
                    "FX04DN",
                    "FX04DI"
                ],
                "type": "str"
            },
            "name": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "_is_factory_setting": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "ext"
                ],
                "type": "str"
            }
        }
    },
    "extensioncontroller_extenderprofile_cellular": {
        "stated": false,
        "options": {
            "controller-report": {
                "required": false,
                "type": "dict",
                "options": {
                    "interval": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "signal-threshold": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "dataplan": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "modem1": {
                "required": false,
                "type": "dict",
                "options": {
                    "auto-switch": {
                        "required": false,
                        "type": "dict",
                        "options": {
                            "dataplan": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "disconnect": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "disconnect-period": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "disconnect-threshold": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "signal": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "switch-back": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "choices": [
                                    "time",
                                    "timer"
                                ],
                                "elements": "str"
                            },
                            "switch-back-time": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "switch-back-timer": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            }
                        }
                    },
                    "conn-status": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "default-sim": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "sim1",
                            "sim2",
                            "carrier",
                            "cost"
                        ],
                        "type": "str"
                    },
                    "gps": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "modem-id": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "preferred-carrier": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "redundant-intf": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "redundant-mode": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "sim1-pin": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "sim1-pin-code": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "sim2-pin": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "sim2-pin-code": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    }
                }
            },
            "modem2": {
                "required": false,
                "type": "dict",
                "options": {
                    "auto-switch": {
                        "required": false,
                        "type": "dict",
                        "options": {
                            "dataplan": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "disconnect": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "disconnect-period": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "disconnect-threshold": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "signal": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "switch-back": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "choices": [
                                    "time",
                                    "timer"
                                ],
                                "elements": "str"
                            },
                            "switch-back-time": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "switch-back-timer": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            }
                        }
                    },
                    "conn-status": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "default-sim": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "sim1",
                            "sim2",
                            "carrier",
                            "cost"
                        ],
                        "type": "str"
                    },
                    "gps": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "modem-id": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "preferred-carrier": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "redundant-intf": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "redundant-mode": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "sim1-pin": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "sim1-pin-code": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "sim2-pin": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "sim2-pin-code": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    }
                }
            },
            "sms-notification": {
                "required": false,
                "type": "dict",
                "options": {
                    "alert": {
                        "required": false,
                        "type": "dict",
                        "options": {
                            "data-exhausted": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "fgt-backup-mode-switch": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "low-signal-strength": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "mode-switch": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "os-image-fallback": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "session-disconnect": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "system-reboot": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        }
                    },
                    "receiver": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "alert": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "choices": [
                                    "system-reboot",
                                    "data-exhausted",
                                    "session-disconnect",
                                    "low-signal-strength",
                                    "mode-switch",
                                    "os-image-fallback",
                                    "fgt-backup-mode-switch"
                                ],
                                "elements": "str"
                            },
                            "name": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "phone-number": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "status": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            }
        }
    },
    "extensioncontroller_extenderprofile_cellular_controllerreport": {
        "stated": false,
        "options": {
            "interval": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "signal-threshold": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "extensioncontroller_extenderprofile_cellular_modem1": {
        "stated": false,
        "options": {
            "auto-switch": {
                "required": false,
                "type": "dict",
                "options": {
                    "dataplan": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "disconnect": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "disconnect-period": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "disconnect-threshold": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "signal": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "switch-back": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "time",
                            "timer"
                        ],
                        "elements": "str"
                    },
                    "switch-back-time": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "switch-back-timer": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                }
            },
            "conn-status": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "default-sim": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "sim1",
                    "sim2",
                    "carrier",
                    "cost"
                ],
                "type": "str"
            },
            "gps": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "modem-id": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "preferred-carrier": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "redundant-intf": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "redundant-mode": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sim1-pin": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sim1-pin-code": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "sim2-pin": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sim2-pin-code": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "extensioncontroller_extenderprofile_cellular_modem1_autoswitch": {
        "stated": false,
        "options": {
            "dataplan": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "disconnect": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "disconnect-period": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "disconnect-threshold": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "signal": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "switch-back": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "time",
                    "timer"
                ],
                "elements": "str"
            },
            "switch-back-time": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "switch-back-timer": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "extensioncontroller_extenderprofile_cellular_modem2": {
        "stated": false,
        "options": {
            "auto-switch": {
                "required": false,
                "type": "dict",
                "options": {
                    "dataplan": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "disconnect": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "disconnect-period": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "disconnect-threshold": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "signal": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "switch-back": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "time",
                            "timer"
                        ],
                        "elements": "str"
                    },
                    "switch-back-time": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "switch-back-timer": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                }
            },
            "conn-status": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "default-sim": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "sim1",
                    "sim2",
                    "carrier",
                    "cost"
                ],
                "type": "str"
            },
            "gps": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "modem-id": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "preferred-carrier": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "redundant-intf": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "redundant-mode": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sim1-pin": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sim1-pin-code": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "sim2-pin": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sim2-pin-code": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "extensioncontroller_extenderprofile_cellular_modem2_autoswitch": {
        "stated": false,
        "options": {
            "dataplan": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "disconnect": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "disconnect-period": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "disconnect-threshold": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "signal": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "switch-back": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "time",
                    "timer"
                ],
                "elements": "str"
            },
            "switch-back-time": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "switch-back-timer": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "extensioncontroller_extenderprofile_cellular_smsnotification": {
        "stated": false,
        "options": {
            "alert": {
                "required": false,
                "type": "dict",
                "options": {
                    "data-exhausted": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "fgt-backup-mode-switch": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "low-signal-strength": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "mode-switch": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "os-image-fallback": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "session-disconnect": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "system-reboot": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                }
            },
            "receiver": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "alert": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "system-reboot",
                            "data-exhausted",
                            "session-disconnect",
                            "low-signal-strength",
                            "mode-switch",
                            "os-image-fallback",
                            "fgt-backup-mode-switch"
                        ],
                        "elements": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "phone-number": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "status": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "extensioncontroller_extenderprofile_cellular_smsnotification_alert": {
        "stated": false,
        "options": {
            "data-exhausted": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "fgt-backup-mode-switch": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "low-signal-strength": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "mode-switch": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "os-image-fallback": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "session-disconnect": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "system-reboot": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "extensioncontroller_extenderprofile_cellular_smsnotification_receiver": {
        "stated": true,
        "options": {
            "alert": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "system-reboot",
                    "data-exhausted",
                    "session-disconnect",
                    "low-signal-strength",
                    "mode-switch",
                    "os-image-fallback",
                    "fgt-backup-mode-switch"
                ],
                "elements": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "phone-number": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "extensioncontroller_extenderprofile_lanextension": {
        "stated": false,
        "options": {
            "backhaul": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "port": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "wan",
                            "lte1",
                            "lte2",
                            "port1",
                            "port2",
                            "port3",
                            "port4",
                            "port5",
                            "sfp"
                        ],
                        "type": "str"
                    },
                    "role": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "primary",
                            "secondary"
                        ],
                        "type": "str"
                    },
                    "weight": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "backhaul-interface": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "backhaul-ip": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipsec-tunnel": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "link-loadbalance": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "activebackup",
                    "loadbalance"
                ],
                "type": "str"
            }
        }
    },
    "extensioncontroller_extenderprofile_lanextension_backhaul": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "port": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "wan",
                    "lte1",
                    "lte2",
                    "port1",
                    "port2",
                    "port3",
                    "port4",
                    "port5",
                    "sfp"
                ],
                "type": "str"
            },
            "role": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "primary",
                    "secondary"
                ],
                "type": "str"
            },
            "weight": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "filefilter_profile": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "extended-log": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "feature-set": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "proxy",
                    "flow"
                ],
                "type": "str"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "replacemsg-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "rules": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "log-only",
                            "block"
                        ],
                        "type": "str"
                    },
                    "comment": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "direction": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "any",
                            "incoming",
                            "outgoing"
                        ],
                        "type": "str"
                    },
                    "file-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "password-protected": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "any",
                            "yes"
                        ],
                        "type": "str"
                    },
                    "protocol": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "imap",
                            "smtp",
                            "pop3",
                            "http",
                            "ftp",
                            "mapi",
                            "cifs",
                            "ssh"
                        ],
                        "elements": "str"
                    }
                },
                "elements": "dict"
            },
            "scan-archive-contents": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "filefilter_profile_rules": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "log-only",
                    "block"
                ],
                "type": "str"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "direction": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "any",
                    "incoming",
                    "outgoing"
                ],
                "type": "str"
            },
            "file-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "password-protected": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "any",
                    "yes"
                ],
                "type": "str"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "imap",
                    "smtp",
                    "pop3",
                    "http",
                    "ftp",
                    "mapi",
                    "cifs",
                    "ssh"
                ],
                "elements": "str"
            }
        }
    },
    "firewall_accessproxy": {
        "stated": true,
        "options": {
            "api-gateway": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "http-cookie-age": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "http-cookie-domain": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "http-cookie-domain-from-host": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "http-cookie-generation": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "http-cookie-path": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "http-cookie-share": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "same-ip"
                        ],
                        "type": "str"
                    },
                    "https-cookie-secure": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ldb-method": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "static",
                            "round-robin",
                            "weighted",
                            "least-session",
                            "least-rtt",
                            "first-alive",
                            "http-host"
                        ],
                        "type": "str"
                    },
                    "persistence": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "http-cookie"
                        ],
                        "type": "str"
                    },
                    "realservers": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "address": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "health-check": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "health-check-proto": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "ping",
                                    "http",
                                    "tcp-connect"
                                ],
                                "type": "str"
                            },
                            "http-host": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "ip": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "mappedport": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            },
                            "port": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "status": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "active",
                                    "standby",
                                    "disable"
                                ],
                                "type": "str"
                            },
                            "weight": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "addr-type": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "fqdn",
                                    "ip"
                                ],
                                "type": "str"
                            },
                            "domain": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": false,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "holddown-interval": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "ssh-client-cert": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "ssh-host-key": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "no_log": true,
                                "type": "raw"
                            },
                            "ssh-host-key-validation": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "type": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "tcp-forwarding",
                                    "ssh"
                                ],
                                "type": "str"
                            },
                            "translate-host": {
                                "required": false,
                                "revision": {
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "external-auth": {
                                "required": false,
                                "revision": {
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "tunnel-encryption": {
                                "required": false,
                                "revision": {
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "saml-server": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "service": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "http",
                            "https",
                            "tcp-forwarding",
                            "samlsp",
                            "web-portal",
                            "saas"
                        ],
                        "type": "str"
                    },
                    "ssl-algorithm": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "high",
                            "medium",
                            "low",
                            "custom"
                        ],
                        "type": "str"
                    },
                    "ssl-cipher-suites": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "cipher": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "TLS-RSA-WITH-RC4-128-MD5",
                                    "TLS-RSA-WITH-RC4-128-SHA",
                                    "TLS-RSA-WITH-DES-CBC-SHA",
                                    "TLS-RSA-WITH-3DES-EDE-CBC-SHA",
                                    "TLS-RSA-WITH-AES-128-CBC-SHA",
                                    "TLS-RSA-WITH-AES-256-CBC-SHA",
                                    "TLS-RSA-WITH-AES-128-CBC-SHA256",
                                    "TLS-RSA-WITH-AES-256-CBC-SHA256",
                                    "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA",
                                    "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA",
                                    "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                                    "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                                    "TLS-RSA-WITH-SEED-CBC-SHA",
                                    "TLS-RSA-WITH-ARIA-128-CBC-SHA256",
                                    "TLS-RSA-WITH-ARIA-256-CBC-SHA384",
                                    "TLS-DHE-RSA-WITH-DES-CBC-SHA",
                                    "TLS-DHE-RSA-WITH-3DES-EDE-CBC-SHA",
                                    "TLS-DHE-RSA-WITH-AES-128-CBC-SHA",
                                    "TLS-DHE-RSA-WITH-AES-256-CBC-SHA",
                                    "TLS-DHE-RSA-WITH-AES-128-CBC-SHA256",
                                    "TLS-DHE-RSA-WITH-AES-256-CBC-SHA256",
                                    "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA",
                                    "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA",
                                    "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                                    "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                                    "TLS-DHE-RSA-WITH-SEED-CBC-SHA",
                                    "TLS-DHE-RSA-WITH-ARIA-128-CBC-SHA256",
                                    "TLS-DHE-RSA-WITH-ARIA-256-CBC-SHA384",
                                    "TLS-ECDHE-RSA-WITH-RC4-128-SHA",
                                    "TLS-ECDHE-RSA-WITH-3DES-EDE-CBC-SHA",
                                    "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA",
                                    "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA",
                                    "TLS-ECDHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                                    "TLS-ECDHE-ECDSA-WITH-CHACHA20-POLY1305-SHA256",
                                    "TLS-DHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                                    "TLS-DHE-RSA-WITH-AES-128-GCM-SHA256",
                                    "TLS-DHE-RSA-WITH-AES-256-GCM-SHA384",
                                    "TLS-DHE-DSS-WITH-AES-128-CBC-SHA",
                                    "TLS-DHE-DSS-WITH-AES-256-CBC-SHA",
                                    "TLS-DHE-DSS-WITH-AES-128-CBC-SHA256",
                                    "TLS-DHE-DSS-WITH-AES-128-GCM-SHA256",
                                    "TLS-DHE-DSS-WITH-AES-256-CBC-SHA256",
                                    "TLS-DHE-DSS-WITH-AES-256-GCM-SHA384",
                                    "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA256",
                                    "TLS-ECDHE-RSA-WITH-AES-128-GCM-SHA256",
                                    "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA384",
                                    "TLS-ECDHE-RSA-WITH-AES-256-GCM-SHA384",
                                    "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA",
                                    "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA256",
                                    "TLS-ECDHE-ECDSA-WITH-AES-128-GCM-SHA256",
                                    "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA384",
                                    "TLS-ECDHE-ECDSA-WITH-AES-256-GCM-SHA384",
                                    "TLS-RSA-WITH-AES-128-GCM-SHA256",
                                    "TLS-RSA-WITH-AES-256-GCM-SHA384",
                                    "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA",
                                    "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA",
                                    "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA256",
                                    "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA256",
                                    "TLS-DHE-DSS-WITH-SEED-CBC-SHA",
                                    "TLS-DHE-DSS-WITH-ARIA-128-CBC-SHA256",
                                    "TLS-DHE-DSS-WITH-ARIA-256-CBC-SHA384",
                                    "TLS-ECDHE-RSA-WITH-ARIA-128-CBC-SHA256",
                                    "TLS-ECDHE-RSA-WITH-ARIA-256-CBC-SHA384",
                                    "TLS-ECDHE-ECDSA-WITH-ARIA-128-CBC-SHA256",
                                    "TLS-ECDHE-ECDSA-WITH-ARIA-256-CBC-SHA384",
                                    "TLS-DHE-DSS-WITH-3DES-EDE-CBC-SHA",
                                    "TLS-DHE-DSS-WITH-DES-CBC-SHA",
                                    "TLS-AES-128-GCM-SHA256",
                                    "TLS-AES-256-GCM-SHA384",
                                    "TLS-CHACHA20-POLY1305-SHA256",
                                    "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA"
                                ],
                                "type": "str"
                            },
                            "priority": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "versions": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "choices": [
                                    "tls-1.0",
                                    "tls-1.1",
                                    "tls-1.2",
                                    "tls-1.3"
                                ],
                                "elements": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "ssl-dh-bits": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "768",
                            "1024",
                            "1536",
                            "2048",
                            "3072",
                            "4096"
                        ],
                        "type": "str"
                    },
                    "ssl-max-version": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "tls-1.0",
                            "tls-1.1",
                            "tls-1.2",
                            "tls-1.3"
                        ],
                        "type": "str"
                    },
                    "ssl-min-version": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "tls-1.0",
                            "tls-1.1",
                            "tls-1.2",
                            "tls-1.3"
                        ],
                        "type": "str"
                    },
                    "url-map": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "url-map-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "sub-string",
                            "wildcard",
                            "regex"
                        ],
                        "type": "str"
                    },
                    "virtual-host": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "saml-redirect": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ssl-vpn-web-portal": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "application": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "ssl-renegotiation": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "h2-support": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "h3-support": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "quic": {
                        "required": false,
                        "type": "dict",
                        "options": {
                            "ack-delay-exponent": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "active-connection-id-limit": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "active-migration": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "grease-quic-bit": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "max-ack-delay": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "max-datagram-frame-size": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "max-idle-timeout": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "max-udp-payload-size": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "int"
                            }
                        }
                    }
                },
                "elements": "dict"
            },
            "client-cert": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "empty-cert-action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "block",
                    "accept",
                    "accept-unmanageable"
                ],
                "type": "str"
            },
            "ldb-method": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "static",
                    "round-robin",
                    "weighted",
                    "least-session",
                    "least-rtt",
                    "first-alive"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "realservers": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "port": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "active",
                            "standby",
                            "disable"
                        ],
                        "type": "str"
                    },
                    "weight": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "server-pubkey-auth": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "server-pubkey-auth-settings": {
                "required": false,
                "type": "dict",
                "options": {
                    "auth-ca": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "cert-extension": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "critical": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "no",
                                    "yes"
                                ],
                                "type": "str"
                            },
                            "data": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "type": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "fixed",
                                    "user"
                                ],
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "permit-agent-forwarding": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "permit-port-forwarding": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "permit-pty": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "permit-user-rc": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "permit-x11-forwarding": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "source-address": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "vip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "api-gateway6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "http-cookie-age": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "http-cookie-domain": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "http-cookie-domain-from-host": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "http-cookie-generation": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "http-cookie-path": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "http-cookie-share": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "same-ip"
                        ],
                        "type": "str"
                    },
                    "https-cookie-secure": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ldb-method": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "static",
                            "round-robin",
                            "weighted",
                            "first-alive",
                            "http-host"
                        ],
                        "type": "str"
                    },
                    "persistence": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "http-cookie"
                        ],
                        "type": "str"
                    },
                    "realservers": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "addr-type": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "fqdn",
                                    "ip"
                                ],
                                "type": "str"
                            },
                            "address": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "domain": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": false,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "health-check": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "health-check-proto": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "ping",
                                    "http",
                                    "tcp-connect"
                                ],
                                "type": "str"
                            },
                            "holddown-interval": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "http-host": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "ip": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "mappedport": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            },
                            "port": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "ssh-client-cert": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "ssh-host-key": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "no_log": true,
                                "type": "raw"
                            },
                            "ssh-host-key-validation": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "status": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "active",
                                    "standby",
                                    "disable"
                                ],
                                "type": "str"
                            },
                            "type": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "tcp-forwarding",
                                    "ssh"
                                ],
                                "type": "str"
                            },
                            "weight": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "translate-host": {
                                "required": false,
                                "revision": {
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "external-auth": {
                                "required": false,
                                "revision": {
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "tunnel-encryption": {
                                "required": false,
                                "revision": {
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "saml-redirect": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "saml-server": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "service": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "http",
                            "https",
                            "tcp-forwarding",
                            "samlsp",
                            "web-portal",
                            "saas"
                        ],
                        "type": "str"
                    },
                    "ssl-algorithm": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "high",
                            "medium",
                            "low"
                        ],
                        "type": "str"
                    },
                    "ssl-cipher-suites": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "cipher": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "TLS-RSA-WITH-RC4-128-MD5",
                                    "TLS-RSA-WITH-RC4-128-SHA",
                                    "TLS-RSA-WITH-DES-CBC-SHA",
                                    "TLS-RSA-WITH-3DES-EDE-CBC-SHA",
                                    "TLS-RSA-WITH-AES-128-CBC-SHA",
                                    "TLS-RSA-WITH-AES-256-CBC-SHA",
                                    "TLS-RSA-WITH-AES-128-CBC-SHA256",
                                    "TLS-RSA-WITH-AES-256-CBC-SHA256",
                                    "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA",
                                    "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA",
                                    "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                                    "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                                    "TLS-RSA-WITH-SEED-CBC-SHA",
                                    "TLS-RSA-WITH-ARIA-128-CBC-SHA256",
                                    "TLS-RSA-WITH-ARIA-256-CBC-SHA384",
                                    "TLS-DHE-RSA-WITH-DES-CBC-SHA",
                                    "TLS-DHE-RSA-WITH-3DES-EDE-CBC-SHA",
                                    "TLS-DHE-RSA-WITH-AES-128-CBC-SHA",
                                    "TLS-DHE-RSA-WITH-AES-256-CBC-SHA",
                                    "TLS-DHE-RSA-WITH-AES-128-CBC-SHA256",
                                    "TLS-DHE-RSA-WITH-AES-256-CBC-SHA256",
                                    "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA",
                                    "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA",
                                    "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                                    "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                                    "TLS-DHE-RSA-WITH-SEED-CBC-SHA",
                                    "TLS-DHE-RSA-WITH-ARIA-128-CBC-SHA256",
                                    "TLS-DHE-RSA-WITH-ARIA-256-CBC-SHA384",
                                    "TLS-ECDHE-RSA-WITH-RC4-128-SHA",
                                    "TLS-ECDHE-RSA-WITH-3DES-EDE-CBC-SHA",
                                    "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA",
                                    "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA",
                                    "TLS-ECDHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                                    "TLS-ECDHE-ECDSA-WITH-CHACHA20-POLY1305-SHA256",
                                    "TLS-DHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                                    "TLS-DHE-RSA-WITH-AES-128-GCM-SHA256",
                                    "TLS-DHE-RSA-WITH-AES-256-GCM-SHA384",
                                    "TLS-DHE-DSS-WITH-AES-128-CBC-SHA",
                                    "TLS-DHE-DSS-WITH-AES-256-CBC-SHA",
                                    "TLS-DHE-DSS-WITH-AES-128-CBC-SHA256",
                                    "TLS-DHE-DSS-WITH-AES-128-GCM-SHA256",
                                    "TLS-DHE-DSS-WITH-AES-256-CBC-SHA256",
                                    "TLS-DHE-DSS-WITH-AES-256-GCM-SHA384",
                                    "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA256",
                                    "TLS-ECDHE-RSA-WITH-AES-128-GCM-SHA256",
                                    "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA384",
                                    "TLS-ECDHE-RSA-WITH-AES-256-GCM-SHA384",
                                    "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA",
                                    "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA256",
                                    "TLS-ECDHE-ECDSA-WITH-AES-128-GCM-SHA256",
                                    "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA384",
                                    "TLS-ECDHE-ECDSA-WITH-AES-256-GCM-SHA384",
                                    "TLS-RSA-WITH-AES-128-GCM-SHA256",
                                    "TLS-RSA-WITH-AES-256-GCM-SHA384",
                                    "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA",
                                    "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA",
                                    "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA256",
                                    "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA256",
                                    "TLS-DHE-DSS-WITH-SEED-CBC-SHA",
                                    "TLS-DHE-DSS-WITH-ARIA-128-CBC-SHA256",
                                    "TLS-DHE-DSS-WITH-ARIA-256-CBC-SHA384",
                                    "TLS-ECDHE-RSA-WITH-ARIA-128-CBC-SHA256",
                                    "TLS-ECDHE-RSA-WITH-ARIA-256-CBC-SHA384",
                                    "TLS-ECDHE-ECDSA-WITH-ARIA-128-CBC-SHA256",
                                    "TLS-ECDHE-ECDSA-WITH-ARIA-256-CBC-SHA384",
                                    "TLS-DHE-DSS-WITH-3DES-EDE-CBC-SHA",
                                    "TLS-DHE-DSS-WITH-DES-CBC-SHA",
                                    "TLS-AES-128-GCM-SHA256",
                                    "TLS-AES-256-GCM-SHA384",
                                    "TLS-CHACHA20-POLY1305-SHA256",
                                    "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA"
                                ],
                                "type": "str"
                            },
                            "priority": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "versions": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "choices": [
                                    "tls-1.0",
                                    "tls-1.1",
                                    "tls-1.2",
                                    "tls-1.3"
                                ],
                                "elements": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "ssl-dh-bits": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "768",
                            "1024",
                            "1536",
                            "2048",
                            "3072",
                            "4096"
                        ],
                        "type": "str"
                    },
                    "ssl-max-version": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "tls-1.0",
                            "tls-1.1",
                            "tls-1.2",
                            "tls-1.3"
                        ],
                        "type": "str"
                    },
                    "ssl-min-version": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "tls-1.0",
                            "tls-1.1",
                            "tls-1.2",
                            "tls-1.3"
                        ],
                        "type": "str"
                    },
                    "ssl-vpn-web-portal": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "url-map": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "url-map-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "sub-string",
                            "wildcard",
                            "regex"
                        ],
                        "type": "str"
                    },
                    "virtual-host": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "application": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "ssl-renegotiation": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "h2-support": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "h3-support": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "quic": {
                        "required": false,
                        "type": "dict",
                        "options": {
                            "ack-delay-exponent": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "active-connection-id-limit": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "active-migration": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "grease-quic-bit": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "max-ack-delay": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "max-datagram-frame-size": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "max-idle-timeout": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "max-udp-payload-size": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "int"
                            }
                        }
                    }
                },
                "elements": "dict"
            },
            "auth-portal": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "auth-virtual-host": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "decrypted-traffic-mirror": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "log-blocked-traffic": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "add-vhost-domain-to-dnsdb": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "user-agent-detect": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "http-supported-max-version": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "http1",
                    "http2"
                ],
                "type": "str"
            },
            "svr-pool-multiplex": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "svr-pool-server-max-request": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "svr-pool-ttl": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "svr-pool-server-max-concurrent-request": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "firewall_accessproxy6": {
        "stated": true,
        "options": {
            "add-vhost-domain-to-dnsdb": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "api-gateway": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "application": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "http-cookie-age": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "http-cookie-domain": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "http-cookie-domain-from-host": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "http-cookie-generation": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "http-cookie-path": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "http-cookie-share": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "same-ip"
                        ],
                        "type": "str"
                    },
                    "https-cookie-secure": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ldb-method": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "static",
                            "round-robin",
                            "weighted",
                            "first-alive",
                            "http-host"
                        ],
                        "type": "str"
                    },
                    "persistence": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "http-cookie"
                        ],
                        "type": "str"
                    },
                    "realservers": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "addr-type": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "fqdn",
                                    "ip"
                                ],
                                "type": "str"
                            },
                            "address": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "domain": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "health-check": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "health-check-proto": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "ping",
                                    "http",
                                    "tcp-connect"
                                ],
                                "type": "str"
                            },
                            "holddown-interval": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "http-host": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "id": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "ip": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "mappedport": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            },
                            "port": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "ssh-client-cert": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "ssh-host-key": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "no_log": true,
                                "type": "raw"
                            },
                            "ssh-host-key-validation": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "status": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "active",
                                    "standby",
                                    "disable"
                                ],
                                "type": "str"
                            },
                            "type": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "tcp-forwarding",
                                    "ssh"
                                ],
                                "type": "str"
                            },
                            "weight": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "translate-host": {
                                "required": false,
                                "revision": {
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "external-auth": {
                                "required": false,
                                "revision": {
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "tunnel-encryption": {
                                "required": false,
                                "revision": {
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "saml-redirect": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "saml-server": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "service": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "http",
                            "https",
                            "tcp-forwarding",
                            "samlsp",
                            "web-portal",
                            "saas"
                        ],
                        "type": "str"
                    },
                    "ssl-algorithm": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "high",
                            "medium",
                            "low"
                        ],
                        "type": "str"
                    },
                    "ssl-cipher-suites": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "cipher": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "TLS-RSA-WITH-RC4-128-MD5",
                                    "TLS-RSA-WITH-RC4-128-SHA",
                                    "TLS-RSA-WITH-DES-CBC-SHA",
                                    "TLS-RSA-WITH-3DES-EDE-CBC-SHA",
                                    "TLS-RSA-WITH-AES-128-CBC-SHA",
                                    "TLS-RSA-WITH-AES-256-CBC-SHA",
                                    "TLS-RSA-WITH-AES-128-CBC-SHA256",
                                    "TLS-RSA-WITH-AES-256-CBC-SHA256",
                                    "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA",
                                    "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA",
                                    "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                                    "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                                    "TLS-RSA-WITH-SEED-CBC-SHA",
                                    "TLS-RSA-WITH-ARIA-128-CBC-SHA256",
                                    "TLS-RSA-WITH-ARIA-256-CBC-SHA384",
                                    "TLS-DHE-RSA-WITH-DES-CBC-SHA",
                                    "TLS-DHE-RSA-WITH-3DES-EDE-CBC-SHA",
                                    "TLS-DHE-RSA-WITH-AES-128-CBC-SHA",
                                    "TLS-DHE-RSA-WITH-AES-256-CBC-SHA",
                                    "TLS-DHE-RSA-WITH-AES-128-CBC-SHA256",
                                    "TLS-DHE-RSA-WITH-AES-256-CBC-SHA256",
                                    "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA",
                                    "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA",
                                    "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                                    "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                                    "TLS-DHE-RSA-WITH-SEED-CBC-SHA",
                                    "TLS-DHE-RSA-WITH-ARIA-128-CBC-SHA256",
                                    "TLS-DHE-RSA-WITH-ARIA-256-CBC-SHA384",
                                    "TLS-ECDHE-RSA-WITH-RC4-128-SHA",
                                    "TLS-ECDHE-RSA-WITH-3DES-EDE-CBC-SHA",
                                    "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA",
                                    "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA",
                                    "TLS-ECDHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                                    "TLS-ECDHE-ECDSA-WITH-CHACHA20-POLY1305-SHA256",
                                    "TLS-DHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                                    "TLS-DHE-RSA-WITH-AES-128-GCM-SHA256",
                                    "TLS-DHE-RSA-WITH-AES-256-GCM-SHA384",
                                    "TLS-DHE-DSS-WITH-AES-128-CBC-SHA",
                                    "TLS-DHE-DSS-WITH-AES-256-CBC-SHA",
                                    "TLS-DHE-DSS-WITH-AES-128-CBC-SHA256",
                                    "TLS-DHE-DSS-WITH-AES-128-GCM-SHA256",
                                    "TLS-DHE-DSS-WITH-AES-256-CBC-SHA256",
                                    "TLS-DHE-DSS-WITH-AES-256-GCM-SHA384",
                                    "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA256",
                                    "TLS-ECDHE-RSA-WITH-AES-128-GCM-SHA256",
                                    "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA384",
                                    "TLS-ECDHE-RSA-WITH-AES-256-GCM-SHA384",
                                    "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA",
                                    "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA256",
                                    "TLS-ECDHE-ECDSA-WITH-AES-128-GCM-SHA256",
                                    "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA384",
                                    "TLS-ECDHE-ECDSA-WITH-AES-256-GCM-SHA384",
                                    "TLS-RSA-WITH-AES-128-GCM-SHA256",
                                    "TLS-RSA-WITH-AES-256-GCM-SHA384",
                                    "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA",
                                    "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA",
                                    "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA256",
                                    "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA256",
                                    "TLS-DHE-DSS-WITH-SEED-CBC-SHA",
                                    "TLS-DHE-DSS-WITH-ARIA-128-CBC-SHA256",
                                    "TLS-DHE-DSS-WITH-ARIA-256-CBC-SHA384",
                                    "TLS-ECDHE-RSA-WITH-ARIA-128-CBC-SHA256",
                                    "TLS-ECDHE-RSA-WITH-ARIA-256-CBC-SHA384",
                                    "TLS-ECDHE-ECDSA-WITH-ARIA-128-CBC-SHA256",
                                    "TLS-ECDHE-ECDSA-WITH-ARIA-256-CBC-SHA384",
                                    "TLS-DHE-DSS-WITH-3DES-EDE-CBC-SHA",
                                    "TLS-DHE-DSS-WITH-DES-CBC-SHA",
                                    "TLS-AES-128-GCM-SHA256",
                                    "TLS-AES-256-GCM-SHA384",
                                    "TLS-CHACHA20-POLY1305-SHA256",
                                    "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA"
                                ],
                                "type": "str"
                            },
                            "priority": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "versions": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "choices": [
                                    "tls-1.0",
                                    "tls-1.1",
                                    "tls-1.2",
                                    "tls-1.3"
                                ],
                                "elements": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "ssl-dh-bits": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "768",
                            "1024",
                            "1536",
                            "2048",
                            "3072",
                            "4096"
                        ],
                        "type": "str"
                    },
                    "ssl-max-version": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "tls-1.0",
                            "tls-1.1",
                            "tls-1.2",
                            "tls-1.3"
                        ],
                        "type": "str"
                    },
                    "ssl-min-version": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "tls-1.0",
                            "tls-1.1",
                            "tls-1.2",
                            "tls-1.3"
                        ],
                        "type": "str"
                    },
                    "ssl-vpn-web-portal": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "url-map": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "url-map-type": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "sub-string",
                            "wildcard",
                            "regex"
                        ],
                        "type": "str"
                    },
                    "virtual-host": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ssl-renegotiation": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "h2-support": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "h3-support": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "quic": {
                        "required": false,
                        "type": "dict",
                        "options": {
                            "ack-delay-exponent": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "active-connection-id-limit": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "active-migration": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "grease-quic-bit": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "max-ack-delay": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "max-datagram-frame-size": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "max-idle-timeout": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "max-udp-payload-size": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "int"
                            }
                        }
                    }
                },
                "elements": "dict"
            },
            "api-gateway6": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "application": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "http-cookie-age": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "http-cookie-domain": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "http-cookie-domain-from-host": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "http-cookie-generation": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "http-cookie-path": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "http-cookie-share": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "same-ip"
                        ],
                        "type": "str"
                    },
                    "https-cookie-secure": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ldb-method": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "static",
                            "round-robin",
                            "weighted",
                            "first-alive",
                            "http-host"
                        ],
                        "type": "str"
                    },
                    "persistence": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "http-cookie"
                        ],
                        "type": "str"
                    },
                    "realservers": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "addr-type": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "fqdn",
                                    "ip"
                                ],
                                "type": "str"
                            },
                            "address": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "domain": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "health-check": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "health-check-proto": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "ping",
                                    "http",
                                    "tcp-connect"
                                ],
                                "type": "str"
                            },
                            "holddown-interval": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "http-host": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "id": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "ip": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "mappedport": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            },
                            "port": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "ssh-client-cert": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "ssh-host-key": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "no_log": true,
                                "type": "raw"
                            },
                            "ssh-host-key-validation": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "status": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "active",
                                    "standby",
                                    "disable"
                                ],
                                "type": "str"
                            },
                            "type": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "tcp-forwarding",
                                    "ssh"
                                ],
                                "type": "str"
                            },
                            "weight": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "translate-host": {
                                "required": false,
                                "revision": {
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "external-auth": {
                                "required": false,
                                "revision": {
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "tunnel-encryption": {
                                "required": false,
                                "revision": {
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "saml-redirect": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "saml-server": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "service": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "http",
                            "https",
                            "tcp-forwarding",
                            "samlsp",
                            "web-portal",
                            "saas"
                        ],
                        "type": "str"
                    },
                    "ssl-algorithm": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "high",
                            "medium",
                            "low"
                        ],
                        "type": "str"
                    },
                    "ssl-cipher-suites": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "cipher": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "TLS-RSA-WITH-RC4-128-MD5",
                                    "TLS-RSA-WITH-RC4-128-SHA",
                                    "TLS-RSA-WITH-DES-CBC-SHA",
                                    "TLS-RSA-WITH-3DES-EDE-CBC-SHA",
                                    "TLS-RSA-WITH-AES-128-CBC-SHA",
                                    "TLS-RSA-WITH-AES-256-CBC-SHA",
                                    "TLS-RSA-WITH-AES-128-CBC-SHA256",
                                    "TLS-RSA-WITH-AES-256-CBC-SHA256",
                                    "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA",
                                    "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA",
                                    "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                                    "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                                    "TLS-RSA-WITH-SEED-CBC-SHA",
                                    "TLS-RSA-WITH-ARIA-128-CBC-SHA256",
                                    "TLS-RSA-WITH-ARIA-256-CBC-SHA384",
                                    "TLS-DHE-RSA-WITH-DES-CBC-SHA",
                                    "TLS-DHE-RSA-WITH-3DES-EDE-CBC-SHA",
                                    "TLS-DHE-RSA-WITH-AES-128-CBC-SHA",
                                    "TLS-DHE-RSA-WITH-AES-256-CBC-SHA",
                                    "TLS-DHE-RSA-WITH-AES-128-CBC-SHA256",
                                    "TLS-DHE-RSA-WITH-AES-256-CBC-SHA256",
                                    "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA",
                                    "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA",
                                    "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                                    "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                                    "TLS-DHE-RSA-WITH-SEED-CBC-SHA",
                                    "TLS-DHE-RSA-WITH-ARIA-128-CBC-SHA256",
                                    "TLS-DHE-RSA-WITH-ARIA-256-CBC-SHA384",
                                    "TLS-ECDHE-RSA-WITH-RC4-128-SHA",
                                    "TLS-ECDHE-RSA-WITH-3DES-EDE-CBC-SHA",
                                    "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA",
                                    "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA",
                                    "TLS-ECDHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                                    "TLS-ECDHE-ECDSA-WITH-CHACHA20-POLY1305-SHA256",
                                    "TLS-DHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                                    "TLS-DHE-RSA-WITH-AES-128-GCM-SHA256",
                                    "TLS-DHE-RSA-WITH-AES-256-GCM-SHA384",
                                    "TLS-DHE-DSS-WITH-AES-128-CBC-SHA",
                                    "TLS-DHE-DSS-WITH-AES-256-CBC-SHA",
                                    "TLS-DHE-DSS-WITH-AES-128-CBC-SHA256",
                                    "TLS-DHE-DSS-WITH-AES-128-GCM-SHA256",
                                    "TLS-DHE-DSS-WITH-AES-256-CBC-SHA256",
                                    "TLS-DHE-DSS-WITH-AES-256-GCM-SHA384",
                                    "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA256",
                                    "TLS-ECDHE-RSA-WITH-AES-128-GCM-SHA256",
                                    "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA384",
                                    "TLS-ECDHE-RSA-WITH-AES-256-GCM-SHA384",
                                    "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA",
                                    "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA256",
                                    "TLS-ECDHE-ECDSA-WITH-AES-128-GCM-SHA256",
                                    "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA384",
                                    "TLS-ECDHE-ECDSA-WITH-AES-256-GCM-SHA384",
                                    "TLS-RSA-WITH-AES-128-GCM-SHA256",
                                    "TLS-RSA-WITH-AES-256-GCM-SHA384",
                                    "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA",
                                    "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA",
                                    "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA256",
                                    "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA256",
                                    "TLS-DHE-DSS-WITH-SEED-CBC-SHA",
                                    "TLS-DHE-DSS-WITH-ARIA-128-CBC-SHA256",
                                    "TLS-DHE-DSS-WITH-ARIA-256-CBC-SHA384",
                                    "TLS-ECDHE-RSA-WITH-ARIA-128-CBC-SHA256",
                                    "TLS-ECDHE-RSA-WITH-ARIA-256-CBC-SHA384",
                                    "TLS-ECDHE-ECDSA-WITH-ARIA-128-CBC-SHA256",
                                    "TLS-ECDHE-ECDSA-WITH-ARIA-256-CBC-SHA384",
                                    "TLS-DHE-DSS-WITH-3DES-EDE-CBC-SHA",
                                    "TLS-DHE-DSS-WITH-DES-CBC-SHA",
                                    "TLS-AES-128-GCM-SHA256",
                                    "TLS-AES-256-GCM-SHA384",
                                    "TLS-CHACHA20-POLY1305-SHA256",
                                    "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA"
                                ],
                                "type": "str"
                            },
                            "priority": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "versions": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "choices": [
                                    "tls-1.0",
                                    "tls-1.1",
                                    "tls-1.2",
                                    "tls-1.3"
                                ],
                                "elements": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "ssl-dh-bits": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "768",
                            "1024",
                            "1536",
                            "2048",
                            "3072",
                            "4096"
                        ],
                        "type": "str"
                    },
                    "ssl-max-version": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "tls-1.0",
                            "tls-1.1",
                            "tls-1.2",
                            "tls-1.3"
                        ],
                        "type": "str"
                    },
                    "ssl-min-version": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "tls-1.0",
                            "tls-1.1",
                            "tls-1.2",
                            "tls-1.3"
                        ],
                        "type": "str"
                    },
                    "ssl-vpn-web-portal": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "url-map": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "url-map-type": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "sub-string",
                            "wildcard",
                            "regex"
                        ],
                        "type": "str"
                    },
                    "virtual-host": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ssl-renegotiation": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "h2-support": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "h3-support": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "quic": {
                        "required": false,
                        "type": "dict",
                        "options": {
                            "ack-delay-exponent": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "active-connection-id-limit": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "active-migration": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "grease-quic-bit": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "max-ack-delay": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "max-datagram-frame-size": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "max-idle-timeout": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "max-udp-payload-size": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "int"
                            }
                        }
                    }
                },
                "elements": "dict"
            },
            "auth-portal": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "auth-virtual-host": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "client-cert": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "decrypted-traffic-mirror": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "empty-cert-action": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "block",
                    "accept",
                    "accept-unmanageable"
                ],
                "type": "str"
            },
            "log-blocked-traffic": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "user-agent-detect": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "vip": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "http-supported-max-version": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "http1",
                    "http2"
                ],
                "type": "str"
            },
            "svr-pool-multiplex": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "svr-pool-server-max-request": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "svr-pool-ttl": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "svr-pool-server-max-concurrent-request": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "firewall_accessproxy6_apigateway": {
        "stated": true,
        "options": {
            "application": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "http-cookie-age": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "http-cookie-domain": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "http-cookie-domain-from-host": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "http-cookie-generation": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "http-cookie-path": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "http-cookie-share": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "same-ip"
                ],
                "type": "str"
            },
            "https-cookie-secure": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ldb-method": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "static",
                    "round-robin",
                    "weighted",
                    "first-alive",
                    "http-host"
                ],
                "type": "str"
            },
            "persistence": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http-cookie"
                ],
                "type": "str"
            },
            "realservers": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "addr-type": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "fqdn",
                            "ip"
                        ],
                        "type": "str"
                    },
                    "address": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "domain": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "health-check": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "health-check-proto": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ping",
                            "http",
                            "tcp-connect"
                        ],
                        "type": "str"
                    },
                    "holddown-interval": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "http-host": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ip": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "mappedport": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "port": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ssh-client-cert": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ssh-host-key": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "ssh-host-key-validation": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "active",
                            "standby",
                            "disable"
                        ],
                        "type": "str"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "tcp-forwarding",
                            "ssh"
                        ],
                        "type": "str"
                    },
                    "weight": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "translate-host": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "external-auth": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "tunnel-encryption": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "saml-redirect": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "saml-server": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "service": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "http",
                    "https",
                    "tcp-forwarding",
                    "samlsp",
                    "web-portal",
                    "saas"
                ],
                "type": "str"
            },
            "ssl-algorithm": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "high",
                    "medium",
                    "low"
                ],
                "type": "str"
            },
            "ssl-cipher-suites": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "cipher": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "TLS-RSA-WITH-RC4-128-MD5",
                            "TLS-RSA-WITH-RC4-128-SHA",
                            "TLS-RSA-WITH-DES-CBC-SHA",
                            "TLS-RSA-WITH-3DES-EDE-CBC-SHA",
                            "TLS-RSA-WITH-AES-128-CBC-SHA",
                            "TLS-RSA-WITH-AES-256-CBC-SHA",
                            "TLS-RSA-WITH-AES-128-CBC-SHA256",
                            "TLS-RSA-WITH-AES-256-CBC-SHA256",
                            "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA",
                            "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA",
                            "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                            "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                            "TLS-RSA-WITH-SEED-CBC-SHA",
                            "TLS-RSA-WITH-ARIA-128-CBC-SHA256",
                            "TLS-RSA-WITH-ARIA-256-CBC-SHA384",
                            "TLS-DHE-RSA-WITH-DES-CBC-SHA",
                            "TLS-DHE-RSA-WITH-3DES-EDE-CBC-SHA",
                            "TLS-DHE-RSA-WITH-AES-128-CBC-SHA",
                            "TLS-DHE-RSA-WITH-AES-256-CBC-SHA",
                            "TLS-DHE-RSA-WITH-AES-128-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-AES-256-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA",
                            "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA",
                            "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-SEED-CBC-SHA",
                            "TLS-DHE-RSA-WITH-ARIA-128-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-ARIA-256-CBC-SHA384",
                            "TLS-ECDHE-RSA-WITH-RC4-128-SHA",
                            "TLS-ECDHE-RSA-WITH-3DES-EDE-CBC-SHA",
                            "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA",
                            "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA",
                            "TLS-ECDHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-CHACHA20-POLY1305-SHA256",
                            "TLS-DHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                            "TLS-DHE-RSA-WITH-AES-128-GCM-SHA256",
                            "TLS-DHE-RSA-WITH-AES-256-GCM-SHA384",
                            "TLS-DHE-DSS-WITH-AES-128-CBC-SHA",
                            "TLS-DHE-DSS-WITH-AES-256-CBC-SHA",
                            "TLS-DHE-DSS-WITH-AES-128-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-AES-128-GCM-SHA256",
                            "TLS-DHE-DSS-WITH-AES-256-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-AES-256-GCM-SHA384",
                            "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA256",
                            "TLS-ECDHE-RSA-WITH-AES-128-GCM-SHA256",
                            "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA384",
                            "TLS-ECDHE-RSA-WITH-AES-256-GCM-SHA384",
                            "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA",
                            "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-AES-128-GCM-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA384",
                            "TLS-ECDHE-ECDSA-WITH-AES-256-GCM-SHA384",
                            "TLS-RSA-WITH-AES-128-GCM-SHA256",
                            "TLS-RSA-WITH-AES-256-GCM-SHA384",
                            "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA",
                            "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA",
                            "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-SEED-CBC-SHA",
                            "TLS-DHE-DSS-WITH-ARIA-128-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-ARIA-256-CBC-SHA384",
                            "TLS-ECDHE-RSA-WITH-ARIA-128-CBC-SHA256",
                            "TLS-ECDHE-RSA-WITH-ARIA-256-CBC-SHA384",
                            "TLS-ECDHE-ECDSA-WITH-ARIA-128-CBC-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-ARIA-256-CBC-SHA384",
                            "TLS-DHE-DSS-WITH-3DES-EDE-CBC-SHA",
                            "TLS-DHE-DSS-WITH-DES-CBC-SHA",
                            "TLS-AES-128-GCM-SHA256",
                            "TLS-AES-256-GCM-SHA384",
                            "TLS-CHACHA20-POLY1305-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA"
                        ],
                        "type": "str"
                    },
                    "priority": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "versions": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "tls-1.0",
                            "tls-1.1",
                            "tls-1.2",
                            "tls-1.3"
                        ],
                        "elements": "str"
                    }
                },
                "elements": "dict"
            },
            "ssl-dh-bits": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "768",
                    "1024",
                    "1536",
                    "2048",
                    "3072",
                    "4096"
                ],
                "type": "str"
            },
            "ssl-max-version": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "tls-1.0",
                    "tls-1.1",
                    "tls-1.2",
                    "tls-1.3"
                ],
                "type": "str"
            },
            "ssl-min-version": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "tls-1.0",
                    "tls-1.1",
                    "tls-1.2",
                    "tls-1.3"
                ],
                "type": "str"
            },
            "ssl-vpn-web-portal": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "url-map": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "url-map-type": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "sub-string",
                    "wildcard",
                    "regex"
                ],
                "type": "str"
            },
            "virtual-host": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ssl-renegotiation": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "h2-support": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "h3-support": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "quic": {
                "required": false,
                "type": "dict",
                "options": {
                    "ack-delay-exponent": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "active-connection-id-limit": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "active-migration": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "grease-quic-bit": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "max-ack-delay": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "max-datagram-frame-size": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "max-idle-timeout": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "max-udp-payload-size": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                }
            }
        }
    },
    "firewall_accessproxy6_apigateway6": {
        "stated": true,
        "options": {
            "application": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "http-cookie-age": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "http-cookie-domain": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "http-cookie-domain-from-host": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "http-cookie-generation": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "http-cookie-path": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "http-cookie-share": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "same-ip"
                ],
                "type": "str"
            },
            "https-cookie-secure": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ldb-method": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "static",
                    "round-robin",
                    "weighted",
                    "first-alive",
                    "http-host"
                ],
                "type": "str"
            },
            "persistence": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http-cookie"
                ],
                "type": "str"
            },
            "realservers": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "addr-type": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "fqdn",
                            "ip"
                        ],
                        "type": "str"
                    },
                    "address": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "domain": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "health-check": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "health-check-proto": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ping",
                            "http",
                            "tcp-connect"
                        ],
                        "type": "str"
                    },
                    "holddown-interval": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "http-host": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ip": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "mappedport": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "port": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ssh-client-cert": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ssh-host-key": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "ssh-host-key-validation": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "active",
                            "standby",
                            "disable"
                        ],
                        "type": "str"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "tcp-forwarding",
                            "ssh"
                        ],
                        "type": "str"
                    },
                    "weight": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "translate-host": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "external-auth": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "tunnel-encryption": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "saml-redirect": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "saml-server": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "service": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "http",
                    "https",
                    "tcp-forwarding",
                    "samlsp",
                    "web-portal",
                    "saas"
                ],
                "type": "str"
            },
            "ssl-algorithm": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "high",
                    "medium",
                    "low"
                ],
                "type": "str"
            },
            "ssl-cipher-suites": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "cipher": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "TLS-RSA-WITH-RC4-128-MD5",
                            "TLS-RSA-WITH-RC4-128-SHA",
                            "TLS-RSA-WITH-DES-CBC-SHA",
                            "TLS-RSA-WITH-3DES-EDE-CBC-SHA",
                            "TLS-RSA-WITH-AES-128-CBC-SHA",
                            "TLS-RSA-WITH-AES-256-CBC-SHA",
                            "TLS-RSA-WITH-AES-128-CBC-SHA256",
                            "TLS-RSA-WITH-AES-256-CBC-SHA256",
                            "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA",
                            "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA",
                            "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                            "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                            "TLS-RSA-WITH-SEED-CBC-SHA",
                            "TLS-RSA-WITH-ARIA-128-CBC-SHA256",
                            "TLS-RSA-WITH-ARIA-256-CBC-SHA384",
                            "TLS-DHE-RSA-WITH-DES-CBC-SHA",
                            "TLS-DHE-RSA-WITH-3DES-EDE-CBC-SHA",
                            "TLS-DHE-RSA-WITH-AES-128-CBC-SHA",
                            "TLS-DHE-RSA-WITH-AES-256-CBC-SHA",
                            "TLS-DHE-RSA-WITH-AES-128-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-AES-256-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA",
                            "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA",
                            "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-SEED-CBC-SHA",
                            "TLS-DHE-RSA-WITH-ARIA-128-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-ARIA-256-CBC-SHA384",
                            "TLS-ECDHE-RSA-WITH-RC4-128-SHA",
                            "TLS-ECDHE-RSA-WITH-3DES-EDE-CBC-SHA",
                            "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA",
                            "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA",
                            "TLS-ECDHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-CHACHA20-POLY1305-SHA256",
                            "TLS-DHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                            "TLS-DHE-RSA-WITH-AES-128-GCM-SHA256",
                            "TLS-DHE-RSA-WITH-AES-256-GCM-SHA384",
                            "TLS-DHE-DSS-WITH-AES-128-CBC-SHA",
                            "TLS-DHE-DSS-WITH-AES-256-CBC-SHA",
                            "TLS-DHE-DSS-WITH-AES-128-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-AES-128-GCM-SHA256",
                            "TLS-DHE-DSS-WITH-AES-256-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-AES-256-GCM-SHA384",
                            "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA256",
                            "TLS-ECDHE-RSA-WITH-AES-128-GCM-SHA256",
                            "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA384",
                            "TLS-ECDHE-RSA-WITH-AES-256-GCM-SHA384",
                            "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA",
                            "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-AES-128-GCM-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA384",
                            "TLS-ECDHE-ECDSA-WITH-AES-256-GCM-SHA384",
                            "TLS-RSA-WITH-AES-128-GCM-SHA256",
                            "TLS-RSA-WITH-AES-256-GCM-SHA384",
                            "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA",
                            "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA",
                            "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-SEED-CBC-SHA",
                            "TLS-DHE-DSS-WITH-ARIA-128-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-ARIA-256-CBC-SHA384",
                            "TLS-ECDHE-RSA-WITH-ARIA-128-CBC-SHA256",
                            "TLS-ECDHE-RSA-WITH-ARIA-256-CBC-SHA384",
                            "TLS-ECDHE-ECDSA-WITH-ARIA-128-CBC-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-ARIA-256-CBC-SHA384",
                            "TLS-DHE-DSS-WITH-3DES-EDE-CBC-SHA",
                            "TLS-DHE-DSS-WITH-DES-CBC-SHA",
                            "TLS-AES-128-GCM-SHA256",
                            "TLS-AES-256-GCM-SHA384",
                            "TLS-CHACHA20-POLY1305-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA"
                        ],
                        "type": "str"
                    },
                    "priority": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "versions": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "tls-1.0",
                            "tls-1.1",
                            "tls-1.2",
                            "tls-1.3"
                        ],
                        "elements": "str"
                    }
                },
                "elements": "dict"
            },
            "ssl-dh-bits": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "768",
                    "1024",
                    "1536",
                    "2048",
                    "3072",
                    "4096"
                ],
                "type": "str"
            },
            "ssl-max-version": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "tls-1.0",
                    "tls-1.1",
                    "tls-1.2",
                    "tls-1.3"
                ],
                "type": "str"
            },
            "ssl-min-version": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "tls-1.0",
                    "tls-1.1",
                    "tls-1.2",
                    "tls-1.3"
                ],
                "type": "str"
            },
            "ssl-vpn-web-portal": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "url-map": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "url-map-type": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "sub-string",
                    "wildcard",
                    "regex"
                ],
                "type": "str"
            },
            "virtual-host": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ssl-renegotiation": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "h2-support": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "h3-support": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "quic": {
                "required": false,
                "type": "dict",
                "options": {
                    "ack-delay-exponent": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "active-connection-id-limit": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "active-migration": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "grease-quic-bit": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "max-ack-delay": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "max-datagram-frame-size": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "max-idle-timeout": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "max-udp-payload-size": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                }
            }
        }
    },
    "firewall_accessproxy6_apigateway6_quic": {
        "stated": false,
        "options": {
            "ack-delay-exponent": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "active-connection-id-limit": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "active-migration": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "grease-quic-bit": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "max-ack-delay": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "max-datagram-frame-size": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "max-idle-timeout": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "max-udp-payload-size": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "firewall_accessproxy6_apigateway6_realservers": {
        "stated": true,
        "options": {
            "addr-type": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "fqdn",
                    "ip"
                ],
                "type": "str"
            },
            "address": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "domain": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "health-check": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "health-check-proto": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ping",
                    "http",
                    "tcp-connect"
                ],
                "type": "str"
            },
            "holddown-interval": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "http-host": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "mappedport": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "port": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ssh-client-cert": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ssh-host-key": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "ssh-host-key-validation": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "active",
                    "standby",
                    "disable"
                ],
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "tcp-forwarding",
                    "ssh"
                ],
                "type": "str"
            },
            "weight": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "translate-host": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "external-auth": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tunnel-encryption": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "firewall_accessproxy6_apigateway6_sslciphersuites": {
        "stated": true,
        "options": {
            "cipher": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "TLS-RSA-WITH-RC4-128-MD5",
                    "TLS-RSA-WITH-RC4-128-SHA",
                    "TLS-RSA-WITH-DES-CBC-SHA",
                    "TLS-RSA-WITH-3DES-EDE-CBC-SHA",
                    "TLS-RSA-WITH-AES-128-CBC-SHA",
                    "TLS-RSA-WITH-AES-256-CBC-SHA",
                    "TLS-RSA-WITH-AES-128-CBC-SHA256",
                    "TLS-RSA-WITH-AES-256-CBC-SHA256",
                    "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA",
                    "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA",
                    "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                    "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                    "TLS-RSA-WITH-SEED-CBC-SHA",
                    "TLS-RSA-WITH-ARIA-128-CBC-SHA256",
                    "TLS-RSA-WITH-ARIA-256-CBC-SHA384",
                    "TLS-DHE-RSA-WITH-DES-CBC-SHA",
                    "TLS-DHE-RSA-WITH-3DES-EDE-CBC-SHA",
                    "TLS-DHE-RSA-WITH-AES-128-CBC-SHA",
                    "TLS-DHE-RSA-WITH-AES-256-CBC-SHA",
                    "TLS-DHE-RSA-WITH-AES-128-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-AES-256-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA",
                    "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA",
                    "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-SEED-CBC-SHA",
                    "TLS-DHE-RSA-WITH-ARIA-128-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-ARIA-256-CBC-SHA384",
                    "TLS-ECDHE-RSA-WITH-RC4-128-SHA",
                    "TLS-ECDHE-RSA-WITH-3DES-EDE-CBC-SHA",
                    "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA",
                    "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA",
                    "TLS-ECDHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-CHACHA20-POLY1305-SHA256",
                    "TLS-DHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                    "TLS-DHE-RSA-WITH-AES-128-GCM-SHA256",
                    "TLS-DHE-RSA-WITH-AES-256-GCM-SHA384",
                    "TLS-DHE-DSS-WITH-AES-128-CBC-SHA",
                    "TLS-DHE-DSS-WITH-AES-256-CBC-SHA",
                    "TLS-DHE-DSS-WITH-AES-128-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-AES-128-GCM-SHA256",
                    "TLS-DHE-DSS-WITH-AES-256-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-AES-256-GCM-SHA384",
                    "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA256",
                    "TLS-ECDHE-RSA-WITH-AES-128-GCM-SHA256",
                    "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA384",
                    "TLS-ECDHE-RSA-WITH-AES-256-GCM-SHA384",
                    "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA",
                    "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-AES-128-GCM-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA384",
                    "TLS-ECDHE-ECDSA-WITH-AES-256-GCM-SHA384",
                    "TLS-RSA-WITH-AES-128-GCM-SHA256",
                    "TLS-RSA-WITH-AES-256-GCM-SHA384",
                    "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA",
                    "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA",
                    "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-SEED-CBC-SHA",
                    "TLS-DHE-DSS-WITH-ARIA-128-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-ARIA-256-CBC-SHA384",
                    "TLS-ECDHE-RSA-WITH-ARIA-128-CBC-SHA256",
                    "TLS-ECDHE-RSA-WITH-ARIA-256-CBC-SHA384",
                    "TLS-ECDHE-ECDSA-WITH-ARIA-128-CBC-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-ARIA-256-CBC-SHA384",
                    "TLS-DHE-DSS-WITH-3DES-EDE-CBC-SHA",
                    "TLS-DHE-DSS-WITH-DES-CBC-SHA",
                    "TLS-AES-128-GCM-SHA256",
                    "TLS-AES-256-GCM-SHA384",
                    "TLS-CHACHA20-POLY1305-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA"
                ],
                "type": "str"
            },
            "priority": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "versions": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "tls-1.0",
                    "tls-1.1",
                    "tls-1.2",
                    "tls-1.3"
                ],
                "elements": "str"
            }
        }
    },
    "firewall_accessproxy6_apigateway_quic": {
        "stated": false,
        "options": {
            "ack-delay-exponent": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "active-connection-id-limit": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "active-migration": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "grease-quic-bit": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "max-ack-delay": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "max-datagram-frame-size": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "max-idle-timeout": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "max-udp-payload-size": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "firewall_accessproxy6_apigateway_realservers": {
        "stated": true,
        "options": {
            "addr-type": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "fqdn",
                    "ip"
                ],
                "type": "str"
            },
            "address": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "domain": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "health-check": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "health-check-proto": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ping",
                    "http",
                    "tcp-connect"
                ],
                "type": "str"
            },
            "holddown-interval": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "http-host": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "mappedport": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "port": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ssh-client-cert": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ssh-host-key": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "ssh-host-key-validation": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "active",
                    "standby",
                    "disable"
                ],
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "tcp-forwarding",
                    "ssh"
                ],
                "type": "str"
            },
            "weight": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "translate-host": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "external-auth": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tunnel-encryption": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "firewall_accessproxy6_apigateway_sslciphersuites": {
        "stated": true,
        "options": {
            "cipher": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "TLS-RSA-WITH-RC4-128-MD5",
                    "TLS-RSA-WITH-RC4-128-SHA",
                    "TLS-RSA-WITH-DES-CBC-SHA",
                    "TLS-RSA-WITH-3DES-EDE-CBC-SHA",
                    "TLS-RSA-WITH-AES-128-CBC-SHA",
                    "TLS-RSA-WITH-AES-256-CBC-SHA",
                    "TLS-RSA-WITH-AES-128-CBC-SHA256",
                    "TLS-RSA-WITH-AES-256-CBC-SHA256",
                    "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA",
                    "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA",
                    "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                    "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                    "TLS-RSA-WITH-SEED-CBC-SHA",
                    "TLS-RSA-WITH-ARIA-128-CBC-SHA256",
                    "TLS-RSA-WITH-ARIA-256-CBC-SHA384",
                    "TLS-DHE-RSA-WITH-DES-CBC-SHA",
                    "TLS-DHE-RSA-WITH-3DES-EDE-CBC-SHA",
                    "TLS-DHE-RSA-WITH-AES-128-CBC-SHA",
                    "TLS-DHE-RSA-WITH-AES-256-CBC-SHA",
                    "TLS-DHE-RSA-WITH-AES-128-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-AES-256-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA",
                    "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA",
                    "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-SEED-CBC-SHA",
                    "TLS-DHE-RSA-WITH-ARIA-128-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-ARIA-256-CBC-SHA384",
                    "TLS-ECDHE-RSA-WITH-RC4-128-SHA",
                    "TLS-ECDHE-RSA-WITH-3DES-EDE-CBC-SHA",
                    "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA",
                    "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA",
                    "TLS-ECDHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-CHACHA20-POLY1305-SHA256",
                    "TLS-DHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                    "TLS-DHE-RSA-WITH-AES-128-GCM-SHA256",
                    "TLS-DHE-RSA-WITH-AES-256-GCM-SHA384",
                    "TLS-DHE-DSS-WITH-AES-128-CBC-SHA",
                    "TLS-DHE-DSS-WITH-AES-256-CBC-SHA",
                    "TLS-DHE-DSS-WITH-AES-128-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-AES-128-GCM-SHA256",
                    "TLS-DHE-DSS-WITH-AES-256-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-AES-256-GCM-SHA384",
                    "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA256",
                    "TLS-ECDHE-RSA-WITH-AES-128-GCM-SHA256",
                    "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA384",
                    "TLS-ECDHE-RSA-WITH-AES-256-GCM-SHA384",
                    "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA",
                    "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-AES-128-GCM-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA384",
                    "TLS-ECDHE-ECDSA-WITH-AES-256-GCM-SHA384",
                    "TLS-RSA-WITH-AES-128-GCM-SHA256",
                    "TLS-RSA-WITH-AES-256-GCM-SHA384",
                    "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA",
                    "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA",
                    "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-SEED-CBC-SHA",
                    "TLS-DHE-DSS-WITH-ARIA-128-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-ARIA-256-CBC-SHA384",
                    "TLS-ECDHE-RSA-WITH-ARIA-128-CBC-SHA256",
                    "TLS-ECDHE-RSA-WITH-ARIA-256-CBC-SHA384",
                    "TLS-ECDHE-ECDSA-WITH-ARIA-128-CBC-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-ARIA-256-CBC-SHA384",
                    "TLS-DHE-DSS-WITH-3DES-EDE-CBC-SHA",
                    "TLS-DHE-DSS-WITH-DES-CBC-SHA",
                    "TLS-AES-128-GCM-SHA256",
                    "TLS-AES-256-GCM-SHA384",
                    "TLS-CHACHA20-POLY1305-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA"
                ],
                "type": "str"
            },
            "priority": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "versions": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "tls-1.0",
                    "tls-1.1",
                    "tls-1.2",
                    "tls-1.3"
                ],
                "elements": "str"
            }
        }
    },
    "firewall_accessproxy_apigateway": {
        "stated": true,
        "options": {
            "http-cookie-age": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "http-cookie-domain": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "http-cookie-domain-from-host": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "http-cookie-generation": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "http-cookie-path": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "http-cookie-share": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "same-ip"
                ],
                "type": "str"
            },
            "https-cookie-secure": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ldb-method": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "static",
                    "round-robin",
                    "weighted",
                    "least-session",
                    "least-rtt",
                    "first-alive",
                    "http-host"
                ],
                "type": "str"
            },
            "persistence": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http-cookie"
                ],
                "type": "str"
            },
            "realservers": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "address": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "health-check": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "health-check-proto": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ping",
                            "http",
                            "tcp-connect"
                        ],
                        "type": "str"
                    },
                    "http-host": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "mappedport": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "port": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "active",
                            "standby",
                            "disable"
                        ],
                        "type": "str"
                    },
                    "weight": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "addr-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "fqdn",
                            "ip"
                        ],
                        "type": "str"
                    },
                    "domain": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "holddown-interval": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ssh-client-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ssh-host-key": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "ssh-host-key-validation": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "tcp-forwarding",
                            "ssh"
                        ],
                        "type": "str"
                    },
                    "translate-host": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "external-auth": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "tunnel-encryption": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "saml-server": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "service": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "http",
                    "https",
                    "tcp-forwarding",
                    "samlsp",
                    "web-portal",
                    "saas"
                ],
                "type": "str"
            },
            "ssl-algorithm": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "high",
                    "medium",
                    "low",
                    "custom"
                ],
                "type": "str"
            },
            "ssl-cipher-suites": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "cipher": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "TLS-RSA-WITH-RC4-128-MD5",
                            "TLS-RSA-WITH-RC4-128-SHA",
                            "TLS-RSA-WITH-DES-CBC-SHA",
                            "TLS-RSA-WITH-3DES-EDE-CBC-SHA",
                            "TLS-RSA-WITH-AES-128-CBC-SHA",
                            "TLS-RSA-WITH-AES-256-CBC-SHA",
                            "TLS-RSA-WITH-AES-128-CBC-SHA256",
                            "TLS-RSA-WITH-AES-256-CBC-SHA256",
                            "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA",
                            "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA",
                            "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                            "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                            "TLS-RSA-WITH-SEED-CBC-SHA",
                            "TLS-RSA-WITH-ARIA-128-CBC-SHA256",
                            "TLS-RSA-WITH-ARIA-256-CBC-SHA384",
                            "TLS-DHE-RSA-WITH-DES-CBC-SHA",
                            "TLS-DHE-RSA-WITH-3DES-EDE-CBC-SHA",
                            "TLS-DHE-RSA-WITH-AES-128-CBC-SHA",
                            "TLS-DHE-RSA-WITH-AES-256-CBC-SHA",
                            "TLS-DHE-RSA-WITH-AES-128-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-AES-256-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA",
                            "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA",
                            "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-SEED-CBC-SHA",
                            "TLS-DHE-RSA-WITH-ARIA-128-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-ARIA-256-CBC-SHA384",
                            "TLS-ECDHE-RSA-WITH-RC4-128-SHA",
                            "TLS-ECDHE-RSA-WITH-3DES-EDE-CBC-SHA",
                            "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA",
                            "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA",
                            "TLS-ECDHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-CHACHA20-POLY1305-SHA256",
                            "TLS-DHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                            "TLS-DHE-RSA-WITH-AES-128-GCM-SHA256",
                            "TLS-DHE-RSA-WITH-AES-256-GCM-SHA384",
                            "TLS-DHE-DSS-WITH-AES-128-CBC-SHA",
                            "TLS-DHE-DSS-WITH-AES-256-CBC-SHA",
                            "TLS-DHE-DSS-WITH-AES-128-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-AES-128-GCM-SHA256",
                            "TLS-DHE-DSS-WITH-AES-256-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-AES-256-GCM-SHA384",
                            "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA256",
                            "TLS-ECDHE-RSA-WITH-AES-128-GCM-SHA256",
                            "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA384",
                            "TLS-ECDHE-RSA-WITH-AES-256-GCM-SHA384",
                            "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA",
                            "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-AES-128-GCM-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA384",
                            "TLS-ECDHE-ECDSA-WITH-AES-256-GCM-SHA384",
                            "TLS-RSA-WITH-AES-128-GCM-SHA256",
                            "TLS-RSA-WITH-AES-256-GCM-SHA384",
                            "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA",
                            "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA",
                            "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-SEED-CBC-SHA",
                            "TLS-DHE-DSS-WITH-ARIA-128-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-ARIA-256-CBC-SHA384",
                            "TLS-ECDHE-RSA-WITH-ARIA-128-CBC-SHA256",
                            "TLS-ECDHE-RSA-WITH-ARIA-256-CBC-SHA384",
                            "TLS-ECDHE-ECDSA-WITH-ARIA-128-CBC-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-ARIA-256-CBC-SHA384",
                            "TLS-DHE-DSS-WITH-3DES-EDE-CBC-SHA",
                            "TLS-DHE-DSS-WITH-DES-CBC-SHA",
                            "TLS-AES-128-GCM-SHA256",
                            "TLS-AES-256-GCM-SHA384",
                            "TLS-CHACHA20-POLY1305-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA"
                        ],
                        "type": "str"
                    },
                    "priority": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "versions": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "tls-1.0",
                            "tls-1.1",
                            "tls-1.2",
                            "tls-1.3"
                        ],
                        "elements": "str"
                    }
                },
                "elements": "dict"
            },
            "ssl-dh-bits": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "768",
                    "1024",
                    "1536",
                    "2048",
                    "3072",
                    "4096"
                ],
                "type": "str"
            },
            "ssl-max-version": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "tls-1.0",
                    "tls-1.1",
                    "tls-1.2",
                    "tls-1.3"
                ],
                "type": "str"
            },
            "ssl-min-version": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "tls-1.0",
                    "tls-1.1",
                    "tls-1.2",
                    "tls-1.3"
                ],
                "type": "str"
            },
            "url-map": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "url-map-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "sub-string",
                    "wildcard",
                    "regex"
                ],
                "type": "str"
            },
            "virtual-host": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "saml-redirect": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-vpn-web-portal": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "application": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ssl-renegotiation": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "h2-support": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "h3-support": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "quic": {
                "required": false,
                "type": "dict",
                "options": {
                    "ack-delay-exponent": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "active-connection-id-limit": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "active-migration": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "grease-quic-bit": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "max-ack-delay": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "max-datagram-frame-size": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "max-idle-timeout": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "max-udp-payload-size": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                }
            }
        }
    },
    "firewall_accessproxy_apigateway6": {
        "stated": true,
        "options": {
            "http-cookie-age": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "http-cookie-domain": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "http-cookie-domain-from-host": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "http-cookie-generation": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "http-cookie-path": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "http-cookie-share": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "same-ip"
                ],
                "type": "str"
            },
            "https-cookie-secure": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ldb-method": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "static",
                    "round-robin",
                    "weighted",
                    "first-alive",
                    "http-host"
                ],
                "type": "str"
            },
            "persistence": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http-cookie"
                ],
                "type": "str"
            },
            "realservers": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "addr-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "fqdn",
                            "ip"
                        ],
                        "type": "str"
                    },
                    "address": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "domain": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "health-check": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "health-check-proto": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ping",
                            "http",
                            "tcp-connect"
                        ],
                        "type": "str"
                    },
                    "holddown-interval": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "http-host": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "mappedport": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "port": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ssh-client-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ssh-host-key": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "ssh-host-key-validation": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "active",
                            "standby",
                            "disable"
                        ],
                        "type": "str"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "tcp-forwarding",
                            "ssh"
                        ],
                        "type": "str"
                    },
                    "weight": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "translate-host": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "external-auth": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "tunnel-encryption": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "saml-redirect": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "saml-server": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "service": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "http",
                    "https",
                    "tcp-forwarding",
                    "samlsp",
                    "web-portal",
                    "saas"
                ],
                "type": "str"
            },
            "ssl-algorithm": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "high",
                    "medium",
                    "low"
                ],
                "type": "str"
            },
            "ssl-cipher-suites": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "cipher": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "TLS-RSA-WITH-RC4-128-MD5",
                            "TLS-RSA-WITH-RC4-128-SHA",
                            "TLS-RSA-WITH-DES-CBC-SHA",
                            "TLS-RSA-WITH-3DES-EDE-CBC-SHA",
                            "TLS-RSA-WITH-AES-128-CBC-SHA",
                            "TLS-RSA-WITH-AES-256-CBC-SHA",
                            "TLS-RSA-WITH-AES-128-CBC-SHA256",
                            "TLS-RSA-WITH-AES-256-CBC-SHA256",
                            "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA",
                            "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA",
                            "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                            "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                            "TLS-RSA-WITH-SEED-CBC-SHA",
                            "TLS-RSA-WITH-ARIA-128-CBC-SHA256",
                            "TLS-RSA-WITH-ARIA-256-CBC-SHA384",
                            "TLS-DHE-RSA-WITH-DES-CBC-SHA",
                            "TLS-DHE-RSA-WITH-3DES-EDE-CBC-SHA",
                            "TLS-DHE-RSA-WITH-AES-128-CBC-SHA",
                            "TLS-DHE-RSA-WITH-AES-256-CBC-SHA",
                            "TLS-DHE-RSA-WITH-AES-128-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-AES-256-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA",
                            "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA",
                            "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-SEED-CBC-SHA",
                            "TLS-DHE-RSA-WITH-ARIA-128-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-ARIA-256-CBC-SHA384",
                            "TLS-ECDHE-RSA-WITH-RC4-128-SHA",
                            "TLS-ECDHE-RSA-WITH-3DES-EDE-CBC-SHA",
                            "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA",
                            "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA",
                            "TLS-ECDHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-CHACHA20-POLY1305-SHA256",
                            "TLS-DHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                            "TLS-DHE-RSA-WITH-AES-128-GCM-SHA256",
                            "TLS-DHE-RSA-WITH-AES-256-GCM-SHA384",
                            "TLS-DHE-DSS-WITH-AES-128-CBC-SHA",
                            "TLS-DHE-DSS-WITH-AES-256-CBC-SHA",
                            "TLS-DHE-DSS-WITH-AES-128-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-AES-128-GCM-SHA256",
                            "TLS-DHE-DSS-WITH-AES-256-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-AES-256-GCM-SHA384",
                            "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA256",
                            "TLS-ECDHE-RSA-WITH-AES-128-GCM-SHA256",
                            "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA384",
                            "TLS-ECDHE-RSA-WITH-AES-256-GCM-SHA384",
                            "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA",
                            "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-AES-128-GCM-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA384",
                            "TLS-ECDHE-ECDSA-WITH-AES-256-GCM-SHA384",
                            "TLS-RSA-WITH-AES-128-GCM-SHA256",
                            "TLS-RSA-WITH-AES-256-GCM-SHA384",
                            "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA",
                            "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA",
                            "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-SEED-CBC-SHA",
                            "TLS-DHE-DSS-WITH-ARIA-128-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-ARIA-256-CBC-SHA384",
                            "TLS-ECDHE-RSA-WITH-ARIA-128-CBC-SHA256",
                            "TLS-ECDHE-RSA-WITH-ARIA-256-CBC-SHA384",
                            "TLS-ECDHE-ECDSA-WITH-ARIA-128-CBC-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-ARIA-256-CBC-SHA384",
                            "TLS-DHE-DSS-WITH-3DES-EDE-CBC-SHA",
                            "TLS-DHE-DSS-WITH-DES-CBC-SHA",
                            "TLS-AES-128-GCM-SHA256",
                            "TLS-AES-256-GCM-SHA384",
                            "TLS-CHACHA20-POLY1305-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA"
                        ],
                        "type": "str"
                    },
                    "priority": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "versions": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "tls-1.0",
                            "tls-1.1",
                            "tls-1.2",
                            "tls-1.3"
                        ],
                        "elements": "str"
                    }
                },
                "elements": "dict"
            },
            "ssl-dh-bits": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "768",
                    "1024",
                    "1536",
                    "2048",
                    "3072",
                    "4096"
                ],
                "type": "str"
            },
            "ssl-max-version": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "tls-1.0",
                    "tls-1.1",
                    "tls-1.2",
                    "tls-1.3"
                ],
                "type": "str"
            },
            "ssl-min-version": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "tls-1.0",
                    "tls-1.1",
                    "tls-1.2",
                    "tls-1.3"
                ],
                "type": "str"
            },
            "ssl-vpn-web-portal": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "url-map": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "url-map-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "sub-string",
                    "wildcard",
                    "regex"
                ],
                "type": "str"
            },
            "virtual-host": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "application": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ssl-renegotiation": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "h2-support": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "h3-support": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "quic": {
                "required": false,
                "type": "dict",
                "options": {
                    "ack-delay-exponent": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "active-connection-id-limit": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "active-migration": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "grease-quic-bit": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "max-ack-delay": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "max-datagram-frame-size": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "max-idle-timeout": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "max-udp-payload-size": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                }
            }
        }
    },
    "firewall_accessproxy_apigateway6_quic": {
        "stated": false,
        "options": {
            "ack-delay-exponent": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "active-connection-id-limit": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "active-migration": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "grease-quic-bit": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "max-ack-delay": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "max-datagram-frame-size": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "max-idle-timeout": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "max-udp-payload-size": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "firewall_accessproxy_apigateway6_realservers": {
        "stated": true,
        "options": {
            "addr-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "fqdn",
                    "ip"
                ],
                "type": "str"
            },
            "address": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "domain": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "health-check": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "health-check-proto": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ping",
                    "http",
                    "tcp-connect"
                ],
                "type": "str"
            },
            "holddown-interval": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "http-host": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "mappedport": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ssh-client-cert": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ssh-host-key": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "ssh-host-key-validation": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "active",
                    "standby",
                    "disable"
                ],
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "tcp-forwarding",
                    "ssh"
                ],
                "type": "str"
            },
            "weight": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "translate-host": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "external-auth": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tunnel-encryption": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "firewall_accessproxy_apigateway6_sslciphersuites": {
        "stated": true,
        "options": {
            "cipher": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "TLS-RSA-WITH-RC4-128-MD5",
                    "TLS-RSA-WITH-RC4-128-SHA",
                    "TLS-RSA-WITH-DES-CBC-SHA",
                    "TLS-RSA-WITH-3DES-EDE-CBC-SHA",
                    "TLS-RSA-WITH-AES-128-CBC-SHA",
                    "TLS-RSA-WITH-AES-256-CBC-SHA",
                    "TLS-RSA-WITH-AES-128-CBC-SHA256",
                    "TLS-RSA-WITH-AES-256-CBC-SHA256",
                    "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA",
                    "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA",
                    "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                    "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                    "TLS-RSA-WITH-SEED-CBC-SHA",
                    "TLS-RSA-WITH-ARIA-128-CBC-SHA256",
                    "TLS-RSA-WITH-ARIA-256-CBC-SHA384",
                    "TLS-DHE-RSA-WITH-DES-CBC-SHA",
                    "TLS-DHE-RSA-WITH-3DES-EDE-CBC-SHA",
                    "TLS-DHE-RSA-WITH-AES-128-CBC-SHA",
                    "TLS-DHE-RSA-WITH-AES-256-CBC-SHA",
                    "TLS-DHE-RSA-WITH-AES-128-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-AES-256-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA",
                    "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA",
                    "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-SEED-CBC-SHA",
                    "TLS-DHE-RSA-WITH-ARIA-128-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-ARIA-256-CBC-SHA384",
                    "TLS-ECDHE-RSA-WITH-RC4-128-SHA",
                    "TLS-ECDHE-RSA-WITH-3DES-EDE-CBC-SHA",
                    "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA",
                    "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA",
                    "TLS-ECDHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-CHACHA20-POLY1305-SHA256",
                    "TLS-DHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                    "TLS-DHE-RSA-WITH-AES-128-GCM-SHA256",
                    "TLS-DHE-RSA-WITH-AES-256-GCM-SHA384",
                    "TLS-DHE-DSS-WITH-AES-128-CBC-SHA",
                    "TLS-DHE-DSS-WITH-AES-256-CBC-SHA",
                    "TLS-DHE-DSS-WITH-AES-128-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-AES-128-GCM-SHA256",
                    "TLS-DHE-DSS-WITH-AES-256-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-AES-256-GCM-SHA384",
                    "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA256",
                    "TLS-ECDHE-RSA-WITH-AES-128-GCM-SHA256",
                    "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA384",
                    "TLS-ECDHE-RSA-WITH-AES-256-GCM-SHA384",
                    "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA",
                    "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-AES-128-GCM-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA384",
                    "TLS-ECDHE-ECDSA-WITH-AES-256-GCM-SHA384",
                    "TLS-RSA-WITH-AES-128-GCM-SHA256",
                    "TLS-RSA-WITH-AES-256-GCM-SHA384",
                    "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA",
                    "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA",
                    "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-SEED-CBC-SHA",
                    "TLS-DHE-DSS-WITH-ARIA-128-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-ARIA-256-CBC-SHA384",
                    "TLS-ECDHE-RSA-WITH-ARIA-128-CBC-SHA256",
                    "TLS-ECDHE-RSA-WITH-ARIA-256-CBC-SHA384",
                    "TLS-ECDHE-ECDSA-WITH-ARIA-128-CBC-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-ARIA-256-CBC-SHA384",
                    "TLS-DHE-DSS-WITH-3DES-EDE-CBC-SHA",
                    "TLS-DHE-DSS-WITH-DES-CBC-SHA",
                    "TLS-AES-128-GCM-SHA256",
                    "TLS-AES-256-GCM-SHA384",
                    "TLS-CHACHA20-POLY1305-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA"
                ],
                "type": "str"
            },
            "priority": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "versions": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "tls-1.0",
                    "tls-1.1",
                    "tls-1.2",
                    "tls-1.3"
                ],
                "elements": "str"
            }
        }
    },
    "firewall_accessproxy_apigateway_quic": {
        "stated": false,
        "options": {
            "ack-delay-exponent": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "active-connection-id-limit": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "active-migration": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "grease-quic-bit": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "max-ack-delay": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "max-datagram-frame-size": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "max-idle-timeout": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "max-udp-payload-size": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "firewall_accessproxy_apigateway_realservers": {
        "stated": true,
        "options": {
            "address": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "health-check": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "health-check-proto": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ping",
                    "http",
                    "tcp-connect"
                ],
                "type": "str"
            },
            "http-host": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "mappedport": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "active",
                    "standby",
                    "disable"
                ],
                "type": "str"
            },
            "weight": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "addr-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "fqdn",
                    "ip"
                ],
                "type": "str"
            },
            "domain": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "holddown-interval": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssh-client-cert": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ssh-host-key": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "ssh-host-key-validation": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "tcp-forwarding",
                    "ssh"
                ],
                "type": "str"
            },
            "translate-host": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "external-auth": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tunnel-encryption": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "firewall_accessproxy_apigateway_sslciphersuites": {
        "stated": true,
        "options": {
            "cipher": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "TLS-RSA-WITH-RC4-128-MD5",
                    "TLS-RSA-WITH-RC4-128-SHA",
                    "TLS-RSA-WITH-DES-CBC-SHA",
                    "TLS-RSA-WITH-3DES-EDE-CBC-SHA",
                    "TLS-RSA-WITH-AES-128-CBC-SHA",
                    "TLS-RSA-WITH-AES-256-CBC-SHA",
                    "TLS-RSA-WITH-AES-128-CBC-SHA256",
                    "TLS-RSA-WITH-AES-256-CBC-SHA256",
                    "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA",
                    "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA",
                    "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                    "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                    "TLS-RSA-WITH-SEED-CBC-SHA",
                    "TLS-RSA-WITH-ARIA-128-CBC-SHA256",
                    "TLS-RSA-WITH-ARIA-256-CBC-SHA384",
                    "TLS-DHE-RSA-WITH-DES-CBC-SHA",
                    "TLS-DHE-RSA-WITH-3DES-EDE-CBC-SHA",
                    "TLS-DHE-RSA-WITH-AES-128-CBC-SHA",
                    "TLS-DHE-RSA-WITH-AES-256-CBC-SHA",
                    "TLS-DHE-RSA-WITH-AES-128-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-AES-256-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA",
                    "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA",
                    "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-SEED-CBC-SHA",
                    "TLS-DHE-RSA-WITH-ARIA-128-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-ARIA-256-CBC-SHA384",
                    "TLS-ECDHE-RSA-WITH-RC4-128-SHA",
                    "TLS-ECDHE-RSA-WITH-3DES-EDE-CBC-SHA",
                    "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA",
                    "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA",
                    "TLS-ECDHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-CHACHA20-POLY1305-SHA256",
                    "TLS-DHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                    "TLS-DHE-RSA-WITH-AES-128-GCM-SHA256",
                    "TLS-DHE-RSA-WITH-AES-256-GCM-SHA384",
                    "TLS-DHE-DSS-WITH-AES-128-CBC-SHA",
                    "TLS-DHE-DSS-WITH-AES-256-CBC-SHA",
                    "TLS-DHE-DSS-WITH-AES-128-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-AES-128-GCM-SHA256",
                    "TLS-DHE-DSS-WITH-AES-256-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-AES-256-GCM-SHA384",
                    "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA256",
                    "TLS-ECDHE-RSA-WITH-AES-128-GCM-SHA256",
                    "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA384",
                    "TLS-ECDHE-RSA-WITH-AES-256-GCM-SHA384",
                    "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA",
                    "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-AES-128-GCM-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA384",
                    "TLS-ECDHE-ECDSA-WITH-AES-256-GCM-SHA384",
                    "TLS-RSA-WITH-AES-128-GCM-SHA256",
                    "TLS-RSA-WITH-AES-256-GCM-SHA384",
                    "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA",
                    "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA",
                    "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-SEED-CBC-SHA",
                    "TLS-DHE-DSS-WITH-ARIA-128-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-ARIA-256-CBC-SHA384",
                    "TLS-ECDHE-RSA-WITH-ARIA-128-CBC-SHA256",
                    "TLS-ECDHE-RSA-WITH-ARIA-256-CBC-SHA384",
                    "TLS-ECDHE-ECDSA-WITH-ARIA-128-CBC-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-ARIA-256-CBC-SHA384",
                    "TLS-DHE-DSS-WITH-3DES-EDE-CBC-SHA",
                    "TLS-DHE-DSS-WITH-DES-CBC-SHA",
                    "TLS-AES-128-GCM-SHA256",
                    "TLS-AES-256-GCM-SHA384",
                    "TLS-CHACHA20-POLY1305-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA"
                ],
                "type": "str"
            },
            "priority": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "versions": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "tls-1.0",
                    "tls-1.1",
                    "tls-1.2",
                    "tls-1.3"
                ],
                "elements": "str"
            }
        }
    },
    "firewall_accessproxy_realservers": {
        "stated": true,
        "options": {
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "active",
                    "standby",
                    "disable"
                ],
                "type": "str"
            },
            "weight": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "firewall_accessproxy_serverpubkeyauthsettings": {
        "stated": false,
        "options": {
            "auth-ca": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cert-extension": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "critical": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "no",
                            "yes"
                        ],
                        "type": "str"
                    },
                    "data": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "fixed",
                            "user"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "permit-agent-forwarding": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "permit-port-forwarding": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "permit-pty": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "permit-user-rc": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "permit-x11-forwarding": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "source-address": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "firewall_accessproxy_serverpubkeyauthsettings_certextension": {
        "stated": true,
        "options": {
            "critical": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "no",
                    "yes"
                ],
                "type": "str"
            },
            "data": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "fixed",
                    "user"
                ],
                "type": "str"
            }
        }
    },
    "firewall_accessproxyvirtualhost": {
        "stated": true,
        "options": {
            "host": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "host-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "sub-string",
                    "wildcard"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ssl-certificate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "replacemsg-group": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "firewall_address": {
        "stated": true,
        "options": {
            "allow-routing": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "associated-interface": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cache-ttl": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "color": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "comment": {
                "required": false,
                "type": "raw"
            },
            "country": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dynamic_mapping": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "_scope": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "vdom": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "allow-routing": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "associated-interface": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "cache-ttl": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "color": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "comment": {
                        "required": false,
                        "type": "raw"
                    },
                    "country": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "end-ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "end-mac": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "epg-name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "filter": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "fqdn": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "interface": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "obj-id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "organization": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "policy-group": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sdn": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "aci",
                            "aws",
                            "nsx",
                            "nuage",
                            "azure",
                            "gcp",
                            "oci",
                            "openstack"
                        ],
                        "type": "str"
                    },
                    "sdn-addr-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "private",
                            "public",
                            "all"
                        ],
                        "type": "str"
                    },
                    "sdn-tag": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "start-ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "start-mac": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "subnet": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "subnet-name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "tags": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "tenant": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ipmask",
                            "iprange",
                            "fqdn",
                            "wildcard",
                            "geography",
                            "url",
                            "wildcard-fqdn",
                            "nsx",
                            "aws",
                            "dynamic",
                            "interface-subnet",
                            "mac",
                            "fqdn-group",
                            "route-tag"
                        ],
                        "type": "str"
                    },
                    "url": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "uuid": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "visibility": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "wildcard": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "wildcard-fqdn": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "_image-base64": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "clearpass-spt": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "unknown",
                            "healthy",
                            "quarantine",
                            "checkup",
                            "transition",
                            "infected",
                            "transient"
                        ],
                        "type": "str"
                    },
                    "fsso-group": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "sub-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "sdn",
                            "clearpass-spt",
                            "fsso",
                            "ems-tag",
                            "swc-tag",
                            "fortivoice-tag",
                            "fortinac-tag",
                            "fortipolicy-tag",
                            "device-identification"
                        ],
                        "type": "str"
                    },
                    "global-object": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "obj-tag": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "obj-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ip",
                            "mac"
                        ],
                        "type": "str"
                    },
                    "fabric-object": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "macaddr": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "node-ip-only": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "dirty": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "dirty",
                            "clean"
                        ],
                        "type": "str"
                    },
                    "pattern-end": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "pattern-start": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "tag-detection-level": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "tag-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "hw-model": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "hw-vendor": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "os": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "route-tag": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "sw-version": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "end-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "epg-name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "filter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "fqdn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "list": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "net-id": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "obj-id": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "obj-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "organization": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "policy-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sdn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "aci",
                    "aws",
                    "nsx",
                    "nuage",
                    "azure",
                    "gcp",
                    "oci",
                    "openstack"
                ],
                "type": "str"
            },
            "sdn-tag": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "start-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "subnet": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "subnet-name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tagging": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "category": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "tags": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    }
                },
                "elements": "dict"
            },
            "tenant": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ipmask",
                    "iprange",
                    "fqdn",
                    "wildcard",
                    "geography",
                    "url",
                    "wildcard-fqdn",
                    "nsx",
                    "aws",
                    "dynamic",
                    "interface-subnet",
                    "mac",
                    "fqdn-group",
                    "route-tag"
                ],
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "visibility": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "wildcard": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "wildcard-fqdn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "end-mac": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "interface": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sdn-addr-type": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "private",
                    "public",
                    "all"
                ],
                "type": "str"
            },
            "start-mac": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tags": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "profile-list": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "profile-id": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "_image-base64": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "clearpass-spt": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "unknown",
                    "healthy",
                    "quarantine",
                    "checkup",
                    "transition",
                    "infected",
                    "transient"
                ],
                "type": "str"
            },
            "fsso-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "sub-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "sdn",
                    "clearpass-spt",
                    "fsso",
                    "ems-tag",
                    "swc-tag",
                    "fortivoice-tag",
                    "fortinac-tag",
                    "fortipolicy-tag",
                    "device-identification"
                ],
                "type": "str"
            },
            "global-object": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "obj-tag": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "obj-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ip",
                    "mac"
                ],
                "type": "str"
            },
            "fabric-object": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "macaddr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "node-ip-only": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dirty": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "dirty",
                    "clean"
                ],
                "type": "str"
            },
            "tag-detection-level": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tag-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "hw-model": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "hw-vendor": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "os": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "route-tag": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "sw-version": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "firewall_address6": {
        "stated": true,
        "options": {
            "cache-ttl": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "color": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dynamic_mapping": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "_scope": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "vdom": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "cache-ttl": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "color": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "comment": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "end-ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "fqdn": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "host": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "host-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "any",
                            "specific"
                        ],
                        "type": "str"
                    },
                    "ip6": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "obj-id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sdn": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "nsx"
                        ],
                        "type": "str"
                    },
                    "start-ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "tags": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "template": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ipprefix",
                            "iprange",
                            "nsx",
                            "dynamic",
                            "fqdn",
                            "template",
                            "mac",
                            "geography",
                            "route-tag"
                        ],
                        "type": "str"
                    },
                    "uuid": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "visibility": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "subnet-segment": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "type": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "any",
                                    "specific"
                                ],
                                "type": "str"
                            },
                            "value": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "_image-base64": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "end-mac": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "start-mac": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "country": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "global-object": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "fabric-object": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "macaddr": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "epg-name": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sdn-tag": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "tenant": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "route-tag": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "end-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "fqdn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "host": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "host-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "any",
                    "specific"
                ],
                "type": "str"
            },
            "ip6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "list": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "net-id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "obj-id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "obj-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sdn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "nsx"
                ],
                "type": "str"
            },
            "start-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "subnet-segment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "any",
                            "specific"
                        ],
                        "type": "str"
                    },
                    "value": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "tagging": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "category": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "tags": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    }
                },
                "elements": "dict"
            },
            "template": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ipprefix",
                    "iprange",
                    "nsx",
                    "dynamic",
                    "fqdn",
                    "template",
                    "mac",
                    "geography",
                    "route-tag"
                ],
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "visibility": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tags": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "profile-list": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "profile-id": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "_image-base64": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "end-mac": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "start-mac": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "country": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "global-object": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fabric-object": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "macaddr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "epg-name": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sdn-tag": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tenant": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "route-tag": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "firewall_address6_dynamicmapping": {
        "stated": true,
        "options": {
            "_scope": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "cache-ttl": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "color": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "end-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "fqdn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "host": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "host-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "any",
                    "specific"
                ],
                "type": "str"
            },
            "ip6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "obj-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sdn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "nsx"
                ],
                "type": "str"
            },
            "start-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "template": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ipprefix",
                    "iprange",
                    "nsx",
                    "dynamic",
                    "fqdn",
                    "template",
                    "mac",
                    "geography",
                    "route-tag"
                ],
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "visibility": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "subnet-segment": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "any",
                            "specific"
                        ],
                        "type": "str"
                    },
                    "value": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "_image-base64": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "end-mac": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "start-mac": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "country": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "global-object": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fabric-object": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "macaddr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "epg-name": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sdn-tag": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tenant": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "route-tag": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "firewall_address6_dynamicmapping_subnetsegment": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "any",
                    "specific"
                ],
                "type": "str"
            },
            "value": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "firewall_address6_list": {
        "stated": true,
        "options": {
            "ip": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "net-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "obj-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "firewall_address6_profilelist": {
        "stated": true,
        "options": {
            "profile-id": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            }
        }
    },
    "firewall_address6_subnetsegment": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "any",
                    "specific"
                ],
                "type": "str"
            },
            "value": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "firewall_address6_tagging": {
        "stated": true,
        "options": {
            "category": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "firewall_address6template": {
        "stated": true,
        "options": {
            "ip6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "subnet-segment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "bits": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "exclusive": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "values": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "value": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    }
                },
                "elements": "dict"
            },
            "subnet-segment-count": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "_image-base64": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "fabric-object": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "firewall_address6template_subnetsegment": {
        "stated": true,
        "options": {
            "bits": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "exclusive": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "values": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "value": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "firewall_address6template_subnetsegment_values": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "value": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "firewall_address_dynamicmapping": {
        "stated": true,
        "options": {
            "_scope": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "allow-routing": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "associated-interface": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cache-ttl": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "color": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "country": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "end-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "end-mac": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "epg-name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "filter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "fqdn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "interface": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "obj-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "organization": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "policy-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sdn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "aci",
                    "aws",
                    "nsx",
                    "nuage",
                    "azure",
                    "gcp",
                    "oci",
                    "openstack"
                ],
                "type": "str"
            },
            "sdn-addr-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "private",
                    "public",
                    "all"
                ],
                "type": "str"
            },
            "sdn-tag": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "start-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "start-mac": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "subnet": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "subnet-name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "tenant": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ipmask",
                    "iprange",
                    "fqdn",
                    "wildcard",
                    "geography",
                    "url",
                    "wildcard-fqdn",
                    "nsx",
                    "aws",
                    "dynamic",
                    "interface-subnet",
                    "mac",
                    "fqdn-group",
                    "route-tag"
                ],
                "type": "str"
            },
            "url": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "visibility": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "wildcard": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "wildcard-fqdn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "_image-base64": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "clearpass-spt": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "unknown",
                    "healthy",
                    "quarantine",
                    "checkup",
                    "transition",
                    "infected",
                    "transient"
                ],
                "type": "str"
            },
            "fsso-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "sub-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "sdn",
                    "clearpass-spt",
                    "fsso",
                    "ems-tag",
                    "swc-tag",
                    "fortivoice-tag",
                    "fortinac-tag",
                    "fortipolicy-tag",
                    "device-identification"
                ],
                "type": "str"
            },
            "global-object": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "obj-tag": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "obj-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ip",
                    "mac"
                ],
                "type": "str"
            },
            "fabric-object": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "macaddr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "node-ip-only": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dirty": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "dirty",
                    "clean"
                ],
                "type": "str"
            },
            "pattern-end": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "pattern-start": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tag-detection-level": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tag-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "hw-model": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "hw-vendor": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "os": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "route-tag": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "sw-version": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "firewall_address_list": {
        "stated": true,
        "options": {
            "ip": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "net-id": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "obj-id": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "firewall_address_profilelist": {
        "stated": true,
        "options": {
            "profile-id": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            }
        }
    },
    "firewall_address_tagging": {
        "stated": true,
        "options": {
            "category": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "firewall_addrgrp": {
        "stated": true,
        "options": {
            "allow-routing": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "color": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "comment": {
                "required": false,
                "type": "raw"
            },
            "dynamic_mapping": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "_scope": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "vdom": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "allow-routing": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "color": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "comment": {
                        "required": false,
                        "type": "raw"
                    },
                    "exclude": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "exclude-member": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "member": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "elements": "str"
                    },
                    "tags": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "uuid": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "visibility": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "_image-base64": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "global-object": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "default",
                            "array",
                            "folder"
                        ],
                        "type": "str"
                    },
                    "fabric-object": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "category": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "default",
                            "ztna-ems-tag",
                            "ztna-geo-tag"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "member": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "elements": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tagging": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "category": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "tags": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    }
                },
                "elements": "dict"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "visibility": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "exclude": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "exclude-member": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "tags": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "_image-base64": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "global-object": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "default",
                    "array",
                    "folder"
                ],
                "type": "str"
            },
            "fabric-object": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "category": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "default",
                    "ztna-ems-tag",
                    "ztna-geo-tag"
                ],
                "type": "str"
            }
        }
    },
    "firewall_addrgrp6": {
        "stated": true,
        "options": {
            "color": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dynamic_mapping": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "_scope": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "vdom": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "color": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "comment": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "member": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "tags": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "uuid": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "visibility": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "_image-base64": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "global-object": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "fabric-object": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "exclude": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "exclude-member": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    }
                },
                "elements": "dict"
            },
            "member": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tagging": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "category": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "tags": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    }
                },
                "elements": "dict"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "visibility": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tags": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "_image-base64": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "global-object": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fabric-object": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "exclude": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "exclude-member": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "firewall_addrgrp6_dynamicmapping": {
        "stated": true,
        "options": {
            "_scope": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "color": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "member": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "tags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "visibility": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "_image-base64": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "global-object": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fabric-object": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "exclude": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "exclude-member": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "firewall_addrgrp6_tagging": {
        "stated": true,
        "options": {
            "category": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "firewall_addrgrp_dynamicmapping": {
        "stated": true,
        "options": {
            "_scope": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "allow-routing": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "color": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "exclude": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "exclude-member": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "member": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "tags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "visibility": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "_image-base64": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "global-object": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "default",
                    "array",
                    "folder"
                ],
                "type": "str"
            },
            "fabric-object": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "category": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "default",
                    "ztna-ems-tag",
                    "ztna-geo-tag"
                ],
                "type": "str"
            }
        }
    },
    "firewall_addrgrp_tagging": {
        "stated": true,
        "options": {
            "category": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "firewall_carrierendpointbwl": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "entries": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "block",
                            "exempt",
                            "exempt-mass-mms"
                        ],
                        "elements": "str"
                    },
                    "carrier-endpoint": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "log-action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "archive",
                            "intercept"
                        ],
                        "elements": "str"
                    },
                    "pattern-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "wildcard",
                            "regexp",
                            "simple"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "firewall_carrierendpointbwl_entries": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "block",
                    "exempt",
                    "exempt-mass-mms"
                ],
                "elements": "str"
            },
            "carrier-endpoint": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "log-action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "archive",
                    "intercept"
                ],
                "elements": "str"
            },
            "pattern-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "wildcard",
                    "regexp",
                    "simple"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "firewall_casbprofile": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "saas-application": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "access-rule": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "action": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "choices": [
                                    "block",
                                    "monitor",
                                    "bypass"
                                ],
                                "type": "str"
                            },
                            "bypass": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "list",
                                "choices": [
                                    "av",
                                    "dlp",
                                    "web-filter",
                                    "file-filter",
                                    "video-filter"
                                ],
                                "elements": "str"
                            },
                            "name": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "custom-control": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "name": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "option": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "list",
                                "options": {
                                    "name": {
                                        "required": false,
                                        "revision": {
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "user-input": {
                                        "required": false,
                                        "revision": {
                                            "7.4.1": true
                                        },
                                        "type": "list",
                                        "elements": "str"
                                    }
                                },
                                "elements": "dict"
                            }
                        },
                        "elements": "dict"
                    },
                    "domain-control": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "domain-control-domains": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "list",
                        "elements": "str"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "safe-search": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "safe-search-control": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "list",
                        "elements": "str"
                    },
                    "tenant-control": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "tenant-control-tenants": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "list",
                        "elements": "str"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "firewall_casbprofile_saasapplication": {
        "stated": true,
        "options": {
            "access-rule": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "block",
                            "monitor",
                            "bypass"
                        ],
                        "type": "str"
                    },
                    "bypass": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "av",
                            "dlp",
                            "web-filter",
                            "file-filter",
                            "video-filter"
                        ],
                        "elements": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "custom-control": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "option": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "name": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "user-input": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "list",
                                "elements": "str"
                            }
                        },
                        "elements": "dict"
                    }
                },
                "elements": "dict"
            },
            "domain-control": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "domain-control-domains": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "list",
                "elements": "str"
            },
            "log": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "safe-search": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "safe-search-control": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "list",
                "elements": "str"
            },
            "tenant-control": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tenant-control-tenants": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "list",
                "elements": "str"
            }
        }
    },
    "firewall_casbprofile_saasapplication_accessrule": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "block",
                    "monitor",
                    "bypass"
                ],
                "type": "str"
            },
            "bypass": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "av",
                    "dlp",
                    "web-filter",
                    "file-filter",
                    "video-filter"
                ],
                "elements": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "firewall_casbprofile_saasapplication_customcontrol": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "option": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "user-input": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "list",
                        "elements": "str"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "firewall_casbprofile_saasapplication_customcontrol_option": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "user-input": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "list",
                "elements": "str"
            }
        }
    },
    "firewall_decryptedtrafficmirror": {
        "stated": true,
        "options": {
            "dstmac": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "interface": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "traffic-source": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "client",
                    "server",
                    "both"
                ],
                "type": "str"
            },
            "traffic-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "ssl",
                    "ssh"
                ],
                "elements": "str"
            }
        }
    },
    "firewall_explicitproxyaddress": {
        "stated": true,
        "options": {
            "case-sensitivity": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "category": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "color": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "header": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "header-group": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "case-sensitivity": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "header": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "header-name": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "header-name": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "host": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "host-regex": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "method": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "choices": [
                    "delete",
                    "get",
                    "head",
                    "options",
                    "post",
                    "put",
                    "trace",
                    "connect"
                ],
                "elements": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "path": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "tags": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "host-regex",
                    "url",
                    "category",
                    "method",
                    "ua",
                    "header",
                    "src-advanced",
                    "dst-advanced"
                ],
                "type": "str"
            },
            "ua": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "choices": [
                    "chrome",
                    "ms",
                    "firefox",
                    "safari",
                    "other"
                ],
                "elements": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "visibility": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "firewall_explicitproxyaddress_headergroup": {
        "stated": true,
        "options": {
            "case-sensitivity": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "header": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "header-name": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            }
        }
    },
    "firewall_explicitproxyaddrgrp": {
        "stated": true,
        "options": {
            "color": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "member": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "tags": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "src",
                    "dst"
                ],
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "visibility": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "firewall_gtp": {
        "stated": true,
        "options": {
            "addr-notify": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "apn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "deny"
                        ],
                        "type": "str"
                    },
                    "apnmember": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "selection-mode": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "ms",
                            "net",
                            "vrf"
                        ],
                        "elements": "str"
                    }
                },
                "elements": "dict"
            },
            "apn-filter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "authorized-ggsns": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "authorized-sgsns": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "context-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "control-plane-message-rate-limit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "default-apn-action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "default-imsi-action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "default-ip-action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "default-noip-action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "default-policy-action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "denied-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "echo-request-interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "extension-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "forwarded-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "global-tunnel-limit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "gtp-in-gtp": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "gtpu-denied-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "gtpu-forwarded-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "gtpu-log-freq": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "half-close-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "half-open-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "handover-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ie-remove-policy": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "remove-ies": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "apn-restriction",
                            "rat-type",
                            "rai",
                            "uli",
                            "imei"
                        ],
                        "elements": "str"
                    },
                    "sgsn-addr": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sgsn-addr6": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "ie-remover": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ie-white-list-v0v1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ie-white-list-v2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "imsi": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "deny"
                        ],
                        "type": "str"
                    },
                    "apnmember": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "mcc-mnc": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "msisdn-prefix": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "selection-mode": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "ms",
                            "net",
                            "vrf"
                        ],
                        "elements": "str"
                    }
                },
                "elements": "dict"
            },
            "imsi-filter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "interface-notify": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "invalid-reserved-field": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "invalid-sgsns-to-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ip-filter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ip-policy": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "deny"
                        ],
                        "type": "str"
                    },
                    "dstaddr": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "srcaddr": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "dstaddr6": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "srcaddr6": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "log-freq": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "log-gtpu-limit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "log-imsi-prefix": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "log-msisdn-prefix": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "max-message-length": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "message-filter-v0v1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "message-filter-v2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "min-message-length": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "miss-must-ie": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "monitor-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "vdom"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "noip-filter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "noip-policy": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "deny"
                        ],
                        "type": "str"
                    },
                    "end": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "start": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "etsi",
                            "ietf"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "out-of-state-ie": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "out-of-state-message": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "per-apn-shaper": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "apn": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "rate-limit": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "version": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "policy": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "deny"
                        ],
                        "type": "str"
                    },
                    "apn-sel-mode": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "ms",
                            "net",
                            "vrf"
                        ],
                        "elements": "str"
                    },
                    "apnmember": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "imei": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "imsi": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "max-apn-restriction": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "all",
                            "public-1",
                            "public-2",
                            "private-1",
                            "private-2"
                        ],
                        "type": "str"
                    },
                    "messages": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "create-req",
                            "create-res",
                            "update-req",
                            "update-res"
                        ],
                        "elements": "str"
                    },
                    "msisdn": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "rai": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "rat-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "any",
                            "utran",
                            "geran",
                            "wlan",
                            "gan",
                            "hspa",
                            "eutran",
                            "virtual",
                            "nbiot"
                        ],
                        "elements": "str"
                    },
                    "uli": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "imsi-prefix": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "msisdn-prefix": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "apn": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "policy-filter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "port-notify": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "rate-limit-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "per-profile",
                    "per-stream",
                    "per-apn"
                ],
                "type": "str"
            },
            "rate-limited-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "rate-sampling-interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "remove-if-echo-expires": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "remove-if-recovery-differ": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "reserved-ie": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "send-delete-when-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "send-delete-when-timeout-v2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "spoof-src-addr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "state-invalid-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "traffic-count-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tunnel-limit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tunnel-limit-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tunnel-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "unknown-version-action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "user-plane-message-rate-limit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "warning-threshold": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "policy-v2": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "deny",
                            "allow"
                        ],
                        "type": "str"
                    },
                    "apn-sel-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "ms",
                            "net",
                            "vrf"
                        ],
                        "elements": "str"
                    },
                    "apnmember": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "imsi-prefix": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "max-apn-restriction": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "all",
                            "public-1",
                            "public-2",
                            "private-1",
                            "private-2"
                        ],
                        "type": "str"
                    },
                    "mei": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "messages": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "create-ses-req",
                            "create-ses-res",
                            "modify-bearer-req",
                            "modify-bearer-res"
                        ],
                        "elements": "str"
                    },
                    "msisdn-prefix": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "rat-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "any",
                            "utran",
                            "geran",
                            "wlan",
                            "gan",
                            "hspa",
                            "eutran",
                            "virtual",
                            "nbiot",
                            "ltem",
                            "nr"
                        ],
                        "elements": "str"
                    },
                    "uli": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    }
                },
                "elements": "dict"
            },
            "sub-second-interval": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "0.1",
                    "0.25",
                    "0.5"
                ],
                "type": "str"
            },
            "sub-second-sampling": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "authorized-ggsns6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "authorized-sgsns6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "handover-group6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "invalid-sgsns6-to-log": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ie-validation": {
                "required": false,
                "type": "dict",
                "options": {
                    "apn-restriction": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "charging-ID": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "charging-gateway-addr": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "end-user-addr": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "gsn-addr": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "imei": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "imsi": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "mm-context": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ms-tzone": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ms-validated": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "msisdn": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "nsapi": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "pdp-context": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "qos-profile": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "rai": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "rat-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "reordering-required": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "selection-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "uli": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "message-rate-limit": {
                "required": false,
                "type": "dict",
                "options": {
                    "create-aa-pdp-request": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "create-aa-pdp-response": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "create-mbms-request": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "create-mbms-response": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "create-pdp-request": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "create-pdp-response": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "delete-aa-pdp-request": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "delete-aa-pdp-response": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "delete-mbms-request": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "delete-mbms-response": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "delete-pdp-request": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "delete-pdp-response": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "echo-reponse": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "echo-request": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "error-indication": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "failure-report-request": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "failure-report-response": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "fwd-reloc-complete-ack": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "fwd-relocation-complete": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "fwd-relocation-request": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "fwd-relocation-response": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "fwd-srns-context": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "fwd-srns-context-ack": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "g-pdu": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "identification-request": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "identification-response": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "mbms-de-reg-request": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "mbms-de-reg-response": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "mbms-notify-rej-request": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "mbms-notify-rej-response": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "mbms-notify-request": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "mbms-notify-response": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "mbms-reg-request": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "mbms-reg-response": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "mbms-ses-start-request": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "mbms-ses-start-response": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "mbms-ses-stop-request": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "mbms-ses-stop-response": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "note-ms-request": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "note-ms-response": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "pdu-notify-rej-request": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "pdu-notify-rej-response": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "pdu-notify-request": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "pdu-notify-response": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ran-info": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "relocation-cancel-request": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "relocation-cancel-response": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "send-route-request": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "send-route-response": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "sgsn-context-ack": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "sgsn-context-request": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "sgsn-context-response": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "support-ext-hdr-notify": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "update-mbms-request": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "update-mbms-response": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "update-pdp-request": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "update-pdp-response": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "version-not-support": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                }
            },
            "message-rate-limit-v0": {
                "required": false,
                "type": "dict",
                "options": {
                    "create-pdp-request": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "delete-pdp-request": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "echo-request": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                }
            },
            "message-rate-limit-v1": {
                "required": false,
                "type": "dict",
                "options": {
                    "create-pdp-request": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "delete-pdp-request": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "echo-request": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                }
            },
            "message-rate-limit-v2": {
                "required": false,
                "type": "dict",
                "options": {
                    "create-session-request": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "delete-session-request": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "echo-request": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                }
            },
            "ie-allow-list-v0v1": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ie-allow-list-v2": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "rat-timeout-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "message-filter": {
                "required": false,
                "type": "dict",
                "options": {
                    "create-aa-pdp": {
                        "required": false,
                        "revision": {
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "allow",
                            "deny"
                        ],
                        "type": "str"
                    },
                    "create-mbms": {
                        "required": false,
                        "revision": {
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "allow",
                            "deny"
                        ],
                        "type": "str"
                    },
                    "create-pdp": {
                        "required": false,
                        "revision": {
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "allow",
                            "deny"
                        ],
                        "type": "str"
                    },
                    "data-record": {
                        "required": false,
                        "revision": {
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "allow",
                            "deny"
                        ],
                        "type": "str"
                    },
                    "delete-aa-pdp": {
                        "required": false,
                        "revision": {
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "allow",
                            "deny"
                        ],
                        "type": "str"
                    },
                    "delete-mbms": {
                        "required": false,
                        "revision": {
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "allow",
                            "deny"
                        ],
                        "type": "str"
                    },
                    "delete-pdp": {
                        "required": false,
                        "revision": {
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "allow",
                            "deny"
                        ],
                        "type": "str"
                    },
                    "echo": {
                        "required": false,
                        "revision": {
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "allow",
                            "deny"
                        ],
                        "type": "str"
                    },
                    "error-indication": {
                        "required": false,
                        "revision": {
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "allow",
                            "deny"
                        ],
                        "type": "str"
                    },
                    "failure-report": {
                        "required": false,
                        "revision": {
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "allow",
                            "deny"
                        ],
                        "type": "str"
                    },
                    "fwd-relocation": {
                        "required": false,
                        "revision": {
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "allow",
                            "deny"
                        ],
                        "type": "str"
                    },
                    "fwd-srns-context": {
                        "required": false,
                        "revision": {
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "allow",
                            "deny"
                        ],
                        "type": "str"
                    },
                    "gtp-pdu": {
                        "required": false,
                        "revision": {
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "allow",
                            "deny"
                        ],
                        "type": "str"
                    },
                    "identification": {
                        "required": false,
                        "revision": {
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "allow",
                            "deny"
                        ],
                        "type": "str"
                    },
                    "mbms-notification": {
                        "required": false,
                        "revision": {
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "allow",
                            "deny"
                        ],
                        "type": "str"
                    },
                    "node-alive": {
                        "required": false,
                        "revision": {
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "allow",
                            "deny"
                        ],
                        "type": "str"
                    },
                    "note-ms-present": {
                        "required": false,
                        "revision": {
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "allow",
                            "deny"
                        ],
                        "type": "str"
                    },
                    "pdu-notification": {
                        "required": false,
                        "revision": {
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "allow",
                            "deny"
                        ],
                        "type": "str"
                    },
                    "ran-info": {
                        "required": false,
                        "revision": {
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "allow",
                            "deny"
                        ],
                        "type": "str"
                    },
                    "redirection": {
                        "required": false,
                        "revision": {
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "allow",
                            "deny"
                        ],
                        "type": "str"
                    },
                    "relocation-cancel": {
                        "required": false,
                        "revision": {
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "allow",
                            "deny"
                        ],
                        "type": "str"
                    },
                    "send-route": {
                        "required": false,
                        "revision": {
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "allow",
                            "deny"
                        ],
                        "type": "str"
                    },
                    "sgsn-context": {
                        "required": false,
                        "revision": {
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "allow",
                            "deny"
                        ],
                        "type": "str"
                    },
                    "support-extension": {
                        "required": false,
                        "revision": {
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "allow",
                            "deny"
                        ],
                        "type": "str"
                    },
                    "unknown-message-action": {
                        "required": false,
                        "revision": {
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "allow",
                            "deny"
                        ],
                        "type": "str"
                    },
                    "update-mbms": {
                        "required": false,
                        "revision": {
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "allow",
                            "deny"
                        ],
                        "type": "str"
                    },
                    "update-pdp": {
                        "required": false,
                        "revision": {
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "allow",
                            "deny"
                        ],
                        "type": "str"
                    },
                    "version-not-support": {
                        "required": false,
                        "revision": {
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "allow",
                            "deny"
                        ],
                        "type": "str"
                    }
                }
            }
        }
    },
    "firewall_gtp_apn": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "apnmember": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "selection-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "ms",
                    "net",
                    "vrf"
                ],
                "elements": "str"
            }
        }
    },
    "firewall_gtp_ieremovepolicy": {
        "stated": true,
        "options": {
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "remove-ies": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "apn-restriction",
                    "rat-type",
                    "rai",
                    "uli",
                    "imei"
                ],
                "elements": "str"
            },
            "sgsn-addr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sgsn-addr6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "firewall_gtp_ievalidation": {
        "stated": false,
        "options": {
            "apn-restriction": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "charging-ID": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "charging-gateway-addr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "end-user-addr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "gsn-addr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "imei": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "imsi": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mm-context": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ms-tzone": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ms-validated": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "msisdn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "nsapi": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "pdp-context": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "qos-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "rai": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "rat-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "reordering-required": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "selection-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "uli": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "firewall_gtp_imsi": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "apnmember": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mcc-mnc": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "msisdn-prefix": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "selection-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "ms",
                    "net",
                    "vrf"
                ],
                "elements": "str"
            }
        }
    },
    "firewall_gtp_ippolicy": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "dstaddr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "srcaddr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dstaddr6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "srcaddr6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "firewall_gtp_messagefilter": {
        "stated": false,
        "options": {
            "create-aa-pdp": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "create-mbms": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "create-pdp": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "data-record": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "delete-aa-pdp": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "delete-mbms": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "delete-pdp": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "echo": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "error-indication": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "failure-report": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "fwd-relocation": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "fwd-srns-context": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "gtp-pdu": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "identification": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "mbms-notification": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "node-alive": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "note-ms-present": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "pdu-notification": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "ran-info": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "redirection": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "relocation-cancel": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "send-route": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "sgsn-context": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "support-extension": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "unknown-message-action": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "update-mbms": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "update-pdp": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "version-not-support": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            }
        }
    },
    "firewall_gtp_messageratelimit": {
        "stated": false,
        "options": {
            "create-aa-pdp-request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "create-aa-pdp-response": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "create-mbms-request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "create-mbms-response": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "create-pdp-request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "create-pdp-response": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "delete-aa-pdp-request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "delete-aa-pdp-response": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "delete-mbms-request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "delete-mbms-response": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "delete-pdp-request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "delete-pdp-response": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "echo-reponse": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "echo-request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "error-indication": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "failure-report-request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "failure-report-response": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fwd-reloc-complete-ack": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fwd-relocation-complete": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fwd-relocation-request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fwd-relocation-response": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fwd-srns-context": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fwd-srns-context-ack": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "g-pdu": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "identification-request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "identification-response": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mbms-de-reg-request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mbms-de-reg-response": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mbms-notify-rej-request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mbms-notify-rej-response": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mbms-notify-request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mbms-notify-response": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mbms-reg-request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mbms-reg-response": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mbms-ses-start-request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mbms-ses-start-response": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mbms-ses-stop-request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mbms-ses-stop-response": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "note-ms-request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "note-ms-response": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "pdu-notify-rej-request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "pdu-notify-rej-response": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "pdu-notify-request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "pdu-notify-response": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ran-info": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "relocation-cancel-request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "relocation-cancel-response": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "send-route-request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "send-route-response": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "sgsn-context-ack": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "sgsn-context-request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "sgsn-context-response": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "support-ext-hdr-notify": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "update-mbms-request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "update-mbms-response": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "update-pdp-request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "update-pdp-response": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "version-not-support": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "firewall_gtp_messageratelimitv0": {
        "stated": false,
        "options": {
            "create-pdp-request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "delete-pdp-request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "echo-request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "firewall_gtp_messageratelimitv1": {
        "stated": false,
        "options": {
            "create-pdp-request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "delete-pdp-request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "echo-request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "firewall_gtp_messageratelimitv2": {
        "stated": false,
        "options": {
            "create-session-request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "delete-session-request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "echo-request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "firewall_gtp_noippolicy": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "end": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "start": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "etsi",
                    "ietf"
                ],
                "type": "str"
            }
        }
    },
    "firewall_gtp_perapnshaper": {
        "stated": true,
        "options": {
            "apn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "rate-limit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "version": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "firewall_gtp_policy": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "apn-sel-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "ms",
                    "net",
                    "vrf"
                ],
                "elements": "str"
            },
            "apnmember": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "imei": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "imsi": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "max-apn-restriction": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "all",
                    "public-1",
                    "public-2",
                    "private-1",
                    "private-2"
                ],
                "type": "str"
            },
            "messages": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "create-req",
                    "create-res",
                    "update-req",
                    "update-res"
                ],
                "elements": "str"
            },
            "msisdn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "rai": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "rat-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "any",
                    "utran",
                    "geran",
                    "wlan",
                    "gan",
                    "hspa",
                    "eutran",
                    "virtual",
                    "nbiot"
                ],
                "elements": "str"
            },
            "uli": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "imsi-prefix": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "msisdn-prefix": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "apn": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "firewall_gtp_policyv2": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "deny",
                    "allow"
                ],
                "type": "str"
            },
            "apn-sel-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "ms",
                    "net",
                    "vrf"
                ],
                "elements": "str"
            },
            "apnmember": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "imsi-prefix": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "max-apn-restriction": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "all",
                    "public-1",
                    "public-2",
                    "private-1",
                    "private-2"
                ],
                "type": "str"
            },
            "mei": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "messages": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "create-ses-req",
                    "create-ses-res",
                    "modify-bearer-req",
                    "modify-bearer-res"
                ],
                "elements": "str"
            },
            "msisdn-prefix": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "rat-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "any",
                    "utran",
                    "geran",
                    "wlan",
                    "gan",
                    "hspa",
                    "eutran",
                    "virtual",
                    "nbiot",
                    "ltem",
                    "nr"
                ],
                "elements": "str"
            },
            "uli": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "firewall_identitybasedroute": {
        "stated": true,
        "options": {
            "comments": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "rule": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "device": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "gateway": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "groups": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "firewall_identitybasedroute_rule": {
        "stated": true,
        "options": {
            "device": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "gateway": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "groups": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "firewall_internetservice": {
        "stated": false,
        "options": {
            "database": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "isdb",
                    "irdb"
                ],
                "type": "str"
            },
            "direction": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "src",
                    "dst",
                    "both"
                ],
                "type": "str"
            },
            "entry": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "ip-number": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "ip-range-number": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "port": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "raw"
                    },
                    "protocol": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "icon-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "offset": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "reputation": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "sld-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "extra-ip-range-number": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip-number": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip-range-number": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "jitter-threshold": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "latency-threshold": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "obsolete": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "packetloss-threshold": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "singularity": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "city": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "country": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "region": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "city6": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "country6": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "extra-ip6-range-number": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip6-range-number": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "region6": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "firewall_internetservice_entry": {
        "stated": true,
        "options": {
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "ip-number": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "ip-range-number": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            }
        }
    },
    "firewall_internetserviceaddition": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "entry": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "port-range": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "end-port": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "start-port": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            }
                        },
                        "elements": "dict"
                    },
                    "protocol": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "addr-mode": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ipv4",
                            "ipv6"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "firewall_internetserviceaddition_entry": {
        "stated": true,
        "options": {
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "port-range": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "end-port": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "start-port": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "addr-mode": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ipv4",
                    "ipv6"
                ],
                "type": "str"
            }
        }
    },
    "firewall_internetserviceaddition_entry_portrange": {
        "stated": true,
        "options": {
            "end-port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "start-port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "firewall_internetservicecustom": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "disable-entry": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "ip-range": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "list",
                        "options": {
                            "end-ip": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": false,
                                    "7.2.3": false,
                                    "7.2.4": false,
                                    "7.4.0": false,
                                    "7.4.1": false
                                },
                                "type": "str"
                            },
                            "id": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": false,
                                    "7.2.3": false,
                                    "7.2.4": false,
                                    "7.4.0": false,
                                    "7.4.1": false
                                },
                                "type": "int"
                            },
                            "start-ip": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": false,
                                    "7.2.3": false,
                                    "7.2.4": false,
                                    "7.4.0": false,
                                    "7.4.1": false
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "port": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "raw"
                    },
                    "protocol": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "entry": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "dst": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "port-range": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "end-port": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "id": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "start-port": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            }
                        },
                        "elements": "dict"
                    },
                    "protocol": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "addr-mode": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ipv4",
                            "ipv6"
                        ],
                        "type": "str"
                    },
                    "dst6": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    }
                },
                "elements": "dict"
            },
            "master-service-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "reputation": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "firewall_internetservicecustom_disableentry": {
        "stated": true,
        "options": {
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "ip-range": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "end-ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "start-ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            }
        }
    },
    "firewall_internetservicecustom_disableentry_iprange": {
        "stated": true,
        "options": {
            "end-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "start-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "firewall_internetservicecustom_entry": {
        "stated": true,
        "options": {
            "dst": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "port-range": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "end-port": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "start-port": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "addr-mode": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ipv4",
                    "ipv6"
                ],
                "type": "str"
            },
            "dst6": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "firewall_internetservicecustom_entry_portrange": {
        "stated": true,
        "options": {
            "end-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "start-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "firewall_internetservicecustomgroup": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "member": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "firewall_internetservicegroup": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "member": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "direction": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "both",
                    "source",
                    "destination"
                ],
                "type": "str"
            }
        }
    },
    "firewall_internetservicename": {
        "stated": true,
        "options": {
            "city-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "country-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "internet-service-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "region-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "default",
                    "location"
                ],
                "type": "str"
            }
        }
    },
    "firewall_ippool": {
        "stated": true,
        "options": {
            "arp-intf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "arp-reply": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "associated-interface": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "block-size": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "comments": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dynamic_mapping": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "_scope": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "vdom": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "arp-intf": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "arp-reply": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "associated-interface": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "block-size": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "comments": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "endip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "num-blocks-per-user": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "pba-timeout": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "permit-any-host": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "source-endip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "source-startip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "startip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "overload",
                            "one-to-one",
                            "fixed-port-range",
                            "port-block-allocation",
                            "cgn-resource-allocation"
                        ],
                        "type": "str"
                    },
                    "cgn-block-size": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "cgn-client-endip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "cgn-client-startip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "cgn-fixedalloc": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "cgn-overload": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "cgn-port-end": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "cgn-port-start": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "cgn-spa": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "utilization-alarm-clear": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "utilization-alarm-raise": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "endport": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "port-per-user": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "startport": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "add-nat64-route": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "cgn-client-ipv6shift": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "nat64": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "subnet-broadcast-in-ippool": {
                        "required": false,
                        "revision": {
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": false,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "exclude-ip": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    }
                },
                "elements": "dict"
            },
            "endip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "num-blocks-per-user": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "pba-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "permit-any-host": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "source-endip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "source-startip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "startip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "overload",
                    "one-to-one",
                    "fixed-port-range",
                    "port-block-allocation",
                    "cgn-resource-allocation"
                ],
                "type": "str"
            },
            "utilization-alarm-clear": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "cgn-fixedalloc": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "cgn-client-startip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cgn-client-endip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cgn-overload": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "cgn-block-size": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "utilization-alarm-raise": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "cgn-port-start": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "cgn-spa": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "cgn-port-end": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "endport": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "port-per-user": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "startport": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "add-nat64-route": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "nat64": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "cgn-client-ipv6shift": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "subnet-broadcast-in-ippool": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "exclude-ip": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "firewall_ippool6": {
        "stated": true,
        "options": {
            "comments": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dynamic_mapping": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "_scope": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "vdom": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "comments": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "endip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "startip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "add-nat46-route": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "nat46": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "endip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "startip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "add-nat46-route": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "nat46": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "firewall_ippool6_dynamicmapping": {
        "stated": true,
        "options": {
            "_scope": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "comments": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "endip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "startip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "add-nat46-route": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "nat46": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "firewall_ippool_dynamicmapping": {
        "stated": true,
        "options": {
            "_scope": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "arp-intf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "arp-reply": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "associated-interface": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "block-size": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "comments": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "endip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "num-blocks-per-user": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "pba-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "permit-any-host": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "source-endip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "source-startip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "startip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "overload",
                    "one-to-one",
                    "fixed-port-range",
                    "port-block-allocation",
                    "cgn-resource-allocation"
                ],
                "type": "str"
            },
            "cgn-block-size": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "cgn-client-endip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cgn-client-startip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cgn-fixedalloc": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "cgn-overload": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "cgn-port-end": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "cgn-port-start": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "cgn-spa": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "utilization-alarm-clear": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "utilization-alarm-raise": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "endport": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "port-per-user": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "startport": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "add-nat64-route": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "cgn-client-ipv6shift": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "nat64": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "subnet-broadcast-in-ippool": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "exclude-ip": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "firewall_ippoolgrp": {
        "stated": true,
        "options": {
            "comments": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "member": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "firewall_ldbmonitor": {
        "stated": true,
        "options": {
            "http-get": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "http-match": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "http-max-redirects": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "retry": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ping",
                    "tcp",
                    "http",
                    "passive-sip",
                    "https",
                    "dns"
                ],
                "type": "str"
            },
            "src-ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dns-match-ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dns-protocol": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "udp",
                    "tcp"
                ],
                "type": "str"
            },
            "dns-request-domain": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "firewall_mmsprofile": {
        "stated": true,
        "options": {
            "avnotificationtable": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "bwordtable": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "carrier-endpoint-prefix": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "carrier-endpoint-prefix-range-max": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "carrier-endpoint-prefix-range-min": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "carrier-endpoint-prefix-string": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "carrierendpointbwltable": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "mm1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "avmonitor",
                    "block",
                    "oversize",
                    "quarantine",
                    "scan",
                    "avquery",
                    "bannedword",
                    "no-content-summary",
                    "archive-summary",
                    "archive-full",
                    "carrier-endpoint-bwl",
                    "remove-blocked",
                    "chunkedbypass",
                    "clientcomfort",
                    "servercomfort",
                    "strict-file",
                    "mms-checksum"
                ],
                "elements": "str"
            },
            "mm1-addr-hdr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "mm1-addr-source": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "http-header",
                    "cookie"
                ],
                "type": "str"
            },
            "mm1-convert-hex": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mm1-outbreak-prevention": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disabled",
                    "files",
                    "full-archive"
                ],
                "type": "str"
            },
            "mm1-retr-dupe": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mm1-retrieve-scan": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mm1comfortamount": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mm1comfortinterval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mm1oversizelimit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mm3": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "avmonitor",
                    "block",
                    "oversize",
                    "quarantine",
                    "scan",
                    "avquery",
                    "bannedword",
                    "no-content-summary",
                    "archive-summary",
                    "archive-full",
                    "carrier-endpoint-bwl",
                    "remove-blocked",
                    "fragmail",
                    "splice",
                    "mms-checksum"
                ],
                "elements": "str"
            },
            "mm3-outbreak-prevention": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disabled",
                    "files",
                    "full-archive"
                ],
                "type": "str"
            },
            "mm3oversizelimit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mm4": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "avmonitor",
                    "block",
                    "oversize",
                    "quarantine",
                    "scan",
                    "avquery",
                    "bannedword",
                    "no-content-summary",
                    "archive-summary",
                    "archive-full",
                    "carrier-endpoint-bwl",
                    "remove-blocked",
                    "fragmail",
                    "splice",
                    "mms-checksum"
                ],
                "elements": "str"
            },
            "mm4-outbreak-prevention": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disabled",
                    "files",
                    "full-archive"
                ],
                "type": "str"
            },
            "mm4oversizelimit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mm7": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "avmonitor",
                    "block",
                    "oversize",
                    "quarantine",
                    "scan",
                    "avquery",
                    "bannedword",
                    "no-content-summary",
                    "archive-summary",
                    "archive-full",
                    "carrier-endpoint-bwl",
                    "remove-blocked",
                    "chunkedbypass",
                    "clientcomfort",
                    "servercomfort",
                    "strict-file",
                    "mms-checksum"
                ],
                "elements": "str"
            },
            "mm7-addr-hdr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "mm7-addr-source": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "http-header",
                    "cookie"
                ],
                "type": "str"
            },
            "mm7-convert-hex": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mm7-outbreak-prevention": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disabled",
                    "files",
                    "full-archive"
                ],
                "type": "str"
            },
            "mm7comfortamount": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mm7comfortinterval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mm7oversizelimit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mms-antispam-mass-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mms-av-block-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mms-av-oversize-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mms-av-virus-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mms-carrier-endpoint-filter-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mms-checksum-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mms-checksum-table": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "mms-notification-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mms-web-content-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mmsbwordthreshold": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "notif-msisdn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "msisdn": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "threshold": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "flood-thresh-1",
                            "flood-thresh-2",
                            "flood-thresh-3",
                            "dupe-thresh-1",
                            "dupe-thresh-2",
                            "dupe-thresh-3"
                        ],
                        "elements": "str"
                    }
                },
                "elements": "dict"
            },
            "remove-blocked-const-length": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "replacemsg-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dupe": {
                "required": false,
                "type": "dict",
                "options": {
                    "action1": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "log",
                            "archive",
                            "intercept",
                            "block",
                            "archive-first",
                            "alert-notif"
                        ],
                        "elements": "str"
                    },
                    "action2": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "log",
                            "archive",
                            "intercept",
                            "block",
                            "archive-first",
                            "alert-notif"
                        ],
                        "elements": "str"
                    },
                    "action3": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "log",
                            "archive",
                            "intercept",
                            "block",
                            "archive-first",
                            "alert-notif"
                        ],
                        "elements": "str"
                    },
                    "block-time1": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "block-time2": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "block-time3": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "limit1": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "limit2": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "limit3": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "protocol": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "status1": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "status2": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "status3": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "window1": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "window2": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "window3": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                }
            },
            "flood": {
                "required": false,
                "type": "dict",
                "options": {
                    "action1": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "log",
                            "archive",
                            "intercept",
                            "block",
                            "archive-first",
                            "alert-notif"
                        ],
                        "elements": "str"
                    },
                    "action2": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "log",
                            "archive",
                            "intercept",
                            "block",
                            "archive-first",
                            "alert-notif"
                        ],
                        "elements": "str"
                    },
                    "action3": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "log",
                            "archive",
                            "intercept",
                            "block",
                            "archive-first",
                            "alert-notif"
                        ],
                        "elements": "str"
                    },
                    "block-time1": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "block-time2": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "block-time3": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "limit1": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "limit2": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "limit3": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "protocol": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "status1": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "status2": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "status3": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "window1": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "window2": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "window3": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                }
            },
            "notification": {
                "required": false,
                "type": "dict",
                "options": {
                    "alert-int": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "alert-int-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "hours",
                            "minutes"
                        ],
                        "type": "str"
                    },
                    "alert-src-msisdn": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "alert-status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "bword-int": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "bword-int-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "hours",
                            "minutes"
                        ],
                        "type": "str"
                    },
                    "bword-status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "carrier-endpoint-bwl-int": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "carrier-endpoint-bwl-int-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "hours",
                            "minutes"
                        ],
                        "type": "str"
                    },
                    "carrier-endpoint-bwl-status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "days-allowed": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "sunday",
                            "monday",
                            "tuesday",
                            "wednesday",
                            "thursday",
                            "friday",
                            "saturday"
                        ],
                        "elements": "str"
                    },
                    "detect-server": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "dupe-int": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "dupe-int-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "hours",
                            "minutes"
                        ],
                        "type": "str"
                    },
                    "dupe-status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "file-block-int": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "file-block-int-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "hours",
                            "minutes"
                        ],
                        "type": "str"
                    },
                    "file-block-status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "flood-int": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "flood-int-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "hours",
                            "minutes"
                        ],
                        "type": "str"
                    },
                    "flood-status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "from-in-header": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "mms-checksum-int": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "mms-checksum-int-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "hours",
                            "minutes"
                        ],
                        "type": "str"
                    },
                    "mms-checksum-status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "mmsc-hostname": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "mmsc-password": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "mmsc-port": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "mmsc-url": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "mmsc-username": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "msg-protocol": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "mm1",
                            "mm3",
                            "mm4",
                            "mm7"
                        ],
                        "type": "str"
                    },
                    "msg-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "submit-req",
                            "deliver-req"
                        ],
                        "type": "str"
                    },
                    "protocol": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "rate-limit": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "tod-window-duration": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "tod-window-end": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "tod-window-start": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "user-domain": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vas-id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vasp-id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "virus-int": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "virus-int-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "hours",
                            "minutes"
                        ],
                        "type": "str"
                    },
                    "virus-status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "outbreak-prevention": {
                "required": false,
                "type": "dict",
                "options": {
                    "external-blocklist": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ftgd-service": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            }
        }
    },
    "firewall_mmsprofile_dupe": {
        "stated": false,
        "options": {
            "action1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "log",
                    "archive",
                    "intercept",
                    "block",
                    "archive-first",
                    "alert-notif"
                ],
                "elements": "str"
            },
            "action2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "log",
                    "archive",
                    "intercept",
                    "block",
                    "archive-first",
                    "alert-notif"
                ],
                "elements": "str"
            },
            "action3": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "log",
                    "archive",
                    "intercept",
                    "block",
                    "archive-first",
                    "alert-notif"
                ],
                "elements": "str"
            },
            "block-time1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "block-time2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "block-time3": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "limit1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "limit2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "limit3": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "status1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "status2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "status3": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "window1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "window2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "window3": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "firewall_mmsprofile_flood": {
        "stated": false,
        "options": {
            "action1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "log",
                    "archive",
                    "intercept",
                    "block",
                    "archive-first",
                    "alert-notif"
                ],
                "elements": "str"
            },
            "action2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "log",
                    "archive",
                    "intercept",
                    "block",
                    "archive-first",
                    "alert-notif"
                ],
                "elements": "str"
            },
            "action3": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "log",
                    "archive",
                    "intercept",
                    "block",
                    "archive-first",
                    "alert-notif"
                ],
                "elements": "str"
            },
            "block-time1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "block-time2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "block-time3": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "limit1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "limit2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "limit3": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "status1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "status2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "status3": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "window1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "window2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "window3": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "firewall_mmsprofile_notification": {
        "stated": false,
        "options": {
            "alert-int": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "alert-int-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "hours",
                    "minutes"
                ],
                "type": "str"
            },
            "alert-src-msisdn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "alert-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "bword-int": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "bword-int-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "hours",
                    "minutes"
                ],
                "type": "str"
            },
            "bword-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "carrier-endpoint-bwl-int": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "carrier-endpoint-bwl-int-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "hours",
                    "minutes"
                ],
                "type": "str"
            },
            "carrier-endpoint-bwl-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "days-allowed": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "sunday",
                    "monday",
                    "tuesday",
                    "wednesday",
                    "thursday",
                    "friday",
                    "saturday"
                ],
                "elements": "str"
            },
            "detect-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dupe-int": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "dupe-int-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "hours",
                    "minutes"
                ],
                "type": "str"
            },
            "dupe-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "file-block-int": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "file-block-int-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "hours",
                    "minutes"
                ],
                "type": "str"
            },
            "file-block-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "flood-int": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "flood-int-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "hours",
                    "minutes"
                ],
                "type": "str"
            },
            "flood-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "from-in-header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mms-checksum-int": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mms-checksum-int-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "hours",
                    "minutes"
                ],
                "type": "str"
            },
            "mms-checksum-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mmsc-hostname": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "mmsc-password": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "mmsc-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mmsc-url": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "mmsc-username": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "msg-protocol": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "mm1",
                    "mm3",
                    "mm4",
                    "mm7"
                ],
                "type": "str"
            },
            "msg-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "submit-req",
                    "deliver-req"
                ],
                "type": "str"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "rate-limit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tod-window-duration": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tod-window-end": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "tod-window-start": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "user-domain": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vas-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vasp-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "virus-int": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "virus-int-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "hours",
                    "minutes"
                ],
                "type": "str"
            },
            "virus-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "firewall_mmsprofile_notifmsisdn": {
        "stated": true,
        "options": {
            "msisdn": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "threshold": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "flood-thresh-1",
                    "flood-thresh-2",
                    "flood-thresh-3",
                    "dupe-thresh-1",
                    "dupe-thresh-2",
                    "dupe-thresh-3"
                ],
                "elements": "str"
            }
        }
    },
    "firewall_mmsprofile_outbreakprevention": {
        "stated": false,
        "options": {
            "external-blocklist": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ftgd-service": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "firewall_multicastaddress": {
        "stated": true,
        "options": {
            "associated-interface": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "color": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "end-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "start-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "subnet": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tagging": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "category": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "tags": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    }
                },
                "elements": "dict"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "multicastrange",
                    "broadcastmask"
                ],
                "type": "str"
            },
            "visibility": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tags": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "firewall_multicastaddress6": {
        "stated": true,
        "options": {
            "color": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ip6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tagging": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "category": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "tags": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    }
                },
                "elements": "dict"
            },
            "visibility": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tags": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "firewall_multicastaddress6_tagging": {
        "stated": true,
        "options": {
            "category": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "firewall_multicastaddress_tagging": {
        "stated": true,
        "options": {
            "category": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "firewall_networkservicedynamic": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "filter": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sdn": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "firewall_profilegroup": {
        "stated": true,
        "options": {
            "application-list": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "av-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dlp-sensor": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dnsfilter-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "icap-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ips-sensor": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "mms-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "profile-protocol-options": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "spamfilter-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "ssh-filter-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ssl-ssh-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "voip-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "waf-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "webfilter-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cifs-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "emailfilter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "casi-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "file-filter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "videofilter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dlp-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sctp-filter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ips-voip-filter": {
                "required": false,
                "revision": {
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "casb-profile": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "virtual-patch-profile": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "firewall_profileprotocoloptions": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "oversize-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "replacemsg-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "rpc-over-http": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "switching-protocols-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "feature-set": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "proxy",
                    "flow"
                ],
                "type": "str"
            },
            "cifs": {
                "required": false,
                "type": "dict",
                "options": {
                    "domain-controller": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "file-filter": {
                        "required": false,
                        "type": "dict",
                        "options": {
                            "entries": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "options": {
                                    "action": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": false,
                                            "6.2.9": false,
                                            "6.2.10": false,
                                            "6.2.11": false,
                                            "6.2.12": false,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "log",
                                            "block"
                                        ],
                                        "type": "str"
                                    },
                                    "comment": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": false,
                                            "6.2.9": false,
                                            "6.2.10": false,
                                            "6.2.11": false,
                                            "6.2.12": false,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "direction": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": false,
                                            "6.2.9": false,
                                            "6.2.10": false,
                                            "6.2.11": false,
                                            "6.2.12": false,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "any",
                                            "incoming",
                                            "outgoing"
                                        ],
                                        "type": "str"
                                    },
                                    "file-type": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": false,
                                            "6.2.9": false,
                                            "6.2.10": false,
                                            "6.2.11": false,
                                            "6.2.12": false,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "raw"
                                    },
                                    "filter": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": false,
                                            "6.2.9": false,
                                            "6.2.10": false,
                                            "6.2.11": false,
                                            "6.2.12": false,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "protocol": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": false,
                                            "6.2.9": false,
                                            "6.2.10": false,
                                            "6.2.11": false,
                                            "6.2.12": false,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "list",
                                        "choices": [
                                            "cifs"
                                        ],
                                        "elements": "str"
                                    }
                                },
                                "elements": "dict"
                            },
                            "log": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "status": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            }
                        }
                    },
                    "options": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "oversize"
                        ],
                        "elements": "str"
                    },
                    "oversize-limit": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ports": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "scan-bzip2": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "server-credential-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "credential-replication",
                            "credential-keytab"
                        ],
                        "type": "str"
                    },
                    "server-keytab": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "list",
                        "options": {
                            "keytab": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "no_log": true,
                                "type": "str"
                            },
                            "password": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "no_log": true,
                                "type": "raw"
                            },
                            "principal": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "tcp-window-maximum": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "tcp-window-minimum": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "tcp-window-size": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "tcp-window-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "system",
                            "static",
                            "dynamic",
                            "auto-tuning"
                        ],
                        "type": "str"
                    },
                    "uncompressed-nest-limit": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "uncompressed-oversize-limit": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                }
            },
            "dns": {
                "required": false,
                "type": "dict",
                "options": {
                    "ports": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "ftp": {
                "required": false,
                "type": "dict",
                "options": {
                    "comfort-amount": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "comfort-interval": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "inspect-all": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "options": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "clientcomfort",
                            "no-content-summary",
                            "oversize",
                            "splice",
                            "bypass-rest-command",
                            "bypass-mode-command"
                        ],
                        "elements": "str"
                    },
                    "oversize-limit": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ports": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "scan-bzip2": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ssl-offloaded": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "no",
                            "yes"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "uncompressed-nest-limit": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "uncompressed-oversize-limit": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "stream-based-uncompressed-limit": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "tcp-window-maximum": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "tcp-window-minimum": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "tcp-window-size": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "tcp-window-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "system",
                            "static",
                            "dynamic",
                            "auto-tuning"
                        ],
                        "type": "str"
                    },
                    "explicit-ftp-tls": {
                        "required": false,
                        "revision": {
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "http": {
                "required": false,
                "type": "dict",
                "options": {
                    "block-page-status-code": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "comfort-amount": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "comfort-interval": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "fortinet-bar": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "fortinet-bar-port": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "inspect-all": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "options": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "oversize",
                            "chunkedbypass",
                            "clientcomfort",
                            "no-content-summary",
                            "servercomfort"
                        ],
                        "elements": "str"
                    },
                    "oversize-limit": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ports": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "post-lang": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "jisx0201",
                            "jisx0208",
                            "jisx0212",
                            "gb2312",
                            "ksc5601-ex",
                            "euc-jp",
                            "sjis",
                            "iso2022-jp",
                            "iso2022-jp-1",
                            "iso2022-jp-2",
                            "euc-cn",
                            "ces-gbk",
                            "hz",
                            "ces-big5",
                            "euc-kr",
                            "iso2022-jp-3",
                            "iso8859-1",
                            "tis620",
                            "cp874",
                            "cp1252",
                            "cp1251"
                        ],
                        "elements": "str"
                    },
                    "proxy-after-tcp-handshake": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "range-block": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "retry-count": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "scan-bzip2": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ssl-offloaded": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "no",
                            "yes"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "stream-based-uncompressed-limit": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "streaming-content-bypass": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "strip-x-forwarded-for": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "switching-protocols": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "bypass",
                            "block"
                        ],
                        "type": "str"
                    },
                    "tcp-window-maximum": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "tcp-window-minimum": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "tcp-window-size": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "tcp-window-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "system",
                            "static",
                            "dynamic",
                            "auto-tuning"
                        ],
                        "type": "str"
                    },
                    "tunnel-non-http": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "uncompressed-nest-limit": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "uncompressed-oversize-limit": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "unknown-http-version": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "best-effort",
                            "reject",
                            "tunnel"
                        ],
                        "type": "str"
                    },
                    "http-policy": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "address-ip-rating": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "h2c": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "verify-dns-for-policy-matching": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "unknown-content-encoding": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "block",
                            "inspect",
                            "bypass"
                        ],
                        "type": "str"
                    }
                }
            },
            "imap": {
                "required": false,
                "type": "dict",
                "options": {
                    "inspect-all": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "options": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "oversize",
                            "fragmail",
                            "no-content-summary"
                        ],
                        "elements": "str"
                    },
                    "oversize-limit": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ports": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "proxy-after-tcp-handshake": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "scan-bzip2": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ssl-offloaded": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "no",
                            "yes"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "uncompressed-nest-limit": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "uncompressed-oversize-limit": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                }
            },
            "mail-signature": {
                "required": false,
                "type": "dict",
                "options": {
                    "signature": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "mapi": {
                "required": false,
                "type": "dict",
                "options": {
                    "options": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "fragmail",
                            "oversize",
                            "no-content-summary"
                        ],
                        "elements": "str"
                    },
                    "oversize-limit": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ports": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "scan-bzip2": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "uncompressed-nest-limit": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "uncompressed-oversize-limit": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                }
            },
            "nntp": {
                "required": false,
                "type": "dict",
                "options": {
                    "inspect-all": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "options": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "oversize",
                            "no-content-summary",
                            "splice"
                        ],
                        "elements": "str"
                    },
                    "oversize-limit": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ports": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "proxy-after-tcp-handshake": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "scan-bzip2": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "uncompressed-nest-limit": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "uncompressed-oversize-limit": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                }
            },
            "pop3": {
                "required": false,
                "type": "dict",
                "options": {
                    "inspect-all": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "options": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "oversize",
                            "fragmail",
                            "no-content-summary"
                        ],
                        "elements": "str"
                    },
                    "oversize-limit": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ports": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "proxy-after-tcp-handshake": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "scan-bzip2": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ssl-offloaded": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "no",
                            "yes"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "uncompressed-nest-limit": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "uncompressed-oversize-limit": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                }
            },
            "smtp": {
                "required": false,
                "type": "dict",
                "options": {
                    "inspect-all": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "options": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "oversize",
                            "fragmail",
                            "no-content-summary",
                            "splice"
                        ],
                        "elements": "str"
                    },
                    "oversize-limit": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ports": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "proxy-after-tcp-handshake": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "scan-bzip2": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "server-busy": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ssl-offloaded": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "no",
                            "yes"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "uncompressed-nest-limit": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "uncompressed-oversize-limit": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                }
            },
            "ssh": {
                "required": false,
                "type": "dict",
                "options": {
                    "comfort-amount": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "comfort-interval": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "options": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "oversize",
                            "clientcomfort",
                            "servercomfort"
                        ],
                        "elements": "str"
                    },
                    "oversize-limit": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "scan-bzip2": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "uncompressed-nest-limit": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "uncompressed-oversize-limit": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ssl-offloaded": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "no",
                            "yes"
                        ],
                        "type": "str"
                    },
                    "stream-based-uncompressed-limit": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "tcp-window-maximum": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "tcp-window-minimum": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "tcp-window-size": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "tcp-window-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "system",
                            "static",
                            "dynamic",
                            "auto-tuning"
                        ],
                        "type": "str"
                    }
                }
            }
        }
    },
    "firewall_profileprotocoloptions_cifs": {
        "stated": false,
        "options": {
            "ports": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "options": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "oversize"
                ],
                "elements": "str"
            },
            "oversize-limit": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "scan-bzip2": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tcp-window-maximum": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tcp-window-minimum": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tcp-window-size": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tcp-window-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "system",
                    "static",
                    "dynamic",
                    "auto-tuning"
                ],
                "type": "str"
            },
            "uncompressed-nest-limit": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "uncompressed-oversize-limit": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "domain-controller": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "file-filter": {
                "required": false,
                "type": "dict",
                "options": {
                    "entries": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "action": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "log",
                                    "block"
                                ],
                                "type": "str"
                            },
                            "comment": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "direction": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "any",
                                    "incoming",
                                    "outgoing"
                                ],
                                "type": "str"
                            },
                            "file-type": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            },
                            "filter": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "protocol": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "choices": [
                                    "cifs"
                                ],
                                "elements": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "server-credential-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "credential-replication",
                    "credential-keytab"
                ],
                "type": "str"
            },
            "server-keytab": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "list",
                "options": {
                    "keytab": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "str"
                    },
                    "password": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "principal": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "firewall_profileprotocoloptions_cifs_filefilter": {
        "stated": false,
        "options": {
            "entries": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "log",
                            "block"
                        ],
                        "type": "str"
                    },
                    "comment": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "direction": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "any",
                            "incoming",
                            "outgoing"
                        ],
                        "type": "str"
                    },
                    "file-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "filter": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "protocol": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "cifs"
                        ],
                        "elements": "str"
                    }
                },
                "elements": "dict"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "firewall_profileprotocoloptions_cifs_filefilter_entries": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "log",
                    "block"
                ],
                "type": "str"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "direction": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "any",
                    "incoming",
                    "outgoing"
                ],
                "type": "str"
            },
            "file-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "filter": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "cifs"
                ],
                "elements": "str"
            }
        }
    },
    "firewall_profileprotocoloptions_cifs_serverkeytab": {
        "stated": true,
        "options": {
            "keytab": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "str"
            },
            "password": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "principal": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "firewall_profileprotocoloptions_dns": {
        "stated": false,
        "options": {
            "ports": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "firewall_profileprotocoloptions_ftp": {
        "stated": false,
        "options": {
            "comfort-amount": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "comfort-interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "inspect-all": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "options": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "clientcomfort",
                    "no-content-summary",
                    "oversize",
                    "splice",
                    "bypass-rest-command",
                    "bypass-mode-command"
                ],
                "elements": "str"
            },
            "oversize-limit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ports": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "scan-bzip2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "uncompressed-nest-limit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "uncompressed-oversize-limit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ssl-offloaded": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "no",
                    "yes"
                ],
                "type": "str"
            },
            "stream-based-uncompressed-limit": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tcp-window-maximum": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tcp-window-minimum": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tcp-window-size": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tcp-window-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "system",
                    "static",
                    "dynamic",
                    "auto-tuning"
                ],
                "type": "str"
            },
            "explicit-ftp-tls": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "firewall_profileprotocoloptions_http": {
        "stated": false,
        "options": {
            "block-page-status-code": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "comfort-amount": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "comfort-interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fortinet-bar": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fortinet-bar-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "http-policy": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "inspect-all": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "options": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "oversize",
                    "chunkedbypass",
                    "clientcomfort",
                    "no-content-summary",
                    "servercomfort"
                ],
                "elements": "str"
            },
            "oversize-limit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ports": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "post-lang": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "jisx0201",
                    "jisx0208",
                    "jisx0212",
                    "gb2312",
                    "ksc5601-ex",
                    "euc-jp",
                    "sjis",
                    "iso2022-jp",
                    "iso2022-jp-1",
                    "iso2022-jp-2",
                    "euc-cn",
                    "ces-gbk",
                    "hz",
                    "ces-big5",
                    "euc-kr",
                    "iso2022-jp-3",
                    "iso8859-1",
                    "tis620",
                    "cp874",
                    "cp1252",
                    "cp1251"
                ],
                "elements": "str"
            },
            "range-block": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "retry-count": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "scan-bzip2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "streaming-content-bypass": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "strip-x-forwarded-for": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "switching-protocols": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "bypass",
                    "block"
                ],
                "type": "str"
            },
            "uncompressed-nest-limit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "uncompressed-oversize-limit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tcp-window-maximum": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tcp-window-minimum": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tcp-window-size": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tcp-window-type": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "system",
                    "static",
                    "dynamic",
                    "auto-tuning"
                ],
                "type": "str"
            },
            "ssl-offloaded": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "no",
                    "yes"
                ],
                "type": "str"
            },
            "stream-based-uncompressed-limit": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "proxy-after-tcp-handshake": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tunnel-non-http": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "unknown-http-version": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "best-effort",
                    "reject",
                    "tunnel"
                ],
                "type": "str"
            },
            "address-ip-rating": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "h2c": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "verify-dns-for-policy-matching": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "unknown-content-encoding": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "block",
                    "inspect",
                    "bypass"
                ],
                "type": "str"
            }
        }
    },
    "firewall_profileprotocoloptions_imap": {
        "stated": false,
        "options": {
            "inspect-all": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "options": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "oversize",
                    "fragmail",
                    "no-content-summary"
                ],
                "elements": "str"
            },
            "oversize-limit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ports": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "scan-bzip2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "uncompressed-nest-limit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "uncompressed-oversize-limit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ssl-offloaded": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "no",
                    "yes"
                ],
                "type": "str"
            },
            "proxy-after-tcp-handshake": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "firewall_profileprotocoloptions_mailsignature": {
        "stated": false,
        "options": {
            "signature": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "firewall_profileprotocoloptions_mapi": {
        "stated": false,
        "options": {
            "options": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "fragmail",
                    "oversize",
                    "no-content-summary"
                ],
                "elements": "str"
            },
            "oversize-limit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ports": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "scan-bzip2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "uncompressed-nest-limit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "uncompressed-oversize-limit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "firewall_profileprotocoloptions_nntp": {
        "stated": false,
        "options": {
            "inspect-all": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "options": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "oversize",
                    "no-content-summary",
                    "splice"
                ],
                "elements": "str"
            },
            "oversize-limit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ports": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "scan-bzip2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "uncompressed-nest-limit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "uncompressed-oversize-limit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "proxy-after-tcp-handshake": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "firewall_profileprotocoloptions_pop3": {
        "stated": false,
        "options": {
            "inspect-all": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "options": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "oversize",
                    "fragmail",
                    "no-content-summary"
                ],
                "elements": "str"
            },
            "oversize-limit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ports": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "scan-bzip2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "uncompressed-nest-limit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "uncompressed-oversize-limit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ssl-offloaded": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "no",
                    "yes"
                ],
                "type": "str"
            },
            "proxy-after-tcp-handshake": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "firewall_profileprotocoloptions_smtp": {
        "stated": false,
        "options": {
            "inspect-all": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "options": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "oversize",
                    "fragmail",
                    "no-content-summary",
                    "splice"
                ],
                "elements": "str"
            },
            "oversize-limit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ports": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "scan-bzip2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "server-busy": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "uncompressed-nest-limit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "uncompressed-oversize-limit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ssl-offloaded": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "no",
                    "yes"
                ],
                "type": "str"
            },
            "proxy-after-tcp-handshake": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "firewall_profileprotocoloptions_ssh": {
        "stated": false,
        "options": {
            "comfort-amount": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "comfort-interval": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "options": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "oversize",
                    "clientcomfort",
                    "servercomfort"
                ],
                "elements": "str"
            },
            "oversize-limit": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "scan-bzip2": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "uncompressed-nest-limit": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "uncompressed-oversize-limit": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ssl-offloaded": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "no",
                    "yes"
                ],
                "type": "str"
            },
            "stream-based-uncompressed-limit": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tcp-window-maximum": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tcp-window-minimum": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tcp-window-size": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tcp-window-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "system",
                    "static",
                    "dynamic",
                    "auto-tuning"
                ],
                "type": "str"
            }
        }
    },
    "firewall_proxyaddress": {
        "stated": true,
        "options": {
            "case-sensitivity": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "category": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "color": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "header-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "case-sensitivity": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "header": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "header-name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "header-name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "host": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "host-regex": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "method": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "delete",
                    "get",
                    "head",
                    "options",
                    "post",
                    "put",
                    "trace",
                    "connect"
                ],
                "elements": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "path": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "query": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "referrer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tagging": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "category": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "tags": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    }
                },
                "elements": "dict"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "host-regex",
                    "url",
                    "category",
                    "method",
                    "ua",
                    "header",
                    "src-advanced",
                    "dst-advanced",
                    "url-list",
                    "saas"
                ],
                "type": "str"
            },
            "ua": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "chrome",
                    "ms",
                    "firefox",
                    "safari",
                    "other",
                    "ie",
                    "edge"
                ],
                "elements": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "visibility": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tags": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "_image-base64": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "application": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ua-max-ver": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ua-min-ver": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "firewall_proxyaddress_headergroup": {
        "stated": true,
        "options": {
            "case-sensitivity": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "header-name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "firewall_proxyaddress_tagging": {
        "stated": true,
        "options": {
            "category": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "firewall_proxyaddrgrp": {
        "stated": true,
        "options": {
            "color": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "member": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tagging": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "category": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "tags": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    }
                },
                "elements": "dict"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "src",
                    "dst"
                ],
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "visibility": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tags": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "_image-base64": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "firewall_proxyaddrgrp_tagging": {
        "stated": true,
        "options": {
            "category": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "firewall_schedule_group": {
        "stated": true,
        "options": {
            "color": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "member": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "global-object": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fabric-object": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "firewall_schedule_onetime": {
        "stated": true,
        "options": {
            "color": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "end": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "expiration-days": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "start": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "global-object": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fabric-object": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "end-utc": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "start-utc": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "firewall_schedule_recurring": {
        "stated": true,
        "options": {
            "color": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "day": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "sunday",
                    "monday",
                    "tuesday",
                    "wednesday",
                    "thursday",
                    "friday",
                    "saturday",
                    "none"
                ],
                "elements": "str"
            },
            "end": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "start": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "global-object": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fabric-object": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "firewall_service_category": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "global-object": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fabric-object": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "firewall_service_custom": {
        "stated": true,
        "options": {
            "app-category": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "app-service-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "app-id",
                    "app-category"
                ],
                "type": "str"
            },
            "application": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "category": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "check-reset-range": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "default",
                    "strict"
                ],
                "type": "str"
            },
            "color": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "comment": {
                "required": false,
                "type": "raw"
            },
            "fqdn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "helper": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "auto",
                    "ftp",
                    "tftp",
                    "ras",
                    "h323",
                    "tns",
                    "mms",
                    "sip",
                    "pptp",
                    "rtsp",
                    "dns-udp",
                    "dns-tcp",
                    "pmap",
                    "rsh",
                    "dcerpc",
                    "mgcp",
                    "gtp-c",
                    "gtp-u",
                    "gtp-b",
                    "pfcp"
                ],
                "type": "str"
            },
            "icmpcode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "icmptype": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "iprange": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ICMP",
                    "IP",
                    "TCP/UDP/SCTP",
                    "ICMP6",
                    "HTTP",
                    "FTP",
                    "CONNECT",
                    "SOCKS",
                    "ALL",
                    "SOCKS-TCP",
                    "SOCKS-UDP"
                ],
                "type": "str"
            },
            "protocol-number": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "proxy": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sctp-portrange": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "session-ttl": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "tcp-halfclose-timer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tcp-halfopen-timer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tcp-portrange": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tcp-timewait-timer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "udp-idle-timer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "udp-portrange": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "visibility": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "explicit-proxy": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "global-object": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fabric-object": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tcp-rst-timer": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "firewall_service_group": {
        "stated": true,
        "options": {
            "color": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "comment": {
                "required": false,
                "type": "raw"
            },
            "member": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "proxy": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "explicit-proxy": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "global-object": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fabric-object": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "firewall_shaper_peripshaper": {
        "stated": true,
        "options": {
            "bandwidth-unit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "kbps",
                    "mbps",
                    "gbps"
                ],
                "type": "str"
            },
            "diffserv-forward": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "diffserv-reverse": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "diffservcode-forward": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "diffservcode-rev": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "max-bandwidth": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "max-concurrent-session": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "max-concurrent-tcp-session": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "max-concurrent-udp-session": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "firewall_shaper_trafficshaper": {
        "stated": true,
        "options": {
            "bandwidth-unit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "kbps",
                    "mbps",
                    "gbps"
                ],
                "type": "str"
            },
            "diffserv": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "diffservcode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "guaranteed-bandwidth": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "maximum-bandwidth": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "per-policy": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "priority": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "high",
                    "medium",
                    "low"
                ],
                "type": "str"
            },
            "dscp-marking-method": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "multi-stage",
                    "static"
                ],
                "type": "str"
            },
            "exceed-bandwidth": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "exceed-class-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "exceed-dscp": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "maximum-dscp": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "overhead": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "cos": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cos-marking": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "cos-marking-method": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "multi-stage",
                    "static"
                ],
                "type": "str"
            },
            "exceed-cos": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "maximum-cos": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "firewall_shapingprofile": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "default-class-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "profile-name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "shaping-entries": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "class-id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "guaranteed-bandwidth-percentage": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "maximum-bandwidth-percentage": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "priority": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "low",
                            "medium",
                            "high",
                            "critical",
                            "top"
                        ],
                        "type": "str"
                    },
                    "burst-in-msec": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "cburst-in-msec": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "limit": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "max": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "min": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "red-probability": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "policing",
                    "queuing"
                ],
                "type": "str"
            }
        }
    },
    "firewall_shapingprofile_shapingentries": {
        "stated": true,
        "options": {
            "class-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "guaranteed-bandwidth-percentage": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "maximum-bandwidth-percentage": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "priority": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "low",
                    "medium",
                    "high",
                    "critical",
                    "top"
                ],
                "type": "str"
            },
            "burst-in-msec": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "cburst-in-msec": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "limit": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "max": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "min": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "red-probability": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "firewall_ssh_localca": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "password": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "private-key": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "str"
            },
            "public-key": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "str"
            },
            "source": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "built-in",
                    "user"
                ],
                "type": "str"
            }
        }
    },
    "firewall_sslsshprofile": {
        "stated": true,
        "options": {
            "caname": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "mapi-over-https": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "rpc-over-https": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "server-cert": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "server-cert-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "re-sign",
                    "replace"
                ],
                "type": "str"
            },
            "ssl-anomalies-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-exempt": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "address": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "address6": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "fortiguard-category": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "regex": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "fortiguard-category",
                            "address",
                            "address6",
                            "wildcard-fqdn",
                            "regex",
                            "finger-print"
                        ],
                        "type": "str"
                    },
                    "wildcard-fqdn": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "ssl-exemptions-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "ftps-client-cert-request": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "bypass",
                            "inspect",
                            "block"
                        ],
                        "type": "str"
                    },
                    "https-client-cert-request": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "bypass",
                            "inspect",
                            "block"
                        ],
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "imaps-client-cert-request": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "bypass",
                            "inspect",
                            "block"
                        ],
                        "type": "str"
                    },
                    "ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "pop3s-client-cert-request": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "bypass",
                            "inspect",
                            "block"
                        ],
                        "type": "str"
                    },
                    "smtps-client-cert-request": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "bypass",
                            "inspect",
                            "block"
                        ],
                        "type": "str"
                    },
                    "ssl-other-client-cert-request": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "bypass",
                            "inspect",
                            "block"
                        ],
                        "type": "str"
                    },
                    "ftps-client-certificate": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "bypass",
                            "inspect",
                            "block"
                        ],
                        "type": "str"
                    },
                    "https-client-certificate": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "bypass",
                            "inspect",
                            "block"
                        ],
                        "type": "str"
                    },
                    "imaps-client-certificate": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "bypass",
                            "inspect",
                            "block"
                        ],
                        "type": "str"
                    },
                    "pop3s-client-certificate": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "bypass",
                            "inspect",
                            "block"
                        ],
                        "type": "str"
                    },
                    "smtps-client-certificate": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "bypass",
                            "inspect",
                            "block"
                        ],
                        "type": "str"
                    },
                    "ssl-other-client-certificate": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "bypass",
                            "inspect",
                            "block"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "untrusted-caname": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "use-ssl-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "whitelist": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "block-blacklisted-certificates": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "certname": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "ssl-invalid-server-cert-log": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-negotiation-log": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ftps": {
                "required": false,
                "type": "dict",
                "options": {
                    "cert-validation-failure": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block",
                            "ignore"
                        ],
                        "type": "str"
                    },
                    "cert-validation-timeout": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block",
                            "ignore"
                        ],
                        "type": "str"
                    },
                    "client-certificate": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "bypass",
                            "inspect",
                            "block"
                        ],
                        "type": "str"
                    },
                    "expired-server-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block",
                            "ignore"
                        ],
                        "type": "str"
                    },
                    "ports": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "revoked-server-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block",
                            "ignore"
                        ],
                        "type": "str"
                    },
                    "sni-server-cert-check": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable",
                            "strict"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "deep-inspection"
                        ],
                        "type": "str"
                    },
                    "unsupported-ssl-cipher": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block"
                        ],
                        "type": "str"
                    },
                    "unsupported-ssl-negotiation": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block"
                        ],
                        "type": "str"
                    },
                    "untrusted-server-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block",
                            "ignore"
                        ],
                        "type": "str"
                    },
                    "unsupported-ssl": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "bypass",
                            "inspect",
                            "block"
                        ],
                        "type": "str"
                    },
                    "client-cert-request": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "bypass",
                            "inspect",
                            "block"
                        ],
                        "type": "str"
                    },
                    "invalid-server-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block"
                        ],
                        "type": "str"
                    },
                    "allow-invalid-server-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "untrusted-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "allow",
                            "block",
                            "ignore"
                        ],
                        "type": "str"
                    },
                    "min-allowed-ssl-version": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ssl-3.0",
                            "tls-1.0",
                            "tls-1.1",
                            "tls-1.2",
                            "tls-1.3"
                        ],
                        "type": "str"
                    },
                    "unsupported-ssl-version": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "block",
                            "allow",
                            "inspect"
                        ],
                        "type": "str"
                    }
                }
            },
            "https": {
                "required": false,
                "type": "dict",
                "options": {
                    "cert-validation-failure": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block",
                            "ignore"
                        ],
                        "type": "str"
                    },
                    "cert-validation-timeout": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block",
                            "ignore"
                        ],
                        "type": "str"
                    },
                    "client-certificate": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "bypass",
                            "inspect",
                            "block"
                        ],
                        "type": "str"
                    },
                    "expired-server-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block",
                            "ignore"
                        ],
                        "type": "str"
                    },
                    "ports": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "proxy-after-tcp-handshake": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "revoked-server-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block",
                            "ignore"
                        ],
                        "type": "str"
                    },
                    "sni-server-cert-check": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable",
                            "strict"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "certificate-inspection",
                            "deep-inspection"
                        ],
                        "type": "str"
                    },
                    "unsupported-ssl-cipher": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block"
                        ],
                        "type": "str"
                    },
                    "unsupported-ssl-negotiation": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block"
                        ],
                        "type": "str"
                    },
                    "untrusted-server-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block",
                            "ignore"
                        ],
                        "type": "str"
                    },
                    "unsupported-ssl": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "bypass",
                            "inspect",
                            "block"
                        ],
                        "type": "str"
                    },
                    "client-cert-request": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "bypass",
                            "inspect",
                            "block"
                        ],
                        "type": "str"
                    },
                    "invalid-server-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block"
                        ],
                        "type": "str"
                    },
                    "allow-invalid-server-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "untrusted-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "allow",
                            "block",
                            "ignore"
                        ],
                        "type": "str"
                    },
                    "cert-probe-failure": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "block",
                            "allow"
                        ],
                        "type": "str"
                    },
                    "min-allowed-ssl-version": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ssl-3.0",
                            "tls-1.0",
                            "tls-1.1",
                            "tls-1.2",
                            "tls-1.3"
                        ],
                        "type": "str"
                    },
                    "unsupported-ssl-version": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "block",
                            "allow",
                            "inspect"
                        ],
                        "type": "str"
                    },
                    "quic": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "imaps": {
                "required": false,
                "type": "dict",
                "options": {
                    "cert-validation-failure": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block",
                            "ignore"
                        ],
                        "type": "str"
                    },
                    "cert-validation-timeout": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block",
                            "ignore"
                        ],
                        "type": "str"
                    },
                    "client-certificate": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "bypass",
                            "inspect",
                            "block"
                        ],
                        "type": "str"
                    },
                    "expired-server-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block",
                            "ignore"
                        ],
                        "type": "str"
                    },
                    "ports": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "proxy-after-tcp-handshake": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "revoked-server-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block",
                            "ignore"
                        ],
                        "type": "str"
                    },
                    "sni-server-cert-check": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable",
                            "strict"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "deep-inspection"
                        ],
                        "type": "str"
                    },
                    "unsupported-ssl-cipher": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block"
                        ],
                        "type": "str"
                    },
                    "unsupported-ssl-negotiation": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block"
                        ],
                        "type": "str"
                    },
                    "untrusted-server-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block",
                            "ignore"
                        ],
                        "type": "str"
                    },
                    "unsupported-ssl": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "bypass",
                            "inspect",
                            "block"
                        ],
                        "type": "str"
                    },
                    "client-cert-request": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "bypass",
                            "inspect",
                            "block"
                        ],
                        "type": "str"
                    },
                    "invalid-server-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block"
                        ],
                        "type": "str"
                    },
                    "allow-invalid-server-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "untrusted-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "allow",
                            "block",
                            "ignore"
                        ],
                        "type": "str"
                    },
                    "unsupported-ssl-version": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "block",
                            "allow",
                            "inspect"
                        ],
                        "type": "str"
                    },
                    "min-allowed-ssl-version": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ssl-3.0",
                            "tls-1.0",
                            "tls-1.1",
                            "tls-1.2",
                            "tls-1.3"
                        ],
                        "type": "str"
                    }
                }
            },
            "pop3s": {
                "required": false,
                "type": "dict",
                "options": {
                    "cert-validation-failure": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block",
                            "ignore"
                        ],
                        "type": "str"
                    },
                    "cert-validation-timeout": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block",
                            "ignore"
                        ],
                        "type": "str"
                    },
                    "client-certificate": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "bypass",
                            "inspect",
                            "block"
                        ],
                        "type": "str"
                    },
                    "expired-server-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block",
                            "ignore"
                        ],
                        "type": "str"
                    },
                    "ports": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "proxy-after-tcp-handshake": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "revoked-server-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block",
                            "ignore"
                        ],
                        "type": "str"
                    },
                    "sni-server-cert-check": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable",
                            "strict"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "deep-inspection"
                        ],
                        "type": "str"
                    },
                    "unsupported-ssl-cipher": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block"
                        ],
                        "type": "str"
                    },
                    "unsupported-ssl-negotiation": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block"
                        ],
                        "type": "str"
                    },
                    "untrusted-server-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block",
                            "ignore"
                        ],
                        "type": "str"
                    },
                    "unsupported-ssl": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "bypass",
                            "inspect",
                            "block"
                        ],
                        "type": "str"
                    },
                    "client-cert-request": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "bypass",
                            "inspect",
                            "block"
                        ],
                        "type": "str"
                    },
                    "invalid-server-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block"
                        ],
                        "type": "str"
                    },
                    "allow-invalid-server-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "untrusted-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "allow",
                            "block",
                            "ignore"
                        ],
                        "type": "str"
                    },
                    "unsupported-ssl-version": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "block",
                            "allow",
                            "inspect"
                        ],
                        "type": "str"
                    },
                    "min-allowed-ssl-version": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ssl-3.0",
                            "tls-1.0",
                            "tls-1.1",
                            "tls-1.2",
                            "tls-1.3"
                        ],
                        "type": "str"
                    }
                }
            },
            "smtps": {
                "required": false,
                "type": "dict",
                "options": {
                    "cert-validation-failure": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block",
                            "ignore"
                        ],
                        "type": "str"
                    },
                    "cert-validation-timeout": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block",
                            "ignore"
                        ],
                        "type": "str"
                    },
                    "client-certificate": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "bypass",
                            "inspect",
                            "block"
                        ],
                        "type": "str"
                    },
                    "expired-server-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block",
                            "ignore"
                        ],
                        "type": "str"
                    },
                    "ports": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "proxy-after-tcp-handshake": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "revoked-server-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block",
                            "ignore"
                        ],
                        "type": "str"
                    },
                    "sni-server-cert-check": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable",
                            "strict"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "deep-inspection"
                        ],
                        "type": "str"
                    },
                    "unsupported-ssl-cipher": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block"
                        ],
                        "type": "str"
                    },
                    "unsupported-ssl-negotiation": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block"
                        ],
                        "type": "str"
                    },
                    "untrusted-server-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block",
                            "ignore"
                        ],
                        "type": "str"
                    },
                    "unsupported-ssl": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "bypass",
                            "inspect",
                            "block"
                        ],
                        "type": "str"
                    },
                    "client-cert-request": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "bypass",
                            "inspect",
                            "block"
                        ],
                        "type": "str"
                    },
                    "invalid-server-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block"
                        ],
                        "type": "str"
                    },
                    "allow-invalid-server-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "untrusted-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "allow",
                            "block",
                            "ignore"
                        ],
                        "type": "str"
                    },
                    "unsupported-ssl-version": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "block",
                            "allow",
                            "inspect"
                        ],
                        "type": "str"
                    },
                    "min-allowed-ssl-version": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ssl-3.0",
                            "tls-1.0",
                            "tls-1.1",
                            "tls-1.2",
                            "tls-1.3"
                        ],
                        "type": "str"
                    }
                }
            },
            "ssh": {
                "required": false,
                "type": "dict",
                "options": {
                    "inspect-all": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "deep-inspection"
                        ],
                        "type": "str"
                    },
                    "ports": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "proxy-after-tcp-handshake": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ssh-algorithm": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "compatible",
                            "high-encryption"
                        ],
                        "type": "str"
                    },
                    "ssh-tun-policy-check": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "deep-inspection"
                        ],
                        "type": "str"
                    },
                    "unsupported-version": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "block",
                            "bypass"
                        ],
                        "type": "str"
                    },
                    "ssh-policy-check": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "block": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "list",
                        "choices": [
                            "x11-filter",
                            "ssh-shell",
                            "exec",
                            "port-forward"
                        ],
                        "elements": "str"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "list",
                        "choices": [
                            "x11-filter",
                            "ssh-shell",
                            "exec",
                            "port-forward"
                        ],
                        "elements": "str"
                    }
                }
            },
            "ssl": {
                "required": false,
                "type": "dict",
                "options": {
                    "cert-validation-failure": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block",
                            "ignore"
                        ],
                        "type": "str"
                    },
                    "cert-validation-timeout": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block",
                            "ignore"
                        ],
                        "type": "str"
                    },
                    "client-certificate": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "bypass",
                            "inspect",
                            "block"
                        ],
                        "type": "str"
                    },
                    "expired-server-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block",
                            "ignore"
                        ],
                        "type": "str"
                    },
                    "inspect-all": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "certificate-inspection",
                            "deep-inspection"
                        ],
                        "type": "str"
                    },
                    "revoked-server-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block",
                            "ignore"
                        ],
                        "type": "str"
                    },
                    "sni-server-cert-check": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable",
                            "strict"
                        ],
                        "type": "str"
                    },
                    "unsupported-ssl-cipher": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block"
                        ],
                        "type": "str"
                    },
                    "unsupported-ssl-negotiation": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block"
                        ],
                        "type": "str"
                    },
                    "untrusted-server-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block",
                            "ignore"
                        ],
                        "type": "str"
                    },
                    "unsupported-ssl": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "bypass",
                            "inspect",
                            "block"
                        ],
                        "type": "str"
                    },
                    "client-cert-request": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "bypass",
                            "inspect",
                            "block"
                        ],
                        "type": "str"
                    },
                    "invalid-server-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block"
                        ],
                        "type": "str"
                    },
                    "allow-invalid-server-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "untrusted-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "allow",
                            "block",
                            "ignore"
                        ],
                        "type": "str"
                    },
                    "cert-probe-failure": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "block",
                            "allow"
                        ],
                        "type": "str"
                    },
                    "min-allowed-ssl-version": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ssl-3.0",
                            "tls-1.0",
                            "tls-1.1",
                            "tls-1.2",
                            "tls-1.3"
                        ],
                        "type": "str"
                    },
                    "unsupported-ssl-version": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "block",
                            "allow",
                            "inspect"
                        ],
                        "type": "str"
                    }
                }
            },
            "allowlist": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "block-blocklisted-certificates": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dot": {
                "required": false,
                "type": "dict",
                "options": {
                    "cert-validation-failure": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block",
                            "ignore"
                        ],
                        "type": "str"
                    },
                    "cert-validation-timeout": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block",
                            "ignore"
                        ],
                        "type": "str"
                    },
                    "client-certificate": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "bypass",
                            "inspect",
                            "block"
                        ],
                        "type": "str"
                    },
                    "expired-server-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block",
                            "ignore"
                        ],
                        "type": "str"
                    },
                    "proxy-after-tcp-handshake": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "revoked-server-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block",
                            "ignore"
                        ],
                        "type": "str"
                    },
                    "sni-server-cert-check": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "enable",
                            "strict",
                            "disable"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "deep-inspection"
                        ],
                        "type": "str"
                    },
                    "unsupported-ssl-cipher": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "block",
                            "allow"
                        ],
                        "type": "str"
                    },
                    "unsupported-ssl-negotiation": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "block",
                            "allow"
                        ],
                        "type": "str"
                    },
                    "untrusted-server-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block",
                            "ignore"
                        ],
                        "type": "str"
                    },
                    "unsupported-ssl-version": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "block",
                            "allow",
                            "inspect"
                        ],
                        "type": "str"
                    },
                    "min-allowed-ssl-version": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ssl-3.0",
                            "tls-1.0",
                            "tls-1.1",
                            "tls-1.2",
                            "tls-1.3"
                        ],
                        "type": "str"
                    },
                    "quic": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "supported-alpn": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http1-1",
                    "http2",
                    "all"
                ],
                "type": "str"
            },
            "ssl-anomaly-log": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-exemption-ip-rating": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-exemption-log": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-handshake-log": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-server-cert-log": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "firewall_sslsshprofile_dot": {
        "stated": false,
        "options": {
            "cert-validation-failure": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block",
                    "ignore"
                ],
                "type": "str"
            },
            "cert-validation-timeout": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block",
                    "ignore"
                ],
                "type": "str"
            },
            "client-certificate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "bypass",
                    "inspect",
                    "block"
                ],
                "type": "str"
            },
            "expired-server-cert": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block",
                    "ignore"
                ],
                "type": "str"
            },
            "proxy-after-tcp-handshake": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "revoked-server-cert": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block",
                    "ignore"
                ],
                "type": "str"
            },
            "sni-server-cert-check": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "enable",
                    "strict",
                    "disable"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "deep-inspection"
                ],
                "type": "str"
            },
            "unsupported-ssl-cipher": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "block",
                    "allow"
                ],
                "type": "str"
            },
            "unsupported-ssl-negotiation": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "block",
                    "allow"
                ],
                "type": "str"
            },
            "untrusted-server-cert": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block",
                    "ignore"
                ],
                "type": "str"
            },
            "unsupported-ssl-version": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "block",
                    "allow",
                    "inspect"
                ],
                "type": "str"
            },
            "min-allowed-ssl-version": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ssl-3.0",
                    "tls-1.0",
                    "tls-1.1",
                    "tls-1.2",
                    "tls-1.3"
                ],
                "type": "str"
            },
            "quic": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "firewall_sslsshprofile_ftps": {
        "stated": false,
        "options": {
            "allow-invalid-server-cert": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "client-cert-request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "bypass",
                    "inspect",
                    "block"
                ],
                "type": "str"
            },
            "ports": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "deep-inspection"
                ],
                "type": "str"
            },
            "unsupported-ssl": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "bypass",
                    "inspect",
                    "block"
                ],
                "type": "str"
            },
            "untrusted-cert": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "allow",
                    "block",
                    "ignore"
                ],
                "type": "str"
            },
            "invalid-server-cert": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block"
                ],
                "type": "str"
            },
            "sni-server-cert-check": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "strict"
                ],
                "type": "str"
            },
            "untrusted-server-cert": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block",
                    "ignore"
                ],
                "type": "str"
            },
            "cert-validation-failure": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block",
                    "ignore"
                ],
                "type": "str"
            },
            "cert-validation-timeout": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block",
                    "ignore"
                ],
                "type": "str"
            },
            "client-certificate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "bypass",
                    "inspect",
                    "block"
                ],
                "type": "str"
            },
            "expired-server-cert": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block",
                    "ignore"
                ],
                "type": "str"
            },
            "revoked-server-cert": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block",
                    "ignore"
                ],
                "type": "str"
            },
            "unsupported-ssl-cipher": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block"
                ],
                "type": "str"
            },
            "unsupported-ssl-negotiation": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block"
                ],
                "type": "str"
            },
            "min-allowed-ssl-version": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ssl-3.0",
                    "tls-1.0",
                    "tls-1.1",
                    "tls-1.2",
                    "tls-1.3"
                ],
                "type": "str"
            },
            "unsupported-ssl-version": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "block",
                    "allow",
                    "inspect"
                ],
                "type": "str"
            }
        }
    },
    "firewall_sslsshprofile_https": {
        "stated": false,
        "options": {
            "allow-invalid-server-cert": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "client-cert-request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "bypass",
                    "inspect",
                    "block"
                ],
                "type": "str"
            },
            "ports": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "certificate-inspection",
                    "deep-inspection"
                ],
                "type": "str"
            },
            "unsupported-ssl": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "bypass",
                    "inspect",
                    "block"
                ],
                "type": "str"
            },
            "untrusted-cert": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "allow",
                    "block",
                    "ignore"
                ],
                "type": "str"
            },
            "invalid-server-cert": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block"
                ],
                "type": "str"
            },
            "sni-server-cert-check": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "strict"
                ],
                "type": "str"
            },
            "untrusted-server-cert": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block",
                    "ignore"
                ],
                "type": "str"
            },
            "cert-validation-failure": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block",
                    "ignore"
                ],
                "type": "str"
            },
            "cert-validation-timeout": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block",
                    "ignore"
                ],
                "type": "str"
            },
            "client-certificate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "bypass",
                    "inspect",
                    "block"
                ],
                "type": "str"
            },
            "expired-server-cert": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block",
                    "ignore"
                ],
                "type": "str"
            },
            "proxy-after-tcp-handshake": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "revoked-server-cert": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block",
                    "ignore"
                ],
                "type": "str"
            },
            "unsupported-ssl-cipher": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block"
                ],
                "type": "str"
            },
            "unsupported-ssl-negotiation": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block"
                ],
                "type": "str"
            },
            "cert-probe-failure": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "block",
                    "allow"
                ],
                "type": "str"
            },
            "min-allowed-ssl-version": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ssl-3.0",
                    "tls-1.0",
                    "tls-1.1",
                    "tls-1.2",
                    "tls-1.3"
                ],
                "type": "str"
            },
            "unsupported-ssl-version": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "block",
                    "allow",
                    "inspect"
                ],
                "type": "str"
            },
            "quic": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "firewall_sslsshprofile_imaps": {
        "stated": false,
        "options": {
            "allow-invalid-server-cert": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "client-cert-request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "bypass",
                    "inspect",
                    "block"
                ],
                "type": "str"
            },
            "ports": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "deep-inspection"
                ],
                "type": "str"
            },
            "unsupported-ssl": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "bypass",
                    "inspect",
                    "block"
                ],
                "type": "str"
            },
            "untrusted-cert": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "allow",
                    "block",
                    "ignore"
                ],
                "type": "str"
            },
            "invalid-server-cert": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block"
                ],
                "type": "str"
            },
            "sni-server-cert-check": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "strict"
                ],
                "type": "str"
            },
            "untrusted-server-cert": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block",
                    "ignore"
                ],
                "type": "str"
            },
            "cert-validation-failure": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block",
                    "ignore"
                ],
                "type": "str"
            },
            "cert-validation-timeout": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block",
                    "ignore"
                ],
                "type": "str"
            },
            "client-certificate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "bypass",
                    "inspect",
                    "block"
                ],
                "type": "str"
            },
            "expired-server-cert": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block",
                    "ignore"
                ],
                "type": "str"
            },
            "proxy-after-tcp-handshake": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "revoked-server-cert": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block",
                    "ignore"
                ],
                "type": "str"
            },
            "unsupported-ssl-cipher": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block"
                ],
                "type": "str"
            },
            "unsupported-ssl-negotiation": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block"
                ],
                "type": "str"
            },
            "unsupported-ssl-version": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "block",
                    "allow",
                    "inspect"
                ],
                "type": "str"
            },
            "min-allowed-ssl-version": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ssl-3.0",
                    "tls-1.0",
                    "tls-1.1",
                    "tls-1.2",
                    "tls-1.3"
                ],
                "type": "str"
            }
        }
    },
    "firewall_sslsshprofile_pop3s": {
        "stated": false,
        "options": {
            "allow-invalid-server-cert": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "client-cert-request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "bypass",
                    "inspect",
                    "block"
                ],
                "type": "str"
            },
            "ports": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "deep-inspection"
                ],
                "type": "str"
            },
            "unsupported-ssl": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "bypass",
                    "inspect",
                    "block"
                ],
                "type": "str"
            },
            "untrusted-cert": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "allow",
                    "block",
                    "ignore"
                ],
                "type": "str"
            },
            "invalid-server-cert": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block"
                ],
                "type": "str"
            },
            "sni-server-cert-check": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "strict"
                ],
                "type": "str"
            },
            "untrusted-server-cert": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block",
                    "ignore"
                ],
                "type": "str"
            },
            "cert-validation-failure": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block",
                    "ignore"
                ],
                "type": "str"
            },
            "cert-validation-timeout": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block",
                    "ignore"
                ],
                "type": "str"
            },
            "client-certificate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "bypass",
                    "inspect",
                    "block"
                ],
                "type": "str"
            },
            "expired-server-cert": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block",
                    "ignore"
                ],
                "type": "str"
            },
            "proxy-after-tcp-handshake": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "revoked-server-cert": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block",
                    "ignore"
                ],
                "type": "str"
            },
            "unsupported-ssl-cipher": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block"
                ],
                "type": "str"
            },
            "unsupported-ssl-negotiation": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block"
                ],
                "type": "str"
            },
            "unsupported-ssl-version": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "block",
                    "allow",
                    "inspect"
                ],
                "type": "str"
            },
            "min-allowed-ssl-version": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ssl-3.0",
                    "tls-1.0",
                    "tls-1.1",
                    "tls-1.2",
                    "tls-1.3"
                ],
                "type": "str"
            }
        }
    },
    "firewall_sslsshprofile_smtps": {
        "stated": false,
        "options": {
            "allow-invalid-server-cert": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "client-cert-request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "bypass",
                    "inspect",
                    "block"
                ],
                "type": "str"
            },
            "ports": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "deep-inspection"
                ],
                "type": "str"
            },
            "unsupported-ssl": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "bypass",
                    "inspect",
                    "block"
                ],
                "type": "str"
            },
            "untrusted-cert": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "allow",
                    "block",
                    "ignore"
                ],
                "type": "str"
            },
            "invalid-server-cert": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block"
                ],
                "type": "str"
            },
            "sni-server-cert-check": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "strict"
                ],
                "type": "str"
            },
            "untrusted-server-cert": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block",
                    "ignore"
                ],
                "type": "str"
            },
            "cert-validation-failure": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block",
                    "ignore"
                ],
                "type": "str"
            },
            "cert-validation-timeout": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block",
                    "ignore"
                ],
                "type": "str"
            },
            "client-certificate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "bypass",
                    "inspect",
                    "block"
                ],
                "type": "str"
            },
            "expired-server-cert": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block",
                    "ignore"
                ],
                "type": "str"
            },
            "proxy-after-tcp-handshake": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "revoked-server-cert": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block",
                    "ignore"
                ],
                "type": "str"
            },
            "unsupported-ssl-cipher": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block"
                ],
                "type": "str"
            },
            "unsupported-ssl-negotiation": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block"
                ],
                "type": "str"
            },
            "unsupported-ssl-version": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "block",
                    "allow",
                    "inspect"
                ],
                "type": "str"
            },
            "min-allowed-ssl-version": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ssl-3.0",
                    "tls-1.0",
                    "tls-1.1",
                    "tls-1.2",
                    "tls-1.3"
                ],
                "type": "str"
            }
        }
    },
    "firewall_sslsshprofile_ssh": {
        "stated": false,
        "options": {
            "inspect-all": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "deep-inspection"
                ],
                "type": "str"
            },
            "ports": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ssh-algorithm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "compatible",
                    "high-encryption"
                ],
                "type": "str"
            },
            "ssh-policy-check": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssh-tun-policy-check": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "deep-inspection"
                ],
                "type": "str"
            },
            "unsupported-version": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "block",
                    "bypass"
                ],
                "type": "str"
            },
            "block": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "choices": [
                    "x11-filter",
                    "ssh-shell",
                    "exec",
                    "port-forward"
                ],
                "elements": "str"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "choices": [
                    "x11-filter",
                    "ssh-shell",
                    "exec",
                    "port-forward"
                ],
                "elements": "str"
            },
            "proxy-after-tcp-handshake": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "firewall_sslsshprofile_ssl": {
        "stated": false,
        "options": {
            "allow-invalid-server-cert": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "client-cert-request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "bypass",
                    "inspect",
                    "block"
                ],
                "type": "str"
            },
            "inspect-all": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "certificate-inspection",
                    "deep-inspection"
                ],
                "type": "str"
            },
            "unsupported-ssl": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "bypass",
                    "inspect",
                    "block"
                ],
                "type": "str"
            },
            "untrusted-cert": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "allow",
                    "block",
                    "ignore"
                ],
                "type": "str"
            },
            "invalid-server-cert": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block"
                ],
                "type": "str"
            },
            "sni-server-cert-check": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "strict"
                ],
                "type": "str"
            },
            "untrusted-server-cert": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block",
                    "ignore"
                ],
                "type": "str"
            },
            "cert-validation-failure": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block",
                    "ignore"
                ],
                "type": "str"
            },
            "cert-validation-timeout": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block",
                    "ignore"
                ],
                "type": "str"
            },
            "client-certificate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "bypass",
                    "inspect",
                    "block"
                ],
                "type": "str"
            },
            "expired-server-cert": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block",
                    "ignore"
                ],
                "type": "str"
            },
            "revoked-server-cert": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block",
                    "ignore"
                ],
                "type": "str"
            },
            "unsupported-ssl-cipher": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block"
                ],
                "type": "str"
            },
            "unsupported-ssl-negotiation": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block"
                ],
                "type": "str"
            },
            "cert-probe-failure": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "block",
                    "allow"
                ],
                "type": "str"
            },
            "min-allowed-ssl-version": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ssl-3.0",
                    "tls-1.0",
                    "tls-1.1",
                    "tls-1.2",
                    "tls-1.3"
                ],
                "type": "str"
            },
            "unsupported-ssl-version": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "block",
                    "allow",
                    "inspect"
                ],
                "type": "str"
            }
        }
    },
    "firewall_sslsshprofile_sslexempt": {
        "stated": true,
        "options": {
            "address": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "address6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "fortiguard-category": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "regex": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "fortiguard-category",
                    "address",
                    "address6",
                    "wildcard-fqdn",
                    "regex",
                    "finger-print"
                ],
                "type": "str"
            },
            "wildcard-fqdn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "firewall_sslsshprofile_sslserver": {
        "stated": true,
        "options": {
            "ftps-client-cert-request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "bypass",
                    "inspect",
                    "block"
                ],
                "type": "str"
            },
            "https-client-cert-request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "bypass",
                    "inspect",
                    "block"
                ],
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "imaps-client-cert-request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "bypass",
                    "inspect",
                    "block"
                ],
                "type": "str"
            },
            "ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "pop3s-client-cert-request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "bypass",
                    "inspect",
                    "block"
                ],
                "type": "str"
            },
            "smtps-client-cert-request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "bypass",
                    "inspect",
                    "block"
                ],
                "type": "str"
            },
            "ssl-other-client-cert-request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "bypass",
                    "inspect",
                    "block"
                ],
                "type": "str"
            },
            "ftps-client-certificate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "bypass",
                    "inspect",
                    "block"
                ],
                "type": "str"
            },
            "https-client-certificate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "bypass",
                    "inspect",
                    "block"
                ],
                "type": "str"
            },
            "imaps-client-certificate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "bypass",
                    "inspect",
                    "block"
                ],
                "type": "str"
            },
            "pop3s-client-certificate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "bypass",
                    "inspect",
                    "block"
                ],
                "type": "str"
            },
            "smtps-client-certificate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "bypass",
                    "inspect",
                    "block"
                ],
                "type": "str"
            },
            "ssl-other-client-certificate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "bypass",
                    "inspect",
                    "block"
                ],
                "type": "str"
            }
        }
    },
    "firewall_trafficclass": {
        "stated": true,
        "options": {
            "class-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "class-name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "firewall_vendormac": {
        "stated": false,
        "options": {
            "id": {
                "required": false,
                "revision": {
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mac-number": {
                "required": false,
                "revision": {
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": true
                },
                "type": "str"
            },
            "obsolete": {
                "required": false,
                "revision": {
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "firewall_vip": {
        "stated": true,
        "options": {
            "arp-reply": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "color": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dns-mapping-ttl": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "dynamic_mapping": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "_scope": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "vdom": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "arp-reply": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "color": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "comment": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "dns-mapping-ttl": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "extaddr": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "extintf": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "extip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "extport": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "gratuitous-arp-interval": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "http-cookie-age": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "http-cookie-domain": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "http-cookie-domain-from-host": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "http-cookie-generation": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "http-cookie-path": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "http-cookie-share": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "same-ip"
                        ],
                        "type": "str"
                    },
                    "http-ip-header": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "http-ip-header-name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "http-multiplex": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "https-cookie-secure": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ldb-method": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "static",
                            "round-robin",
                            "weighted",
                            "least-session",
                            "least-rtt",
                            "first-alive",
                            "http-host"
                        ],
                        "type": "str"
                    },
                    "mapped-addr": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "mappedip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "mappedport": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "max-embryonic-connections": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "monitor": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "nat-source-vip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "outlook-web-access": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "persistence": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "http-cookie",
                            "ssl-session-id"
                        ],
                        "type": "str"
                    },
                    "portforward": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "portmapping-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "1-to-1",
                            "m-to-n"
                        ],
                        "type": "str"
                    },
                    "protocol": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "tcp",
                            "udp",
                            "sctp",
                            "icmp"
                        ],
                        "type": "str"
                    },
                    "realservers": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "client-ip": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            },
                            "healthcheck": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable",
                                    "vip"
                                ],
                                "type": "str"
                            },
                            "holddown-interval": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "http-host": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "ip": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "max-connections": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "monitor": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            },
                            "port": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "seq": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "status": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "active",
                                    "standby",
                                    "disable"
                                ],
                                "type": "str"
                            },
                            "weight": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "address": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "type": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "ip",
                                    "address"
                                ],
                                "type": "str"
                            },
                            "translate-host": {
                                "required": false,
                                "revision": {
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "health-check-proto": {
                                "required": false,
                                "revision": {
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "ping",
                                    "http"
                                ],
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "server-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "http",
                            "https",
                            "ssl",
                            "tcp",
                            "udp",
                            "ip",
                            "imaps",
                            "pop3s",
                            "smtps",
                            "ssh"
                        ],
                        "type": "str"
                    },
                    "service": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "src-filter": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "srcintf-filter": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "ssl-algorithm": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "high",
                            "medium",
                            "low",
                            "custom"
                        ],
                        "type": "str"
                    },
                    "ssl-certificate": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ssl-cipher-suites": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "cipher": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "TLS-RSA-WITH-RC4-128-MD5",
                                    "TLS-RSA-WITH-RC4-128-SHA",
                                    "TLS-RSA-WITH-DES-CBC-SHA",
                                    "TLS-RSA-WITH-3DES-EDE-CBC-SHA",
                                    "TLS-RSA-WITH-AES-128-CBC-SHA",
                                    "TLS-RSA-WITH-AES-256-CBC-SHA",
                                    "TLS-RSA-WITH-AES-128-CBC-SHA256",
                                    "TLS-RSA-WITH-AES-256-CBC-SHA256",
                                    "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA",
                                    "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA",
                                    "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                                    "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                                    "TLS-RSA-WITH-SEED-CBC-SHA",
                                    "TLS-RSA-WITH-ARIA-128-CBC-SHA256",
                                    "TLS-RSA-WITH-ARIA-256-CBC-SHA384",
                                    "TLS-DHE-RSA-WITH-DES-CBC-SHA",
                                    "TLS-DHE-RSA-WITH-3DES-EDE-CBC-SHA",
                                    "TLS-DHE-RSA-WITH-AES-128-CBC-SHA",
                                    "TLS-DHE-RSA-WITH-AES-256-CBC-SHA",
                                    "TLS-DHE-RSA-WITH-AES-128-CBC-SHA256",
                                    "TLS-DHE-RSA-WITH-AES-256-CBC-SHA256",
                                    "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA",
                                    "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA",
                                    "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                                    "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                                    "TLS-DHE-RSA-WITH-SEED-CBC-SHA",
                                    "TLS-DHE-RSA-WITH-ARIA-128-CBC-SHA256",
                                    "TLS-DHE-RSA-WITH-ARIA-256-CBC-SHA384",
                                    "TLS-ECDHE-RSA-WITH-RC4-128-SHA",
                                    "TLS-ECDHE-RSA-WITH-3DES-EDE-CBC-SHA",
                                    "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA",
                                    "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA",
                                    "TLS-ECDHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                                    "TLS-ECDHE-ECDSA-WITH-CHACHA20-POLY1305-SHA256",
                                    "TLS-DHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                                    "TLS-DHE-RSA-WITH-AES-128-GCM-SHA256",
                                    "TLS-DHE-RSA-WITH-AES-256-GCM-SHA384",
                                    "TLS-DHE-DSS-WITH-AES-128-CBC-SHA",
                                    "TLS-DHE-DSS-WITH-AES-256-CBC-SHA",
                                    "TLS-DHE-DSS-WITH-AES-128-CBC-SHA256",
                                    "TLS-DHE-DSS-WITH-AES-128-GCM-SHA256",
                                    "TLS-DHE-DSS-WITH-AES-256-CBC-SHA256",
                                    "TLS-DHE-DSS-WITH-AES-256-GCM-SHA384",
                                    "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA256",
                                    "TLS-ECDHE-RSA-WITH-AES-128-GCM-SHA256",
                                    "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA384",
                                    "TLS-ECDHE-RSA-WITH-AES-256-GCM-SHA384",
                                    "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA",
                                    "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA256",
                                    "TLS-ECDHE-ECDSA-WITH-AES-128-GCM-SHA256",
                                    "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA384",
                                    "TLS-ECDHE-ECDSA-WITH-AES-256-GCM-SHA384",
                                    "TLS-RSA-WITH-AES-128-GCM-SHA256",
                                    "TLS-RSA-WITH-AES-256-GCM-SHA384",
                                    "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA",
                                    "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA",
                                    "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA256",
                                    "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA256",
                                    "TLS-DHE-DSS-WITH-SEED-CBC-SHA",
                                    "TLS-DHE-DSS-WITH-ARIA-128-CBC-SHA256",
                                    "TLS-DHE-DSS-WITH-ARIA-256-CBC-SHA384",
                                    "TLS-ECDHE-RSA-WITH-ARIA-128-CBC-SHA256",
                                    "TLS-ECDHE-RSA-WITH-ARIA-256-CBC-SHA384",
                                    "TLS-ECDHE-ECDSA-WITH-ARIA-128-CBC-SHA256",
                                    "TLS-ECDHE-ECDSA-WITH-ARIA-256-CBC-SHA384",
                                    "TLS-DHE-DSS-WITH-3DES-EDE-CBC-SHA",
                                    "TLS-DHE-DSS-WITH-DES-CBC-SHA",
                                    "TLS-AES-128-GCM-SHA256",
                                    "TLS-AES-256-GCM-SHA384",
                                    "TLS-CHACHA20-POLY1305-SHA256",
                                    "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA"
                                ],
                                "type": "str"
                            },
                            "id": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "versions": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "choices": [
                                    "ssl-3.0",
                                    "tls-1.0",
                                    "tls-1.1",
                                    "tls-1.2",
                                    "tls-1.3"
                                ],
                                "elements": "str"
                            },
                            "priority": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            }
                        },
                        "elements": "dict"
                    },
                    "ssl-client-fallback": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ssl-client-renegotiation": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "deny",
                            "allow",
                            "secure"
                        ],
                        "type": "str"
                    },
                    "ssl-client-session-state-max": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ssl-client-session-state-timeout": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ssl-client-session-state-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "time",
                            "count",
                            "both"
                        ],
                        "type": "str"
                    },
                    "ssl-dh-bits": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "768",
                            "1024",
                            "1536",
                            "2048",
                            "3072",
                            "4096"
                        ],
                        "type": "str"
                    },
                    "ssl-hpkp": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable",
                            "report-only"
                        ],
                        "type": "str"
                    },
                    "ssl-hpkp-age": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ssl-hpkp-backup": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ssl-hpkp-include-subdomains": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ssl-hpkp-primary": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ssl-hpkp-report-uri": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ssl-hsts": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ssl-hsts-age": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ssl-hsts-include-subdomains": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ssl-http-location-conversion": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ssl-http-match-host": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ssl-max-version": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ssl-3.0",
                            "tls-1.0",
                            "tls-1.1",
                            "tls-1.2",
                            "tls-1.3"
                        ],
                        "type": "str"
                    },
                    "ssl-min-version": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ssl-3.0",
                            "tls-1.0",
                            "tls-1.1",
                            "tls-1.2",
                            "tls-1.3"
                        ],
                        "type": "str"
                    },
                    "ssl-mode": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "half",
                            "full"
                        ],
                        "type": "str"
                    },
                    "ssl-pfs": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "require",
                            "deny",
                            "allow"
                        ],
                        "type": "str"
                    },
                    "ssl-send-empty-frags": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ssl-server-algorithm": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "high",
                            "low",
                            "medium",
                            "custom",
                            "client"
                        ],
                        "type": "str"
                    },
                    "ssl-server-max-version": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ssl-3.0",
                            "tls-1.0",
                            "tls-1.1",
                            "tls-1.2",
                            "client",
                            "tls-1.3"
                        ],
                        "type": "str"
                    },
                    "ssl-server-min-version": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ssl-3.0",
                            "tls-1.0",
                            "tls-1.1",
                            "tls-1.2",
                            "client",
                            "tls-1.3"
                        ],
                        "type": "str"
                    },
                    "ssl-server-session-state-max": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ssl-server-session-state-timeout": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ssl-server-session-state-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "time",
                            "count",
                            "both"
                        ],
                        "type": "str"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "static-nat",
                            "load-balance",
                            "server-load-balance",
                            "dns-translation",
                            "fqdn",
                            "access-proxy"
                        ],
                        "type": "str"
                    },
                    "uuid": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "weblogic-server": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "websphere-server": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "http-redirect": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ssl-client-rekey-count": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "int"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "add-nat46-route": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ipv6-mappedip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ipv6-mappedport": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "nat44": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "nat46": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ssl-accept-ffdhe-groups": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "http-multiplex-max-request": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "http-multiplex-ttl": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "http-supported-max-version": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "http1",
                            "http2"
                        ],
                        "type": "str"
                    },
                    "ssl-server-renegotiation": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "h2-support": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "h3-support": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "http-multiplex-max-concurrent-request": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "extaddr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "extintf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "extip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "extport": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "gratuitous-arp-interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "http-cookie-age": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "http-cookie-domain": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "http-cookie-domain-from-host": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "http-cookie-generation": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "http-cookie-path": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "http-cookie-share": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "same-ip"
                ],
                "type": "str"
            },
            "http-ip-header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "http-ip-header-name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "http-multiplex": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "https-cookie-secure": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ldb-method": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "static",
                    "round-robin",
                    "weighted",
                    "least-session",
                    "least-rtt",
                    "first-alive",
                    "http-host"
                ],
                "type": "str"
            },
            "mapped-addr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "mappedip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "mappedport": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "max-embryonic-connections": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "monitor": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "nat-source-vip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "outlook-web-access": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "persistence": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http-cookie",
                    "ssl-session-id"
                ],
                "type": "str"
            },
            "portforward": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "portmapping-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "1-to-1",
                    "m-to-n"
                ],
                "type": "str"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "tcp",
                    "udp",
                    "sctp",
                    "icmp"
                ],
                "type": "str"
            },
            "realservers": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "client-ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "healthcheck": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable",
                            "vip"
                        ],
                        "type": "str"
                    },
                    "holddown-interval": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "http-host": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "max-connections": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "monitor": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "port": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "seq": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "active",
                            "standby",
                            "disable"
                        ],
                        "type": "str"
                    },
                    "weight": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "address": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ip",
                            "address"
                        ],
                        "type": "str"
                    },
                    "translate-host": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "server-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "http",
                    "https",
                    "ssl",
                    "tcp",
                    "udp",
                    "ip",
                    "imaps",
                    "pop3s",
                    "smtps",
                    "ssh"
                ],
                "type": "str"
            },
            "service": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "src-filter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcintf-filter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ssl-algorithm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "high",
                    "medium",
                    "low",
                    "custom"
                ],
                "type": "str"
            },
            "ssl-certificate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ssl-cipher-suites": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "cipher": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "TLS-RSA-WITH-RC4-128-MD5",
                            "TLS-RSA-WITH-RC4-128-SHA",
                            "TLS-RSA-WITH-DES-CBC-SHA",
                            "TLS-RSA-WITH-3DES-EDE-CBC-SHA",
                            "TLS-RSA-WITH-AES-128-CBC-SHA",
                            "TLS-RSA-WITH-AES-256-CBC-SHA",
                            "TLS-RSA-WITH-AES-128-CBC-SHA256",
                            "TLS-RSA-WITH-AES-256-CBC-SHA256",
                            "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA",
                            "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA",
                            "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                            "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                            "TLS-RSA-WITH-SEED-CBC-SHA",
                            "TLS-RSA-WITH-ARIA-128-CBC-SHA256",
                            "TLS-RSA-WITH-ARIA-256-CBC-SHA384",
                            "TLS-DHE-RSA-WITH-DES-CBC-SHA",
                            "TLS-DHE-RSA-WITH-3DES-EDE-CBC-SHA",
                            "TLS-DHE-RSA-WITH-AES-128-CBC-SHA",
                            "TLS-DHE-RSA-WITH-AES-256-CBC-SHA",
                            "TLS-DHE-RSA-WITH-AES-128-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-AES-256-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA",
                            "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA",
                            "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-SEED-CBC-SHA",
                            "TLS-DHE-RSA-WITH-ARIA-128-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-ARIA-256-CBC-SHA384",
                            "TLS-ECDHE-RSA-WITH-RC4-128-SHA",
                            "TLS-ECDHE-RSA-WITH-3DES-EDE-CBC-SHA",
                            "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA",
                            "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA",
                            "TLS-ECDHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-CHACHA20-POLY1305-SHA256",
                            "TLS-DHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                            "TLS-DHE-RSA-WITH-AES-128-GCM-SHA256",
                            "TLS-DHE-RSA-WITH-AES-256-GCM-SHA384",
                            "TLS-DHE-DSS-WITH-AES-128-CBC-SHA",
                            "TLS-DHE-DSS-WITH-AES-256-CBC-SHA",
                            "TLS-DHE-DSS-WITH-AES-128-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-AES-128-GCM-SHA256",
                            "TLS-DHE-DSS-WITH-AES-256-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-AES-256-GCM-SHA384",
                            "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA256",
                            "TLS-ECDHE-RSA-WITH-AES-128-GCM-SHA256",
                            "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA384",
                            "TLS-ECDHE-RSA-WITH-AES-256-GCM-SHA384",
                            "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA",
                            "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-AES-128-GCM-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA384",
                            "TLS-ECDHE-ECDSA-WITH-AES-256-GCM-SHA384",
                            "TLS-RSA-WITH-AES-128-GCM-SHA256",
                            "TLS-RSA-WITH-AES-256-GCM-SHA384",
                            "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA",
                            "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA",
                            "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-SEED-CBC-SHA",
                            "TLS-DHE-DSS-WITH-ARIA-128-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-ARIA-256-CBC-SHA384",
                            "TLS-ECDHE-RSA-WITH-ARIA-128-CBC-SHA256",
                            "TLS-ECDHE-RSA-WITH-ARIA-256-CBC-SHA384",
                            "TLS-ECDHE-ECDSA-WITH-ARIA-128-CBC-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-ARIA-256-CBC-SHA384",
                            "TLS-DHE-DSS-WITH-3DES-EDE-CBC-SHA",
                            "TLS-DHE-DSS-WITH-DES-CBC-SHA",
                            "TLS-AES-128-GCM-SHA256",
                            "TLS-AES-256-GCM-SHA384",
                            "TLS-CHACHA20-POLY1305-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA"
                        ],
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "versions": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "ssl-3.0",
                            "tls-1.0",
                            "tls-1.1",
                            "tls-1.2",
                            "tls-1.3"
                        ],
                        "elements": "str"
                    },
                    "priority": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "ssl-client-fallback": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-client-renegotiation": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "deny",
                    "allow",
                    "secure"
                ],
                "type": "str"
            },
            "ssl-client-session-state-max": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ssl-client-session-state-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ssl-client-session-state-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "time",
                    "count",
                    "both"
                ],
                "type": "str"
            },
            "ssl-dh-bits": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "768",
                    "1024",
                    "1536",
                    "2048",
                    "3072",
                    "4096"
                ],
                "type": "str"
            },
            "ssl-hpkp": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "report-only"
                ],
                "type": "str"
            },
            "ssl-hpkp-age": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ssl-hpkp-backup": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ssl-hpkp-include-subdomains": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-hpkp-primary": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ssl-hpkp-report-uri": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ssl-hsts": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-hsts-age": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ssl-hsts-include-subdomains": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-http-location-conversion": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-http-match-host": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-max-version": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ssl-3.0",
                    "tls-1.0",
                    "tls-1.1",
                    "tls-1.2",
                    "tls-1.3"
                ],
                "type": "str"
            },
            "ssl-min-version": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ssl-3.0",
                    "tls-1.0",
                    "tls-1.1",
                    "tls-1.2",
                    "tls-1.3"
                ],
                "type": "str"
            },
            "ssl-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "half",
                    "full"
                ],
                "type": "str"
            },
            "ssl-pfs": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "require",
                    "deny",
                    "allow"
                ],
                "type": "str"
            },
            "ssl-send-empty-frags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-server-algorithm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "high",
                    "low",
                    "medium",
                    "custom",
                    "client"
                ],
                "type": "str"
            },
            "ssl-server-cipher-suites": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "cipher": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "TLS-RSA-WITH-RC4-128-MD5",
                            "TLS-RSA-WITH-RC4-128-SHA",
                            "TLS-RSA-WITH-DES-CBC-SHA",
                            "TLS-RSA-WITH-3DES-EDE-CBC-SHA",
                            "TLS-RSA-WITH-AES-128-CBC-SHA",
                            "TLS-RSA-WITH-AES-256-CBC-SHA",
                            "TLS-RSA-WITH-AES-128-CBC-SHA256",
                            "TLS-RSA-WITH-AES-256-CBC-SHA256",
                            "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA",
                            "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA",
                            "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                            "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                            "TLS-RSA-WITH-SEED-CBC-SHA",
                            "TLS-RSA-WITH-ARIA-128-CBC-SHA256",
                            "TLS-RSA-WITH-ARIA-256-CBC-SHA384",
                            "TLS-DHE-RSA-WITH-DES-CBC-SHA",
                            "TLS-DHE-RSA-WITH-3DES-EDE-CBC-SHA",
                            "TLS-DHE-RSA-WITH-AES-128-CBC-SHA",
                            "TLS-DHE-RSA-WITH-AES-256-CBC-SHA",
                            "TLS-DHE-RSA-WITH-AES-128-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-AES-256-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA",
                            "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA",
                            "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-SEED-CBC-SHA",
                            "TLS-DHE-RSA-WITH-ARIA-128-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-ARIA-256-CBC-SHA384",
                            "TLS-ECDHE-RSA-WITH-RC4-128-SHA",
                            "TLS-ECDHE-RSA-WITH-3DES-EDE-CBC-SHA",
                            "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA",
                            "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA",
                            "TLS-ECDHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-CHACHA20-POLY1305-SHA256",
                            "TLS-DHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                            "TLS-DHE-RSA-WITH-AES-128-GCM-SHA256",
                            "TLS-DHE-RSA-WITH-AES-256-GCM-SHA384",
                            "TLS-DHE-DSS-WITH-AES-128-CBC-SHA",
                            "TLS-DHE-DSS-WITH-AES-256-CBC-SHA",
                            "TLS-DHE-DSS-WITH-AES-128-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-AES-128-GCM-SHA256",
                            "TLS-DHE-DSS-WITH-AES-256-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-AES-256-GCM-SHA384",
                            "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA256",
                            "TLS-ECDHE-RSA-WITH-AES-128-GCM-SHA256",
                            "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA384",
                            "TLS-ECDHE-RSA-WITH-AES-256-GCM-SHA384",
                            "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA",
                            "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-AES-128-GCM-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA384",
                            "TLS-ECDHE-ECDSA-WITH-AES-256-GCM-SHA384",
                            "TLS-RSA-WITH-AES-128-GCM-SHA256",
                            "TLS-RSA-WITH-AES-256-GCM-SHA384",
                            "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA",
                            "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA",
                            "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-SEED-CBC-SHA",
                            "TLS-DHE-DSS-WITH-ARIA-128-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-ARIA-256-CBC-SHA384",
                            "TLS-ECDHE-RSA-WITH-ARIA-128-CBC-SHA256",
                            "TLS-ECDHE-RSA-WITH-ARIA-256-CBC-SHA384",
                            "TLS-ECDHE-ECDSA-WITH-ARIA-128-CBC-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-ARIA-256-CBC-SHA384",
                            "TLS-DHE-DSS-WITH-3DES-EDE-CBC-SHA",
                            "TLS-DHE-DSS-WITH-DES-CBC-SHA",
                            "TLS-AES-128-GCM-SHA256",
                            "TLS-AES-256-GCM-SHA384",
                            "TLS-CHACHA20-POLY1305-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA"
                        ],
                        "type": "str"
                    },
                    "priority": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "versions": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "ssl-3.0",
                            "tls-1.0",
                            "tls-1.1",
                            "tls-1.2",
                            "tls-1.3"
                        ],
                        "elements": "str"
                    }
                },
                "elements": "dict"
            },
            "ssl-server-max-version": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ssl-3.0",
                    "tls-1.0",
                    "tls-1.1",
                    "tls-1.2",
                    "client",
                    "tls-1.3"
                ],
                "type": "str"
            },
            "ssl-server-min-version": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ssl-3.0",
                    "tls-1.0",
                    "tls-1.1",
                    "tls-1.2",
                    "client",
                    "tls-1.3"
                ],
                "type": "str"
            },
            "ssl-server-session-state-max": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ssl-server-session-state-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ssl-server-session-state-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "time",
                    "count",
                    "both"
                ],
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "static-nat",
                    "load-balance",
                    "server-load-balance",
                    "dns-translation",
                    "fqdn",
                    "access-proxy"
                ],
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "weblogic-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "websphere-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "http-redirect": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-client-rekey-count": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "add-nat46-route": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ipv6-mappedip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipv6-mappedport": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "nat44": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "nat46": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-accept-ffdhe-groups": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "http-multiplex-max-request": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "http-multiplex-ttl": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "http-supported-max-version": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "http1",
                    "http2"
                ],
                "type": "str"
            },
            "ssl-server-renegotiation": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "h2-support": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "h3-support": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "http-multiplex-max-concurrent-request": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "quic": {
                "required": false,
                "type": "dict",
                "options": {
                    "ack-delay-exponent": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "active-connection-id-limit": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "active-migration": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "grease-quic-bit": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "max-ack-delay": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "max-datagram-frame-size": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "max-idle-timeout": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "max-udp-payload-size": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                }
            }
        }
    },
    "firewall_vip46": {
        "stated": true,
        "options": {
            "arp-reply": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "color": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dynamic_mapping": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "_scope": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "vdom": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "arp-reply": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "color": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "comment": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "extip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "extport": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ldb-method": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "static",
                            "round-robin",
                            "weighted",
                            "least-session",
                            "least-rtt",
                            "first-alive"
                        ],
                        "type": "str"
                    },
                    "mappedip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "mappedport": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "monitor": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "portforward": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "protocol": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "tcp",
                            "udp"
                        ],
                        "type": "str"
                    },
                    "server-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "http",
                            "tcp",
                            "udp",
                            "ip"
                        ],
                        "type": "str"
                    },
                    "src-filter": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "static-nat",
                            "server-load-balance"
                        ],
                        "type": "str"
                    },
                    "uuid": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "srcintf-filter": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    }
                },
                "elements": "dict"
            },
            "extip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "extport": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ldb-method": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "static",
                    "round-robin",
                    "weighted",
                    "least-session",
                    "least-rtt",
                    "first-alive"
                ],
                "type": "str"
            },
            "mappedip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "mappedport": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "monitor": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "portforward": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "tcp",
                    "udp"
                ],
                "type": "str"
            },
            "realservers": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "client-ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "healthcheck": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable",
                            "vip"
                        ],
                        "type": "str"
                    },
                    "holddown-interval": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "max-connections": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "monitor": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "port": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "active",
                            "standby",
                            "disable"
                        ],
                        "type": "str"
                    },
                    "weight": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "server-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "http",
                    "tcp",
                    "udp",
                    "ip"
                ],
                "type": "str"
            },
            "src-filter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "static-nat",
                    "server-load-balance"
                ],
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "srcintf-filter": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "firewall_vip46_dynamicmapping": {
        "stated": true,
        "options": {
            "_scope": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "arp-reply": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "color": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "extip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "extport": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ldb-method": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "static",
                    "round-robin",
                    "weighted",
                    "least-session",
                    "least-rtt",
                    "first-alive"
                ],
                "type": "str"
            },
            "mappedip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "mappedport": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "monitor": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "portforward": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "tcp",
                    "udp"
                ],
                "type": "str"
            },
            "server-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "http",
                    "tcp",
                    "udp",
                    "ip"
                ],
                "type": "str"
            },
            "src-filter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "static-nat",
                    "server-load-balance"
                ],
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "srcintf-filter": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "firewall_vip46_realservers": {
        "stated": true,
        "options": {
            "client-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "healthcheck": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "vip"
                ],
                "type": "str"
            },
            "holddown-interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "max-connections": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "monitor": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "active",
                    "standby",
                    "disable"
                ],
                "type": "str"
            },
            "weight": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "firewall_vip6": {
        "stated": true,
        "options": {
            "arp-reply": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "color": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dynamic_mapping": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "_scope": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "vdom": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "arp-reply": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "color": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "comment": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "extip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "extport": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "http-cookie-age": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "http-cookie-domain": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "http-cookie-domain-from-host": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "http-cookie-generation": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "http-cookie-path": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "http-cookie-share": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "same-ip"
                        ],
                        "type": "str"
                    },
                    "http-ip-header": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "http-ip-header-name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "http-multiplex": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "https-cookie-secure": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ldb-method": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "static",
                            "round-robin",
                            "weighted",
                            "least-session",
                            "least-rtt",
                            "first-alive",
                            "http-host"
                        ],
                        "type": "str"
                    },
                    "mappedip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "mappedport": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "max-embryonic-connections": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "monitor": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "outlook-web-access": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "persistence": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "http-cookie",
                            "ssl-session-id"
                        ],
                        "type": "str"
                    },
                    "portforward": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "protocol": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "tcp",
                            "udp",
                            "sctp"
                        ],
                        "type": "str"
                    },
                    "server-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "http",
                            "https",
                            "ssl",
                            "tcp",
                            "udp",
                            "ip",
                            "imaps",
                            "pop3s",
                            "smtps"
                        ],
                        "type": "str"
                    },
                    "src-filter": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "ssl-algorithm": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "high",
                            "low",
                            "medium",
                            "custom"
                        ],
                        "type": "str"
                    },
                    "ssl-certificate": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ssl-client-fallback": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ssl-client-renegotiation": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "deny",
                            "allow",
                            "secure"
                        ],
                        "type": "str"
                    },
                    "ssl-client-session-state-max": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ssl-client-session-state-timeout": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ssl-client-session-state-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "time",
                            "count",
                            "both"
                        ],
                        "type": "str"
                    },
                    "ssl-dh-bits": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "768",
                            "1024",
                            "1536",
                            "2048",
                            "3072",
                            "4096"
                        ],
                        "type": "str"
                    },
                    "ssl-hpkp": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable",
                            "report-only"
                        ],
                        "type": "str"
                    },
                    "ssl-hpkp-age": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ssl-hpkp-backup": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ssl-hpkp-include-subdomains": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ssl-hpkp-primary": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ssl-hpkp-report-uri": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ssl-hsts": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ssl-hsts-age": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ssl-hsts-include-subdomains": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ssl-http-location-conversion": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ssl-http-match-host": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ssl-max-version": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ssl-3.0",
                            "tls-1.0",
                            "tls-1.1",
                            "tls-1.2",
                            "tls-1.3"
                        ],
                        "type": "str"
                    },
                    "ssl-min-version": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ssl-3.0",
                            "tls-1.0",
                            "tls-1.1",
                            "tls-1.2",
                            "tls-1.3"
                        ],
                        "type": "str"
                    },
                    "ssl-mode": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "half",
                            "full"
                        ],
                        "type": "str"
                    },
                    "ssl-pfs": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "require",
                            "deny",
                            "allow"
                        ],
                        "type": "str"
                    },
                    "ssl-send-empty-frags": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ssl-server-algorithm": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "high",
                            "low",
                            "medium",
                            "custom",
                            "client"
                        ],
                        "type": "str"
                    },
                    "ssl-server-max-version": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ssl-3.0",
                            "tls-1.0",
                            "tls-1.1",
                            "tls-1.2",
                            "client",
                            "tls-1.3"
                        ],
                        "type": "str"
                    },
                    "ssl-server-min-version": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ssl-3.0",
                            "tls-1.0",
                            "tls-1.1",
                            "tls-1.2",
                            "client",
                            "tls-1.3"
                        ],
                        "type": "str"
                    },
                    "ssl-server-session-state-max": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ssl-server-session-state-timeout": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ssl-server-session-state-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "time",
                            "count",
                            "both"
                        ],
                        "type": "str"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "static-nat",
                            "server-load-balance",
                            "access-proxy"
                        ],
                        "type": "str"
                    },
                    "uuid": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "weblogic-server": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "websphere-server": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "http-redirect": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ssl-client-rekey-count": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "int"
                    },
                    "nat-source-vip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "add-nat64-route": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "embedded-ipv4-address": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ipv4-mappedip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ipv4-mappedport": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "nat64": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "nat66": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "realservers": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "client-ip": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "healthcheck": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable",
                                    "vip"
                                ],
                                "type": "str"
                            },
                            "holddown-interval": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "http-host": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "ip": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "max-connections": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "monitor": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            },
                            "port": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "status": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "active",
                                    "standby",
                                    "disable"
                                ],
                                "type": "str"
                            },
                            "weight": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "translate-host": {
                                "required": false,
                                "revision": {
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "ssl-accept-ffdhe-groups": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ssl-cipher-suites": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "cipher": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "TLS-RSA-WITH-RC4-128-MD5",
                                    "TLS-RSA-WITH-RC4-128-SHA",
                                    "TLS-RSA-WITH-DES-CBC-SHA",
                                    "TLS-RSA-WITH-3DES-EDE-CBC-SHA",
                                    "TLS-RSA-WITH-AES-128-CBC-SHA",
                                    "TLS-RSA-WITH-AES-256-CBC-SHA",
                                    "TLS-RSA-WITH-AES-128-CBC-SHA256",
                                    "TLS-RSA-WITH-AES-256-CBC-SHA256",
                                    "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA",
                                    "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA",
                                    "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                                    "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                                    "TLS-RSA-WITH-SEED-CBC-SHA",
                                    "TLS-RSA-WITH-ARIA-128-CBC-SHA256",
                                    "TLS-RSA-WITH-ARIA-256-CBC-SHA384",
                                    "TLS-DHE-RSA-WITH-DES-CBC-SHA",
                                    "TLS-DHE-RSA-WITH-3DES-EDE-CBC-SHA",
                                    "TLS-DHE-RSA-WITH-AES-128-CBC-SHA",
                                    "TLS-DHE-RSA-WITH-AES-256-CBC-SHA",
                                    "TLS-DHE-RSA-WITH-AES-128-CBC-SHA256",
                                    "TLS-DHE-RSA-WITH-AES-256-CBC-SHA256",
                                    "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA",
                                    "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA",
                                    "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                                    "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                                    "TLS-DHE-RSA-WITH-SEED-CBC-SHA",
                                    "TLS-DHE-RSA-WITH-ARIA-128-CBC-SHA256",
                                    "TLS-DHE-RSA-WITH-ARIA-256-CBC-SHA384",
                                    "TLS-ECDHE-RSA-WITH-RC4-128-SHA",
                                    "TLS-ECDHE-RSA-WITH-3DES-EDE-CBC-SHA",
                                    "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA",
                                    "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA",
                                    "TLS-ECDHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                                    "TLS-ECDHE-ECDSA-WITH-CHACHA20-POLY1305-SHA256",
                                    "TLS-DHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                                    "TLS-DHE-RSA-WITH-AES-128-GCM-SHA256",
                                    "TLS-DHE-RSA-WITH-AES-256-GCM-SHA384",
                                    "TLS-DHE-DSS-WITH-AES-128-CBC-SHA",
                                    "TLS-DHE-DSS-WITH-AES-256-CBC-SHA",
                                    "TLS-DHE-DSS-WITH-AES-128-CBC-SHA256",
                                    "TLS-DHE-DSS-WITH-AES-128-GCM-SHA256",
                                    "TLS-DHE-DSS-WITH-AES-256-CBC-SHA256",
                                    "TLS-DHE-DSS-WITH-AES-256-GCM-SHA384",
                                    "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA256",
                                    "TLS-ECDHE-RSA-WITH-AES-128-GCM-SHA256",
                                    "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA384",
                                    "TLS-ECDHE-RSA-WITH-AES-256-GCM-SHA384",
                                    "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA",
                                    "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA256",
                                    "TLS-ECDHE-ECDSA-WITH-AES-128-GCM-SHA256",
                                    "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA384",
                                    "TLS-ECDHE-ECDSA-WITH-AES-256-GCM-SHA384",
                                    "TLS-RSA-WITH-AES-128-GCM-SHA256",
                                    "TLS-RSA-WITH-AES-256-GCM-SHA384",
                                    "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA",
                                    "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA",
                                    "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA256",
                                    "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA256",
                                    "TLS-DHE-DSS-WITH-SEED-CBC-SHA",
                                    "TLS-DHE-DSS-WITH-ARIA-128-CBC-SHA256",
                                    "TLS-DHE-DSS-WITH-ARIA-256-CBC-SHA384",
                                    "TLS-ECDHE-RSA-WITH-ARIA-128-CBC-SHA256",
                                    "TLS-ECDHE-RSA-WITH-ARIA-256-CBC-SHA384",
                                    "TLS-ECDHE-ECDSA-WITH-ARIA-128-CBC-SHA256",
                                    "TLS-ECDHE-ECDSA-WITH-ARIA-256-CBC-SHA384",
                                    "TLS-DHE-DSS-WITH-3DES-EDE-CBC-SHA",
                                    "TLS-DHE-DSS-WITH-DES-CBC-SHA",
                                    "TLS-AES-128-GCM-SHA256",
                                    "TLS-AES-256-GCM-SHA384",
                                    "TLS-CHACHA20-POLY1305-SHA256",
                                    "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA"
                                ],
                                "type": "str"
                            },
                            "priority": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "versions": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "choices": [
                                    "ssl-3.0",
                                    "tls-1.0",
                                    "tls-1.1",
                                    "tls-1.2",
                                    "tls-1.3"
                                ],
                                "elements": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "ndp-reply": {
                        "required": false,
                        "revision": {
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": false,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ssl-server-renegotiation": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "extip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "extport": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "http-cookie-age": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "http-cookie-domain": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "http-cookie-domain-from-host": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "http-cookie-generation": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "http-cookie-path": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "http-cookie-share": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "same-ip"
                ],
                "type": "str"
            },
            "http-ip-header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "http-ip-header-name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "http-multiplex": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "https-cookie-secure": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ldb-method": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "static",
                    "round-robin",
                    "weighted",
                    "least-session",
                    "least-rtt",
                    "first-alive",
                    "http-host"
                ],
                "type": "str"
            },
            "mappedip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "mappedport": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "max-embryonic-connections": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "monitor": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "outlook-web-access": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "persistence": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http-cookie",
                    "ssl-session-id"
                ],
                "type": "str"
            },
            "portforward": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "tcp",
                    "udp",
                    "sctp"
                ],
                "type": "str"
            },
            "realservers": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "client-ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "healthcheck": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable",
                            "vip"
                        ],
                        "type": "str"
                    },
                    "holddown-interval": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "http-host": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "max-connections": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "monitor": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "port": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "active",
                            "standby",
                            "disable"
                        ],
                        "type": "str"
                    },
                    "weight": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "translate-host": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "server-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "http",
                    "https",
                    "ssl",
                    "tcp",
                    "udp",
                    "ip",
                    "imaps",
                    "pop3s",
                    "smtps"
                ],
                "type": "str"
            },
            "src-filter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ssl-algorithm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "high",
                    "low",
                    "medium",
                    "custom"
                ],
                "type": "str"
            },
            "ssl-certificate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ssl-cipher-suites": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "cipher": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "TLS-RSA-WITH-RC4-128-MD5",
                            "TLS-RSA-WITH-RC4-128-SHA",
                            "TLS-RSA-WITH-DES-CBC-SHA",
                            "TLS-RSA-WITH-3DES-EDE-CBC-SHA",
                            "TLS-RSA-WITH-AES-128-CBC-SHA",
                            "TLS-RSA-WITH-AES-256-CBC-SHA",
                            "TLS-RSA-WITH-AES-128-CBC-SHA256",
                            "TLS-RSA-WITH-AES-256-CBC-SHA256",
                            "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA",
                            "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA",
                            "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                            "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                            "TLS-RSA-WITH-SEED-CBC-SHA",
                            "TLS-RSA-WITH-ARIA-128-CBC-SHA256",
                            "TLS-RSA-WITH-ARIA-256-CBC-SHA384",
                            "TLS-DHE-RSA-WITH-DES-CBC-SHA",
                            "TLS-DHE-RSA-WITH-3DES-EDE-CBC-SHA",
                            "TLS-DHE-RSA-WITH-AES-128-CBC-SHA",
                            "TLS-DHE-RSA-WITH-AES-256-CBC-SHA",
                            "TLS-DHE-RSA-WITH-AES-128-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-AES-256-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA",
                            "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA",
                            "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-SEED-CBC-SHA",
                            "TLS-DHE-RSA-WITH-ARIA-128-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-ARIA-256-CBC-SHA384",
                            "TLS-ECDHE-RSA-WITH-RC4-128-SHA",
                            "TLS-ECDHE-RSA-WITH-3DES-EDE-CBC-SHA",
                            "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA",
                            "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA",
                            "TLS-ECDHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-CHACHA20-POLY1305-SHA256",
                            "TLS-DHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                            "TLS-DHE-RSA-WITH-AES-128-GCM-SHA256",
                            "TLS-DHE-RSA-WITH-AES-256-GCM-SHA384",
                            "TLS-DHE-DSS-WITH-AES-128-CBC-SHA",
                            "TLS-DHE-DSS-WITH-AES-256-CBC-SHA",
                            "TLS-DHE-DSS-WITH-AES-128-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-AES-128-GCM-SHA256",
                            "TLS-DHE-DSS-WITH-AES-256-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-AES-256-GCM-SHA384",
                            "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA256",
                            "TLS-ECDHE-RSA-WITH-AES-128-GCM-SHA256",
                            "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA384",
                            "TLS-ECDHE-RSA-WITH-AES-256-GCM-SHA384",
                            "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA",
                            "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-AES-128-GCM-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA384",
                            "TLS-ECDHE-ECDSA-WITH-AES-256-GCM-SHA384",
                            "TLS-RSA-WITH-AES-128-GCM-SHA256",
                            "TLS-RSA-WITH-AES-256-GCM-SHA384",
                            "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA",
                            "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA",
                            "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-SEED-CBC-SHA",
                            "TLS-DHE-DSS-WITH-ARIA-128-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-ARIA-256-CBC-SHA384",
                            "TLS-ECDHE-RSA-WITH-ARIA-128-CBC-SHA256",
                            "TLS-ECDHE-RSA-WITH-ARIA-256-CBC-SHA384",
                            "TLS-ECDHE-ECDSA-WITH-ARIA-128-CBC-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-ARIA-256-CBC-SHA384",
                            "TLS-DHE-DSS-WITH-3DES-EDE-CBC-SHA",
                            "TLS-DHE-DSS-WITH-DES-CBC-SHA",
                            "TLS-AES-128-GCM-SHA256",
                            "TLS-AES-256-GCM-SHA384",
                            "TLS-CHACHA20-POLY1305-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA"
                        ],
                        "type": "str"
                    },
                    "priority": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "versions": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "ssl-3.0",
                            "tls-1.0",
                            "tls-1.1",
                            "tls-1.2",
                            "tls-1.3"
                        ],
                        "elements": "str"
                    }
                },
                "elements": "dict"
            },
            "ssl-client-fallback": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-client-renegotiation": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "deny",
                    "allow",
                    "secure"
                ],
                "type": "str"
            },
            "ssl-client-session-state-max": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ssl-client-session-state-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ssl-client-session-state-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "time",
                    "count",
                    "both"
                ],
                "type": "str"
            },
            "ssl-dh-bits": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "768",
                    "1024",
                    "1536",
                    "2048",
                    "3072",
                    "4096"
                ],
                "type": "str"
            },
            "ssl-hpkp": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "report-only"
                ],
                "type": "str"
            },
            "ssl-hpkp-age": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ssl-hpkp-backup": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ssl-hpkp-include-subdomains": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-hpkp-primary": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ssl-hpkp-report-uri": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ssl-hsts": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-hsts-age": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ssl-hsts-include-subdomains": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-http-location-conversion": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-http-match-host": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-max-version": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ssl-3.0",
                    "tls-1.0",
                    "tls-1.1",
                    "tls-1.2",
                    "tls-1.3"
                ],
                "type": "str"
            },
            "ssl-min-version": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ssl-3.0",
                    "tls-1.0",
                    "tls-1.1",
                    "tls-1.2",
                    "tls-1.3"
                ],
                "type": "str"
            },
            "ssl-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "half",
                    "full"
                ],
                "type": "str"
            },
            "ssl-pfs": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "require",
                    "deny",
                    "allow"
                ],
                "type": "str"
            },
            "ssl-send-empty-frags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-server-algorithm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "high",
                    "low",
                    "medium",
                    "custom",
                    "client"
                ],
                "type": "str"
            },
            "ssl-server-cipher-suites": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "cipher": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "TLS-RSA-WITH-RC4-128-MD5",
                            "TLS-RSA-WITH-RC4-128-SHA",
                            "TLS-RSA-WITH-DES-CBC-SHA",
                            "TLS-RSA-WITH-3DES-EDE-CBC-SHA",
                            "TLS-RSA-WITH-AES-128-CBC-SHA",
                            "TLS-RSA-WITH-AES-256-CBC-SHA",
                            "TLS-RSA-WITH-AES-128-CBC-SHA256",
                            "TLS-RSA-WITH-AES-256-CBC-SHA256",
                            "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA",
                            "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA",
                            "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                            "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                            "TLS-RSA-WITH-SEED-CBC-SHA",
                            "TLS-RSA-WITH-ARIA-128-CBC-SHA256",
                            "TLS-RSA-WITH-ARIA-256-CBC-SHA384",
                            "TLS-DHE-RSA-WITH-DES-CBC-SHA",
                            "TLS-DHE-RSA-WITH-3DES-EDE-CBC-SHA",
                            "TLS-DHE-RSA-WITH-AES-128-CBC-SHA",
                            "TLS-DHE-RSA-WITH-AES-256-CBC-SHA",
                            "TLS-DHE-RSA-WITH-AES-128-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-AES-256-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA",
                            "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA",
                            "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-SEED-CBC-SHA",
                            "TLS-DHE-RSA-WITH-ARIA-128-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-ARIA-256-CBC-SHA384",
                            "TLS-ECDHE-RSA-WITH-RC4-128-SHA",
                            "TLS-ECDHE-RSA-WITH-3DES-EDE-CBC-SHA",
                            "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA",
                            "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA",
                            "TLS-ECDHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-CHACHA20-POLY1305-SHA256",
                            "TLS-DHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                            "TLS-DHE-RSA-WITH-AES-128-GCM-SHA256",
                            "TLS-DHE-RSA-WITH-AES-256-GCM-SHA384",
                            "TLS-DHE-DSS-WITH-AES-128-CBC-SHA",
                            "TLS-DHE-DSS-WITH-AES-256-CBC-SHA",
                            "TLS-DHE-DSS-WITH-AES-128-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-AES-128-GCM-SHA256",
                            "TLS-DHE-DSS-WITH-AES-256-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-AES-256-GCM-SHA384",
                            "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA256",
                            "TLS-ECDHE-RSA-WITH-AES-128-GCM-SHA256",
                            "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA384",
                            "TLS-ECDHE-RSA-WITH-AES-256-GCM-SHA384",
                            "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA",
                            "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-AES-128-GCM-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA384",
                            "TLS-ECDHE-ECDSA-WITH-AES-256-GCM-SHA384",
                            "TLS-RSA-WITH-AES-128-GCM-SHA256",
                            "TLS-RSA-WITH-AES-256-GCM-SHA384",
                            "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA",
                            "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA",
                            "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-SEED-CBC-SHA",
                            "TLS-DHE-DSS-WITH-ARIA-128-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-ARIA-256-CBC-SHA384",
                            "TLS-ECDHE-RSA-WITH-ARIA-128-CBC-SHA256",
                            "TLS-ECDHE-RSA-WITH-ARIA-256-CBC-SHA384",
                            "TLS-ECDHE-ECDSA-WITH-ARIA-128-CBC-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-ARIA-256-CBC-SHA384",
                            "TLS-DHE-DSS-WITH-3DES-EDE-CBC-SHA",
                            "TLS-DHE-DSS-WITH-DES-CBC-SHA",
                            "TLS-AES-128-GCM-SHA256",
                            "TLS-AES-256-GCM-SHA384",
                            "TLS-CHACHA20-POLY1305-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA"
                        ],
                        "type": "str"
                    },
                    "priority": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "versions": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "ssl-3.0",
                            "tls-1.0",
                            "tls-1.1",
                            "tls-1.2",
                            "tls-1.3"
                        ],
                        "elements": "str"
                    }
                },
                "elements": "dict"
            },
            "ssl-server-max-version": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ssl-3.0",
                    "tls-1.0",
                    "tls-1.1",
                    "tls-1.2",
                    "client",
                    "tls-1.3"
                ],
                "type": "str"
            },
            "ssl-server-min-version": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ssl-3.0",
                    "tls-1.0",
                    "tls-1.1",
                    "tls-1.2",
                    "client",
                    "tls-1.3"
                ],
                "type": "str"
            },
            "ssl-server-session-state-max": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ssl-server-session-state-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ssl-server-session-state-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "time",
                    "count",
                    "both"
                ],
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "static-nat",
                    "server-load-balance",
                    "access-proxy"
                ],
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "weblogic-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "websphere-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "http-redirect": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-client-rekey-count": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "int"
            },
            "nat-source-vip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "add-nat64-route": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "embedded-ipv4-address": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ipv4-mappedip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipv4-mappedport": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "nat64": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "nat66": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-accept-ffdhe-groups": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ndp-reply": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-server-renegotiation": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "firewall_vip64": {
        "stated": true,
        "options": {
            "arp-reply": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "color": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dynamic_mapping": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "_scope": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "vdom": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "arp-reply": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "color": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "comment": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "extip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "extport": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ldb-method": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "static",
                            "round-robin",
                            "weighted",
                            "least-session",
                            "least-rtt",
                            "first-alive"
                        ],
                        "type": "str"
                    },
                    "mappedip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "mappedport": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "monitor": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "portforward": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "protocol": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "tcp",
                            "udp"
                        ],
                        "type": "str"
                    },
                    "server-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "http",
                            "tcp",
                            "udp",
                            "ip"
                        ],
                        "type": "str"
                    },
                    "src-filter": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "static-nat",
                            "server-load-balance"
                        ],
                        "type": "str"
                    },
                    "uuid": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "extip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "extport": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ldb-method": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "static",
                    "round-robin",
                    "weighted",
                    "least-session",
                    "least-rtt",
                    "first-alive"
                ],
                "type": "str"
            },
            "mappedip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "mappedport": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "monitor": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "portforward": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "tcp",
                    "udp"
                ],
                "type": "str"
            },
            "realservers": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "client-ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "healthcheck": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable",
                            "vip"
                        ],
                        "type": "str"
                    },
                    "holddown-interval": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "max-connections": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "monitor": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "port": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "active",
                            "standby",
                            "disable"
                        ],
                        "type": "str"
                    },
                    "weight": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "server-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "http",
                    "tcp",
                    "udp",
                    "ip"
                ],
                "type": "str"
            },
            "src-filter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "static-nat",
                    "server-load-balance"
                ],
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "firewall_vip64_dynamicmapping": {
        "stated": true,
        "options": {
            "_scope": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "arp-reply": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "color": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "extip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "extport": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ldb-method": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "static",
                    "round-robin",
                    "weighted",
                    "least-session",
                    "least-rtt",
                    "first-alive"
                ],
                "type": "str"
            },
            "mappedip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "mappedport": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "monitor": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "portforward": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "tcp",
                    "udp"
                ],
                "type": "str"
            },
            "server-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "http",
                    "tcp",
                    "udp",
                    "ip"
                ],
                "type": "str"
            },
            "src-filter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "static-nat",
                    "server-load-balance"
                ],
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "firewall_vip64_realservers": {
        "stated": true,
        "options": {
            "client-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "healthcheck": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "vip"
                ],
                "type": "str"
            },
            "holddown-interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "max-connections": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "monitor": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "active",
                    "standby",
                    "disable"
                ],
                "type": "str"
            },
            "weight": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "firewall_vip6_dynamicmapping": {
        "stated": true,
        "options": {
            "_scope": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "arp-reply": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "color": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "extip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "extport": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "http-cookie-age": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "http-cookie-domain": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "http-cookie-domain-from-host": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "http-cookie-generation": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "http-cookie-path": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "http-cookie-share": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "same-ip"
                ],
                "type": "str"
            },
            "http-ip-header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "http-ip-header-name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "http-multiplex": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "https-cookie-secure": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ldb-method": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "static",
                    "round-robin",
                    "weighted",
                    "least-session",
                    "least-rtt",
                    "first-alive",
                    "http-host"
                ],
                "type": "str"
            },
            "mappedip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "mappedport": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "max-embryonic-connections": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "monitor": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "outlook-web-access": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "persistence": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http-cookie",
                    "ssl-session-id"
                ],
                "type": "str"
            },
            "portforward": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "tcp",
                    "udp",
                    "sctp"
                ],
                "type": "str"
            },
            "server-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "http",
                    "https",
                    "ssl",
                    "tcp",
                    "udp",
                    "ip",
                    "imaps",
                    "pop3s",
                    "smtps"
                ],
                "type": "str"
            },
            "src-filter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ssl-algorithm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "high",
                    "low",
                    "medium",
                    "custom"
                ],
                "type": "str"
            },
            "ssl-certificate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ssl-client-fallback": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-client-renegotiation": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "deny",
                    "allow",
                    "secure"
                ],
                "type": "str"
            },
            "ssl-client-session-state-max": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ssl-client-session-state-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ssl-client-session-state-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "time",
                    "count",
                    "both"
                ],
                "type": "str"
            },
            "ssl-dh-bits": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "768",
                    "1024",
                    "1536",
                    "2048",
                    "3072",
                    "4096"
                ],
                "type": "str"
            },
            "ssl-hpkp": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "report-only"
                ],
                "type": "str"
            },
            "ssl-hpkp-age": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ssl-hpkp-backup": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ssl-hpkp-include-subdomains": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-hpkp-primary": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ssl-hpkp-report-uri": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ssl-hsts": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-hsts-age": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ssl-hsts-include-subdomains": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-http-location-conversion": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-http-match-host": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-max-version": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ssl-3.0",
                    "tls-1.0",
                    "tls-1.1",
                    "tls-1.2",
                    "tls-1.3"
                ],
                "type": "str"
            },
            "ssl-min-version": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ssl-3.0",
                    "tls-1.0",
                    "tls-1.1",
                    "tls-1.2",
                    "tls-1.3"
                ],
                "type": "str"
            },
            "ssl-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "half",
                    "full"
                ],
                "type": "str"
            },
            "ssl-pfs": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "require",
                    "deny",
                    "allow"
                ],
                "type": "str"
            },
            "ssl-send-empty-frags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-server-algorithm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "high",
                    "low",
                    "medium",
                    "custom",
                    "client"
                ],
                "type": "str"
            },
            "ssl-server-max-version": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ssl-3.0",
                    "tls-1.0",
                    "tls-1.1",
                    "tls-1.2",
                    "client",
                    "tls-1.3"
                ],
                "type": "str"
            },
            "ssl-server-min-version": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ssl-3.0",
                    "tls-1.0",
                    "tls-1.1",
                    "tls-1.2",
                    "client",
                    "tls-1.3"
                ],
                "type": "str"
            },
            "ssl-server-session-state-max": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ssl-server-session-state-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ssl-server-session-state-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "time",
                    "count",
                    "both"
                ],
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "static-nat",
                    "server-load-balance",
                    "access-proxy"
                ],
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "weblogic-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "websphere-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "http-redirect": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-client-rekey-count": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "int"
            },
            "nat-source-vip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "add-nat64-route": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "embedded-ipv4-address": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ipv4-mappedip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipv4-mappedport": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "nat64": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "nat66": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "realservers": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "client-ip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "healthcheck": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable",
                            "vip"
                        ],
                        "type": "str"
                    },
                    "holddown-interval": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "http-host": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "max-connections": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "monitor": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "port": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "active",
                            "standby",
                            "disable"
                        ],
                        "type": "str"
                    },
                    "weight": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "translate-host": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "ssl-accept-ffdhe-groups": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-cipher-suites": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "cipher": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "TLS-RSA-WITH-RC4-128-MD5",
                            "TLS-RSA-WITH-RC4-128-SHA",
                            "TLS-RSA-WITH-DES-CBC-SHA",
                            "TLS-RSA-WITH-3DES-EDE-CBC-SHA",
                            "TLS-RSA-WITH-AES-128-CBC-SHA",
                            "TLS-RSA-WITH-AES-256-CBC-SHA",
                            "TLS-RSA-WITH-AES-128-CBC-SHA256",
                            "TLS-RSA-WITH-AES-256-CBC-SHA256",
                            "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA",
                            "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA",
                            "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                            "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                            "TLS-RSA-WITH-SEED-CBC-SHA",
                            "TLS-RSA-WITH-ARIA-128-CBC-SHA256",
                            "TLS-RSA-WITH-ARIA-256-CBC-SHA384",
                            "TLS-DHE-RSA-WITH-DES-CBC-SHA",
                            "TLS-DHE-RSA-WITH-3DES-EDE-CBC-SHA",
                            "TLS-DHE-RSA-WITH-AES-128-CBC-SHA",
                            "TLS-DHE-RSA-WITH-AES-256-CBC-SHA",
                            "TLS-DHE-RSA-WITH-AES-128-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-AES-256-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA",
                            "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA",
                            "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-SEED-CBC-SHA",
                            "TLS-DHE-RSA-WITH-ARIA-128-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-ARIA-256-CBC-SHA384",
                            "TLS-ECDHE-RSA-WITH-RC4-128-SHA",
                            "TLS-ECDHE-RSA-WITH-3DES-EDE-CBC-SHA",
                            "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA",
                            "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA",
                            "TLS-ECDHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-CHACHA20-POLY1305-SHA256",
                            "TLS-DHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                            "TLS-DHE-RSA-WITH-AES-128-GCM-SHA256",
                            "TLS-DHE-RSA-WITH-AES-256-GCM-SHA384",
                            "TLS-DHE-DSS-WITH-AES-128-CBC-SHA",
                            "TLS-DHE-DSS-WITH-AES-256-CBC-SHA",
                            "TLS-DHE-DSS-WITH-AES-128-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-AES-128-GCM-SHA256",
                            "TLS-DHE-DSS-WITH-AES-256-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-AES-256-GCM-SHA384",
                            "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA256",
                            "TLS-ECDHE-RSA-WITH-AES-128-GCM-SHA256",
                            "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA384",
                            "TLS-ECDHE-RSA-WITH-AES-256-GCM-SHA384",
                            "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA",
                            "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-AES-128-GCM-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA384",
                            "TLS-ECDHE-ECDSA-WITH-AES-256-GCM-SHA384",
                            "TLS-RSA-WITH-AES-128-GCM-SHA256",
                            "TLS-RSA-WITH-AES-256-GCM-SHA384",
                            "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA",
                            "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA",
                            "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-SEED-CBC-SHA",
                            "TLS-DHE-DSS-WITH-ARIA-128-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-ARIA-256-CBC-SHA384",
                            "TLS-ECDHE-RSA-WITH-ARIA-128-CBC-SHA256",
                            "TLS-ECDHE-RSA-WITH-ARIA-256-CBC-SHA384",
                            "TLS-ECDHE-ECDSA-WITH-ARIA-128-CBC-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-ARIA-256-CBC-SHA384",
                            "TLS-DHE-DSS-WITH-3DES-EDE-CBC-SHA",
                            "TLS-DHE-DSS-WITH-DES-CBC-SHA",
                            "TLS-AES-128-GCM-SHA256",
                            "TLS-AES-256-GCM-SHA384",
                            "TLS-CHACHA20-POLY1305-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA"
                        ],
                        "type": "str"
                    },
                    "priority": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "versions": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "ssl-3.0",
                            "tls-1.0",
                            "tls-1.1",
                            "tls-1.2",
                            "tls-1.3"
                        ],
                        "elements": "str"
                    }
                },
                "elements": "dict"
            },
            "ndp-reply": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-server-renegotiation": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "firewall_vip6_dynamicmapping_realservers": {
        "stated": true,
        "options": {
            "client-ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "healthcheck": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable",
                    "vip"
                ],
                "type": "str"
            },
            "holddown-interval": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "http-host": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "max-connections": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "monitor": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "active",
                    "standby",
                    "disable"
                ],
                "type": "str"
            },
            "weight": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "translate-host": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "firewall_vip6_dynamicmapping_sslciphersuites": {
        "stated": true,
        "options": {
            "cipher": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "TLS-RSA-WITH-RC4-128-MD5",
                    "TLS-RSA-WITH-RC4-128-SHA",
                    "TLS-RSA-WITH-DES-CBC-SHA",
                    "TLS-RSA-WITH-3DES-EDE-CBC-SHA",
                    "TLS-RSA-WITH-AES-128-CBC-SHA",
                    "TLS-RSA-WITH-AES-256-CBC-SHA",
                    "TLS-RSA-WITH-AES-128-CBC-SHA256",
                    "TLS-RSA-WITH-AES-256-CBC-SHA256",
                    "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA",
                    "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA",
                    "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                    "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                    "TLS-RSA-WITH-SEED-CBC-SHA",
                    "TLS-RSA-WITH-ARIA-128-CBC-SHA256",
                    "TLS-RSA-WITH-ARIA-256-CBC-SHA384",
                    "TLS-DHE-RSA-WITH-DES-CBC-SHA",
                    "TLS-DHE-RSA-WITH-3DES-EDE-CBC-SHA",
                    "TLS-DHE-RSA-WITH-AES-128-CBC-SHA",
                    "TLS-DHE-RSA-WITH-AES-256-CBC-SHA",
                    "TLS-DHE-RSA-WITH-AES-128-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-AES-256-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA",
                    "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA",
                    "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-SEED-CBC-SHA",
                    "TLS-DHE-RSA-WITH-ARIA-128-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-ARIA-256-CBC-SHA384",
                    "TLS-ECDHE-RSA-WITH-RC4-128-SHA",
                    "TLS-ECDHE-RSA-WITH-3DES-EDE-CBC-SHA",
                    "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA",
                    "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA",
                    "TLS-ECDHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-CHACHA20-POLY1305-SHA256",
                    "TLS-DHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                    "TLS-DHE-RSA-WITH-AES-128-GCM-SHA256",
                    "TLS-DHE-RSA-WITH-AES-256-GCM-SHA384",
                    "TLS-DHE-DSS-WITH-AES-128-CBC-SHA",
                    "TLS-DHE-DSS-WITH-AES-256-CBC-SHA",
                    "TLS-DHE-DSS-WITH-AES-128-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-AES-128-GCM-SHA256",
                    "TLS-DHE-DSS-WITH-AES-256-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-AES-256-GCM-SHA384",
                    "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA256",
                    "TLS-ECDHE-RSA-WITH-AES-128-GCM-SHA256",
                    "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA384",
                    "TLS-ECDHE-RSA-WITH-AES-256-GCM-SHA384",
                    "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA",
                    "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-AES-128-GCM-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA384",
                    "TLS-ECDHE-ECDSA-WITH-AES-256-GCM-SHA384",
                    "TLS-RSA-WITH-AES-128-GCM-SHA256",
                    "TLS-RSA-WITH-AES-256-GCM-SHA384",
                    "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA",
                    "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA",
                    "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-SEED-CBC-SHA",
                    "TLS-DHE-DSS-WITH-ARIA-128-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-ARIA-256-CBC-SHA384",
                    "TLS-ECDHE-RSA-WITH-ARIA-128-CBC-SHA256",
                    "TLS-ECDHE-RSA-WITH-ARIA-256-CBC-SHA384",
                    "TLS-ECDHE-ECDSA-WITH-ARIA-128-CBC-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-ARIA-256-CBC-SHA384",
                    "TLS-DHE-DSS-WITH-3DES-EDE-CBC-SHA",
                    "TLS-DHE-DSS-WITH-DES-CBC-SHA",
                    "TLS-AES-128-GCM-SHA256",
                    "TLS-AES-256-GCM-SHA384",
                    "TLS-CHACHA20-POLY1305-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA"
                ],
                "type": "str"
            },
            "priority": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "versions": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "list",
                "choices": [
                    "ssl-3.0",
                    "tls-1.0",
                    "tls-1.1",
                    "tls-1.2",
                    "tls-1.3"
                ],
                "elements": "str"
            }
        }
    },
    "firewall_vip6_realservers": {
        "stated": true,
        "options": {
            "client-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "healthcheck": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "vip"
                ],
                "type": "str"
            },
            "holddown-interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "http-host": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "max-connections": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "monitor": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "active",
                    "standby",
                    "disable"
                ],
                "type": "str"
            },
            "weight": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "translate-host": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "firewall_vip6_sslciphersuites": {
        "stated": true,
        "options": {
            "cipher": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "TLS-RSA-WITH-RC4-128-MD5",
                    "TLS-RSA-WITH-RC4-128-SHA",
                    "TLS-RSA-WITH-DES-CBC-SHA",
                    "TLS-RSA-WITH-3DES-EDE-CBC-SHA",
                    "TLS-RSA-WITH-AES-128-CBC-SHA",
                    "TLS-RSA-WITH-AES-256-CBC-SHA",
                    "TLS-RSA-WITH-AES-128-CBC-SHA256",
                    "TLS-RSA-WITH-AES-256-CBC-SHA256",
                    "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA",
                    "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA",
                    "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                    "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                    "TLS-RSA-WITH-SEED-CBC-SHA",
                    "TLS-RSA-WITH-ARIA-128-CBC-SHA256",
                    "TLS-RSA-WITH-ARIA-256-CBC-SHA384",
                    "TLS-DHE-RSA-WITH-DES-CBC-SHA",
                    "TLS-DHE-RSA-WITH-3DES-EDE-CBC-SHA",
                    "TLS-DHE-RSA-WITH-AES-128-CBC-SHA",
                    "TLS-DHE-RSA-WITH-AES-256-CBC-SHA",
                    "TLS-DHE-RSA-WITH-AES-128-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-AES-256-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA",
                    "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA",
                    "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-SEED-CBC-SHA",
                    "TLS-DHE-RSA-WITH-ARIA-128-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-ARIA-256-CBC-SHA384",
                    "TLS-ECDHE-RSA-WITH-RC4-128-SHA",
                    "TLS-ECDHE-RSA-WITH-3DES-EDE-CBC-SHA",
                    "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA",
                    "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA",
                    "TLS-ECDHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-CHACHA20-POLY1305-SHA256",
                    "TLS-DHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                    "TLS-DHE-RSA-WITH-AES-128-GCM-SHA256",
                    "TLS-DHE-RSA-WITH-AES-256-GCM-SHA384",
                    "TLS-DHE-DSS-WITH-AES-128-CBC-SHA",
                    "TLS-DHE-DSS-WITH-AES-256-CBC-SHA",
                    "TLS-DHE-DSS-WITH-AES-128-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-AES-128-GCM-SHA256",
                    "TLS-DHE-DSS-WITH-AES-256-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-AES-256-GCM-SHA384",
                    "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA256",
                    "TLS-ECDHE-RSA-WITH-AES-128-GCM-SHA256",
                    "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA384",
                    "TLS-ECDHE-RSA-WITH-AES-256-GCM-SHA384",
                    "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA",
                    "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-AES-128-GCM-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA384",
                    "TLS-ECDHE-ECDSA-WITH-AES-256-GCM-SHA384",
                    "TLS-RSA-WITH-AES-128-GCM-SHA256",
                    "TLS-RSA-WITH-AES-256-GCM-SHA384",
                    "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA",
                    "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA",
                    "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-SEED-CBC-SHA",
                    "TLS-DHE-DSS-WITH-ARIA-128-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-ARIA-256-CBC-SHA384",
                    "TLS-ECDHE-RSA-WITH-ARIA-128-CBC-SHA256",
                    "TLS-ECDHE-RSA-WITH-ARIA-256-CBC-SHA384",
                    "TLS-ECDHE-ECDSA-WITH-ARIA-128-CBC-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-ARIA-256-CBC-SHA384",
                    "TLS-DHE-DSS-WITH-3DES-EDE-CBC-SHA",
                    "TLS-DHE-DSS-WITH-DES-CBC-SHA",
                    "TLS-AES-128-GCM-SHA256",
                    "TLS-AES-256-GCM-SHA384",
                    "TLS-CHACHA20-POLY1305-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA"
                ],
                "type": "str"
            },
            "priority": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "versions": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "ssl-3.0",
                    "tls-1.0",
                    "tls-1.1",
                    "tls-1.2",
                    "tls-1.3"
                ],
                "elements": "str"
            }
        }
    },
    "firewall_vip6_sslserverciphersuites": {
        "stated": true,
        "options": {
            "cipher": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "TLS-RSA-WITH-RC4-128-MD5",
                    "TLS-RSA-WITH-RC4-128-SHA",
                    "TLS-RSA-WITH-DES-CBC-SHA",
                    "TLS-RSA-WITH-3DES-EDE-CBC-SHA",
                    "TLS-RSA-WITH-AES-128-CBC-SHA",
                    "TLS-RSA-WITH-AES-256-CBC-SHA",
                    "TLS-RSA-WITH-AES-128-CBC-SHA256",
                    "TLS-RSA-WITH-AES-256-CBC-SHA256",
                    "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA",
                    "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA",
                    "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                    "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                    "TLS-RSA-WITH-SEED-CBC-SHA",
                    "TLS-RSA-WITH-ARIA-128-CBC-SHA256",
                    "TLS-RSA-WITH-ARIA-256-CBC-SHA384",
                    "TLS-DHE-RSA-WITH-DES-CBC-SHA",
                    "TLS-DHE-RSA-WITH-3DES-EDE-CBC-SHA",
                    "TLS-DHE-RSA-WITH-AES-128-CBC-SHA",
                    "TLS-DHE-RSA-WITH-AES-256-CBC-SHA",
                    "TLS-DHE-RSA-WITH-AES-128-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-AES-256-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA",
                    "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA",
                    "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-SEED-CBC-SHA",
                    "TLS-DHE-RSA-WITH-ARIA-128-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-ARIA-256-CBC-SHA384",
                    "TLS-ECDHE-RSA-WITH-RC4-128-SHA",
                    "TLS-ECDHE-RSA-WITH-3DES-EDE-CBC-SHA",
                    "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA",
                    "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA",
                    "TLS-ECDHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-CHACHA20-POLY1305-SHA256",
                    "TLS-DHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                    "TLS-DHE-RSA-WITH-AES-128-GCM-SHA256",
                    "TLS-DHE-RSA-WITH-AES-256-GCM-SHA384",
                    "TLS-DHE-DSS-WITH-AES-128-CBC-SHA",
                    "TLS-DHE-DSS-WITH-AES-256-CBC-SHA",
                    "TLS-DHE-DSS-WITH-AES-128-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-AES-128-GCM-SHA256",
                    "TLS-DHE-DSS-WITH-AES-256-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-AES-256-GCM-SHA384",
                    "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA256",
                    "TLS-ECDHE-RSA-WITH-AES-128-GCM-SHA256",
                    "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA384",
                    "TLS-ECDHE-RSA-WITH-AES-256-GCM-SHA384",
                    "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA",
                    "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-AES-128-GCM-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA384",
                    "TLS-ECDHE-ECDSA-WITH-AES-256-GCM-SHA384",
                    "TLS-RSA-WITH-AES-128-GCM-SHA256",
                    "TLS-RSA-WITH-AES-256-GCM-SHA384",
                    "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA",
                    "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA",
                    "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-SEED-CBC-SHA",
                    "TLS-DHE-DSS-WITH-ARIA-128-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-ARIA-256-CBC-SHA384",
                    "TLS-ECDHE-RSA-WITH-ARIA-128-CBC-SHA256",
                    "TLS-ECDHE-RSA-WITH-ARIA-256-CBC-SHA384",
                    "TLS-ECDHE-ECDSA-WITH-ARIA-128-CBC-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-ARIA-256-CBC-SHA384",
                    "TLS-DHE-DSS-WITH-3DES-EDE-CBC-SHA",
                    "TLS-DHE-DSS-WITH-DES-CBC-SHA",
                    "TLS-AES-128-GCM-SHA256",
                    "TLS-AES-256-GCM-SHA384",
                    "TLS-CHACHA20-POLY1305-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA"
                ],
                "type": "str"
            },
            "priority": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "versions": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "ssl-3.0",
                    "tls-1.0",
                    "tls-1.1",
                    "tls-1.2",
                    "tls-1.3"
                ],
                "elements": "str"
            }
        }
    },
    "firewall_vip_dynamicmapping": {
        "stated": true,
        "options": {
            "_scope": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "arp-reply": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "color": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dns-mapping-ttl": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "extaddr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "extintf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "extip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "extport": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "gratuitous-arp-interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "http-cookie-age": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "http-cookie-domain": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "http-cookie-domain-from-host": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "http-cookie-generation": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "http-cookie-path": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "http-cookie-share": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "same-ip"
                ],
                "type": "str"
            },
            "http-ip-header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "http-ip-header-name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "http-multiplex": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "https-cookie-secure": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ldb-method": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "static",
                    "round-robin",
                    "weighted",
                    "least-session",
                    "least-rtt",
                    "first-alive",
                    "http-host"
                ],
                "type": "str"
            },
            "mapped-addr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "mappedip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "mappedport": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "max-embryonic-connections": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "monitor": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "nat-source-vip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "outlook-web-access": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "persistence": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http-cookie",
                    "ssl-session-id"
                ],
                "type": "str"
            },
            "portforward": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "portmapping-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "1-to-1",
                    "m-to-n"
                ],
                "type": "str"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "tcp",
                    "udp",
                    "sctp",
                    "icmp"
                ],
                "type": "str"
            },
            "realservers": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "client-ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "healthcheck": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable",
                            "vip"
                        ],
                        "type": "str"
                    },
                    "holddown-interval": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "http-host": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "max-connections": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "monitor": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "port": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "seq": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "active",
                            "standby",
                            "disable"
                        ],
                        "type": "str"
                    },
                    "weight": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "address": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ip",
                            "address"
                        ],
                        "type": "str"
                    },
                    "translate-host": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "health-check-proto": {
                        "required": false,
                        "revision": {
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ping",
                            "http"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "server-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "http",
                    "https",
                    "ssl",
                    "tcp",
                    "udp",
                    "ip",
                    "imaps",
                    "pop3s",
                    "smtps",
                    "ssh"
                ],
                "type": "str"
            },
            "service": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "src-filter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcintf-filter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ssl-algorithm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "high",
                    "medium",
                    "low",
                    "custom"
                ],
                "type": "str"
            },
            "ssl-certificate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ssl-cipher-suites": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "cipher": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "TLS-RSA-WITH-RC4-128-MD5",
                            "TLS-RSA-WITH-RC4-128-SHA",
                            "TLS-RSA-WITH-DES-CBC-SHA",
                            "TLS-RSA-WITH-3DES-EDE-CBC-SHA",
                            "TLS-RSA-WITH-AES-128-CBC-SHA",
                            "TLS-RSA-WITH-AES-256-CBC-SHA",
                            "TLS-RSA-WITH-AES-128-CBC-SHA256",
                            "TLS-RSA-WITH-AES-256-CBC-SHA256",
                            "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA",
                            "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA",
                            "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                            "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                            "TLS-RSA-WITH-SEED-CBC-SHA",
                            "TLS-RSA-WITH-ARIA-128-CBC-SHA256",
                            "TLS-RSA-WITH-ARIA-256-CBC-SHA384",
                            "TLS-DHE-RSA-WITH-DES-CBC-SHA",
                            "TLS-DHE-RSA-WITH-3DES-EDE-CBC-SHA",
                            "TLS-DHE-RSA-WITH-AES-128-CBC-SHA",
                            "TLS-DHE-RSA-WITH-AES-256-CBC-SHA",
                            "TLS-DHE-RSA-WITH-AES-128-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-AES-256-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA",
                            "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA",
                            "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-SEED-CBC-SHA",
                            "TLS-DHE-RSA-WITH-ARIA-128-CBC-SHA256",
                            "TLS-DHE-RSA-WITH-ARIA-256-CBC-SHA384",
                            "TLS-ECDHE-RSA-WITH-RC4-128-SHA",
                            "TLS-ECDHE-RSA-WITH-3DES-EDE-CBC-SHA",
                            "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA",
                            "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA",
                            "TLS-ECDHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-CHACHA20-POLY1305-SHA256",
                            "TLS-DHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                            "TLS-DHE-RSA-WITH-AES-128-GCM-SHA256",
                            "TLS-DHE-RSA-WITH-AES-256-GCM-SHA384",
                            "TLS-DHE-DSS-WITH-AES-128-CBC-SHA",
                            "TLS-DHE-DSS-WITH-AES-256-CBC-SHA",
                            "TLS-DHE-DSS-WITH-AES-128-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-AES-128-GCM-SHA256",
                            "TLS-DHE-DSS-WITH-AES-256-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-AES-256-GCM-SHA384",
                            "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA256",
                            "TLS-ECDHE-RSA-WITH-AES-128-GCM-SHA256",
                            "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA384",
                            "TLS-ECDHE-RSA-WITH-AES-256-GCM-SHA384",
                            "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA",
                            "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-AES-128-GCM-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA384",
                            "TLS-ECDHE-ECDSA-WITH-AES-256-GCM-SHA384",
                            "TLS-RSA-WITH-AES-128-GCM-SHA256",
                            "TLS-RSA-WITH-AES-256-GCM-SHA384",
                            "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA",
                            "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA",
                            "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-SEED-CBC-SHA",
                            "TLS-DHE-DSS-WITH-ARIA-128-CBC-SHA256",
                            "TLS-DHE-DSS-WITH-ARIA-256-CBC-SHA384",
                            "TLS-ECDHE-RSA-WITH-ARIA-128-CBC-SHA256",
                            "TLS-ECDHE-RSA-WITH-ARIA-256-CBC-SHA384",
                            "TLS-ECDHE-ECDSA-WITH-ARIA-128-CBC-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-ARIA-256-CBC-SHA384",
                            "TLS-DHE-DSS-WITH-3DES-EDE-CBC-SHA",
                            "TLS-DHE-DSS-WITH-DES-CBC-SHA",
                            "TLS-AES-128-GCM-SHA256",
                            "TLS-AES-256-GCM-SHA384",
                            "TLS-CHACHA20-POLY1305-SHA256",
                            "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA"
                        ],
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "versions": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "ssl-3.0",
                            "tls-1.0",
                            "tls-1.1",
                            "tls-1.2",
                            "tls-1.3"
                        ],
                        "elements": "str"
                    },
                    "priority": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "ssl-client-fallback": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-client-renegotiation": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "deny",
                    "allow",
                    "secure"
                ],
                "type": "str"
            },
            "ssl-client-session-state-max": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ssl-client-session-state-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ssl-client-session-state-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "time",
                    "count",
                    "both"
                ],
                "type": "str"
            },
            "ssl-dh-bits": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "768",
                    "1024",
                    "1536",
                    "2048",
                    "3072",
                    "4096"
                ],
                "type": "str"
            },
            "ssl-hpkp": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "report-only"
                ],
                "type": "str"
            },
            "ssl-hpkp-age": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ssl-hpkp-backup": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ssl-hpkp-include-subdomains": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-hpkp-primary": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ssl-hpkp-report-uri": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ssl-hsts": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-hsts-age": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ssl-hsts-include-subdomains": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-http-location-conversion": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-http-match-host": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-max-version": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ssl-3.0",
                    "tls-1.0",
                    "tls-1.1",
                    "tls-1.2",
                    "tls-1.3"
                ],
                "type": "str"
            },
            "ssl-min-version": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ssl-3.0",
                    "tls-1.0",
                    "tls-1.1",
                    "tls-1.2",
                    "tls-1.3"
                ],
                "type": "str"
            },
            "ssl-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "half",
                    "full"
                ],
                "type": "str"
            },
            "ssl-pfs": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "require",
                    "deny",
                    "allow"
                ],
                "type": "str"
            },
            "ssl-send-empty-frags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-server-algorithm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "high",
                    "low",
                    "medium",
                    "custom",
                    "client"
                ],
                "type": "str"
            },
            "ssl-server-max-version": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ssl-3.0",
                    "tls-1.0",
                    "tls-1.1",
                    "tls-1.2",
                    "client",
                    "tls-1.3"
                ],
                "type": "str"
            },
            "ssl-server-min-version": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ssl-3.0",
                    "tls-1.0",
                    "tls-1.1",
                    "tls-1.2",
                    "client",
                    "tls-1.3"
                ],
                "type": "str"
            },
            "ssl-server-session-state-max": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ssl-server-session-state-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ssl-server-session-state-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "time",
                    "count",
                    "both"
                ],
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "static-nat",
                    "load-balance",
                    "server-load-balance",
                    "dns-translation",
                    "fqdn",
                    "access-proxy"
                ],
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "weblogic-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "websphere-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "http-redirect": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-client-rekey-count": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "add-nat46-route": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ipv6-mappedip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipv6-mappedport": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "nat44": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "nat46": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-accept-ffdhe-groups": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "http-multiplex-max-request": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "http-multiplex-ttl": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "http-supported-max-version": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "http1",
                    "http2"
                ],
                "type": "str"
            },
            "ssl-server-renegotiation": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "h2-support": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "h3-support": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "http-multiplex-max-concurrent-request": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "firewall_vip_dynamicmapping_realservers": {
        "stated": true,
        "options": {
            "client-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "healthcheck": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable",
                    "vip"
                ],
                "type": "str"
            },
            "holddown-interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "http-host": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "max-connections": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "monitor": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "seq": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "active",
                    "standby",
                    "disable"
                ],
                "type": "str"
            },
            "weight": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "address": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "ip",
                    "address"
                ],
                "type": "str"
            },
            "translate-host": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "health-check-proto": {
                "required": false,
                "revision": {
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "ping",
                    "http"
                ],
                "type": "str"
            }
        }
    },
    "firewall_vip_dynamicmapping_sslciphersuites": {
        "stated": true,
        "options": {
            "cipher": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "TLS-RSA-WITH-RC4-128-MD5",
                    "TLS-RSA-WITH-RC4-128-SHA",
                    "TLS-RSA-WITH-DES-CBC-SHA",
                    "TLS-RSA-WITH-3DES-EDE-CBC-SHA",
                    "TLS-RSA-WITH-AES-128-CBC-SHA",
                    "TLS-RSA-WITH-AES-256-CBC-SHA",
                    "TLS-RSA-WITH-AES-128-CBC-SHA256",
                    "TLS-RSA-WITH-AES-256-CBC-SHA256",
                    "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA",
                    "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA",
                    "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                    "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                    "TLS-RSA-WITH-SEED-CBC-SHA",
                    "TLS-RSA-WITH-ARIA-128-CBC-SHA256",
                    "TLS-RSA-WITH-ARIA-256-CBC-SHA384",
                    "TLS-DHE-RSA-WITH-DES-CBC-SHA",
                    "TLS-DHE-RSA-WITH-3DES-EDE-CBC-SHA",
                    "TLS-DHE-RSA-WITH-AES-128-CBC-SHA",
                    "TLS-DHE-RSA-WITH-AES-256-CBC-SHA",
                    "TLS-DHE-RSA-WITH-AES-128-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-AES-256-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA",
                    "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA",
                    "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-SEED-CBC-SHA",
                    "TLS-DHE-RSA-WITH-ARIA-128-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-ARIA-256-CBC-SHA384",
                    "TLS-ECDHE-RSA-WITH-RC4-128-SHA",
                    "TLS-ECDHE-RSA-WITH-3DES-EDE-CBC-SHA",
                    "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA",
                    "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA",
                    "TLS-ECDHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-CHACHA20-POLY1305-SHA256",
                    "TLS-DHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                    "TLS-DHE-RSA-WITH-AES-128-GCM-SHA256",
                    "TLS-DHE-RSA-WITH-AES-256-GCM-SHA384",
                    "TLS-DHE-DSS-WITH-AES-128-CBC-SHA",
                    "TLS-DHE-DSS-WITH-AES-256-CBC-SHA",
                    "TLS-DHE-DSS-WITH-AES-128-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-AES-128-GCM-SHA256",
                    "TLS-DHE-DSS-WITH-AES-256-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-AES-256-GCM-SHA384",
                    "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA256",
                    "TLS-ECDHE-RSA-WITH-AES-128-GCM-SHA256",
                    "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA384",
                    "TLS-ECDHE-RSA-WITH-AES-256-GCM-SHA384",
                    "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA",
                    "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-AES-128-GCM-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA384",
                    "TLS-ECDHE-ECDSA-WITH-AES-256-GCM-SHA384",
                    "TLS-RSA-WITH-AES-128-GCM-SHA256",
                    "TLS-RSA-WITH-AES-256-GCM-SHA384",
                    "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA",
                    "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA",
                    "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-SEED-CBC-SHA",
                    "TLS-DHE-DSS-WITH-ARIA-128-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-ARIA-256-CBC-SHA384",
                    "TLS-ECDHE-RSA-WITH-ARIA-128-CBC-SHA256",
                    "TLS-ECDHE-RSA-WITH-ARIA-256-CBC-SHA384",
                    "TLS-ECDHE-ECDSA-WITH-ARIA-128-CBC-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-ARIA-256-CBC-SHA384",
                    "TLS-DHE-DSS-WITH-3DES-EDE-CBC-SHA",
                    "TLS-DHE-DSS-WITH-DES-CBC-SHA",
                    "TLS-AES-128-GCM-SHA256",
                    "TLS-AES-256-GCM-SHA384",
                    "TLS-CHACHA20-POLY1305-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA"
                ],
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "versions": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "list",
                "choices": [
                    "ssl-3.0",
                    "tls-1.0",
                    "tls-1.1",
                    "tls-1.2",
                    "tls-1.3"
                ],
                "elements": "str"
            },
            "priority": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            }
        }
    },
    "firewall_vip_quic": {
        "stated": false,
        "options": {
            "ack-delay-exponent": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "active-connection-id-limit": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "active-migration": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "grease-quic-bit": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "max-ack-delay": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "max-datagram-frame-size": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "max-idle-timeout": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "max-udp-payload-size": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "firewall_vip_realservers": {
        "stated": true,
        "options": {
            "client-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "healthcheck": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "vip"
                ],
                "type": "str"
            },
            "holddown-interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "http-host": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "max-connections": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "monitor": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "seq": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "active",
                    "standby",
                    "disable"
                ],
                "type": "str"
            },
            "weight": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "address": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ip",
                    "address"
                ],
                "type": "str"
            },
            "translate-host": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "firewall_vip_sslciphersuites": {
        "stated": true,
        "options": {
            "cipher": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "TLS-RSA-WITH-RC4-128-MD5",
                    "TLS-RSA-WITH-RC4-128-SHA",
                    "TLS-RSA-WITH-DES-CBC-SHA",
                    "TLS-RSA-WITH-3DES-EDE-CBC-SHA",
                    "TLS-RSA-WITH-AES-128-CBC-SHA",
                    "TLS-RSA-WITH-AES-256-CBC-SHA",
                    "TLS-RSA-WITH-AES-128-CBC-SHA256",
                    "TLS-RSA-WITH-AES-256-CBC-SHA256",
                    "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA",
                    "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA",
                    "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                    "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                    "TLS-RSA-WITH-SEED-CBC-SHA",
                    "TLS-RSA-WITH-ARIA-128-CBC-SHA256",
                    "TLS-RSA-WITH-ARIA-256-CBC-SHA384",
                    "TLS-DHE-RSA-WITH-DES-CBC-SHA",
                    "TLS-DHE-RSA-WITH-3DES-EDE-CBC-SHA",
                    "TLS-DHE-RSA-WITH-AES-128-CBC-SHA",
                    "TLS-DHE-RSA-WITH-AES-256-CBC-SHA",
                    "TLS-DHE-RSA-WITH-AES-128-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-AES-256-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA",
                    "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA",
                    "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-SEED-CBC-SHA",
                    "TLS-DHE-RSA-WITH-ARIA-128-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-ARIA-256-CBC-SHA384",
                    "TLS-ECDHE-RSA-WITH-RC4-128-SHA",
                    "TLS-ECDHE-RSA-WITH-3DES-EDE-CBC-SHA",
                    "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA",
                    "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA",
                    "TLS-ECDHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-CHACHA20-POLY1305-SHA256",
                    "TLS-DHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                    "TLS-DHE-RSA-WITH-AES-128-GCM-SHA256",
                    "TLS-DHE-RSA-WITH-AES-256-GCM-SHA384",
                    "TLS-DHE-DSS-WITH-AES-128-CBC-SHA",
                    "TLS-DHE-DSS-WITH-AES-256-CBC-SHA",
                    "TLS-DHE-DSS-WITH-AES-128-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-AES-128-GCM-SHA256",
                    "TLS-DHE-DSS-WITH-AES-256-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-AES-256-GCM-SHA384",
                    "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA256",
                    "TLS-ECDHE-RSA-WITH-AES-128-GCM-SHA256",
                    "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA384",
                    "TLS-ECDHE-RSA-WITH-AES-256-GCM-SHA384",
                    "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA",
                    "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-AES-128-GCM-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA384",
                    "TLS-ECDHE-ECDSA-WITH-AES-256-GCM-SHA384",
                    "TLS-RSA-WITH-AES-128-GCM-SHA256",
                    "TLS-RSA-WITH-AES-256-GCM-SHA384",
                    "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA",
                    "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA",
                    "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-SEED-CBC-SHA",
                    "TLS-DHE-DSS-WITH-ARIA-128-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-ARIA-256-CBC-SHA384",
                    "TLS-ECDHE-RSA-WITH-ARIA-128-CBC-SHA256",
                    "TLS-ECDHE-RSA-WITH-ARIA-256-CBC-SHA384",
                    "TLS-ECDHE-ECDSA-WITH-ARIA-128-CBC-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-ARIA-256-CBC-SHA384",
                    "TLS-DHE-DSS-WITH-3DES-EDE-CBC-SHA",
                    "TLS-DHE-DSS-WITH-DES-CBC-SHA",
                    "TLS-AES-128-GCM-SHA256",
                    "TLS-AES-256-GCM-SHA384",
                    "TLS-CHACHA20-POLY1305-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA"
                ],
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "versions": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "ssl-3.0",
                    "tls-1.0",
                    "tls-1.1",
                    "tls-1.2",
                    "tls-1.3"
                ],
                "elements": "str"
            },
            "priority": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "firewall_vip_sslserverciphersuites": {
        "stated": true,
        "options": {
            "cipher": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "TLS-RSA-WITH-RC4-128-MD5",
                    "TLS-RSA-WITH-RC4-128-SHA",
                    "TLS-RSA-WITH-DES-CBC-SHA",
                    "TLS-RSA-WITH-3DES-EDE-CBC-SHA",
                    "TLS-RSA-WITH-AES-128-CBC-SHA",
                    "TLS-RSA-WITH-AES-256-CBC-SHA",
                    "TLS-RSA-WITH-AES-128-CBC-SHA256",
                    "TLS-RSA-WITH-AES-256-CBC-SHA256",
                    "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA",
                    "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA",
                    "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                    "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                    "TLS-RSA-WITH-SEED-CBC-SHA",
                    "TLS-RSA-WITH-ARIA-128-CBC-SHA256",
                    "TLS-RSA-WITH-ARIA-256-CBC-SHA384",
                    "TLS-DHE-RSA-WITH-DES-CBC-SHA",
                    "TLS-DHE-RSA-WITH-3DES-EDE-CBC-SHA",
                    "TLS-DHE-RSA-WITH-AES-128-CBC-SHA",
                    "TLS-DHE-RSA-WITH-AES-256-CBC-SHA",
                    "TLS-DHE-RSA-WITH-AES-128-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-AES-256-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA",
                    "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA",
                    "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-SEED-CBC-SHA",
                    "TLS-DHE-RSA-WITH-ARIA-128-CBC-SHA256",
                    "TLS-DHE-RSA-WITH-ARIA-256-CBC-SHA384",
                    "TLS-ECDHE-RSA-WITH-RC4-128-SHA",
                    "TLS-ECDHE-RSA-WITH-3DES-EDE-CBC-SHA",
                    "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA",
                    "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA",
                    "TLS-ECDHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-CHACHA20-POLY1305-SHA256",
                    "TLS-DHE-RSA-WITH-CHACHA20-POLY1305-SHA256",
                    "TLS-DHE-RSA-WITH-AES-128-GCM-SHA256",
                    "TLS-DHE-RSA-WITH-AES-256-GCM-SHA384",
                    "TLS-DHE-DSS-WITH-AES-128-CBC-SHA",
                    "TLS-DHE-DSS-WITH-AES-256-CBC-SHA",
                    "TLS-DHE-DSS-WITH-AES-128-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-AES-128-GCM-SHA256",
                    "TLS-DHE-DSS-WITH-AES-256-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-AES-256-GCM-SHA384",
                    "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA256",
                    "TLS-ECDHE-RSA-WITH-AES-128-GCM-SHA256",
                    "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA384",
                    "TLS-ECDHE-RSA-WITH-AES-256-GCM-SHA384",
                    "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA",
                    "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-AES-128-GCM-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA384",
                    "TLS-ECDHE-ECDSA-WITH-AES-256-GCM-SHA384",
                    "TLS-RSA-WITH-AES-128-GCM-SHA256",
                    "TLS-RSA-WITH-AES-256-GCM-SHA384",
                    "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA",
                    "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA",
                    "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-SEED-CBC-SHA",
                    "TLS-DHE-DSS-WITH-ARIA-128-CBC-SHA256",
                    "TLS-DHE-DSS-WITH-ARIA-256-CBC-SHA384",
                    "TLS-ECDHE-RSA-WITH-ARIA-128-CBC-SHA256",
                    "TLS-ECDHE-RSA-WITH-ARIA-256-CBC-SHA384",
                    "TLS-ECDHE-ECDSA-WITH-ARIA-128-CBC-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-ARIA-256-CBC-SHA384",
                    "TLS-DHE-DSS-WITH-3DES-EDE-CBC-SHA",
                    "TLS-DHE-DSS-WITH-DES-CBC-SHA",
                    "TLS-AES-128-GCM-SHA256",
                    "TLS-AES-256-GCM-SHA384",
                    "TLS-CHACHA20-POLY1305-SHA256",
                    "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA"
                ],
                "type": "str"
            },
            "priority": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "versions": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "ssl-3.0",
                    "tls-1.0",
                    "tls-1.1",
                    "tls-1.2",
                    "tls-1.3"
                ],
                "elements": "str"
            }
        }
    },
    "firewall_vipgrp": {
        "stated": true,
        "options": {
            "color": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "comments": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dynamic_mapping": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "_scope": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "vdom": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "color": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "comments": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "interface": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "member": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "uuid": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "interface": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "member": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "firewall_vipgrp46": {
        "stated": true,
        "options": {
            "color": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "comments": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "member": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "firewall_vipgrp6": {
        "stated": true,
        "options": {
            "color": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "comments": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "member": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "firewall_vipgrp64": {
        "stated": true,
        "options": {
            "color": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "comments": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "member": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "firewall_vipgrp_dynamicmapping": {
        "stated": true,
        "options": {
            "_scope": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "color": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "comments": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "interface": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "member": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "firewall_wildcardfqdn_custom": {
        "stated": true,
        "options": {
            "color": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "visibility": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "wildcard-fqdn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "firewall_wildcardfqdn_group": {
        "stated": true,
        "options": {
            "color": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "member": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "visibility": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "fmg_device_blueprint": {
        "stated": true,
        "options": {
            "cliprofs": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "description": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dev-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "folder": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "pkg": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "platform": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "prefer-img-ver": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "prerun-cliprof": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "prov-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "templates",
                    "template-group"
                ],
                "type": "str"
            },
            "template-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "templates": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "auth-template": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ha-config": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ha-hbdev": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "ha-monitor": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ha-password": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "linked-to-model": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "fmg_fabric_authorization_template": {
        "stated": true,
        "options": {
            "description": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "extender-controller": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "platforms": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "count": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "extension-type": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "wan-extension",
                            "lan-extension"
                        ],
                        "type": "str"
                    },
                    "fortilink": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "prefix": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ap",
                            "extender",
                            "switch"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "switch-controller": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "wireless-controller": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "fmg_fabric_authorization_template_platforms": {
        "stated": true,
        "options": {
            "count": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "extension-type": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "wan-extension",
                    "lan-extension"
                ],
                "type": "str"
            },
            "fortilink": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "prefix": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ap",
                    "extender",
                    "switch"
                ],
                "type": "str"
            }
        }
    },
    "fmg_variable": {
        "stated": true,
        "options": {
            "description": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dynamic_mapping": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "_scope": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": false,
                                    "7.0.3": false,
                                    "7.0.4": false,
                                    "7.0.5": false,
                                    "7.0.6": false,
                                    "7.0.7": false,
                                    "7.0.8": false,
                                    "7.0.9": false,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "vdom": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": false,
                                    "7.0.3": false,
                                    "7.0.4": false,
                                    "7.0.5": false,
                                    "7.0.6": false,
                                    "7.0.7": false,
                                    "7.0.8": false,
                                    "7.0.9": false,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "value": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "value": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "fmg_variable_dynamicmapping": {
        "stated": true,
        "options": {
            "_scope": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "value": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "fmupdate_analyzer_virusreport": {
        "stated": false,
        "options": {
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "fmupdate_avips_advancedlog": {
        "stated": false,
        "options": {
            "log-fortigate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "log-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "fmupdate_avips_webproxy": {
        "stated": false,
        "options": {
            "ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": false,
                    "6.2.3": false,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "ip6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": false,
                    "6.2.3": false,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "proxy",
                    "tunnel"
                ],
                "type": "str"
            },
            "password": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "no_log": true,
                "type": "raw"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "username": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "address": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "fmupdate_customurllist": {
        "stated": false,
        "options": {
            "db_selection": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "both",
                    "custom-url",
                    "fortiguard-db"
                ],
                "elements": "str"
            }
        }
    },
    "fmupdate_diskquota": {
        "stated": false,
        "options": {
            "value": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "fmupdate_fctservices": {
        "stated": false,
        "options": {
            "port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "fmupdate_fdssetting": {
        "stated": false,
        "options": {
            "User-Agent": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "fds-clt-ssl-protocol": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "sslv3",
                    "tlsv1.0",
                    "tlsv1.1",
                    "tlsv1.2",
                    "tlsv1.3"
                ],
                "type": "str"
            },
            "fds-ssl-protocol": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "sslv3",
                    "tlsv1.0",
                    "tlsv1.1",
                    "tlsv1.2",
                    "tlsv1.3"
                ],
                "type": "str"
            },
            "fmtr-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "emergency",
                    "alert",
                    "critical",
                    "error",
                    "warn",
                    "notice",
                    "info",
                    "debug",
                    "disable"
                ],
                "type": "str"
            },
            "linkd-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "emergency",
                    "alert",
                    "critical",
                    "error",
                    "warn",
                    "notice",
                    "info",
                    "debug",
                    "disable"
                ],
                "type": "str"
            },
            "max-av-ips-version": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "max-work": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "push-override": {
                "required": false,
                "type": "dict",
                "options": {
                    "ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "port": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "push-override-to-client": {
                "required": false,
                "type": "dict",
                "options": {
                    "announce-ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "id": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "ip": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "port": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            }
                        },
                        "elements": "dict"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "send_report": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "send_setup": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "server-override": {
                "required": false,
                "type": "dict",
                "options": {
                    "servlist": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "id": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "ip": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "ip6": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "port": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "service-type": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw",
                                "choices": [
                                    "fds",
                                    "fct"
                                ]
                            }
                        },
                        "elements": "dict"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "system-support-fct": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "4.x",
                    "5.0",
                    "5.2",
                    "5.4",
                    "5.6",
                    "6.0",
                    "6.2",
                    "6.4",
                    "7.0"
                ],
                "elements": "str"
            },
            "system-support-fgt": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "5.4",
                    "5.6",
                    "6.0",
                    "6.2",
                    "6.4",
                    "7.0",
                    "7.2",
                    "7.4"
                ],
                "elements": "str"
            },
            "system-support-fml": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "4.x",
                    "5.x",
                    "6.x",
                    "6.0",
                    "6.2",
                    "6.4",
                    "7.0",
                    "7.2"
                ],
                "elements": "str"
            },
            "system-support-fsa": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "1.x",
                    "2.x",
                    "3.x",
                    "4.x",
                    "3.0",
                    "3.1",
                    "3.2"
                ],
                "elements": "str"
            },
            "system-support-fsw": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "choices": [
                    "5.4",
                    "5.6",
                    "6.0",
                    "6.2",
                    "4.x",
                    "5.0",
                    "5.2",
                    "6.4"
                ],
                "elements": "str"
            },
            "umsvc-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "emergency",
                    "alert",
                    "critical",
                    "error",
                    "warn",
                    "notice",
                    "info",
                    "debug",
                    "disable"
                ],
                "type": "str"
            },
            "unreg-dev-option": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ignore",
                    "svc-only",
                    "add-service"
                ],
                "type": "str"
            },
            "update-schedule": {
                "required": false,
                "type": "dict",
                "options": {
                    "day": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "Sunday",
                            "Monday",
                            "Tuesday",
                            "Wednesday",
                            "Thursday",
                            "Friday",
                            "Saturday"
                        ],
                        "type": "str"
                    },
                    "frequency": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "every",
                            "daily",
                            "weekly"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "time": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    }
                }
            },
            "wanip-query-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "ipify"
                ],
                "type": "str"
            },
            "fortiguard-anycast": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fortiguard-anycast-source": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "fortinet",
                    "aws"
                ],
                "type": "str"
            },
            "system-support-fdc": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "3.x",
                    "4.x"
                ],
                "elements": "str"
            },
            "system-support-fts": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "3.x",
                    "4.x",
                    "7.x"
                ],
                "elements": "str"
            },
            "system-support-faz": {
                "required": false,
                "revision": {
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "6.x",
                    "7.x"
                ],
                "elements": "str"
            },
            "system-support-fis": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "1.x",
                    "2.x"
                ],
                "elements": "str"
            }
        }
    },
    "fmupdate_fdssetting_pushoverride": {
        "stated": false,
        "options": {
            "ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "fmupdate_fdssetting_pushoverridetoclient": {
        "stated": false,
        "options": {
            "announce-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "port": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "fmupdate_fdssetting_pushoverridetoclient_announceip": {
        "stated": true,
        "options": {
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "fmupdate_fdssetting_serveroverride": {
        "stated": false,
        "options": {
            "servlist": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ip6": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "port": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "service-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw",
                        "choices": [
                            "fds",
                            "fct"
                        ]
                    }
                },
                "elements": "dict"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "fmupdate_fdssetting_serveroverride_servlist": {
        "stated": true,
        "options": {
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ip6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "service-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw",
                "choices": [
                    "fds",
                    "fct"
                ]
            }
        }
    },
    "fmupdate_fdssetting_updateschedule": {
        "stated": false,
        "options": {
            "day": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "Sunday",
                    "Monday",
                    "Tuesday",
                    "Wednesday",
                    "Thursday",
                    "Friday",
                    "Saturday"
                ],
                "type": "str"
            },
            "frequency": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "every",
                    "daily",
                    "weekly"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "time": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "fmupdate_fwmsetting": {
        "stated": false,
        "options": {
            "fds-image-timeout": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "max-fds-retry": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "multiple-steps-interval": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "skip-disk-check": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "auto-scan-fgt-disk": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "check-fgt-disk": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fds-failover-fmg": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "immx-source": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "fmg",
                    "fgt",
                    "cloud"
                ],
                "type": "str"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "fwm",
                    "fwm_dm",
                    "fwm_dm_json"
                ],
                "type": "str"
            },
            "upgrade-timeout": {
                "required": false,
                "type": "dict",
                "options": {
                    "check-status-timeout": {
                        "required": false,
                        "revision": {
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": false,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ctrl-check-status-timeout": {
                        "required": false,
                        "revision": {
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": false,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ctrl-put-image-by-fds-timeout": {
                        "required": false,
                        "revision": {
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": false,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ha-sync-timeout": {
                        "required": false,
                        "revision": {
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": false,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "license-check-timeout": {
                        "required": false,
                        "revision": {
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": false,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "prepare-image-timeout": {
                        "required": false,
                        "revision": {
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": false,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "put-image-by-fds-timeout": {
                        "required": false,
                        "revision": {
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": false,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "put-image-timeout": {
                        "required": false,
                        "revision": {
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": false,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "reboot-of-fsck-timeout": {
                        "required": false,
                        "revision": {
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": false,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "reboot-of-upgrade-timeout": {
                        "required": false,
                        "revision": {
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": false,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "retrieve-timeout": {
                        "required": false,
                        "revision": {
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": false,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "rpc-timeout": {
                        "required": false,
                        "revision": {
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": false,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "total-timeout": {
                        "required": false,
                        "revision": {
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": false,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                }
            }
        }
    },
    "fmupdate_fwmsetting_upgradetimeout": {
        "stated": false,
        "options": {
            "check-status-timeout": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ctrl-check-status-timeout": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ctrl-put-image-by-fds-timeout": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ha-sync-timeout": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "license-check-timeout": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "prepare-image-timeout": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "put-image-by-fds-timeout": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "put-image-timeout": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "reboot-of-fsck-timeout": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "reboot-of-upgrade-timeout": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "retrieve-timeout": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "rpc-timeout": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "total-timeout": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "fmupdate_multilayer": {
        "stated": false,
        "options": {
            "webspam-rating": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "fmupdate_publicnetwork": {
        "stated": false,
        "options": {
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "fmupdate_serveraccesspriorities": {
        "stated": false,
        "options": {
            "access-public": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "av-ips": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "private-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ip6": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "time_zone": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "web-spam": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "fmupdate_serveraccesspriorities_privateserver": {
        "stated": true,
        "options": {
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ip6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "time_zone": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "fmupdate_serveroverridestatus": {
        "stated": false,
        "options": {
            "mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "strict",
                    "loose"
                ],
                "type": "str"
            }
        }
    },
    "fmupdate_service": {
        "stated": false,
        "options": {
            "avips": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "query-antispam": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "query-antivirus": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "query-filequery": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "query-geoip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "query-outbreak-prevention": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "query-webfilter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "webfilter-https-traversal": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "query-iot": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "query-iot-collection": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "query-iot-vulnerability": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "fmupdate_webspam_fgdsetting": {
        "stated": false,
        "options": {
            "as-cache": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "as-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "nospam",
                    "all"
                ],
                "type": "str"
            },
            "as-preload": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "av-cache": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "av-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "novirus",
                    "all"
                ],
                "type": "str"
            },
            "av-preload": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "av2-cache": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "av2-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "noav2",
                    "all"
                ],
                "type": "str"
            },
            "av2-preload": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "eventlog-query": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fgd-pull-interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fq-cache": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fq-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "nofilequery",
                    "all"
                ],
                "type": "str"
            },
            "fq-preload": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "linkd-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "emergency",
                    "alert",
                    "critical",
                    "error",
                    "warn",
                    "notice",
                    "info",
                    "debug",
                    "disable"
                ],
                "type": "str"
            },
            "max-client-worker": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "max-log-quota": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "max-unrated-site": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "restrict-as1-dbver": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "restrict-as2-dbver": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "restrict-as4-dbver": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "restrict-av-dbver": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "restrict-av2-dbver": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "restrict-fq-dbver": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "restrict-wf-dbver": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "server-override": {
                "required": false,
                "type": "dict",
                "options": {
                    "servlist": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "id": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "ip": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "ip6": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "port": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "service-type": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw",
                                "choices": [
                                    "fgd",
                                    "fgc",
                                    "fsa"
                                ]
                            }
                        },
                        "elements": "dict"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "stat-log-interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "stat-sync-interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "update-interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "update-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "wf-cache": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "wf-dn-cache-expire-time": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "wf-dn-cache-max-number": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "wf-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "nourl",
                    "all"
                ],
                "type": "str"
            },
            "wf-preload": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "iot-cache": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "iot-log": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "nofilequery",
                    "all"
                ],
                "type": "str"
            },
            "iot-preload": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "restrict-iots-dbver": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "iotv-preload": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "fmupdate_webspam_fgdsetting_serveroverride": {
        "stated": false,
        "options": {
            "servlist": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ip6": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "port": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "service-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw",
                        "choices": [
                            "fgd",
                            "fgc",
                            "fsa"
                        ]
                    }
                },
                "elements": "dict"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "fmupdate_webspam_fgdsetting_serveroverride_servlist": {
        "stated": true,
        "options": {
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ip6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "service-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw",
                "choices": [
                    "fgd",
                    "fgc",
                    "fsa"
                ]
            }
        }
    },
    "fmupdate_webspam_webproxy": {
        "stated": false,
        "options": {
            "ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": false,
                    "6.2.3": false,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "ip6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": false,
                    "6.2.3": false,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "proxy",
                    "tunnel"
                ],
                "type": "str"
            },
            "password": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "no_log": true,
                "type": "raw"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "username": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "address": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "fsp_vlan": {
        "stated": true,
        "options": {
            "_dhcp-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "auth": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": false,
                    "6.2.3": false,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "radius",
                    "usergroup"
                ],
                "type": "str"
            },
            "color": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "comments": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": false,
                    "6.2.3": false,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "dynamic_mapping": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "_dhcp-status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "_scope": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "vdom": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "dhcp-server": {
                        "required": false,
                        "type": "dict",
                        "options": {
                            "auto-configuration": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "auto-managed-status": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "conflicted-ip-timeout": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "ddns-auth": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "tsig"
                                ],
                                "type": "str"
                            },
                            "ddns-key": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "no_log": true,
                                "type": "raw"
                            },
                            "ddns-keyname": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "no_log": true,
                                "type": "str"
                            },
                            "ddns-server-ip": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "ddns-ttl": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "ddns-update": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "ddns-update-override": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "ddns-zone": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "default-gateway": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "dhcp-settings-from-fortiipam": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "dns-server1": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "dns-server2": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "dns-server3": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "dns-server4": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "dns-service": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "default",
                                    "specify",
                                    "local"
                                ],
                                "type": "str"
                            },
                            "domain": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "enable": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "exclude-range": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "options": {
                                    "end-ip": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "id": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "start-ip": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "vci-match": {
                                        "required": false,
                                        "revision": {
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "vci-string": {
                                        "required": false,
                                        "revision": {
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "raw"
                                    },
                                    "lease-time": {
                                        "required": false,
                                        "revision": {
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "uci-match": {
                                        "required": false,
                                        "revision": {
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "uci-string": {
                                        "required": false,
                                        "revision": {
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "raw"
                                    }
                                },
                                "elements": "dict"
                            },
                            "filename": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "forticlient-on-net-status": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "ip-mode": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "range",
                                    "usrgrp"
                                ],
                                "type": "str"
                            },
                            "ip-range": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "options": {
                                    "end-ip": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "id": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "start-ip": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "vci-match": {
                                        "required": false,
                                        "revision": {
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "vci-string": {
                                        "required": false,
                                        "revision": {
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "raw"
                                    },
                                    "lease-time": {
                                        "required": false,
                                        "revision": {
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "uci-match": {
                                        "required": false,
                                        "revision": {
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "uci-string": {
                                        "required": false,
                                        "revision": {
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "raw"
                                    }
                                },
                                "elements": "dict"
                            },
                            "ipsec-lease-hold": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "lease-time": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "mac-acl-default-action": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "assign",
                                    "block"
                                ],
                                "type": "str"
                            },
                            "netmask": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "next-server": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "ntp-server1": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "ntp-server2": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "ntp-server3": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "ntp-service": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "default",
                                    "specify",
                                    "local"
                                ],
                                "type": "str"
                            },
                            "option1": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            },
                            "option2": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            },
                            "option3": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            },
                            "option4": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "option5": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "option6": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "options": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "options": {
                                    "code": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "id": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "ip": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "raw"
                                    },
                                    "type": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "hex",
                                            "string",
                                            "ip",
                                            "fqdn"
                                        ],
                                        "type": "str"
                                    },
                                    "value": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "vci-match": {
                                        "required": false,
                                        "revision": {
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "vci-string": {
                                        "required": false,
                                        "revision": {
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "raw"
                                    },
                                    "uci-match": {
                                        "required": false,
                                        "revision": {
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "uci-string": {
                                        "required": false,
                                        "revision": {
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "raw"
                                    }
                                },
                                "elements": "dict"
                            },
                            "reserved-address": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "options": {
                                    "action": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "assign",
                                            "block",
                                            "reserved"
                                        ],
                                        "type": "str"
                                    },
                                    "circuit-id": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "circuit-id-type": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "hex",
                                            "string"
                                        ],
                                        "type": "str"
                                    },
                                    "description": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "id": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "ip": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "mac": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "remote-id": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "remote-id-type": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "hex",
                                            "string"
                                        ],
                                        "type": "str"
                                    },
                                    "type": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "mac",
                                            "option82"
                                        ],
                                        "type": "str"
                                    }
                                },
                                "elements": "dict"
                            },
                            "server-type": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "regular",
                                    "ipsec"
                                ],
                                "type": "str"
                            },
                            "status": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "tftp-server": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            },
                            "timezone": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "00",
                                    "01",
                                    "02",
                                    "03",
                                    "04",
                                    "05",
                                    "06",
                                    "07",
                                    "08",
                                    "09",
                                    "10",
                                    "11",
                                    "12",
                                    "13",
                                    "14",
                                    "15",
                                    "16",
                                    "17",
                                    "18",
                                    "19",
                                    "20",
                                    "21",
                                    "22",
                                    "23",
                                    "24",
                                    "25",
                                    "26",
                                    "27",
                                    "28",
                                    "29",
                                    "30",
                                    "31",
                                    "32",
                                    "33",
                                    "34",
                                    "35",
                                    "36",
                                    "37",
                                    "38",
                                    "39",
                                    "40",
                                    "41",
                                    "42",
                                    "43",
                                    "44",
                                    "45",
                                    "46",
                                    "47",
                                    "48",
                                    "49",
                                    "50",
                                    "51",
                                    "52",
                                    "53",
                                    "54",
                                    "55",
                                    "56",
                                    "57",
                                    "58",
                                    "59",
                                    "60",
                                    "61",
                                    "62",
                                    "63",
                                    "64",
                                    "65",
                                    "66",
                                    "67",
                                    "68",
                                    "69",
                                    "70",
                                    "71",
                                    "72",
                                    "73",
                                    "74",
                                    "75",
                                    "76",
                                    "77",
                                    "78",
                                    "79",
                                    "80",
                                    "81",
                                    "82",
                                    "83",
                                    "84",
                                    "85",
                                    "86",
                                    "87"
                                ],
                                "type": "str"
                            },
                            "timezone-option": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "default",
                                    "specify"
                                ],
                                "type": "str"
                            },
                            "vci-match": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "vci-string": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            },
                            "wifi-ac-service": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "specify",
                                    "local"
                                ],
                                "type": "str"
                            },
                            "wifi-ac1": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "wifi-ac2": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "wifi-ac3": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "wins-server1": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "wins-server2": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "relay-agent": {
                                "required": false,
                                "revision": {
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "shared-subnet": {
                                "required": false,
                                "revision": {
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            }
                        }
                    },
                    "interface": {
                        "required": false,
                        "type": "dict",
                        "options": {
                            "dhcp-relay-agent-option": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "dhcp-relay-ip": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            },
                            "dhcp-relay-service": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "dhcp-relay-type": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "regular",
                                    "ipsec"
                                ],
                                "type": "str"
                            },
                            "ip": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "ipv6": {
                                "required": false,
                                "type": "dict",
                                "options": {
                                    "autoconf": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "dhcp6-client-options": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "list",
                                        "choices": [
                                            "rapid",
                                            "iapd",
                                            "iana",
                                            "dns",
                                            "dnsname"
                                        ],
                                        "elements": "str"
                                    },
                                    "dhcp6-information-request": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "dhcp6-prefix-delegation": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "dhcp6-prefix-hint": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "dhcp6-prefix-hint-plt": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "dhcp6-prefix-hint-vlt": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "dhcp6-relay-ip": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "dhcp6-relay-service": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "dhcp6-relay-type": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "regular"
                                        ],
                                        "type": "str"
                                    },
                                    "icmp6-send-redirect": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": false,
                                            "6.2.9": false,
                                            "6.2.10": false,
                                            "6.2.11": false,
                                            "6.2.12": false,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "interface-identifier": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": false,
                                            "6.2.9": false,
                                            "6.2.10": false,
                                            "6.2.11": false,
                                            "6.2.12": false,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "ip6-address": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "ip6-allowaccess": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "list",
                                        "choices": [
                                            "https",
                                            "ping",
                                            "ssh",
                                            "snmp",
                                            "http",
                                            "telnet",
                                            "fgfm",
                                            "capwap",
                                            "fabric"
                                        ],
                                        "elements": "str"
                                    },
                                    "ip6-default-life": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "ip6-delegated-prefix-list": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "list",
                                        "options": {
                                            "autonomous-flag": {
                                                "required": false,
                                                "revision": {
                                                    "6.2.0": false,
                                                    "6.2.2": false,
                                                    "6.2.6": false,
                                                    "6.2.7": false,
                                                    "6.2.8": true,
                                                    "6.2.9": true,
                                                    "6.2.10": true,
                                                    "6.2.11": true,
                                                    "6.2.12": true,
                                                    "6.4.1": false,
                                                    "6.4.3": false,
                                                    "6.4.4": false,
                                                    "6.4.5": true,
                                                    "6.4.6": true,
                                                    "6.4.7": true,
                                                    "6.4.8": true,
                                                    "6.4.9": true,
                                                    "6.4.10": true,
                                                    "6.4.11": true,
                                                    "6.4.12": true,
                                                    "6.4.13": true,
                                                    "7.0.0": true,
                                                    "7.0.1": true,
                                                    "7.0.2": true,
                                                    "7.0.3": true,
                                                    "7.0.4": true,
                                                    "7.0.5": true,
                                                    "7.0.6": true,
                                                    "7.0.7": true,
                                                    "7.0.8": true,
                                                    "7.0.9": true,
                                                    "7.2.0": true,
                                                    "7.2.1": true,
                                                    "7.2.2": true,
                                                    "7.2.3": true,
                                                    "7.2.4": true,
                                                    "7.4.0": true,
                                                    "7.4.1": true
                                                },
                                                "choices": [
                                                    "disable",
                                                    "enable"
                                                ],
                                                "type": "str"
                                            },
                                            "onlink-flag": {
                                                "required": false,
                                                "revision": {
                                                    "6.2.0": false,
                                                    "6.2.2": false,
                                                    "6.2.6": false,
                                                    "6.2.7": false,
                                                    "6.2.8": true,
                                                    "6.2.9": true,
                                                    "6.2.10": true,
                                                    "6.2.11": true,
                                                    "6.2.12": true,
                                                    "6.4.1": false,
                                                    "6.4.3": false,
                                                    "6.4.4": false,
                                                    "6.4.5": true,
                                                    "6.4.6": true,
                                                    "6.4.7": true,
                                                    "6.4.8": true,
                                                    "6.4.9": true,
                                                    "6.4.10": true,
                                                    "6.4.11": true,
                                                    "6.4.12": true,
                                                    "6.4.13": true,
                                                    "7.0.0": true,
                                                    "7.0.1": true,
                                                    "7.0.2": true,
                                                    "7.0.3": true,
                                                    "7.0.4": true,
                                                    "7.0.5": true,
                                                    "7.0.6": true,
                                                    "7.0.7": true,
                                                    "7.0.8": true,
                                                    "7.0.9": true,
                                                    "7.2.0": true,
                                                    "7.2.1": true,
                                                    "7.2.2": true,
                                                    "7.2.3": true,
                                                    "7.2.4": true,
                                                    "7.4.0": true,
                                                    "7.4.1": true
                                                },
                                                "choices": [
                                                    "disable",
                                                    "enable"
                                                ],
                                                "type": "str"
                                            },
                                            "prefix-id": {
                                                "required": false,
                                                "revision": {
                                                    "6.2.0": false,
                                                    "6.2.2": false,
                                                    "6.2.6": false,
                                                    "6.2.7": false,
                                                    "6.2.8": true,
                                                    "6.2.9": true,
                                                    "6.2.10": true,
                                                    "6.2.11": true,
                                                    "6.2.12": true,
                                                    "6.4.1": false,
                                                    "6.4.3": false,
                                                    "6.4.4": false,
                                                    "6.4.5": true,
                                                    "6.4.6": true,
                                                    "6.4.7": true,
                                                    "6.4.8": true,
                                                    "6.4.9": true,
                                                    "6.4.10": true,
                                                    "6.4.11": true,
                                                    "6.4.12": true,
                                                    "6.4.13": true,
                                                    "7.0.0": true,
                                                    "7.0.1": true,
                                                    "7.0.2": true,
                                                    "7.0.3": true,
                                                    "7.0.4": true,
                                                    "7.0.5": true,
                                                    "7.0.6": true,
                                                    "7.0.7": true,
                                                    "7.0.8": true,
                                                    "7.0.9": true,
                                                    "7.2.0": true,
                                                    "7.2.1": true,
                                                    "7.2.2": true,
                                                    "7.2.3": true,
                                                    "7.2.4": true,
                                                    "7.4.0": true,
                                                    "7.4.1": true
                                                },
                                                "type": "int"
                                            },
                                            "rdnss": {
                                                "required": false,
                                                "revision": {
                                                    "6.2.0": false,
                                                    "6.2.2": false,
                                                    "6.2.6": false,
                                                    "6.2.7": false,
                                                    "6.2.8": true,
                                                    "6.2.9": true,
                                                    "6.2.10": true,
                                                    "6.2.11": true,
                                                    "6.2.12": true,
                                                    "6.4.1": false,
                                                    "6.4.3": false,
                                                    "6.4.4": false,
                                                    "6.4.5": true,
                                                    "6.4.6": true,
                                                    "6.4.7": true,
                                                    "6.4.8": true,
                                                    "6.4.9": true,
                                                    "6.4.10": true,
                                                    "6.4.11": true,
                                                    "6.4.12": true,
                                                    "6.4.13": true,
                                                    "7.0.0": true,
                                                    "7.0.1": true,
                                                    "7.0.2": true,
                                                    "7.0.3": true,
                                                    "7.0.4": true,
                                                    "7.0.5": true,
                                                    "7.0.6": true,
                                                    "7.0.7": true,
                                                    "7.0.8": true,
                                                    "7.0.9": true,
                                                    "7.2.0": true,
                                                    "7.2.1": true,
                                                    "7.2.2": true,
                                                    "7.2.3": true,
                                                    "7.2.4": true,
                                                    "7.4.0": true,
                                                    "7.4.1": true
                                                },
                                                "type": "raw"
                                            },
                                            "rdnss-service": {
                                                "required": false,
                                                "revision": {
                                                    "6.2.0": false,
                                                    "6.2.2": false,
                                                    "6.2.6": false,
                                                    "6.2.7": false,
                                                    "6.2.8": true,
                                                    "6.2.9": true,
                                                    "6.2.10": true,
                                                    "6.2.11": true,
                                                    "6.2.12": true,
                                                    "6.4.1": false,
                                                    "6.4.3": false,
                                                    "6.4.4": false,
                                                    "6.4.5": true,
                                                    "6.4.6": true,
                                                    "6.4.7": true,
                                                    "6.4.8": true,
                                                    "6.4.9": true,
                                                    "6.4.10": true,
                                                    "6.4.11": true,
                                                    "6.4.12": true,
                                                    "6.4.13": true,
                                                    "7.0.0": true,
                                                    "7.0.1": true,
                                                    "7.0.2": true,
                                                    "7.0.3": true,
                                                    "7.0.4": true,
                                                    "7.0.5": true,
                                                    "7.0.6": true,
                                                    "7.0.7": true,
                                                    "7.0.8": true,
                                                    "7.0.9": true,
                                                    "7.2.0": true,
                                                    "7.2.1": true,
                                                    "7.2.2": true,
                                                    "7.2.3": true,
                                                    "7.2.4": true,
                                                    "7.4.0": true,
                                                    "7.4.1": true
                                                },
                                                "choices": [
                                                    "delegated",
                                                    "default",
                                                    "specify"
                                                ],
                                                "type": "str"
                                            },
                                            "subnet": {
                                                "required": false,
                                                "revision": {
                                                    "6.2.0": false,
                                                    "6.2.2": false,
                                                    "6.2.6": false,
                                                    "6.2.7": false,
                                                    "6.2.8": true,
                                                    "6.2.9": true,
                                                    "6.2.10": true,
                                                    "6.2.11": true,
                                                    "6.2.12": true,
                                                    "6.4.1": false,
                                                    "6.4.3": false,
                                                    "6.4.4": false,
                                                    "6.4.5": true,
                                                    "6.4.6": true,
                                                    "6.4.7": true,
                                                    "6.4.8": true,
                                                    "6.4.9": true,
                                                    "6.4.10": true,
                                                    "6.4.11": true,
                                                    "6.4.12": true,
                                                    "6.4.13": true,
                                                    "7.0.0": true,
                                                    "7.0.1": true,
                                                    "7.0.2": true,
                                                    "7.0.3": true,
                                                    "7.0.4": true,
                                                    "7.0.5": true,
                                                    "7.0.6": true,
                                                    "7.0.7": true,
                                                    "7.0.8": true,
                                                    "7.0.9": true,
                                                    "7.2.0": true,
                                                    "7.2.1": true,
                                                    "7.2.2": true,
                                                    "7.2.3": true,
                                                    "7.2.4": true,
                                                    "7.4.0": true,
                                                    "7.4.1": true
                                                },
                                                "type": "str"
                                            },
                                            "upstream-interface": {
                                                "required": false,
                                                "revision": {
                                                    "6.2.0": false,
                                                    "6.2.2": false,
                                                    "6.2.6": false,
                                                    "6.2.7": false,
                                                    "6.2.8": true,
                                                    "6.2.9": true,
                                                    "6.2.10": true,
                                                    "6.2.11": true,
                                                    "6.2.12": true,
                                                    "6.4.1": false,
                                                    "6.4.3": false,
                                                    "6.4.4": false,
                                                    "6.4.5": true,
                                                    "6.4.6": true,
                                                    "6.4.7": true,
                                                    "6.4.8": true,
                                                    "6.4.9": true,
                                                    "6.4.10": true,
                                                    "6.4.11": true,
                                                    "6.4.12": true,
                                                    "6.4.13": true,
                                                    "7.0.0": true,
                                                    "7.0.1": true,
                                                    "7.0.2": true,
                                                    "7.0.3": true,
                                                    "7.0.4": true,
                                                    "7.0.5": true,
                                                    "7.0.6": true,
                                                    "7.0.7": true,
                                                    "7.0.8": true,
                                                    "7.0.9": true,
                                                    "7.2.0": true,
                                                    "7.2.1": true,
                                                    "7.2.2": true,
                                                    "7.2.3": true,
                                                    "7.2.4": true,
                                                    "7.4.0": true,
                                                    "7.4.1": true
                                                },
                                                "type": "str"
                                            },
                                            "delegated-prefix-iaid": {
                                                "required": false,
                                                "revision": {
                                                    "6.2.0": false,
                                                    "6.2.2": false,
                                                    "6.2.6": false,
                                                    "6.2.7": false,
                                                    "6.2.8": false,
                                                    "6.2.9": false,
                                                    "6.2.10": false,
                                                    "6.2.11": false,
                                                    "6.2.12": false,
                                                    "6.4.1": false,
                                                    "6.4.3": false,
                                                    "6.4.4": false,
                                                    "6.4.6": false,
                                                    "6.4.7": false,
                                                    "6.4.8": false,
                                                    "6.4.9": false,
                                                    "6.4.10": false,
                                                    "6.4.11": false,
                                                    "6.4.12": false,
                                                    "6.4.13": false,
                                                    "7.0.1": false,
                                                    "7.0.2": true,
                                                    "7.0.3": true,
                                                    "7.0.4": true,
                                                    "7.0.5": true,
                                                    "7.0.6": true,
                                                    "7.0.7": true,
                                                    "7.0.8": true,
                                                    "7.0.9": true,
                                                    "7.2.0": true,
                                                    "7.2.1": true,
                                                    "7.2.2": true,
                                                    "7.2.3": true,
                                                    "7.2.4": true,
                                                    "7.4.0": true,
                                                    "7.4.1": true
                                                },
                                                "type": "int"
                                            }
                                        },
                                        "elements": "dict"
                                    },
                                    "ip6-dns-server-override": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "ip6-extra-addr": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "list",
                                        "options": {
                                            "prefix": {
                                                "required": false,
                                                "revision": {
                                                    "6.2.0": false,
                                                    "6.2.2": false,
                                                    "6.2.6": false,
                                                    "6.2.7": false,
                                                    "6.2.8": true,
                                                    "6.2.9": true,
                                                    "6.2.10": true,
                                                    "6.2.11": true,
                                                    "6.2.12": true,
                                                    "6.4.1": false,
                                                    "6.4.3": false,
                                                    "6.4.4": false,
                                                    "6.4.5": true,
                                                    "6.4.6": true,
                                                    "6.4.7": true,
                                                    "6.4.8": true,
                                                    "6.4.9": true,
                                                    "6.4.10": true,
                                                    "6.4.11": true,
                                                    "6.4.12": true,
                                                    "6.4.13": true,
                                                    "7.0.0": true,
                                                    "7.0.1": true,
                                                    "7.0.2": true,
                                                    "7.0.3": true,
                                                    "7.0.4": true,
                                                    "7.0.5": true,
                                                    "7.0.6": true,
                                                    "7.0.7": true,
                                                    "7.0.8": true,
                                                    "7.0.9": true,
                                                    "7.2.0": true,
                                                    "7.2.1": true,
                                                    "7.2.2": true,
                                                    "7.2.3": true,
                                                    "7.2.4": true,
                                                    "7.4.0": true,
                                                    "7.4.1": true
                                                },
                                                "type": "str"
                                            }
                                        },
                                        "elements": "dict"
                                    },
                                    "ip6-hop-limit": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "ip6-link-mtu": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "ip6-manage-flag": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "ip6-max-interval": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "ip6-min-interval": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "ip6-mode": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "static",
                                            "dhcp",
                                            "pppoe",
                                            "delegated"
                                        ],
                                        "type": "str"
                                    },
                                    "ip6-other-flag": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "ip6-prefix-list": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "list",
                                        "options": {
                                            "autonomous-flag": {
                                                "required": false,
                                                "revision": {
                                                    "6.2.0": false,
                                                    "6.2.2": false,
                                                    "6.2.6": false,
                                                    "6.2.7": false,
                                                    "6.2.8": true,
                                                    "6.2.9": true,
                                                    "6.2.10": true,
                                                    "6.2.11": true,
                                                    "6.2.12": true,
                                                    "6.4.1": false,
                                                    "6.4.3": false,
                                                    "6.4.4": false,
                                                    "6.4.5": true,
                                                    "6.4.6": true,
                                                    "6.4.7": true,
                                                    "6.4.8": true,
                                                    "6.4.9": true,
                                                    "6.4.10": true,
                                                    "6.4.11": true,
                                                    "6.4.12": true,
                                                    "6.4.13": true,
                                                    "7.0.0": true,
                                                    "7.0.1": true,
                                                    "7.0.2": true,
                                                    "7.0.3": true,
                                                    "7.0.4": true,
                                                    "7.0.5": true,
                                                    "7.0.6": true,
                                                    "7.0.7": true,
                                                    "7.0.8": true,
                                                    "7.0.9": true,
                                                    "7.2.0": true,
                                                    "7.2.1": true,
                                                    "7.2.2": true,
                                                    "7.2.3": true,
                                                    "7.2.4": true,
                                                    "7.4.0": true,
                                                    "7.4.1": true
                                                },
                                                "choices": [
                                                    "disable",
                                                    "enable"
                                                ],
                                                "type": "str"
                                            },
                                            "dnssl": {
                                                "required": false,
                                                "revision": {
                                                    "6.2.0": false,
                                                    "6.2.2": false,
                                                    "6.2.6": false,
                                                    "6.2.7": false,
                                                    "6.2.8": true,
                                                    "6.2.9": true,
                                                    "6.2.10": true,
                                                    "6.2.11": true,
                                                    "6.2.12": true,
                                                    "6.4.1": false,
                                                    "6.4.3": false,
                                                    "6.4.4": false,
                                                    "6.4.5": true,
                                                    "6.4.6": true,
                                                    "6.4.7": true,
                                                    "6.4.8": true,
                                                    "6.4.9": true,
                                                    "6.4.10": true,
                                                    "6.4.11": true,
                                                    "6.4.12": true,
                                                    "6.4.13": true,
                                                    "7.0.0": true,
                                                    "7.0.1": true,
                                                    "7.0.2": true,
                                                    "7.0.3": true,
                                                    "7.0.4": true,
                                                    "7.0.5": true,
                                                    "7.0.6": true,
                                                    "7.0.7": true,
                                                    "7.0.8": true,
                                                    "7.0.9": true,
                                                    "7.2.0": true,
                                                    "7.2.1": true,
                                                    "7.2.2": true,
                                                    "7.2.3": true,
                                                    "7.2.4": true,
                                                    "7.4.0": true,
                                                    "7.4.1": true
                                                },
                                                "type": "raw"
                                            },
                                            "onlink-flag": {
                                                "required": false,
                                                "revision": {
                                                    "6.2.0": false,
                                                    "6.2.2": false,
                                                    "6.2.6": false,
                                                    "6.2.7": false,
                                                    "6.2.8": true,
                                                    "6.2.9": true,
                                                    "6.2.10": true,
                                                    "6.2.11": true,
                                                    "6.2.12": true,
                                                    "6.4.1": false,
                                                    "6.4.3": false,
                                                    "6.4.4": false,
                                                    "6.4.5": true,
                                                    "6.4.6": true,
                                                    "6.4.7": true,
                                                    "6.4.8": true,
                                                    "6.4.9": true,
                                                    "6.4.10": true,
                                                    "6.4.11": true,
                                                    "6.4.12": true,
                                                    "6.4.13": true,
                                                    "7.0.0": true,
                                                    "7.0.1": true,
                                                    "7.0.2": true,
                                                    "7.0.3": true,
                                                    "7.0.4": true,
                                                    "7.0.5": true,
                                                    "7.0.6": true,
                                                    "7.0.7": true,
                                                    "7.0.8": true,
                                                    "7.0.9": true,
                                                    "7.2.0": true,
                                                    "7.2.1": true,
                                                    "7.2.2": true,
                                                    "7.2.3": true,
                                                    "7.2.4": true,
                                                    "7.4.0": true,
                                                    "7.4.1": true
                                                },
                                                "choices": [
                                                    "disable",
                                                    "enable"
                                                ],
                                                "type": "str"
                                            },
                                            "preferred-life-time": {
                                                "required": false,
                                                "revision": {
                                                    "6.2.0": false,
                                                    "6.2.2": false,
                                                    "6.2.6": false,
                                                    "6.2.7": false,
                                                    "6.2.8": true,
                                                    "6.2.9": true,
                                                    "6.2.10": true,
                                                    "6.2.11": true,
                                                    "6.2.12": true,
                                                    "6.4.1": false,
                                                    "6.4.3": false,
                                                    "6.4.4": false,
                                                    "6.4.5": true,
                                                    "6.4.6": true,
                                                    "6.4.7": true,
                                                    "6.4.8": true,
                                                    "6.4.9": true,
                                                    "6.4.10": true,
                                                    "6.4.11": true,
                                                    "6.4.12": true,
                                                    "6.4.13": true,
                                                    "7.0.0": true,
                                                    "7.0.1": true,
                                                    "7.0.2": true,
                                                    "7.0.3": true,
                                                    "7.0.4": true,
                                                    "7.0.5": true,
                                                    "7.0.6": true,
                                                    "7.0.7": true,
                                                    "7.0.8": true,
                                                    "7.0.9": true,
                                                    "7.2.0": true,
                                                    "7.2.1": true,
                                                    "7.2.2": true,
                                                    "7.2.3": true,
                                                    "7.2.4": true,
                                                    "7.4.0": true,
                                                    "7.4.1": true
                                                },
                                                "type": "int"
                                            },
                                            "prefix": {
                                                "required": false,
                                                "revision": {
                                                    "6.2.0": false,
                                                    "6.2.2": false,
                                                    "6.2.6": false,
                                                    "6.2.7": false,
                                                    "6.2.8": true,
                                                    "6.2.9": true,
                                                    "6.2.10": true,
                                                    "6.2.11": true,
                                                    "6.2.12": true,
                                                    "6.4.1": false,
                                                    "6.4.3": false,
                                                    "6.4.4": false,
                                                    "6.4.5": true,
                                                    "6.4.6": true,
                                                    "6.4.7": true,
                                                    "6.4.8": true,
                                                    "6.4.9": true,
                                                    "6.4.10": true,
                                                    "6.4.11": true,
                                                    "6.4.12": true,
                                                    "6.4.13": true,
                                                    "7.0.0": true,
                                                    "7.0.1": true,
                                                    "7.0.2": true,
                                                    "7.0.3": true,
                                                    "7.0.4": true,
                                                    "7.0.5": true,
                                                    "7.0.6": true,
                                                    "7.0.7": true,
                                                    "7.0.8": true,
                                                    "7.0.9": true,
                                                    "7.2.0": true,
                                                    "7.2.1": true,
                                                    "7.2.2": true,
                                                    "7.2.3": true,
                                                    "7.2.4": true,
                                                    "7.4.0": true,
                                                    "7.4.1": true
                                                },
                                                "type": "str"
                                            },
                                            "rdnss": {
                                                "required": false,
                                                "revision": {
                                                    "6.2.0": false,
                                                    "6.2.2": false,
                                                    "6.2.6": false,
                                                    "6.2.7": false,
                                                    "6.2.8": true,
                                                    "6.2.9": true,
                                                    "6.2.10": true,
                                                    "6.2.11": true,
                                                    "6.2.12": true,
                                                    "6.4.1": false,
                                                    "6.4.3": false,
                                                    "6.4.4": false,
                                                    "6.4.5": true,
                                                    "6.4.6": true,
                                                    "6.4.7": true,
                                                    "6.4.8": true,
                                                    "6.4.9": true,
                                                    "6.4.10": true,
                                                    "6.4.11": true,
                                                    "6.4.12": true,
                                                    "6.4.13": true,
                                                    "7.0.0": true,
                                                    "7.0.1": true,
                                                    "7.0.2": true,
                                                    "7.0.3": true,
                                                    "7.0.4": true,
                                                    "7.0.5": true,
                                                    "7.0.6": true,
                                                    "7.0.7": true,
                                                    "7.0.8": true,
                                                    "7.0.9": true,
                                                    "7.2.0": true,
                                                    "7.2.1": true,
                                                    "7.2.2": true,
                                                    "7.2.3": true,
                                                    "7.2.4": true,
                                                    "7.4.0": true,
                                                    "7.4.1": true
                                                },
                                                "type": "raw"
                                            },
                                            "valid-life-time": {
                                                "required": false,
                                                "revision": {
                                                    "6.2.0": false,
                                                    "6.2.2": false,
                                                    "6.2.6": false,
                                                    "6.2.7": false,
                                                    "6.2.8": true,
                                                    "6.2.9": true,
                                                    "6.2.10": true,
                                                    "6.2.11": true,
                                                    "6.2.12": true,
                                                    "6.4.1": false,
                                                    "6.4.3": false,
                                                    "6.4.4": false,
                                                    "6.4.5": true,
                                                    "6.4.6": true,
                                                    "6.4.7": true,
                                                    "6.4.8": true,
                                                    "6.4.9": true,
                                                    "6.4.10": true,
                                                    "6.4.11": true,
                                                    "6.4.12": true,
                                                    "6.4.13": true,
                                                    "7.0.0": true,
                                                    "7.0.1": true,
                                                    "7.0.2": true,
                                                    "7.0.3": true,
                                                    "7.0.4": true,
                                                    "7.0.5": true,
                                                    "7.0.6": true,
                                                    "7.0.7": true,
                                                    "7.0.8": true,
                                                    "7.0.9": true,
                                                    "7.2.0": true,
                                                    "7.2.1": true,
                                                    "7.2.2": true,
                                                    "7.2.3": true,
                                                    "7.2.4": true,
                                                    "7.4.0": true,
                                                    "7.4.1": true
                                                },
                                                "type": "int"
                                            }
                                        },
                                        "elements": "dict"
                                    },
                                    "ip6-reachable-time": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "ip6-retrans-time": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "ip6-send-adv": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "ip6-subnet": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "ip6-upstream-interface": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "nd-cert": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "nd-cga-modifier": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "nd-mode": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "basic",
                                            "SEND-compatible"
                                        ],
                                        "type": "str"
                                    },
                                    "nd-security-level": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "nd-timestamp-delta": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "nd-timestamp-fuzz": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "unique-autoconf-addr": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": false,
                                            "6.2.9": false,
                                            "6.2.10": false,
                                            "6.2.11": false,
                                            "6.2.12": false,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "vrip6_link_local": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "vrrp-virtual-mac6": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "vrrp6": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "list",
                                        "options": {
                                            "accept-mode": {
                                                "required": false,
                                                "revision": {
                                                    "6.2.0": false,
                                                    "6.2.2": false,
                                                    "6.2.6": false,
                                                    "6.2.7": false,
                                                    "6.2.8": true,
                                                    "6.2.9": true,
                                                    "6.2.10": true,
                                                    "6.2.11": true,
                                                    "6.2.12": true,
                                                    "6.4.1": false,
                                                    "6.4.3": false,
                                                    "6.4.4": false,
                                                    "6.4.5": true,
                                                    "6.4.6": true,
                                                    "6.4.7": true,
                                                    "6.4.8": true,
                                                    "6.4.9": true,
                                                    "6.4.10": true,
                                                    "6.4.11": true,
                                                    "6.4.12": true,
                                                    "6.4.13": true,
                                                    "7.0.0": true,
                                                    "7.0.1": true,
                                                    "7.0.2": true,
                                                    "7.0.3": true,
                                                    "7.0.4": true,
                                                    "7.0.5": true,
                                                    "7.0.6": true,
                                                    "7.0.7": true,
                                                    "7.0.8": true,
                                                    "7.0.9": true,
                                                    "7.2.0": true,
                                                    "7.2.1": true,
                                                    "7.2.2": true,
                                                    "7.2.3": true,
                                                    "7.2.4": true,
                                                    "7.4.0": true,
                                                    "7.4.1": true
                                                },
                                                "choices": [
                                                    "disable",
                                                    "enable"
                                                ],
                                                "type": "str"
                                            },
                                            "adv-interval": {
                                                "required": false,
                                                "revision": {
                                                    "6.2.0": false,
                                                    "6.2.2": false,
                                                    "6.2.6": false,
                                                    "6.2.7": false,
                                                    "6.2.8": true,
                                                    "6.2.9": true,
                                                    "6.2.10": true,
                                                    "6.2.11": true,
                                                    "6.2.12": true,
                                                    "6.4.1": false,
                                                    "6.4.3": false,
                                                    "6.4.4": false,
                                                    "6.4.5": true,
                                                    "6.4.6": true,
                                                    "6.4.7": true,
                                                    "6.4.8": true,
                                                    "6.4.9": true,
                                                    "6.4.10": true,
                                                    "6.4.11": true,
                                                    "6.4.12": true,
                                                    "6.4.13": true,
                                                    "7.0.0": true,
                                                    "7.0.1": true,
                                                    "7.0.2": true,
                                                    "7.0.3": true,
                                                    "7.0.4": true,
                                                    "7.0.5": true,
                                                    "7.0.6": true,
                                                    "7.0.7": true,
                                                    "7.0.8": true,
                                                    "7.0.9": true,
                                                    "7.2.0": true,
                                                    "7.2.1": true,
                                                    "7.2.2": true,
                                                    "7.2.3": true,
                                                    "7.2.4": true,
                                                    "7.4.0": true,
                                                    "7.4.1": true
                                                },
                                                "type": "int"
                                            },
                                            "preempt": {
                                                "required": false,
                                                "revision": {
                                                    "6.2.0": false,
                                                    "6.2.2": false,
                                                    "6.2.6": false,
                                                    "6.2.7": false,
                                                    "6.2.8": true,
                                                    "6.2.9": true,
                                                    "6.2.10": true,
                                                    "6.2.11": true,
                                                    "6.2.12": true,
                                                    "6.4.1": false,
                                                    "6.4.3": false,
                                                    "6.4.4": false,
                                                    "6.4.5": true,
                                                    "6.4.6": true,
                                                    "6.4.7": true,
                                                    "6.4.8": true,
                                                    "6.4.9": true,
                                                    "6.4.10": true,
                                                    "6.4.11": true,
                                                    "6.4.12": true,
                                                    "6.4.13": true,
                                                    "7.0.0": true,
                                                    "7.0.1": true,
                                                    "7.0.2": true,
                                                    "7.0.3": true,
                                                    "7.0.4": true,
                                                    "7.0.5": true,
                                                    "7.0.6": true,
                                                    "7.0.7": true,
                                                    "7.0.8": true,
                                                    "7.0.9": true,
                                                    "7.2.0": true,
                                                    "7.2.1": true,
                                                    "7.2.2": true,
                                                    "7.2.3": true,
                                                    "7.2.4": true,
                                                    "7.4.0": true,
                                                    "7.4.1": true
                                                },
                                                "choices": [
                                                    "disable",
                                                    "enable"
                                                ],
                                                "type": "str"
                                            },
                                            "priority": {
                                                "required": false,
                                                "revision": {
                                                    "6.2.0": false,
                                                    "6.2.2": false,
                                                    "6.2.6": false,
                                                    "6.2.7": false,
                                                    "6.2.8": true,
                                                    "6.2.9": true,
                                                    "6.2.10": true,
                                                    "6.2.11": true,
                                                    "6.2.12": true,
                                                    "6.4.1": false,
                                                    "6.4.3": false,
                                                    "6.4.4": false,
                                                    "6.4.5": true,
                                                    "6.4.6": true,
                                                    "6.4.7": true,
                                                    "6.4.8": true,
                                                    "6.4.9": true,
                                                    "6.4.10": true,
                                                    "6.4.11": true,
                                                    "6.4.12": true,
                                                    "6.4.13": true,
                                                    "7.0.0": true,
                                                    "7.0.1": true,
                                                    "7.0.2": true,
                                                    "7.0.3": true,
                                                    "7.0.4": true,
                                                    "7.0.5": true,
                                                    "7.0.6": true,
                                                    "7.0.7": true,
                                                    "7.0.8": true,
                                                    "7.0.9": true,
                                                    "7.2.0": true,
                                                    "7.2.1": true,
                                                    "7.2.2": true,
                                                    "7.2.3": true,
                                                    "7.2.4": true,
                                                    "7.4.0": true,
                                                    "7.4.1": true
                                                },
                                                "type": "int"
                                            },
                                            "start-time": {
                                                "required": false,
                                                "revision": {
                                                    "6.2.0": false,
                                                    "6.2.2": false,
                                                    "6.2.6": false,
                                                    "6.2.7": false,
                                                    "6.2.8": true,
                                                    "6.2.9": true,
                                                    "6.2.10": true,
                                                    "6.2.11": true,
                                                    "6.2.12": true,
                                                    "6.4.1": false,
                                                    "6.4.3": false,
                                                    "6.4.4": false,
                                                    "6.4.5": true,
                                                    "6.4.6": true,
                                                    "6.4.7": true,
                                                    "6.4.8": true,
                                                    "6.4.9": true,
                                                    "6.4.10": true,
                                                    "6.4.11": true,
                                                    "6.4.12": true,
                                                    "6.4.13": true,
                                                    "7.0.0": true,
                                                    "7.0.1": true,
                                                    "7.0.2": true,
                                                    "7.0.3": true,
                                                    "7.0.4": true,
                                                    "7.0.5": true,
                                                    "7.0.6": true,
                                                    "7.0.7": true,
                                                    "7.0.8": true,
                                                    "7.0.9": true,
                                                    "7.2.0": true,
                                                    "7.2.1": true,
                                                    "7.2.2": true,
                                                    "7.2.3": true,
                                                    "7.2.4": true,
                                                    "7.4.0": true,
                                                    "7.4.1": true
                                                },
                                                "type": "int"
                                            },
                                            "status": {
                                                "required": false,
                                                "revision": {
                                                    "6.2.0": false,
                                                    "6.2.2": false,
                                                    "6.2.6": false,
                                                    "6.2.7": false,
                                                    "6.2.8": true,
                                                    "6.2.9": true,
                                                    "6.2.10": true,
                                                    "6.2.11": true,
                                                    "6.2.12": true,
                                                    "6.4.1": false,
                                                    "6.4.3": false,
                                                    "6.4.4": false,
                                                    "6.4.5": true,
                                                    "6.4.6": true,
                                                    "6.4.7": true,
                                                    "6.4.8": true,
                                                    "6.4.9": true,
                                                    "6.4.10": true,
                                                    "6.4.11": true,
                                                    "6.4.12": true,
                                                    "6.4.13": true,
                                                    "7.0.0": true,
                                                    "7.0.1": true,
                                                    "7.0.2": true,
                                                    "7.0.3": true,
                                                    "7.0.4": true,
                                                    "7.0.5": true,
                                                    "7.0.6": true,
                                                    "7.0.7": true,
                                                    "7.0.8": true,
                                                    "7.0.9": true,
                                                    "7.2.0": true,
                                                    "7.2.1": true,
                                                    "7.2.2": true,
                                                    "7.2.3": true,
                                                    "7.2.4": true,
                                                    "7.4.0": true,
                                                    "7.4.1": true
                                                },
                                                "choices": [
                                                    "disable",
                                                    "enable"
                                                ],
                                                "type": "str"
                                            },
                                            "vrdst6": {
                                                "required": false,
                                                "revision": {
                                                    "6.2.0": false,
                                                    "6.2.2": false,
                                                    "6.2.6": false,
                                                    "6.2.7": false,
                                                    "6.2.8": true,
                                                    "6.2.9": true,
                                                    "6.2.10": true,
                                                    "6.2.11": true,
                                                    "6.2.12": true,
                                                    "6.4.1": false,
                                                    "6.4.3": false,
                                                    "6.4.4": false,
                                                    "6.4.5": true,
                                                    "6.4.6": true,
                                                    "6.4.7": true,
                                                    "6.4.8": true,
                                                    "6.4.9": true,
                                                    "6.4.10": true,
                                                    "6.4.11": true,
                                                    "6.4.12": true,
                                                    "6.4.13": true,
                                                    "7.0.0": true,
                                                    "7.0.1": true,
                                                    "7.0.2": true,
                                                    "7.0.3": true,
                                                    "7.0.4": true,
                                                    "7.0.5": true,
                                                    "7.0.6": true,
                                                    "7.0.7": true,
                                                    "7.0.8": true,
                                                    "7.0.9": true,
                                                    "7.2.0": true,
                                                    "7.2.1": true,
                                                    "7.2.2": true,
                                                    "7.2.3": true,
                                                    "7.2.4": true,
                                                    "7.4.0": true,
                                                    "7.4.1": true
                                                },
                                                "type": "str"
                                            },
                                            "vrgrp": {
                                                "required": false,
                                                "revision": {
                                                    "6.2.0": false,
                                                    "6.2.2": false,
                                                    "6.2.6": false,
                                                    "6.2.7": false,
                                                    "6.2.8": true,
                                                    "6.2.9": true,
                                                    "6.2.10": true,
                                                    "6.2.11": true,
                                                    "6.2.12": true,
                                                    "6.4.1": false,
                                                    "6.4.3": false,
                                                    "6.4.4": false,
                                                    "6.4.5": true,
                                                    "6.4.6": true,
                                                    "6.4.7": true,
                                                    "6.4.8": true,
                                                    "6.4.9": true,
                                                    "6.4.10": true,
                                                    "6.4.11": true,
                                                    "6.4.12": true,
                                                    "6.4.13": true,
                                                    "7.0.0": true,
                                                    "7.0.1": true,
                                                    "7.0.2": true,
                                                    "7.0.3": true,
                                                    "7.0.4": true,
                                                    "7.0.5": true,
                                                    "7.0.6": true,
                                                    "7.0.7": true,
                                                    "7.0.8": true,
                                                    "7.0.9": true,
                                                    "7.2.0": true,
                                                    "7.2.1": true,
                                                    "7.2.2": true,
                                                    "7.2.3": true,
                                                    "7.2.4": true,
                                                    "7.4.0": true,
                                                    "7.4.1": true
                                                },
                                                "type": "int"
                                            },
                                            "vrid": {
                                                "required": false,
                                                "revision": {
                                                    "6.2.0": false,
                                                    "6.2.2": false,
                                                    "6.2.6": false,
                                                    "6.2.7": false,
                                                    "6.2.8": true,
                                                    "6.2.9": true,
                                                    "6.2.10": true,
                                                    "6.2.11": true,
                                                    "6.2.12": true,
                                                    "6.4.1": false,
                                                    "6.4.3": false,
                                                    "6.4.4": false,
                                                    "6.4.5": true,
                                                    "6.4.6": true,
                                                    "6.4.7": true,
                                                    "6.4.8": true,
                                                    "6.4.9": true,
                                                    "6.4.10": true,
                                                    "6.4.11": true,
                                                    "6.4.12": true,
                                                    "6.4.13": true,
                                                    "7.0.0": true,
                                                    "7.0.1": true,
                                                    "7.0.2": true,
                                                    "7.0.3": true,
                                                    "7.0.4": true,
                                                    "7.0.5": true,
                                                    "7.0.6": true,
                                                    "7.0.7": true,
                                                    "7.0.8": true,
                                                    "7.0.9": true,
                                                    "7.2.0": true,
                                                    "7.2.1": true,
                                                    "7.2.2": true,
                                                    "7.2.3": true,
                                                    "7.2.4": true,
                                                    "7.4.0": true,
                                                    "7.4.1": true
                                                },
                                                "type": "int"
                                            },
                                            "vrip6": {
                                                "required": false,
                                                "revision": {
                                                    "6.2.0": false,
                                                    "6.2.2": false,
                                                    "6.2.6": false,
                                                    "6.2.7": false,
                                                    "6.2.8": true,
                                                    "6.2.9": true,
                                                    "6.2.10": true,
                                                    "6.2.11": true,
                                                    "6.2.12": true,
                                                    "6.4.1": false,
                                                    "6.4.3": false,
                                                    "6.4.4": false,
                                                    "6.4.5": true,
                                                    "6.4.6": true,
                                                    "6.4.7": true,
                                                    "6.4.8": true,
                                                    "6.4.9": true,
                                                    "6.4.10": true,
                                                    "6.4.11": true,
                                                    "6.4.12": true,
                                                    "6.4.13": true,
                                                    "7.0.0": true,
                                                    "7.0.1": true,
                                                    "7.0.2": true,
                                                    "7.0.3": true,
                                                    "7.0.4": true,
                                                    "7.0.5": true,
                                                    "7.0.6": true,
                                                    "7.0.7": true,
                                                    "7.0.8": true,
                                                    "7.0.9": true,
                                                    "7.2.0": true,
                                                    "7.2.1": true,
                                                    "7.2.2": true,
                                                    "7.2.3": true,
                                                    "7.2.4": true,
                                                    "7.4.0": true,
                                                    "7.4.1": true
                                                },
                                                "type": "str"
                                            }
                                        },
                                        "elements": "dict"
                                    },
                                    "cli-conn6-status": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": false,
                                            "6.2.9": false,
                                            "6.2.10": false,
                                            "6.2.11": false,
                                            "6.2.12": false,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.6": false,
                                            "6.4.7": false,
                                            "6.4.8": false,
                                            "6.4.9": false,
                                            "6.4.10": false,
                                            "6.4.11": false,
                                            "6.4.12": false,
                                            "6.4.13": false,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "ip6-prefix-mode": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": false,
                                            "6.2.9": false,
                                            "6.2.10": false,
                                            "6.2.11": false,
                                            "6.2.12": false,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.6": false,
                                            "6.4.7": false,
                                            "6.4.8": false,
                                            "6.4.9": false,
                                            "6.4.10": false,
                                            "6.4.11": false,
                                            "6.4.12": false,
                                            "6.4.13": false,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "dhcp6",
                                            "ra"
                                        ],
                                        "type": "str"
                                    },
                                    "ra-send-mtu": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": false,
                                            "6.2.9": false,
                                            "6.2.10": false,
                                            "6.2.11": false,
                                            "6.2.12": false,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "ip6-delegated-prefix-iaid": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": false,
                                            "6.2.9": false,
                                            "6.2.10": false,
                                            "6.2.11": false,
                                            "6.2.12": false,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.6": false,
                                            "6.4.7": false,
                                            "6.4.8": false,
                                            "6.4.9": false,
                                            "6.4.10": false,
                                            "6.4.11": false,
                                            "6.4.12": false,
                                            "6.4.13": false,
                                            "7.0.1": false,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "dhcp6-relay-source-interface": {
                                        "required": false,
                                        "revision": {
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "dhcp6-relay-interface-id": {
                                        "required": false,
                                        "revision": {
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "dhcp6-relay-source-ip": {
                                        "required": false,
                                        "revision": {
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    }
                                }
                            },
                            "secondary-IP": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "secondaryip": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "options": {
                                    "allowaccess": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "list",
                                        "choices": [
                                            "https",
                                            "ping",
                                            "ssh",
                                            "snmp",
                                            "http",
                                            "telnet",
                                            "fgfm",
                                            "auto-ipsec",
                                            "radius-acct",
                                            "probe-response",
                                            "capwap",
                                            "dnp",
                                            "ftm",
                                            "fabric",
                                            "speed-test"
                                        ],
                                        "elements": "str"
                                    },
                                    "detectprotocol": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": false,
                                            "7.2.2": false,
                                            "7.2.3": false,
                                            "7.2.4": false,
                                            "7.4.0": false,
                                            "7.4.1": false
                                        },
                                        "type": "list",
                                        "choices": [
                                            "ping",
                                            "tcp-echo",
                                            "udp-echo"
                                        ],
                                        "elements": "str"
                                    },
                                    "detectserver": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": false,
                                            "7.2.2": false,
                                            "7.2.3": false,
                                            "7.2.4": false,
                                            "7.4.0": false,
                                            "7.4.1": false
                                        },
                                        "type": "str"
                                    },
                                    "gwdetect": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": false,
                                            "7.2.2": false,
                                            "7.2.3": false,
                                            "7.2.4": false,
                                            "7.4.0": false,
                                            "7.4.1": false
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "ha-priority": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": false,
                                            "7.2.2": false,
                                            "7.2.3": false,
                                            "7.2.4": false,
                                            "7.4.0": false,
                                            "7.4.1": false
                                        },
                                        "type": "int"
                                    },
                                    "id": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "ip": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "ping-serv-status": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": false,
                                            "7.2.2": false,
                                            "7.2.3": false,
                                            "7.2.4": false,
                                            "7.4.0": false,
                                            "7.4.1": false
                                        },
                                        "type": "int"
                                    },
                                    "seq": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "secip-relay-ip": {
                                        "required": false,
                                        "revision": {
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    }
                                },
                                "elements": "dict"
                            },
                            "vlanid": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "dhcp-relay-interface-select-method": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": false,
                                    "7.0.2": false,
                                    "7.0.3": false,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "auto",
                                    "sdwan",
                                    "specify"
                                ],
                                "type": "str"
                            },
                            "vrrp": {
                                "required": false,
                                "revision": {
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "options": {
                                    "accept-mode": {
                                        "required": false,
                                        "revision": {
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "adv-interval": {
                                        "required": false,
                                        "revision": {
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "ignore-default-route": {
                                        "required": false,
                                        "revision": {
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "preempt": {
                                        "required": false,
                                        "revision": {
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "priority": {
                                        "required": false,
                                        "revision": {
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "proxy-arp": {
                                        "required": false,
                                        "revision": {
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "list",
                                        "options": {
                                            "id": {
                                                "required": false,
                                                "revision": {
                                                    "7.4.0": true,
                                                    "7.4.1": true
                                                },
                                                "type": "int"
                                            },
                                            "ip": {
                                                "required": false,
                                                "revision": {
                                                    "7.4.0": true,
                                                    "7.4.1": true
                                                },
                                                "type": "str"
                                            }
                                        },
                                        "elements": "dict"
                                    },
                                    "start-time": {
                                        "required": false,
                                        "revision": {
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "status": {
                                        "required": false,
                                        "revision": {
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "version": {
                                        "required": false,
                                        "revision": {
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "2",
                                            "3"
                                        ],
                                        "type": "str"
                                    },
                                    "vrdst": {
                                        "required": false,
                                        "revision": {
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "raw"
                                    },
                                    "vrdst-priority": {
                                        "required": false,
                                        "revision": {
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "vrgrp": {
                                        "required": false,
                                        "revision": {
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "vrid": {
                                        "required": false,
                                        "revision": {
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "vrip": {
                                        "required": false,
                                        "revision": {
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    }
                                },
                                "elements": "dict"
                            }
                        }
                    }
                },
                "elements": "dict"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "portal-message-override-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": false,
                    "6.2.3": false,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "radius-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": false,
                    "6.2.3": false,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "security": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": false,
                    "6.2.3": false,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "open",
                    "captive-portal",
                    "8021x"
                ],
                "type": "str"
            },
            "selected-usergroups": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": false,
                    "6.2.3": false,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "usergroup": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": false,
                    "6.2.3": false,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "vdom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vlanid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "dhcp-server": {
                "required": false,
                "type": "dict",
                "options": {
                    "auto-configuration": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "auto-managed-status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "conflicted-ip-timeout": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ddns-auth": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "tsig"
                        ],
                        "type": "str"
                    },
                    "ddns-key": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "ddns-keyname": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "str"
                    },
                    "ddns-server-ip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ddns-ttl": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ddns-update": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ddns-update-override": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ddns-zone": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "default-gateway": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "dhcp-settings-from-fortiipam": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "dns-server1": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "dns-server2": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "dns-server3": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "dns-server4": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "dns-service": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "default",
                            "specify",
                            "local"
                        ],
                        "type": "str"
                    },
                    "domain": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "enable": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "exclude-range": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "end-ip": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "start-ip": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "vci-match": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "vci-string": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            },
                            "lease-time": {
                                "required": false,
                                "revision": {
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "uci-match": {
                                "required": false,
                                "revision": {
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "uci-string": {
                                "required": false,
                                "revision": {
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            }
                        },
                        "elements": "dict"
                    },
                    "filename": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "forticlient-on-net-status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ip-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "range",
                            "usrgrp"
                        ],
                        "type": "str"
                    },
                    "ip-range": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "end-ip": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "start-ip": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "vci-match": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "vci-string": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            },
                            "lease-time": {
                                "required": false,
                                "revision": {
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "uci-match": {
                                "required": false,
                                "revision": {
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "uci-string": {
                                "required": false,
                                "revision": {
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            }
                        },
                        "elements": "dict"
                    },
                    "ipsec-lease-hold": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "lease-time": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "mac-acl-default-action": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "assign",
                            "block"
                        ],
                        "type": "str"
                    },
                    "netmask": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "next-server": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ntp-server1": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ntp-server2": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ntp-server3": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ntp-service": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "default",
                            "specify",
                            "local"
                        ],
                        "type": "str"
                    },
                    "option1": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "option2": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "option3": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "option4": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "option5": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "option6": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "options": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "code": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "ip": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            },
                            "type": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "hex",
                                    "string",
                                    "ip",
                                    "fqdn"
                                ],
                                "type": "str"
                            },
                            "value": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "vci-match": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "vci-string": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            },
                            "uci-match": {
                                "required": false,
                                "revision": {
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "uci-string": {
                                "required": false,
                                "revision": {
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            }
                        },
                        "elements": "dict"
                    },
                    "reserved-address": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "action": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "assign",
                                    "block",
                                    "reserved"
                                ],
                                "type": "str"
                            },
                            "circuit-id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "circuit-id-type": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "hex",
                                    "string"
                                ],
                                "type": "str"
                            },
                            "description": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "ip": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "mac": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "remote-id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "remote-id-type": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "hex",
                                    "string"
                                ],
                                "type": "str"
                            },
                            "type": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "mac",
                                    "option82"
                                ],
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "server-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "regular",
                            "ipsec"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "tftp-server": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "timezone": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "00",
                            "01",
                            "02",
                            "03",
                            "04",
                            "05",
                            "06",
                            "07",
                            "08",
                            "09",
                            "10",
                            "11",
                            "12",
                            "13",
                            "14",
                            "15",
                            "16",
                            "17",
                            "18",
                            "19",
                            "20",
                            "21",
                            "22",
                            "23",
                            "24",
                            "25",
                            "26",
                            "27",
                            "28",
                            "29",
                            "30",
                            "31",
                            "32",
                            "33",
                            "34",
                            "35",
                            "36",
                            "37",
                            "38",
                            "39",
                            "40",
                            "41",
                            "42",
                            "43",
                            "44",
                            "45",
                            "46",
                            "47",
                            "48",
                            "49",
                            "50",
                            "51",
                            "52",
                            "53",
                            "54",
                            "55",
                            "56",
                            "57",
                            "58",
                            "59",
                            "60",
                            "61",
                            "62",
                            "63",
                            "64",
                            "65",
                            "66",
                            "67",
                            "68",
                            "69",
                            "70",
                            "71",
                            "72",
                            "73",
                            "74",
                            "75",
                            "76",
                            "77",
                            "78",
                            "79",
                            "80",
                            "81",
                            "82",
                            "83",
                            "84",
                            "85",
                            "86",
                            "87"
                        ],
                        "type": "str"
                    },
                    "timezone-option": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "default",
                            "specify"
                        ],
                        "type": "str"
                    },
                    "vci-match": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "vci-string": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "wifi-ac-service": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "specify",
                            "local"
                        ],
                        "type": "str"
                    },
                    "wifi-ac1": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "wifi-ac2": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "wifi-ac3": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "wins-server1": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "wins-server2": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "relay-agent": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "shared-subnet": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "interface": {
                "required": false,
                "type": "dict",
                "options": {
                    "ac-name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "aggregate": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "algorithm": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "L2",
                            "L3",
                            "L4",
                            "LB",
                            "Source-MAC"
                        ],
                        "type": "str"
                    },
                    "alias": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "allowaccess": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "https",
                            "ping",
                            "ssh",
                            "snmp",
                            "http",
                            "telnet",
                            "fgfm",
                            "auto-ipsec",
                            "radius-acct",
                            "probe-response",
                            "capwap",
                            "dnp",
                            "ftm",
                            "fabric",
                            "speed-test"
                        ],
                        "elements": "str"
                    },
                    "ap-discover": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "arpforward": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "atm-protocol": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "ipoa"
                        ],
                        "type": "str"
                    },
                    "auth-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "auto",
                            "pap",
                            "chap",
                            "mschapv1",
                            "mschapv2"
                        ],
                        "type": "str"
                    },
                    "auto-auth-extension-device": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "bandwidth-measure-time": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "bfd": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "global",
                            "enable",
                            "disable"
                        ],
                        "type": "str"
                    },
                    "bfd-desired-min-tx": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "bfd-detect-mult": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "bfd-required-min-rx": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "broadcast-forticlient-discovery": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "broadcast-forward": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "captive-portal": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "cli-conn-status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "color": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ddns": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ddns-auth": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "tsig"
                        ],
                        "type": "str"
                    },
                    "ddns-domain": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ddns-key": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "ddns-keyname": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "str"
                    },
                    "ddns-password": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "ddns-server": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "dhs.org",
                            "dyndns.org",
                            "dyns.net",
                            "tzo.com",
                            "ods.org",
                            "vavic.com",
                            "now.net.cn",
                            "dipdns.net",
                            "easydns.com",
                            "genericDDNS"
                        ],
                        "type": "str"
                    },
                    "ddns-server-ip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ddns-sn": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ddns-ttl": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ddns-username": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ddns-zone": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "dedicated-to": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "management"
                        ],
                        "type": "str"
                    },
                    "defaultgw": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "description": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "detected-peer-mtu": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "detectprotocol": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "ping",
                            "tcp-echo",
                            "udp-echo"
                        ],
                        "elements": "str"
                    },
                    "detectserver": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "device-access-list": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "device-identification": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "device-identification-active-scan": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "device-netscan": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "device-user-identification": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "devindex": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "dhcp-client-identifier": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "dhcp-relay-agent-option": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "dhcp-relay-interface": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "dhcp-relay-interface-select-method": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "auto",
                            "sdwan",
                            "specify"
                        ],
                        "type": "str"
                    },
                    "dhcp-relay-ip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "dhcp-relay-service": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "dhcp-relay-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "regular",
                            "ipsec"
                        ],
                        "type": "str"
                    },
                    "dhcp-renew-time": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "disc-retry-timeout": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "disconnect-threshold": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "distance": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "dns-query": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "recursive",
                            "non-recursive"
                        ],
                        "type": "str"
                    },
                    "dns-server-override": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "drop-fragment": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "drop-overlapped-fragment": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "egress-cos": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "cos0",
                            "cos1",
                            "cos2",
                            "cos3",
                            "cos4",
                            "cos5",
                            "cos6",
                            "cos7"
                        ],
                        "type": "str"
                    },
                    "egress-shaping-profile": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "eip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "endpoint-compliance": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "estimated-downstream-bandwidth": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "estimated-upstream-bandwidth": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "explicit-ftp-proxy": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "explicit-web-proxy": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "external": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "fail-action-on-extender": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "soft-restart",
                            "hard-restart",
                            "reboot"
                        ],
                        "type": "str"
                    },
                    "fail-alert-interfaces": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "fail-alert-method": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "link-failed-signal",
                            "link-down"
                        ],
                        "type": "str"
                    },
                    "fail-detect": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "fail-detect-option": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "detectserver",
                            "link-down"
                        ],
                        "elements": "str"
                    },
                    "fdp": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "fortiheartbeat": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "fortilink": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "fortilink-backup-link": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "fortilink-neighbor-detect": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "lldp",
                            "fortilink"
                        ],
                        "type": "str"
                    },
                    "fortilink-split-interface": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "fortilink-stacking": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "forward-domain": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "forward-error-correction": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable",
                            "rs-fec",
                            "base-r-fec",
                            "fec-cl91",
                            "fec-cl74",
                            "rs-544",
                            "none",
                            "cl91-rs-fec",
                            "cl74-fc-fec",
                            "auto"
                        ],
                        "type": "str"
                    },
                    "fp-anomaly": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "drop_tcp_fin_noack",
                            "pass_winnuke",
                            "pass_tcpland",
                            "pass_udpland",
                            "pass_icmpland",
                            "pass_ipland",
                            "pass_iprr",
                            "pass_ipssrr",
                            "pass_iplsrr",
                            "pass_ipstream",
                            "pass_ipsecurity",
                            "pass_iptimestamp",
                            "pass_ipunknown_option",
                            "pass_ipunknown_prot",
                            "pass_icmp_frag",
                            "pass_tcp_no_flag",
                            "pass_tcp_fin_noack",
                            "drop_winnuke",
                            "drop_tcpland",
                            "drop_udpland",
                            "drop_icmpland",
                            "drop_ipland",
                            "drop_iprr",
                            "drop_ipssrr",
                            "drop_iplsrr",
                            "drop_ipstream",
                            "drop_ipsecurity",
                            "drop_iptimestamp",
                            "drop_ipunknown_option",
                            "drop_ipunknown_prot",
                            "drop_icmp_frag",
                            "drop_tcp_no_flag"
                        ],
                        "elements": "str"
                    },
                    "fp-disable": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "all",
                            "ipsec",
                            "none"
                        ],
                        "elements": "str"
                    },
                    "gateway-address": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "gi-gk": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "gwaddr": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "gwdetect": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ha-priority": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "icmp-accept-redirect": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "icmp-redirect": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "icmp-send-redirect": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ident-accept": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "idle-timeout": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "if-mdix": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "auto",
                            "normal",
                            "crossover"
                        ],
                        "type": "str"
                    },
                    "if-media": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "auto",
                            "copper",
                            "fiber"
                        ],
                        "type": "str"
                    },
                    "in-force-vlan-cos": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "inbandwidth": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ingress-cos": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "cos0",
                            "cos1",
                            "cos2",
                            "cos3",
                            "cos4",
                            "cos5",
                            "cos6",
                            "cos7"
                        ],
                        "type": "str"
                    },
                    "ingress-shaping-profile": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ingress-spillover-threshold": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "internal": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ip-managed-by-fortiipam": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable",
                            "inherit-global"
                        ],
                        "type": "str"
                    },
                    "ipmac": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ips-sniffer-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ipunnumbered": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ipv6": {
                        "required": false,
                        "type": "dict",
                        "options": {
                            "autoconf": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "dhcp6-client-options": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "choices": [
                                    "rapid",
                                    "iapd",
                                    "iana",
                                    "dns",
                                    "dnsname"
                                ],
                                "elements": "str"
                            },
                            "dhcp6-information-request": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "dhcp6-prefix-delegation": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "dhcp6-prefix-hint": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "dhcp6-prefix-hint-plt": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "dhcp6-prefix-hint-vlt": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "dhcp6-relay-ip": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "dhcp6-relay-service": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "dhcp6-relay-type": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "regular"
                                ],
                                "type": "str"
                            },
                            "icmp6-send-redirect": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "interface-identifier": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "ip6-address": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "ip6-allowaccess": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "choices": [
                                    "https",
                                    "ping",
                                    "ssh",
                                    "snmp",
                                    "http",
                                    "telnet",
                                    "fgfm",
                                    "capwap",
                                    "fabric"
                                ],
                                "elements": "str"
                            },
                            "ip6-default-life": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "ip6-delegated-prefix-list": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "options": {
                                    "autonomous-flag": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "onlink-flag": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "prefix-id": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "rdnss": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "raw"
                                    },
                                    "rdnss-service": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "delegated",
                                            "default",
                                            "specify"
                                        ],
                                        "type": "str"
                                    },
                                    "subnet": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "upstream-interface": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "delegated-prefix-iaid": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": false,
                                            "6.2.9": false,
                                            "6.2.10": false,
                                            "6.2.11": false,
                                            "6.2.12": false,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.6": false,
                                            "6.4.7": false,
                                            "6.4.8": false,
                                            "6.4.9": false,
                                            "6.4.10": false,
                                            "6.4.11": false,
                                            "6.4.12": false,
                                            "6.4.13": false,
                                            "7.0.1": false,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    }
                                },
                                "elements": "dict"
                            },
                            "ip6-dns-server-override": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "ip6-extra-addr": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "options": {
                                    "prefix": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    }
                                },
                                "elements": "dict"
                            },
                            "ip6-hop-limit": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "ip6-link-mtu": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "ip6-manage-flag": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "ip6-max-interval": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "ip6-min-interval": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "ip6-mode": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "static",
                                    "dhcp",
                                    "pppoe",
                                    "delegated"
                                ],
                                "type": "str"
                            },
                            "ip6-other-flag": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "ip6-prefix-list": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "options": {
                                    "autonomous-flag": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "dnssl": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "raw"
                                    },
                                    "onlink-flag": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "preferred-life-time": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "prefix": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "rdnss": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "raw"
                                    },
                                    "valid-life-time": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    }
                                },
                                "elements": "dict"
                            },
                            "ip6-reachable-time": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "ip6-retrans-time": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "ip6-send-adv": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "ip6-subnet": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "ip6-upstream-interface": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "nd-cert": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "nd-cga-modifier": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "nd-mode": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "basic",
                                    "SEND-compatible"
                                ],
                                "type": "str"
                            },
                            "nd-security-level": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "nd-timestamp-delta": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "nd-timestamp-fuzz": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "unique-autoconf-addr": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "vrip6_link_local": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "vrrp-virtual-mac6": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "vrrp6": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "options": {
                                    "accept-mode": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "adv-interval": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "preempt": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "priority": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "start-time": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "status": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "vrdst6": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "vrgrp": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "vrid": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "vrip6": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    }
                                },
                                "elements": "dict"
                            },
                            "cli-conn6-status": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "ip6-prefix-mode": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "dhcp6",
                                    "ra"
                                ],
                                "type": "str"
                            },
                            "ra-send-mtu": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "ip6-delegated-prefix-iaid": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "dhcp6-relay-source-interface": {
                                "required": false,
                                "revision": {
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "dhcp6-relay-interface-id": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "dhcp6-relay-source-ip": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        }
                    },
                    "l2forward": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "l2tp-client": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "lacp-ha-slave": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "lacp-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "static",
                            "passive",
                            "active"
                        ],
                        "type": "str"
                    },
                    "lacp-speed": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "slow",
                            "fast"
                        ],
                        "type": "str"
                    },
                    "lcp-echo-interval": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "lcp-max-echo-fails": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "link-up-delay": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "listen-forticlient-connection": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "lldp-network-policy": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "lldp-reception": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable",
                            "vdom"
                        ],
                        "type": "str"
                    },
                    "lldp-transmission": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "enable",
                            "disable",
                            "vdom"
                        ],
                        "type": "str"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "macaddr": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "managed-subnetwork-size": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "256",
                            "512",
                            "1024",
                            "2048",
                            "4096",
                            "8192",
                            "16384",
                            "32768",
                            "65536",
                            "32",
                            "64",
                            "128"
                        ],
                        "type": "str"
                    },
                    "management-ip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "max-egress-burst-rate": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "max-egress-rate": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "measured-downstream-bandwidth": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "measured-upstream-bandwidth": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "mediatype": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "serdes-sfp",
                            "sgmii-sfp",
                            "cfp2-sr10",
                            "cfp2-lr4",
                            "serdes-copper-sfp",
                            "sr",
                            "cr",
                            "lr",
                            "qsfp28-sr4",
                            "qsfp28-lr4",
                            "qsfp28-cr4",
                            "sr4",
                            "cr4",
                            "lr4",
                            "none",
                            "gmii",
                            "sgmii",
                            "sr2",
                            "lr2",
                            "cr2",
                            "sr8",
                            "lr8",
                            "cr8"
                        ],
                        "type": "str"
                    },
                    "member": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "min-links": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "min-links-down": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "operational",
                            "administrative"
                        ],
                        "type": "str"
                    },
                    "mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "static",
                            "dhcp",
                            "pppoe",
                            "pppoa",
                            "ipoa",
                            "eoa"
                        ],
                        "type": "str"
                    },
                    "monitor-bandwidth": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "mtu": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "mtu-override": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "mux-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "llc-encaps",
                            "vc-encaps"
                        ],
                        "type": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ndiscforward": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "netbios-forward": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "netflow-sampler": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "tx",
                            "rx",
                            "both"
                        ],
                        "type": "str"
                    },
                    "np-qos-profile": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "npu-fastpath": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "nst": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "out-force-vlan-cos": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "outbandwidth": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "padt-retry-timeout": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "password": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "peer-interface": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "phy-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "auto",
                            "adsl",
                            "vdsl",
                            "adsl-auto",
                            "vdsl2",
                            "adsl2+",
                            "adsl2",
                            "g.dmt",
                            "t1.413",
                            "g.lite"
                        ],
                        "type": "str"
                    },
                    "ping-serv-status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "poe": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "polling-interval": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "pppoe-unnumbered-negotiate": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "pptp-auth-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "auto",
                            "pap",
                            "chap",
                            "mschapv1",
                            "mschapv2"
                        ],
                        "type": "str"
                    },
                    "pptp-client": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "pptp-password": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "pptp-server-ip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "pptp-timeout": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "pptp-user": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "preserve-session-route": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "priority": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "priority-override": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "proxy-captive-portal": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "redundant-interface": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "remote-ip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "replacemsg-override-group": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "retransmission": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ring-rx": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ring-tx": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "role": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "lan",
                            "wan",
                            "dmz",
                            "undefined"
                        ],
                        "type": "str"
                    },
                    "sample-direction": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "rx",
                            "tx",
                            "both"
                        ],
                        "type": "str"
                    },
                    "sample-rate": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "scan-botnet-connections": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "block",
                            "monitor"
                        ],
                        "type": "str"
                    },
                    "secondary-IP": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "secondaryip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "allowaccess": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "choices": [
                                    "https",
                                    "ping",
                                    "ssh",
                                    "snmp",
                                    "http",
                                    "telnet",
                                    "fgfm",
                                    "auto-ipsec",
                                    "radius-acct",
                                    "probe-response",
                                    "capwap",
                                    "dnp",
                                    "ftm",
                                    "fabric",
                                    "speed-test"
                                ],
                                "elements": "str"
                            },
                            "detectprotocol": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": false,
                                    "7.2.2": false,
                                    "7.2.3": false,
                                    "7.2.4": false,
                                    "7.4.0": false,
                                    "7.4.1": false
                                },
                                "type": "list",
                                "choices": [
                                    "ping",
                                    "tcp-echo",
                                    "udp-echo"
                                ],
                                "elements": "str"
                            },
                            "detectserver": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": false,
                                    "7.2.2": false,
                                    "7.2.3": false,
                                    "7.2.4": false,
                                    "7.4.0": false,
                                    "7.4.1": false
                                },
                                "type": "str"
                            },
                            "gwdetect": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": false,
                                    "7.2.2": false,
                                    "7.2.3": false,
                                    "7.2.4": false,
                                    "7.4.0": false,
                                    "7.4.1": false
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "ha-priority": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": false,
                                    "7.2.2": false,
                                    "7.2.3": false,
                                    "7.2.4": false,
                                    "7.4.0": false,
                                    "7.4.1": false
                                },
                                "type": "int"
                            },
                            "id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "ip": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "ping-serv-status": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": false,
                                    "7.2.2": false,
                                    "7.2.3": false,
                                    "7.2.4": false,
                                    "7.4.0": false,
                                    "7.4.1": false
                                },
                                "type": "int"
                            },
                            "seq": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "secip-relay-ip": {
                                "required": false,
                                "revision": {
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "security-8021x-dynamic-vlan-id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "security-8021x-master": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "security-8021x-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "default",
                            "dynamic-vlan",
                            "fallback",
                            "slave"
                        ],
                        "type": "str"
                    },
                    "security-exempt-list": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "security-external-logout": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "security-external-web": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "security-groups": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "security-mac-auth-bypass": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable",
                            "mac-auth-only"
                        ],
                        "type": "str"
                    },
                    "security-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "captive-portal",
                            "802.1X"
                        ],
                        "type": "str"
                    },
                    "security-redirect-url": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "service-name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sflow-sampler": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "speed": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "auto",
                            "10full",
                            "10half",
                            "100full",
                            "100half",
                            "1000full",
                            "1000half",
                            "10000full",
                            "1000auto",
                            "10000auto",
                            "40000full",
                            "100Gfull",
                            "25000full",
                            "40000auto",
                            "25000auto",
                            "100Gauto",
                            "400Gfull",
                            "400Gauto",
                            "50000full",
                            "2500auto",
                            "5000auto",
                            "50000auto",
                            "200Gfull",
                            "200Gauto",
                            "100auto"
                        ],
                        "type": "str"
                    },
                    "spillover-threshold": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "src-check": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "down",
                            "up"
                        ],
                        "type": "str"
                    },
                    "stp": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "stp-ha-slave": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable",
                            "priority-adjust"
                        ],
                        "type": "str"
                    },
                    "stpforward": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "stpforward-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "rpl-all-ext-id",
                            "rpl-bridge-ext-id",
                            "rpl-nothing"
                        ],
                        "type": "str"
                    },
                    "strip-priority-vlan-tag": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "subst": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "substitute-dst-mac": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "swc-first-create": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "swc-vlan": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "switch": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "switch-controller-access-vlan": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "switch-controller-arp-inspection": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "switch-controller-auth": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "radius",
                            "usergroup"
                        ],
                        "type": "str"
                    },
                    "switch-controller-dhcp-snooping": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "switch-controller-dhcp-snooping-option82": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "switch-controller-dhcp-snooping-verify-mac": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "switch-controller-feature": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "default-vlan",
                            "quarantine",
                            "sniffer",
                            "voice",
                            "camera",
                            "rspan",
                            "video",
                            "nac",
                            "nac-segment"
                        ],
                        "type": "str"
                    },
                    "switch-controller-igmp-snooping": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "switch-controller-igmp-snooping-fast-leave": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "switch-controller-igmp-snooping-proxy": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "switch-controller-iot-scanning": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "switch-controller-learning-limit": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "switch-controller-mgmt-vlan": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "switch-controller-nac": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "switch-controller-radius-server": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "switch-controller-rspan-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "switch-controller-source-ip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "outbound",
                            "fixed"
                        ],
                        "type": "str"
                    },
                    "switch-controller-traffic-policy": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "tc-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ptm",
                            "atm"
                        ],
                        "type": "str"
                    },
                    "tcp-mss": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "trunk": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "trust-ip-1": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "trust-ip-2": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "trust-ip-3": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "trust-ip6-1": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "trust-ip6-2": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "trust-ip6-3": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "physical",
                            "vlan",
                            "aggregate",
                            "redundant",
                            "tunnel",
                            "wireless",
                            "vdom-link",
                            "loopback",
                            "switch",
                            "hard-switch",
                            "hdlc",
                            "vap-switch",
                            "wl-mesh",
                            "fortilink",
                            "switch-vlan",
                            "fctrl-trunk",
                            "tdm",
                            "fext-wan",
                            "vxlan",
                            "emac-vlan",
                            "geneve",
                            "ssl",
                            "lan-extension"
                        ],
                        "type": "str"
                    },
                    "username": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vci": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "vectoring": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "vindex": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "vlan-protocol": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "8021q",
                            "8021ad"
                        ],
                        "type": "str"
                    },
                    "vlanforward": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "vlanid": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "vpi": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "vrf": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "vrrp": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "accept-mode": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "adv-interval": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "ignore-default-route": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "preempt": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "priority": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "start-time": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "status": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "version": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "2",
                                    "3"
                                ],
                                "type": "str"
                            },
                            "vrdst": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            },
                            "vrdst-priority": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "vrgrp": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "vrid": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "vrip": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "proxy-arp": {
                                "required": false,
                                "revision": {
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "options": {
                                    "id": {
                                        "required": false,
                                        "revision": {
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "ip": {
                                        "required": false,
                                        "revision": {
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    }
                                },
                                "elements": "dict"
                            }
                        },
                        "elements": "dict"
                    },
                    "vrrp-virtual-mac": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "wccp": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "weight": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "wifi-5g-threshold": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "wifi-acl": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "deny",
                            "allow"
                        ],
                        "type": "str"
                    },
                    "wifi-ap-band": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "any",
                            "5g-preferred",
                            "5g-only"
                        ],
                        "type": "str"
                    },
                    "wifi-auth": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "PSK",
                            "RADIUS",
                            "radius",
                            "usergroup"
                        ],
                        "type": "str"
                    },
                    "wifi-auto-connect": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "wifi-auto-save": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "wifi-broadcast-ssid": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "wifi-encrypt": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "TKIP",
                            "AES"
                        ],
                        "type": "str"
                    },
                    "wifi-fragment-threshold": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "wifi-key": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "wifi-keyindex": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "int"
                    },
                    "wifi-mac-filter": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "wifi-passphrase": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "wifi-radius-server": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "wifi-rts-threshold": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "wifi-security": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "None",
                            "WEP64",
                            "wep64",
                            "WEP128",
                            "wep128",
                            "WPA_PSK",
                            "WPA_RADIUS",
                            "WPA",
                            "WPA2",
                            "WPA2_AUTO",
                            "open",
                            "wpa-personal",
                            "wpa-enterprise",
                            "wpa-only-personal",
                            "wpa-only-enterprise",
                            "wpa2-only-personal",
                            "wpa2-only-enterprise"
                        ],
                        "type": "str"
                    },
                    "wifi-ssid": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "wifi-usergroup": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "wins-ip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "dhcp-relay-request-all-server": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "stp-ha-secondary": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable",
                            "priority-adjust"
                        ],
                        "type": "str"
                    },
                    "switch-controller-dynamic": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "auth-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "auth-portal-addr": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "dhcp-classless-route-addition": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "dhcp-relay-link-selection": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "dns-server-protocol": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "cleartext",
                            "dot",
                            "doh"
                        ],
                        "elements": "str"
                    },
                    "eap-ca-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "eap-identity": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "eap-method": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "tls",
                            "peap"
                        ],
                        "type": "str"
                    },
                    "eap-password": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "eap-supplicant": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "eap-user-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ike-saml-server": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "lacp-ha-secondary": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "pvc-atm-qos": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "cbr",
                            "rt-vbr",
                            "nrt-vbr"
                        ],
                        "type": "str"
                    },
                    "pvc-chan": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "pvc-crc": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "pvc-pcr": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "pvc-scr": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "pvc-vlan-id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "pvc-vlan-rx-id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "pvc-vlan-rx-op": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "pass-through",
                            "replace",
                            "remove"
                        ],
                        "type": "str"
                    },
                    "pvc-vlan-tx-id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "pvc-vlan-tx-op": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "pass-through",
                            "replace",
                            "remove"
                        ],
                        "type": "str"
                    },
                    "reachable-time": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "select-profile-30a-35b": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "30A",
                            "35B"
                        ],
                        "type": "str"
                    },
                    "sfp-dsl": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "sfp-dsl-adsl-fallback": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "sfp-dsl-autodetect": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "sfp-dsl-mac": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sw-algorithm": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "l2",
                            "l3",
                            "eh"
                        ],
                        "type": "str"
                    },
                    "system-id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "system-id-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "auto",
                            "user"
                        ],
                        "type": "str"
                    },
                    "vlan-id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "vlan-op-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "tag",
                            "untag",
                            "passthrough"
                        ],
                        "type": "str"
                    },
                    "generic-receive-offload": {
                        "required": false,
                        "revision": {
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "interconnect-profile": {
                        "required": false,
                        "revision": {
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "default",
                            "profile1",
                            "profile2"
                        ],
                        "type": "str"
                    },
                    "large-receive-offload": {
                        "required": false,
                        "revision": {
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "aggregate-type": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "physical",
                            "vxlan"
                        ],
                        "type": "str"
                    },
                    "switch-controller-netflow-collect": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "wifi-dns-server1": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "wifi-dns-server2": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "wifi-gateway": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "default-purdue-level": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "1",
                            "2",
                            "3",
                            "4",
                            "5",
                            "1.5",
                            "2.5",
                            "3.5",
                            "5.5"
                        ],
                        "type": "str"
                    },
                    "dhcp-broadcast-flag": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "dhcp-smart-relay": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "switch-controller-offloading": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "switch-controller-offloading-gw": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "switch-controller-offloading-ip": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "dhcp-relay-circuit-id": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "dhcp-relay-source-ip": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "switch-controller-offload": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "switch-controller-offload-gw": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "switch-controller-offload-ip": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                }
            }
        }
    },
    "fsp_vlan_dhcpserver": {
        "stated": false,
        "options": {
            "auto-configuration": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "conflicted-ip-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ddns-auth": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "tsig"
                ],
                "type": "str"
            },
            "ddns-key": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "ddns-keyname": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "str"
            },
            "ddns-server-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ddns-ttl": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ddns-update": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ddns-update-override": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ddns-zone": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "default-gateway": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dns-server1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dns-server2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dns-server3": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dns-service": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "default",
                    "specify",
                    "local"
                ],
                "type": "str"
            },
            "domain": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "enable": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "exclude-range": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "end-ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "start-ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vci-match": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "vci-string": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "lease-time": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "uci-match": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "uci-string": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    }
                },
                "elements": "dict"
            },
            "filename": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "forticlient-on-net-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "interface": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": false,
                    "6.2.3": false,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "ip-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "range",
                    "usrgrp"
                ],
                "type": "str"
            },
            "ip-range": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "end-ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "start-ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vci-match": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "vci-string": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "lease-time": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "uci-match": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "uci-string": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    }
                },
                "elements": "dict"
            },
            "ipsec-lease-hold": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "lease-time": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mac-acl-default-action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "assign",
                    "block"
                ],
                "type": "str"
            },
            "netmask": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "next-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ntp-server1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ntp-server2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ntp-server3": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ntp-service": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "default",
                    "specify",
                    "local"
                ],
                "type": "str"
            },
            "option1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "option2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "option3": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "option4": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "option5": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "option6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "options": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "code": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "hex",
                            "string",
                            "ip",
                            "fqdn"
                        ],
                        "type": "str"
                    },
                    "value": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vci-match": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "vci-string": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "uci-match": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "uci-string": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    }
                },
                "elements": "dict"
            },
            "reserved-address": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "assign",
                            "block",
                            "reserved"
                        ],
                        "type": "str"
                    },
                    "circuit-id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "circuit-id-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "hex",
                            "string"
                        ],
                        "type": "str"
                    },
                    "description": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "mac": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "remote-id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "remote-id-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "hex",
                            "string"
                        ],
                        "type": "str"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "mac",
                            "option82"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "server-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "regular",
                    "ipsec"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tftp-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "timezone": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "00",
                    "01",
                    "02",
                    "03",
                    "04",
                    "05",
                    "06",
                    "07",
                    "08",
                    "09",
                    "10",
                    "11",
                    "12",
                    "13",
                    "14",
                    "15",
                    "16",
                    "17",
                    "18",
                    "19",
                    "20",
                    "21",
                    "22",
                    "23",
                    "24",
                    "25",
                    "26",
                    "27",
                    "28",
                    "29",
                    "30",
                    "31",
                    "32",
                    "33",
                    "34",
                    "35",
                    "36",
                    "37",
                    "38",
                    "39",
                    "40",
                    "41",
                    "42",
                    "43",
                    "44",
                    "45",
                    "46",
                    "47",
                    "48",
                    "49",
                    "50",
                    "51",
                    "52",
                    "53",
                    "54",
                    "55",
                    "56",
                    "57",
                    "58",
                    "59",
                    "60",
                    "61",
                    "62",
                    "63",
                    "64",
                    "65",
                    "66",
                    "67",
                    "68",
                    "69",
                    "70",
                    "71",
                    "72",
                    "73",
                    "74",
                    "75",
                    "76",
                    "77",
                    "78",
                    "79",
                    "80",
                    "81",
                    "82",
                    "83",
                    "84",
                    "85",
                    "86",
                    "87"
                ],
                "type": "str"
            },
            "timezone-option": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "default",
                    "specify"
                ],
                "type": "str"
            },
            "vci-match": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "vci-string": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "wifi-ac1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "wifi-ac2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "wifi-ac3": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "wins-server1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "wins-server2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dns-server4": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "wifi-ac-service": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "specify",
                    "local"
                ],
                "type": "str"
            },
            "auto-managed-status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dhcp-settings-from-fortiipam": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "relay-agent": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "shared-subnet": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "fsp_vlan_dhcpserver_excluderange": {
        "stated": true,
        "options": {
            "end-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "start-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vci-match": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "vci-string": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "lease-time": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "uci-match": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "uci-string": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "fsp_vlan_dhcpserver_iprange": {
        "stated": true,
        "options": {
            "end-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "start-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vci-match": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "vci-string": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "lease-time": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "uci-match": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "uci-string": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "fsp_vlan_dhcpserver_options": {
        "stated": true,
        "options": {
            "code": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "hex",
                    "string",
                    "ip",
                    "fqdn"
                ],
                "type": "str"
            },
            "value": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vci-match": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "vci-string": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "uci-match": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "uci-string": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "fsp_vlan_dhcpserver_reservedaddress": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "assign",
                    "block",
                    "reserved"
                ],
                "type": "str"
            },
            "circuit-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "circuit-id-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "hex",
                    "string"
                ],
                "type": "str"
            },
            "description": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "mac": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "remote-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "remote-id-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "hex",
                    "string"
                ],
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "mac",
                    "option82"
                ],
                "type": "str"
            }
        }
    },
    "fsp_vlan_dynamicmapping": {
        "stated": true,
        "options": {
            "_dhcp-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "_scope": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "dhcp-server": {
                "required": false,
                "type": "dict",
                "options": {
                    "auto-configuration": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "auto-managed-status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "conflicted-ip-timeout": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ddns-auth": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "tsig"
                        ],
                        "type": "str"
                    },
                    "ddns-key": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "ddns-keyname": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "str"
                    },
                    "ddns-server-ip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ddns-ttl": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ddns-update": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ddns-update-override": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ddns-zone": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "default-gateway": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "dhcp-settings-from-fortiipam": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "dns-server1": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "dns-server2": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "dns-server3": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "dns-server4": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "dns-service": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "default",
                            "specify",
                            "local"
                        ],
                        "type": "str"
                    },
                    "domain": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "enable": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "exclude-range": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "end-ip": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "start-ip": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "vci-match": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "vci-string": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            },
                            "lease-time": {
                                "required": false,
                                "revision": {
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "uci-match": {
                                "required": false,
                                "revision": {
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "uci-string": {
                                "required": false,
                                "revision": {
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            }
                        },
                        "elements": "dict"
                    },
                    "filename": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "forticlient-on-net-status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ip-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "range",
                            "usrgrp"
                        ],
                        "type": "str"
                    },
                    "ip-range": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "end-ip": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "start-ip": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "vci-match": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "vci-string": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            },
                            "lease-time": {
                                "required": false,
                                "revision": {
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "uci-match": {
                                "required": false,
                                "revision": {
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "uci-string": {
                                "required": false,
                                "revision": {
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            }
                        },
                        "elements": "dict"
                    },
                    "ipsec-lease-hold": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "lease-time": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "mac-acl-default-action": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "assign",
                            "block"
                        ],
                        "type": "str"
                    },
                    "netmask": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "next-server": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ntp-server1": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ntp-server2": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ntp-server3": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ntp-service": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "default",
                            "specify",
                            "local"
                        ],
                        "type": "str"
                    },
                    "option1": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "option2": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "option3": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "option4": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "option5": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "option6": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "options": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "code": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "ip": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            },
                            "type": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "hex",
                                    "string",
                                    "ip",
                                    "fqdn"
                                ],
                                "type": "str"
                            },
                            "value": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "vci-match": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "vci-string": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            },
                            "uci-match": {
                                "required": false,
                                "revision": {
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "uci-string": {
                                "required": false,
                                "revision": {
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            }
                        },
                        "elements": "dict"
                    },
                    "reserved-address": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "action": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "assign",
                                    "block",
                                    "reserved"
                                ],
                                "type": "str"
                            },
                            "circuit-id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "circuit-id-type": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "hex",
                                    "string"
                                ],
                                "type": "str"
                            },
                            "description": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "ip": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "mac": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "remote-id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "remote-id-type": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "hex",
                                    "string"
                                ],
                                "type": "str"
                            },
                            "type": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "mac",
                                    "option82"
                                ],
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "server-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "regular",
                            "ipsec"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "tftp-server": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "timezone": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "00",
                            "01",
                            "02",
                            "03",
                            "04",
                            "05",
                            "06",
                            "07",
                            "08",
                            "09",
                            "10",
                            "11",
                            "12",
                            "13",
                            "14",
                            "15",
                            "16",
                            "17",
                            "18",
                            "19",
                            "20",
                            "21",
                            "22",
                            "23",
                            "24",
                            "25",
                            "26",
                            "27",
                            "28",
                            "29",
                            "30",
                            "31",
                            "32",
                            "33",
                            "34",
                            "35",
                            "36",
                            "37",
                            "38",
                            "39",
                            "40",
                            "41",
                            "42",
                            "43",
                            "44",
                            "45",
                            "46",
                            "47",
                            "48",
                            "49",
                            "50",
                            "51",
                            "52",
                            "53",
                            "54",
                            "55",
                            "56",
                            "57",
                            "58",
                            "59",
                            "60",
                            "61",
                            "62",
                            "63",
                            "64",
                            "65",
                            "66",
                            "67",
                            "68",
                            "69",
                            "70",
                            "71",
                            "72",
                            "73",
                            "74",
                            "75",
                            "76",
                            "77",
                            "78",
                            "79",
                            "80",
                            "81",
                            "82",
                            "83",
                            "84",
                            "85",
                            "86",
                            "87"
                        ],
                        "type": "str"
                    },
                    "timezone-option": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "default",
                            "specify"
                        ],
                        "type": "str"
                    },
                    "vci-match": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "vci-string": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "wifi-ac-service": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "specify",
                            "local"
                        ],
                        "type": "str"
                    },
                    "wifi-ac1": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "wifi-ac2": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "wifi-ac3": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "wins-server1": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "wins-server2": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "relay-agent": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "shared-subnet": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "interface": {
                "required": false,
                "type": "dict",
                "options": {
                    "dhcp-relay-agent-option": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "dhcp-relay-ip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "dhcp-relay-service": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "dhcp-relay-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "regular",
                            "ipsec"
                        ],
                        "type": "str"
                    },
                    "ip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ipv6": {
                        "required": false,
                        "type": "dict",
                        "options": {
                            "autoconf": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "dhcp6-client-options": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "choices": [
                                    "rapid",
                                    "iapd",
                                    "iana",
                                    "dns",
                                    "dnsname"
                                ],
                                "elements": "str"
                            },
                            "dhcp6-information-request": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "dhcp6-prefix-delegation": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "dhcp6-prefix-hint": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "dhcp6-prefix-hint-plt": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "dhcp6-prefix-hint-vlt": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "dhcp6-relay-ip": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "dhcp6-relay-service": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "dhcp6-relay-type": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "regular"
                                ],
                                "type": "str"
                            },
                            "icmp6-send-redirect": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "interface-identifier": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "ip6-address": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "ip6-allowaccess": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "choices": [
                                    "https",
                                    "ping",
                                    "ssh",
                                    "snmp",
                                    "http",
                                    "telnet",
                                    "fgfm",
                                    "capwap",
                                    "fabric"
                                ],
                                "elements": "str"
                            },
                            "ip6-default-life": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "ip6-delegated-prefix-list": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "options": {
                                    "autonomous-flag": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "onlink-flag": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "prefix-id": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "rdnss": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "raw"
                                    },
                                    "rdnss-service": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "delegated",
                                            "default",
                                            "specify"
                                        ],
                                        "type": "str"
                                    },
                                    "subnet": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "upstream-interface": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "delegated-prefix-iaid": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": false,
                                            "6.2.9": false,
                                            "6.2.10": false,
                                            "6.2.11": false,
                                            "6.2.12": false,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.6": false,
                                            "6.4.7": false,
                                            "6.4.8": false,
                                            "6.4.9": false,
                                            "6.4.10": false,
                                            "6.4.11": false,
                                            "6.4.12": false,
                                            "6.4.13": false,
                                            "7.0.1": false,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    }
                                },
                                "elements": "dict"
                            },
                            "ip6-dns-server-override": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "ip6-extra-addr": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "options": {
                                    "prefix": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    }
                                },
                                "elements": "dict"
                            },
                            "ip6-hop-limit": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "ip6-link-mtu": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "ip6-manage-flag": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "ip6-max-interval": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "ip6-min-interval": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "ip6-mode": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "static",
                                    "dhcp",
                                    "pppoe",
                                    "delegated"
                                ],
                                "type": "str"
                            },
                            "ip6-other-flag": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "ip6-prefix-list": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "options": {
                                    "autonomous-flag": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "dnssl": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "raw"
                                    },
                                    "onlink-flag": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "preferred-life-time": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "prefix": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "rdnss": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "raw"
                                    },
                                    "valid-life-time": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    }
                                },
                                "elements": "dict"
                            },
                            "ip6-reachable-time": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "ip6-retrans-time": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "ip6-send-adv": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "ip6-subnet": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "ip6-upstream-interface": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "nd-cert": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "nd-cga-modifier": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "nd-mode": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "basic",
                                    "SEND-compatible"
                                ],
                                "type": "str"
                            },
                            "nd-security-level": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "nd-timestamp-delta": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "nd-timestamp-fuzz": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "unique-autoconf-addr": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "vrip6_link_local": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "vrrp-virtual-mac6": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "vrrp6": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "options": {
                                    "accept-mode": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "adv-interval": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "preempt": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "priority": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "start-time": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "status": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "disable",
                                            "enable"
                                        ],
                                        "type": "str"
                                    },
                                    "vrdst6": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "vrgrp": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "vrid": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "vrip6": {
                                        "required": false,
                                        "revision": {
                                            "6.2.0": false,
                                            "6.2.2": false,
                                            "6.2.6": false,
                                            "6.2.7": false,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.1": false,
                                            "6.4.3": false,
                                            "6.4.4": false,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    }
                                },
                                "elements": "dict"
                            },
                            "cli-conn6-status": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "ip6-prefix-mode": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "dhcp6",
                                    "ra"
                                ],
                                "type": "str"
                            },
                            "ra-send-mtu": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "ip6-delegated-prefix-iaid": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "dhcp6-relay-source-interface": {
                                "required": false,
                                "revision": {
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "dhcp6-relay-interface-id": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "dhcp6-relay-source-ip": {
                                "required": false,
                                "revision": {
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        }
                    },
                    "secondary-IP": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "secondaryip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "allowaccess": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "choices": [
                                    "https",
                                    "ping",
                                    "ssh",
                                    "snmp",
                                    "http",
                                    "telnet",
                                    "fgfm",
                                    "auto-ipsec",
                                    "radius-acct",
                                    "probe-response",
                                    "capwap",
                                    "dnp",
                                    "ftm",
                                    "fabric",
                                    "speed-test"
                                ],
                                "elements": "str"
                            },
                            "detectprotocol": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": false,
                                    "7.2.2": false,
                                    "7.2.3": false,
                                    "7.2.4": false,
                                    "7.4.0": false,
                                    "7.4.1": false
                                },
                                "type": "list",
                                "choices": [
                                    "ping",
                                    "tcp-echo",
                                    "udp-echo"
                                ],
                                "elements": "str"
                            },
                            "detectserver": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": false,
                                    "7.2.2": false,
                                    "7.2.3": false,
                                    "7.2.4": false,
                                    "7.4.0": false,
                                    "7.4.1": false
                                },
                                "type": "str"
                            },
                            "gwdetect": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": false,
                                    "7.2.2": false,
                                    "7.2.3": false,
                                    "7.2.4": false,
                                    "7.4.0": false,
                                    "7.4.1": false
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "ha-priority": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": false,
                                    "7.2.2": false,
                                    "7.2.3": false,
                                    "7.2.4": false,
                                    "7.4.0": false,
                                    "7.4.1": false
                                },
                                "type": "int"
                            },
                            "id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "ip": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "ping-serv-status": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": false,
                                    "7.2.2": false,
                                    "7.2.3": false,
                                    "7.2.4": false,
                                    "7.4.0": false,
                                    "7.4.1": false
                                },
                                "type": "int"
                            },
                            "seq": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "secip-relay-ip": {
                                "required": false,
                                "revision": {
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "vlanid": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "dhcp-relay-interface-select-method": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "auto",
                            "sdwan",
                            "specify"
                        ],
                        "type": "str"
                    },
                    "vrrp": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "accept-mode": {
                                "required": false,
                                "revision": {
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "adv-interval": {
                                "required": false,
                                "revision": {
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "ignore-default-route": {
                                "required": false,
                                "revision": {
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "preempt": {
                                "required": false,
                                "revision": {
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "priority": {
                                "required": false,
                                "revision": {
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "proxy-arp": {
                                "required": false,
                                "revision": {
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "options": {
                                    "id": {
                                        "required": false,
                                        "revision": {
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "ip": {
                                        "required": false,
                                        "revision": {
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    }
                                },
                                "elements": "dict"
                            },
                            "start-time": {
                                "required": false,
                                "revision": {
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "status": {
                                "required": false,
                                "revision": {
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "version": {
                                "required": false,
                                "revision": {
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "2",
                                    "3"
                                ],
                                "type": "str"
                            },
                            "vrdst": {
                                "required": false,
                                "revision": {
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            },
                            "vrdst-priority": {
                                "required": false,
                                "revision": {
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "vrgrp": {
                                "required": false,
                                "revision": {
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "vrid": {
                                "required": false,
                                "revision": {
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "vrip": {
                                "required": false,
                                "revision": {
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    }
                }
            }
        }
    },
    "fsp_vlan_dynamicmapping_dhcpserver": {
        "stated": false,
        "options": {
            "auto-configuration": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "conflicted-ip-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "ddns-auth": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "tsig"
                ],
                "type": "str"
            },
            "ddns-key": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "no_log": true,
                "type": "raw"
            },
            "ddns-keyname": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "no_log": true,
                "type": "str"
            },
            "ddns-server-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "ddns-ttl": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "ddns-update": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ddns-update-override": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ddns-zone": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "default-gateway": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "dns-server1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "dns-server2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "dns-server3": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "dns-service": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "default",
                    "specify",
                    "local"
                ],
                "type": "str"
            },
            "domain": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "enable": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "exclude-range": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "end-ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "start-ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "vci-match": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "vci-string": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "raw"
                    },
                    "lease-time": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "uci-match": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "uci-string": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "raw"
                    }
                },
                "elements": "dict"
            },
            "filename": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "forticlient-on-net-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "interface": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": false,
                    "6.2.3": false,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "ip-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "range",
                    "usrgrp"
                ],
                "type": "str"
            },
            "ip-range": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "end-ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "start-ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "vci-match": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "vci-string": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "raw"
                    },
                    "lease-time": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "uci-match": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "uci-string": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "raw"
                    }
                },
                "elements": "dict"
            },
            "ipsec-lease-hold": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "lease-time": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "mac-acl-default-action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "assign",
                    "block"
                ],
                "type": "str"
            },
            "netmask": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "next-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "ntp-server1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "ntp-server2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "ntp-server3": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "ntp-service": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "default",
                    "specify",
                    "local"
                ],
                "type": "str"
            },
            "option1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "option2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "option3": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "option4": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "option5": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "option6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "options": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "code": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "raw"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "choices": [
                            "hex",
                            "string",
                            "ip",
                            "fqdn"
                        ],
                        "type": "str"
                    },
                    "value": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "vci-match": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "vci-string": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "raw"
                    },
                    "uci-match": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "uci-string": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "raw"
                    }
                },
                "elements": "dict"
            },
            "reserved-address": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "choices": [
                            "assign",
                            "block",
                            "reserved"
                        ],
                        "type": "str"
                    },
                    "circuit-id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "circuit-id-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "choices": [
                            "hex",
                            "string"
                        ],
                        "type": "str"
                    },
                    "description": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "mac": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "remote-id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "remote-id-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "choices": [
                            "hex",
                            "string"
                        ],
                        "type": "str"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "choices": [
                            "mac",
                            "option82"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "server-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "regular",
                    "ipsec"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tftp-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "timezone": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "00",
                    "01",
                    "02",
                    "03",
                    "04",
                    "05",
                    "06",
                    "07",
                    "08",
                    "09",
                    "10",
                    "11",
                    "12",
                    "13",
                    "14",
                    "15",
                    "16",
                    "17",
                    "18",
                    "19",
                    "20",
                    "21",
                    "22",
                    "23",
                    "24",
                    "25",
                    "26",
                    "27",
                    "28",
                    "29",
                    "30",
                    "31",
                    "32",
                    "33",
                    "34",
                    "35",
                    "36",
                    "37",
                    "38",
                    "39",
                    "40",
                    "41",
                    "42",
                    "43",
                    "44",
                    "45",
                    "46",
                    "47",
                    "48",
                    "49",
                    "50",
                    "51",
                    "52",
                    "53",
                    "54",
                    "55",
                    "56",
                    "57",
                    "58",
                    "59",
                    "60",
                    "61",
                    "62",
                    "63",
                    "64",
                    "65",
                    "66",
                    "67",
                    "68",
                    "69",
                    "70",
                    "71",
                    "72",
                    "73",
                    "74",
                    "75",
                    "76",
                    "77",
                    "78",
                    "79",
                    "80",
                    "81",
                    "82",
                    "83",
                    "84",
                    "85",
                    "86",
                    "87"
                ],
                "type": "str"
            },
            "timezone-option": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "default",
                    "specify"
                ],
                "type": "str"
            },
            "vci-match": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "vci-string": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "wifi-ac1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "wifi-ac2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "wifi-ac3": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "wins-server1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "wins-server2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "dns-server4": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "wifi-ac-service": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "specify",
                    "local"
                ],
                "type": "str"
            },
            "auto-managed-status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dhcp-settings-from-fortiipam": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "relay-agent": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "shared-subnet": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "fsp_vlan_dynamicmapping_dhcpserver_excluderange": {
        "stated": true,
        "options": {
            "end-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "start-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "vci-match": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "vci-string": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "lease-time": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "uci-match": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "uci-string": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "raw"
            }
        }
    },
    "fsp_vlan_dynamicmapping_dhcpserver_iprange": {
        "stated": true,
        "options": {
            "end-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "start-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "vci-match": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "vci-string": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "lease-time": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "uci-match": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "uci-string": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "raw"
            }
        }
    },
    "fsp_vlan_dynamicmapping_dhcpserver_options": {
        "stated": true,
        "options": {
            "code": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "hex",
                    "string",
                    "ip",
                    "fqdn"
                ],
                "type": "str"
            },
            "value": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "vci-match": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "vci-string": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "uci-match": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "uci-string": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "raw"
            }
        }
    },
    "fsp_vlan_dynamicmapping_dhcpserver_reservedaddress": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "assign",
                    "block",
                    "reserved"
                ],
                "type": "str"
            },
            "circuit-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "circuit-id-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "hex",
                    "string"
                ],
                "type": "str"
            },
            "description": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "mac": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "remote-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "remote-id-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "hex",
                    "string"
                ],
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "mac",
                    "option82"
                ],
                "type": "str"
            }
        }
    },
    "fsp_vlan_dynamicmapping_interface": {
        "stated": false,
        "options": {
            "ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "vlanid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "dhcp-relay-agent-option": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dhcp-relay-ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "dhcp-relay-service": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dhcp-relay-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "regular",
                    "ipsec"
                ],
                "type": "str"
            },
            "ipv6": {
                "required": false,
                "type": "dict",
                "options": {
                    "autoconf": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "dhcp6-client-options": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "list",
                        "choices": [
                            "rapid",
                            "iapd",
                            "iana",
                            "dns",
                            "dnsname"
                        ],
                        "elements": "str"
                    },
                    "dhcp6-information-request": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "dhcp6-prefix-delegation": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "dhcp6-prefix-hint": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "dhcp6-prefix-hint-plt": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "dhcp6-prefix-hint-vlt": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "dhcp6-relay-ip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "dhcp6-relay-service": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "dhcp6-relay-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "choices": [
                            "regular"
                        ],
                        "type": "str"
                    },
                    "ip6-address": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "ip6-allowaccess": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "list",
                        "choices": [
                            "https",
                            "ping",
                            "ssh",
                            "snmp",
                            "http",
                            "telnet",
                            "fgfm",
                            "capwap",
                            "fabric"
                        ],
                        "elements": "str"
                    },
                    "ip6-default-life": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "ip6-delegated-prefix-list": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "list",
                        "options": {
                            "autonomous-flag": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": false
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "onlink-flag": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": false
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "prefix-id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": false
                                },
                                "type": "int"
                            },
                            "rdnss": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": false
                                },
                                "type": "raw"
                            },
                            "rdnss-service": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": false
                                },
                                "choices": [
                                    "delegated",
                                    "default",
                                    "specify"
                                ],
                                "type": "str"
                            },
                            "subnet": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": false
                                },
                                "type": "str"
                            },
                            "upstream-interface": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": false
                                },
                                "type": "str"
                            },
                            "delegated-prefix-iaid": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": false
                                },
                                "type": "int"
                            }
                        },
                        "elements": "dict"
                    },
                    "ip6-dns-server-override": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ip6-extra-addr": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "list",
                        "options": {
                            "prefix": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": false
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "ip6-hop-limit": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "ip6-link-mtu": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "ip6-manage-flag": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ip6-max-interval": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "ip6-min-interval": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "ip6-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "choices": [
                            "static",
                            "dhcp",
                            "pppoe",
                            "delegated"
                        ],
                        "type": "str"
                    },
                    "ip6-other-flag": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ip6-prefix-list": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "list",
                        "options": {
                            "autonomous-flag": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": false
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "dnssl": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": false
                                },
                                "type": "raw"
                            },
                            "onlink-flag": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": false
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "preferred-life-time": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": false
                                },
                                "type": "int"
                            },
                            "prefix": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": false
                                },
                                "type": "str"
                            },
                            "rdnss": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": false
                                },
                                "type": "raw"
                            },
                            "valid-life-time": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": false
                                },
                                "type": "int"
                            }
                        },
                        "elements": "dict"
                    },
                    "ip6-reachable-time": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "ip6-retrans-time": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "ip6-send-adv": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ip6-subnet": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "ip6-upstream-interface": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "nd-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "nd-cga-modifier": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "nd-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "choices": [
                            "basic",
                            "SEND-compatible"
                        ],
                        "type": "str"
                    },
                    "nd-security-level": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "nd-timestamp-delta": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "nd-timestamp-fuzz": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "vrip6_link_local": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "vrrp-virtual-mac6": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "vrrp6": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "list",
                        "options": {
                            "accept-mode": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": false
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "adv-interval": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": false
                                },
                                "type": "int"
                            },
                            "preempt": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": false
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "priority": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": false
                                },
                                "type": "int"
                            },
                            "start-time": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": false
                                },
                                "type": "int"
                            },
                            "status": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": false
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "vrdst6": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": false
                                },
                                "type": "str"
                            },
                            "vrgrp": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": false
                                },
                                "type": "int"
                            },
                            "vrid": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": false
                                },
                                "type": "int"
                            },
                            "vrip6": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": false
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "interface-identifier": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "unique-autoconf-addr": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "icmp6-send-redirect": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "cli-conn6-status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "ip6-prefix-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "choices": [
                            "dhcp6",
                            "ra"
                        ],
                        "type": "str"
                    },
                    "ra-send-mtu": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ip6-delegated-prefix-iaid": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "dhcp6-relay-source-interface": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "secondary-IP": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "secondaryip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "allowaccess": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "list",
                        "choices": [
                            "https",
                            "ping",
                            "ssh",
                            "snmp",
                            "http",
                            "telnet",
                            "fgfm",
                            "auto-ipsec",
                            "radius-acct",
                            "probe-response",
                            "capwap",
                            "dnp",
                            "ftm",
                            "fabric",
                            "speed-test"
                        ],
                        "elements": "str"
                    },
                    "detectprotocol": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "list",
                        "choices": [
                            "ping",
                            "tcp-echo",
                            "udp-echo"
                        ],
                        "elements": "str"
                    },
                    "detectserver": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "gwdetect": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ha-priority": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "ip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "ping-serv-status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "seq": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "secip-relay-ip": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "dhcp-relay-interface-select-method": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "auto",
                    "sdwan",
                    "specify"
                ],
                "type": "str"
            },
            "vrrp": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "accept-mode": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "adv-interval": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "ignore-default-route": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "preempt": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "priority": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "proxy-arp": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "list",
                        "options": {
                            "id": {
                                "required": false,
                                "revision": {
                                    "7.4.0": true,
                                    "7.4.1": false
                                },
                                "type": "int"
                            },
                            "ip": {
                                "required": false,
                                "revision": {
                                    "7.4.0": true,
                                    "7.4.1": false
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "start-time": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "version": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "choices": [
                            "2",
                            "3"
                        ],
                        "type": "str"
                    },
                    "vrdst": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "raw"
                    },
                    "vrdst-priority": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "vrgrp": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "vrid": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "vrip": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "fsp_vlan_dynamicmapping_interface_ipv6": {
        "stated": false,
        "options": {
            "autoconf": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dhcp6-client-options": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "list",
                "choices": [
                    "rapid",
                    "iapd",
                    "iana",
                    "dns",
                    "dnsname"
                ],
                "elements": "str"
            },
            "dhcp6-information-request": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dhcp6-prefix-delegation": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dhcp6-prefix-hint": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "dhcp6-prefix-hint-plt": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "dhcp6-prefix-hint-vlt": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "dhcp6-relay-ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "dhcp6-relay-service": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dhcp6-relay-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "regular"
                ],
                "type": "str"
            },
            "ip6-address": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "ip6-allowaccess": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "list",
                "choices": [
                    "https",
                    "ping",
                    "ssh",
                    "snmp",
                    "http",
                    "telnet",
                    "fgfm",
                    "capwap",
                    "fabric"
                ],
                "elements": "str"
            },
            "ip6-default-life": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "ip6-delegated-prefix-list": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "autonomous-flag": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "onlink-flag": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "prefix-id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "rdnss": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "raw"
                    },
                    "rdnss-service": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "choices": [
                            "delegated",
                            "default",
                            "specify"
                        ],
                        "type": "str"
                    },
                    "subnet": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "upstream-interface": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "delegated-prefix-iaid": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "ip6-dns-server-override": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ip6-extra-addr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "prefix": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "ip6-hop-limit": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "ip6-link-mtu": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "ip6-manage-flag": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ip6-max-interval": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "ip6-min-interval": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "ip6-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "static",
                    "dhcp",
                    "pppoe",
                    "delegated"
                ],
                "type": "str"
            },
            "ip6-other-flag": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ip6-prefix-list": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "autonomous-flag": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "dnssl": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "raw"
                    },
                    "onlink-flag": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "preferred-life-time": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "prefix": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "rdnss": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "raw"
                    },
                    "valid-life-time": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "ip6-reachable-time": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "ip6-retrans-time": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "ip6-send-adv": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ip6-subnet": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "ip6-upstream-interface": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "nd-cert": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "nd-cga-modifier": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "nd-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "basic",
                    "SEND-compatible"
                ],
                "type": "str"
            },
            "nd-security-level": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "nd-timestamp-delta": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "nd-timestamp-fuzz": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "vrip6_link_local": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "vrrp-virtual-mac6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "vrrp6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "accept-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "adv-interval": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "preempt": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "priority": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "start-time": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "vrdst6": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "vrgrp": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "vrid": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "vrip6": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "interface-identifier": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "unique-autoconf-addr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "icmp6-send-redirect": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "cli-conn6-status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "ip6-prefix-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "dhcp6",
                    "ra"
                ],
                "type": "str"
            },
            "ra-send-mtu": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ip6-delegated-prefix-iaid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "dhcp6-relay-source-interface": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "fsp_vlan_dynamicmapping_interface_ipv6_ip6delegatedprefixlist": {
        "stated": true,
        "options": {
            "autonomous-flag": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "onlink-flag": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "prefix-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "rdnss": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "rdnss-service": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "delegated",
                    "default",
                    "specify"
                ],
                "type": "str"
            },
            "subnet": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "upstream-interface": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "delegated-prefix-iaid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            }
        }
    },
    "fsp_vlan_dynamicmapping_interface_ipv6_ip6extraaddr": {
        "stated": true,
        "options": {
            "prefix": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "fsp_vlan_dynamicmapping_interface_ipv6_ip6prefixlist": {
        "stated": true,
        "options": {
            "autonomous-flag": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dnssl": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "onlink-flag": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "preferred-life-time": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "prefix": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "rdnss": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "valid-life-time": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            }
        }
    },
    "fsp_vlan_dynamicmapping_interface_ipv6_vrrp6": {
        "stated": true,
        "options": {
            "accept-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "adv-interval": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "preempt": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "priority": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "start-time": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "vrdst6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "vrgrp": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "vrid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "vrip6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "fsp_vlan_dynamicmapping_interface_secondaryip": {
        "stated": true,
        "options": {
            "allowaccess": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "list",
                "choices": [
                    "https",
                    "ping",
                    "ssh",
                    "snmp",
                    "http",
                    "telnet",
                    "fgfm",
                    "auto-ipsec",
                    "radius-acct",
                    "probe-response",
                    "capwap",
                    "dnp",
                    "ftm",
                    "fabric",
                    "speed-test"
                ],
                "elements": "str"
            },
            "detectprotocol": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "choices": [
                    "ping",
                    "tcp-echo",
                    "udp-echo"
                ],
                "elements": "str"
            },
            "detectserver": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "gwdetect": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ha-priority": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "ping-serv-status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "seq": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "secip-relay-ip": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "fsp_vlan_dynamicmapping_interface_vrrp": {
        "stated": true,
        "options": {
            "accept-mode": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "adv-interval": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "ignore-default-route": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "preempt": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "priority": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "proxy-arp": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "id": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "ip": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": false
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "start-time": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "version": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "2",
                    "3"
                ],
                "type": "str"
            },
            "vrdst": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "vrdst-priority": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "vrgrp": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "vrid": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "vrip": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "fsp_vlan_dynamicmapping_interface_vrrp_proxyarp": {
        "stated": true,
        "options": {
            "id": {
                "required": true,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "ip": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "fsp_vlan_interface": {
        "stated": false,
        "options": {
            "ac-name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "aggregate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "algorithm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "L2",
                    "L3",
                    "L4",
                    "LB",
                    "Source-MAC"
                ],
                "type": "str"
            },
            "alias": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "allowaccess": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "https",
                    "ping",
                    "ssh",
                    "snmp",
                    "http",
                    "telnet",
                    "fgfm",
                    "auto-ipsec",
                    "radius-acct",
                    "probe-response",
                    "capwap",
                    "dnp",
                    "ftm",
                    "fabric",
                    "speed-test"
                ],
                "elements": "str"
            },
            "ap-discover": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "arpforward": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "atm-protocol": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "ipoa"
                ],
                "type": "str"
            },
            "auth-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auto",
                    "pap",
                    "chap",
                    "mschapv1",
                    "mschapv2"
                ],
                "type": "str"
            },
            "auto-auth-extension-device": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "bfd": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "global",
                    "enable",
                    "disable"
                ],
                "type": "str"
            },
            "bfd-desired-min-tx": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "bfd-detect-mult": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "bfd-required-min-rx": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "broadcast-forticlient-discovery": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "broadcast-forward": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "captive-portal": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "cli-conn-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "color": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ddns": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ddns-auth": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "tsig"
                ],
                "type": "str"
            },
            "ddns-domain": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ddns-key": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "ddns-keyname": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "str"
            },
            "ddns-password": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "ddns-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "dhs.org",
                    "dyndns.org",
                    "dyns.net",
                    "tzo.com",
                    "ods.org",
                    "vavic.com",
                    "now.net.cn",
                    "dipdns.net",
                    "easydns.com",
                    "genericDDNS"
                ],
                "type": "str"
            },
            "ddns-server-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ddns-sn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ddns-ttl": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ddns-username": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ddns-zone": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dedicated-to": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "management"
                ],
                "type": "str"
            },
            "defaultgw": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "description": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "detected-peer-mtu": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "detectprotocol": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "ping",
                    "tcp-echo",
                    "udp-echo"
                ],
                "elements": "str"
            },
            "detectserver": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "device-access-list": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "device-identification": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "device-identification-active-scan": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "device-netscan": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "device-user-identification": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "devindex": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "dhcp-client-identifier": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dhcp-relay-agent-option": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dhcp-relay-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dhcp-relay-service": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dhcp-relay-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "regular",
                    "ipsec"
                ],
                "type": "str"
            },
            "dhcp-renew-time": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "disc-retry-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "disconnect-threshold": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "distance": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "dns-query": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "recursive",
                    "non-recursive"
                ],
                "type": "str"
            },
            "dns-server-override": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "drop-fragment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "drop-overlapped-fragment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "egress-cos": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "cos0",
                    "cos1",
                    "cos2",
                    "cos3",
                    "cos4",
                    "cos5",
                    "cos6",
                    "cos7"
                ],
                "type": "str"
            },
            "egress-shaping-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "endpoint-compliance": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "estimated-downstream-bandwidth": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "estimated-upstream-bandwidth": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "explicit-ftp-proxy": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "explicit-web-proxy": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "external": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fail-action-on-extender": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "soft-restart",
                    "hard-restart",
                    "reboot"
                ],
                "type": "str"
            },
            "fail-alert-interfaces": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "fail-alert-method": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "link-failed-signal",
                    "link-down"
                ],
                "type": "str"
            },
            "fail-detect": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fail-detect-option": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "detectserver",
                    "link-down"
                ],
                "elements": "str"
            },
            "fdp": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fortiheartbeat": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fortilink": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fortilink-backup-link": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fortilink-split-interface": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fortilink-stacking": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "forward-domain": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "forward-error-correction": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "rs-fec",
                    "base-r-fec",
                    "fec-cl91",
                    "fec-cl74",
                    "rs-544",
                    "none",
                    "cl91-rs-fec",
                    "cl74-fc-fec",
                    "auto"
                ],
                "type": "str"
            },
            "fp-anomaly": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "drop_tcp_fin_noack",
                    "pass_winnuke",
                    "pass_tcpland",
                    "pass_udpland",
                    "pass_icmpland",
                    "pass_ipland",
                    "pass_iprr",
                    "pass_ipssrr",
                    "pass_iplsrr",
                    "pass_ipstream",
                    "pass_ipsecurity",
                    "pass_iptimestamp",
                    "pass_ipunknown_option",
                    "pass_ipunknown_prot",
                    "pass_icmp_frag",
                    "pass_tcp_no_flag",
                    "pass_tcp_fin_noack",
                    "drop_winnuke",
                    "drop_tcpland",
                    "drop_udpland",
                    "drop_icmpland",
                    "drop_ipland",
                    "drop_iprr",
                    "drop_ipssrr",
                    "drop_iplsrr",
                    "drop_ipstream",
                    "drop_ipsecurity",
                    "drop_iptimestamp",
                    "drop_ipunknown_option",
                    "drop_ipunknown_prot",
                    "drop_icmp_frag",
                    "drop_tcp_no_flag"
                ],
                "elements": "str"
            },
            "fp-disable": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "all",
                    "ipsec",
                    "none"
                ],
                "elements": "str"
            },
            "gateway-address": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "gi-gk": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "gwaddr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "gwdetect": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ha-priority": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "icmp-accept-redirect": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "icmp-redirect": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "icmp-send-redirect": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ident-accept": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "idle-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "if-mdix": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auto",
                    "normal",
                    "crossover"
                ],
                "type": "str"
            },
            "if-media": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auto",
                    "copper",
                    "fiber"
                ],
                "type": "str"
            },
            "in-force-vlan-cos": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "inbandwidth": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ingress-cos": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "cos0",
                    "cos1",
                    "cos2",
                    "cos3",
                    "cos4",
                    "cos5",
                    "cos6",
                    "cos7"
                ],
                "type": "str"
            },
            "ingress-spillover-threshold": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "internal": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipmac": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ips-sniffer-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ipunnumbered": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipv6": {
                "required": false,
                "type": "dict",
                "options": {
                    "autoconf": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "dhcp6-client-options": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "rapid",
                            "iapd",
                            "iana",
                            "dns",
                            "dnsname"
                        ],
                        "elements": "str"
                    },
                    "dhcp6-information-request": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "dhcp6-prefix-delegation": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "dhcp6-prefix-hint": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "dhcp6-prefix-hint-plt": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "dhcp6-prefix-hint-vlt": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "dhcp6-relay-ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "dhcp6-relay-service": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "dhcp6-relay-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "regular"
                        ],
                        "type": "str"
                    },
                    "ip6-address": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ip6-allowaccess": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "https",
                            "ping",
                            "ssh",
                            "snmp",
                            "http",
                            "telnet",
                            "fgfm",
                            "capwap",
                            "fabric"
                        ],
                        "elements": "str"
                    },
                    "ip6-default-life": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ip6-dns-server-override": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ip6-hop-limit": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ip6-link-mtu": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ip6-manage-flag": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ip6-max-interval": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ip6-min-interval": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ip6-mode": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "static",
                            "dhcp",
                            "pppoe",
                            "delegated"
                        ],
                        "type": "str"
                    },
                    "ip6-other-flag": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ip6-reachable-time": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ip6-retrans-time": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ip6-send-adv": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ip6-subnet": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ip6-upstream-interface": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "nd-cert": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "nd-cga-modifier": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "nd-mode": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "basic",
                            "SEND-compatible"
                        ],
                        "type": "str"
                    },
                    "nd-security-level": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "nd-timestamp-delta": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "nd-timestamp-fuzz": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "vrip6_link_local": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vrrp-virtual-mac6": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ip6-delegated-prefix-list": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "autonomous-flag": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "onlink-flag": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "prefix-id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "rdnss": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            },
                            "rdnss-service": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "delegated",
                                    "default",
                                    "specify"
                                ],
                                "type": "str"
                            },
                            "subnet": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "upstream-interface": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "delegated-prefix-iaid": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            }
                        },
                        "elements": "dict"
                    },
                    "ip6-extra-addr": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "prefix": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "ip6-prefix-list": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "autonomous-flag": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "dnssl": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            },
                            "onlink-flag": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "preferred-life-time": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "prefix": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "rdnss": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            },
                            "valid-life-time": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            }
                        },
                        "elements": "dict"
                    },
                    "vrrp6": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "accept-mode": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "adv-interval": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "preempt": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "priority": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "start-time": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "status": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "vrdst6": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "vrgrp": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "vrid": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "vrip6": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "interface-identifier": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "unique-autoconf-addr": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "icmp6-send-redirect": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "cli-conn6-status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ip6-prefix-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "dhcp6",
                            "ra"
                        ],
                        "type": "str"
                    },
                    "ra-send-mtu": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ip6-delegated-prefix-iaid": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "dhcp6-relay-source-interface": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "dhcp6-relay-interface-id": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "dhcp6-relay-source-ip": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                }
            },
            "l2forward": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "l2tp-client": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "lacp-ha-slave": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "lacp-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "static",
                    "passive",
                    "active"
                ],
                "type": "str"
            },
            "lacp-speed": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "slow",
                    "fast"
                ],
                "type": "str"
            },
            "lcp-echo-interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "lcp-max-echo-fails": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "link-up-delay": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "listen-forticlient-connection": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "lldp-network-policy": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "lldp-reception": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "vdom"
                ],
                "type": "str"
            },
            "lldp-transmission": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "enable",
                    "disable",
                    "vdom"
                ],
                "type": "str"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "macaddr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "management-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "max-egress-burst-rate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "max-egress-rate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mediatype": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "serdes-sfp",
                    "sgmii-sfp",
                    "cfp2-sr10",
                    "cfp2-lr4",
                    "serdes-copper-sfp",
                    "sr",
                    "cr",
                    "lr",
                    "qsfp28-sr4",
                    "qsfp28-lr4",
                    "qsfp28-cr4",
                    "sr4",
                    "cr4",
                    "lr4",
                    "none",
                    "gmii",
                    "sgmii",
                    "sr2",
                    "lr2",
                    "cr2",
                    "sr8",
                    "lr8",
                    "cr8"
                ],
                "type": "str"
            },
            "member": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "min-links": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "min-links-down": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "operational",
                    "administrative"
                ],
                "type": "str"
            },
            "mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "static",
                    "dhcp",
                    "pppoe",
                    "pppoa",
                    "ipoa",
                    "eoa"
                ],
                "type": "str"
            },
            "mtu": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mtu-override": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mux-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "llc-encaps",
                    "vc-encaps"
                ],
                "type": "str"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ndiscforward": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "netbios-forward": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "netflow-sampler": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "tx",
                    "rx",
                    "both"
                ],
                "type": "str"
            },
            "npu-fastpath": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "nst": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "out-force-vlan-cos": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "outbandwidth": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "padt-retry-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "password": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "peer-interface": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "phy-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auto",
                    "adsl",
                    "vdsl",
                    "adsl-auto",
                    "vdsl2",
                    "adsl2+",
                    "adsl2",
                    "g.dmt",
                    "t1.413",
                    "g.lite"
                ],
                "type": "str"
            },
            "ping-serv-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "poe": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "polling-interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "pppoe-unnumbered-negotiate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "pptp-auth-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auto",
                    "pap",
                    "chap",
                    "mschapv1",
                    "mschapv2"
                ],
                "type": "str"
            },
            "pptp-client": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "pptp-password": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "pptp-server-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "pptp-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "pptp-user": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "preserve-session-route": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "priority": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "priority-override": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "proxy-captive-portal": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "redundant-interface": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "remote-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "replacemsg-override-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "retransmission": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "role": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "lan",
                    "wan",
                    "dmz",
                    "undefined"
                ],
                "type": "str"
            },
            "sample-direction": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "rx",
                    "tx",
                    "both"
                ],
                "type": "str"
            },
            "sample-rate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "scan-botnet-connections": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "block",
                    "monitor"
                ],
                "type": "str"
            },
            "secondary-IP": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "secondaryip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "allowaccess": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "https",
                            "ping",
                            "ssh",
                            "snmp",
                            "http",
                            "telnet",
                            "fgfm",
                            "auto-ipsec",
                            "radius-acct",
                            "probe-response",
                            "capwap",
                            "dnp",
                            "ftm",
                            "fabric",
                            "speed-test"
                        ],
                        "elements": "str"
                    },
                    "detectprotocol": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "list",
                        "choices": [
                            "ping",
                            "tcp-echo",
                            "udp-echo"
                        ],
                        "elements": "str"
                    },
                    "detectserver": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "gwdetect": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ha-priority": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ping-serv-status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "seq": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "secip-relay-ip": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "security-8021x-dynamic-vlan-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "security-8021x-master": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "security-8021x-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "default",
                    "dynamic-vlan",
                    "fallback",
                    "slave"
                ],
                "type": "str"
            },
            "security-exempt-list": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "security-external-logout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "security-external-web": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "security-groups": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "security-mac-auth-bypass": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "mac-auth-only"
                ],
                "type": "str"
            },
            "security-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "captive-portal",
                    "802.1X"
                ],
                "type": "str"
            },
            "security-redirect-url": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "service-name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sflow-sampler": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "speed": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auto",
                    "10full",
                    "10half",
                    "100full",
                    "100half",
                    "1000full",
                    "1000half",
                    "10000full",
                    "1000auto",
                    "10000auto",
                    "40000full",
                    "100Gfull",
                    "25000full",
                    "40000auto",
                    "25000auto",
                    "100Gauto",
                    "400Gfull",
                    "400Gauto",
                    "50000full",
                    "2500auto",
                    "5000auto",
                    "50000auto",
                    "200Gfull",
                    "200Gauto",
                    "100auto"
                ],
                "type": "str"
            },
            "spillover-threshold": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "src-check": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "down",
                    "up"
                ],
                "type": "str"
            },
            "stp": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "stp-ha-slave": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "priority-adjust"
                ],
                "type": "str"
            },
            "stpforward": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "stpforward-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "rpl-all-ext-id",
                    "rpl-bridge-ext-id",
                    "rpl-nothing"
                ],
                "type": "str"
            },
            "strip-priority-vlan-tag": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "subst": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "substitute-dst-mac": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "switch": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "switch-controller-access-vlan": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "switch-controller-arp-inspection": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "switch-controller-auth": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "radius",
                    "usergroup"
                ],
                "type": "str"
            },
            "switch-controller-dhcp-snooping": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "switch-controller-dhcp-snooping-option82": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "switch-controller-dhcp-snooping-verify-mac": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "switch-controller-igmp-snooping": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "switch-controller-learning-limit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "switch-controller-radius-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "switch-controller-traffic-policy": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tc-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ptm",
                    "atm"
                ],
                "type": "str"
            },
            "tcp-mss": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "trunk": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "trust-ip-1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "trust-ip-2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "trust-ip-3": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "trust-ip6-1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "trust-ip6-2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "trust-ip6-3": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "physical",
                    "vlan",
                    "aggregate",
                    "redundant",
                    "tunnel",
                    "wireless",
                    "vdom-link",
                    "loopback",
                    "switch",
                    "hard-switch",
                    "hdlc",
                    "vap-switch",
                    "wl-mesh",
                    "fortilink",
                    "switch-vlan",
                    "fctrl-trunk",
                    "tdm",
                    "fext-wan",
                    "vxlan",
                    "emac-vlan",
                    "geneve",
                    "ssl",
                    "lan-extension"
                ],
                "type": "str"
            },
            "username": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vci": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "vectoring": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "vindex": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "vlanforward": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "vlanid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "vpi": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "vrf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "vrrp": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "accept-mode": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "adv-interval": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ignore-default-route": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "preempt": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "priority": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "start-time": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "version": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "2",
                            "3"
                        ],
                        "type": "str"
                    },
                    "vrdst": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "vrdst-priority": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "vrgrp": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "vrid": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "vrip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "proxy-arp": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "id": {
                                "required": false,
                                "revision": {
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "ip": {
                                "required": false,
                                "revision": {
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    }
                },
                "elements": "dict"
            },
            "vrrp-virtual-mac": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "wccp": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "weight": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "wifi-5g-threshold": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "wifi-acl": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "deny",
                    "allow"
                ],
                "type": "str"
            },
            "wifi-ap-band": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "any",
                    "5g-preferred",
                    "5g-only"
                ],
                "type": "str"
            },
            "wifi-auth": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "PSK",
                    "RADIUS",
                    "radius",
                    "usergroup"
                ],
                "type": "str"
            },
            "wifi-auto-connect": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "wifi-auto-save": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "wifi-broadcast-ssid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "wifi-encrypt": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "TKIP",
                    "AES"
                ],
                "type": "str"
            },
            "wifi-fragment-threshold": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "wifi-key": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "wifi-keyindex": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "int"
            },
            "wifi-mac-filter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "wifi-passphrase": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "wifi-radius-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "wifi-rts-threshold": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "wifi-security": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "None",
                    "WEP64",
                    "wep64",
                    "WEP128",
                    "wep128",
                    "WPA_PSK",
                    "WPA_RADIUS",
                    "WPA",
                    "WPA2",
                    "WPA2_AUTO",
                    "open",
                    "wpa-personal",
                    "wpa-enterprise",
                    "wpa-only-personal",
                    "wpa-only-enterprise",
                    "wpa2-only-personal",
                    "wpa2-only-enterprise"
                ],
                "type": "str"
            },
            "wifi-ssid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "wifi-usergroup": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "wins-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "eip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "fortilink-neighbor-detect": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "lldp",
                    "fortilink"
                ],
                "type": "str"
            },
            "ingress-shaping-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ring-rx": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ring-tx": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "switch-controller-igmp-snooping-fast-leave": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "switch-controller-igmp-snooping-proxy": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "switch-controller-rspan-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "bandwidth-measure-time": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip-managed-by-fortiipam": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "inherit-global"
                ],
                "type": "str"
            },
            "managed-subnetwork-size": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "256",
                    "512",
                    "1024",
                    "2048",
                    "4096",
                    "8192",
                    "16384",
                    "32768",
                    "65536",
                    "32",
                    "64",
                    "128"
                ],
                "type": "str"
            },
            "measured-downstream-bandwidth": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "measured-upstream-bandwidth": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "monitor-bandwidth": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "swc-vlan": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "switch-controller-feature": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "default-vlan",
                    "quarantine",
                    "sniffer",
                    "voice",
                    "camera",
                    "rspan",
                    "video",
                    "nac",
                    "nac-segment"
                ],
                "type": "str"
            },
            "switch-controller-mgmt-vlan": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "switch-controller-nac": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vlan-protocol": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "8021q",
                    "8021ad"
                ],
                "type": "str"
            },
            "dhcp-relay-interface": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dhcp-relay-interface-select-method": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auto",
                    "sdwan",
                    "specify"
                ],
                "type": "str"
            },
            "np-qos-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "swc-first-create": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "switch-controller-iot-scanning": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "switch-controller-source-ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "outbound",
                    "fixed"
                ],
                "type": "str"
            },
            "dhcp-relay-request-all-server": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "stp-ha-secondary": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "priority-adjust"
                ],
                "type": "str"
            },
            "switch-controller-dynamic": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "auth-cert": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "auth-portal-addr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dhcp-classless-route-addition": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dhcp-relay-link-selection": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dns-server-protocol": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "cleartext",
                    "dot",
                    "doh"
                ],
                "elements": "str"
            },
            "eap-ca-cert": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "eap-identity": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "eap-method": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "tls",
                    "peap"
                ],
                "type": "str"
            },
            "eap-password": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "eap-supplicant": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "eap-user-cert": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ike-saml-server": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "lacp-ha-secondary": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "pvc-atm-qos": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "cbr",
                    "rt-vbr",
                    "nrt-vbr"
                ],
                "type": "str"
            },
            "pvc-chan": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "pvc-crc": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "pvc-pcr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "pvc-scr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "pvc-vlan-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "pvc-vlan-rx-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "pvc-vlan-rx-op": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass-through",
                    "replace",
                    "remove"
                ],
                "type": "str"
            },
            "pvc-vlan-tx-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "pvc-vlan-tx-op": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass-through",
                    "replace",
                    "remove"
                ],
                "type": "str"
            },
            "reachable-time": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "select-profile-30a-35b": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "30A",
                    "35B"
                ],
                "type": "str"
            },
            "sfp-dsl": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sfp-dsl-adsl-fallback": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sfp-dsl-autodetect": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sfp-dsl-mac": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sw-algorithm": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "l2",
                    "l3",
                    "eh"
                ],
                "type": "str"
            },
            "system-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "system-id-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auto",
                    "user"
                ],
                "type": "str"
            },
            "vlan-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "vlan-op-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "tag",
                    "untag",
                    "passthrough"
                ],
                "type": "str"
            },
            "generic-receive-offload": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "interconnect-profile": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "default",
                    "profile1",
                    "profile2"
                ],
                "type": "str"
            },
            "large-receive-offload": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "aggregate-type": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "physical",
                    "vxlan"
                ],
                "type": "str"
            },
            "switch-controller-netflow-collect": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "wifi-dns-server1": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "wifi-dns-server2": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "wifi-gateway": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "default-purdue-level": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "1",
                    "2",
                    "3",
                    "4",
                    "5",
                    "1.5",
                    "2.5",
                    "3.5",
                    "5.5"
                ],
                "type": "str"
            },
            "dhcp-broadcast-flag": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dhcp-smart-relay": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "switch-controller-offloading": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "switch-controller-offloading-gw": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "switch-controller-offloading-ip": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dhcp-relay-circuit-id": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "dhcp-relay-source-ip": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "switch-controller-offload": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "switch-controller-offload-gw": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "switch-controller-offload-ip": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "fsp_vlan_interface_ipv6": {
        "stated": false,
        "options": {
            "autoconf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dhcp6-client-options": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "rapid",
                    "iapd",
                    "iana",
                    "dns",
                    "dnsname"
                ],
                "elements": "str"
            },
            "dhcp6-information-request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dhcp6-prefix-delegation": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dhcp6-prefix-hint": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dhcp6-prefix-hint-plt": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "dhcp6-prefix-hint-vlt": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "dhcp6-relay-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dhcp6-relay-service": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dhcp6-relay-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "regular"
                ],
                "type": "str"
            },
            "ip6-address": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ip6-allowaccess": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "https",
                    "ping",
                    "ssh",
                    "snmp",
                    "http",
                    "telnet",
                    "fgfm",
                    "capwap",
                    "fabric"
                ],
                "elements": "str"
            },
            "ip6-default-life": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip6-dns-server-override": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ip6-hop-limit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip6-link-mtu": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip6-manage-flag": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ip6-max-interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip6-min-interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip6-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "static",
                    "dhcp",
                    "pppoe",
                    "delegated"
                ],
                "type": "str"
            },
            "ip6-other-flag": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ip6-reachable-time": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip6-retrans-time": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip6-send-adv": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ip6-subnet": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ip6-upstream-interface": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "nd-cert": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "nd-cga-modifier": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "nd-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "basic",
                    "SEND-compatible"
                ],
                "type": "str"
            },
            "nd-security-level": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "nd-timestamp-delta": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "nd-timestamp-fuzz": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "vrip6_link_local": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vrrp-virtual-mac6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ip6-delegated-prefix-list": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "autonomous-flag": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "onlink-flag": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "prefix-id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "rdnss": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "rdnss-service": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "delegated",
                            "default",
                            "specify"
                        ],
                        "type": "str"
                    },
                    "subnet": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "upstream-interface": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "delegated-prefix-iaid": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "ip6-extra-addr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "prefix": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "ip6-prefix-list": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "autonomous-flag": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "dnssl": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "onlink-flag": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "preferred-life-time": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "prefix": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "rdnss": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "valid-life-time": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "vrrp6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "accept-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "adv-interval": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "preempt": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "priority": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "start-time": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "vrdst6": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vrgrp": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "vrid": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "vrip6": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "interface-identifier": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "unique-autoconf-addr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "icmp6-send-redirect": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "cli-conn6-status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip6-prefix-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "dhcp6",
                    "ra"
                ],
                "type": "str"
            },
            "ra-send-mtu": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ip6-delegated-prefix-iaid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "dhcp6-relay-source-interface": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dhcp6-relay-interface-id": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "dhcp6-relay-source-ip": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "fsp_vlan_interface_ipv6_ip6delegatedprefixlist": {
        "stated": true,
        "options": {
            "autonomous-flag": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "onlink-flag": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "prefix-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "rdnss": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "rdnss-service": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "delegated",
                    "default",
                    "specify"
                ],
                "type": "str"
            },
            "subnet": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "upstream-interface": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "delegated-prefix-iaid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "fsp_vlan_interface_ipv6_ip6extraaddr": {
        "stated": true,
        "options": {
            "prefix": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "fsp_vlan_interface_ipv6_ip6prefixlist": {
        "stated": true,
        "options": {
            "autonomous-flag": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dnssl": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "onlink-flag": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "preferred-life-time": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "prefix": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "rdnss": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "valid-life-time": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "fsp_vlan_interface_ipv6_vrrp6": {
        "stated": true,
        "options": {
            "accept-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "adv-interval": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "preempt": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "priority": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "start-time": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "vrdst6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vrgrp": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "vrid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "vrip6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "fsp_vlan_interface_secondaryip": {
        "stated": true,
        "options": {
            "allowaccess": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "https",
                    "ping",
                    "ssh",
                    "snmp",
                    "http",
                    "telnet",
                    "fgfm",
                    "auto-ipsec",
                    "radius-acct",
                    "probe-response",
                    "capwap",
                    "dnp",
                    "ftm",
                    "fabric",
                    "speed-test"
                ],
                "elements": "str"
            },
            "detectprotocol": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "choices": [
                    "ping",
                    "tcp-echo",
                    "udp-echo"
                ],
                "elements": "str"
            },
            "detectserver": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "gwdetect": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ha-priority": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ping-serv-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "seq": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "secip-relay-ip": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "fsp_vlan_interface_vrrp": {
        "stated": true,
        "options": {
            "accept-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "adv-interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ignore-default-route": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "preempt": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "priority": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "start-time": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "version": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "2",
                    "3"
                ],
                "type": "str"
            },
            "vrdst": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "vrdst-priority": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "vrgrp": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "vrid": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "vrip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "proxy-arp": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "id": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ip": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "fsp_vlan_interface_vrrp_proxyarp": {
        "stated": true,
        "options": {
            "id": {
                "required": true,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "gtp_apn": {
        "stated": true,
        "options": {
            "apn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "gtp_apngrp": {
        "stated": true,
        "options": {
            "member": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "gtp_iewhitelist": {
        "stated": true,
        "options": {
            "entries": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ie": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "message": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "gtp_iewhitelist_entries": {
        "stated": true,
        "options": {
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ie": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "message": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "gtp_messagefilterv0v1": {
        "stated": true,
        "options": {
            "create-mbms": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "create-pdp": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "data-record": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "delete-aa-pdp": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "delete-mbms": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "delete-pdp": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "echo": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "end-marker": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "error-indication": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "failure-report": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "fwd-relocation": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "fwd-srns-context": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "gtp-pdu": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "identification": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "mbms-de-registration": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "mbms-notification": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "mbms-registration": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "mbms-session-start": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "mbms-session-stop": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "mbms-session-update": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "ms-info-change-notif": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "node-alive": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "note-ms-present": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "pdu-notification": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "ran-info": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "redirection": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "relocation-cancel": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "send-route": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "sgsn-context": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "support-extension": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "unknown-message": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "unknown-message-white-list": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "update-mbms": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "update-pdp": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "v0-create-aa-pdp--v1-init-pdp-ctx": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "deny",
                    "allow"
                ],
                "type": "str"
            },
            "version-not-support": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "create-aa-pdp|init-pdp-ctx": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "ue-registration-query": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            }
        }
    },
    "gtp_messagefilterv2": {
        "stated": true,
        "options": {
            "bearer-resource-cmd-fail": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "change-notification": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "create-bearer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "create-session": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "delete-bearer-cmd-fail": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "delete-bearer-req-resp": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "delete-pdn-connection-set": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "delete-session": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "echo": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "modify-bearer-cmd-fail": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "modify-bearer-req-resp": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "resume": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "suspend": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "trace-session": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "unknown-message": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "unknown-message-white-list": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "update-bearer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "update-pdn-connection-set": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "version-not-support": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "context-req-res-ack": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "forward-relocation-cmp-notif-ack": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "forward-relocation-req-res": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "alert-mme-notif-ack": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "configuration-transfer-tunnel": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "create-forwarding-tunnel-req-resp": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "create-indirect-forwarding-tunnel-req-resp": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "cs-paging": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "delete-indirect-forwarding-tunnel-req-resp": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "detach-notif-ack": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "dlink-data-notif-ack": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "dlink-notif-failure": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "forward-access-notif-ack": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "identification-req-resp": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "isr-status": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "mbms-session-start-req-resp": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "mbms-session-stop-req-resp": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "mbms-session-update-req-resp": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "modify-access-req-resp": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "pgw-dlink-notif-ack": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "pgw-restart-notif-ack": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "ran-info-relay": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "release-access-bearer-req-resp": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "relocation-cancel-req-resp": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "remote-ue-report-notif-ack": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "reserved-for-earlier-version": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "stop-paging-indication": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "ue-activity-notif-ack": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "ue-registration-query-req-resp": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            }
        }
    },
    "gtp_tunnellimit": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tunnel-limit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "hotspot20_anqp3gppcellular": {
        "stated": true,
        "options": {
            "mcc-mnc-list": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "mcc": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "mnc": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "hotspot20_anqp3gppcellular_mccmnclist": {
        "stated": true,
        "options": {
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mcc": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "mnc": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "hotspot20_anqpipaddresstype": {
        "stated": true,
        "options": {
            "ipv4-address-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "not-available",
                    "not-known",
                    "public",
                    "port-restricted",
                    "single-NATed-private",
                    "double-NATed-private",
                    "port-restricted-and-single-NATed",
                    "port-restricted-and-double-NATed"
                ],
                "type": "str"
            },
            "ipv6-address-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "not-available",
                    "available",
                    "not-known"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "hotspot20_anqpnairealm": {
        "stated": true,
        "options": {
            "nai-list": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "eap-method": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "auth-param": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "options": {
                                    "id": {
                                        "required": false,
                                        "revision": {
                                            "6.0.0": true,
                                            "6.2.0": true,
                                            "6.2.1": true,
                                            "6.2.2": true,
                                            "6.2.3": true,
                                            "6.2.5": true,
                                            "6.2.6": true,
                                            "6.2.7": true,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.0": true,
                                            "6.4.1": true,
                                            "6.4.2": true,
                                            "6.4.3": true,
                                            "6.4.4": true,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "non-eap-inner-auth",
                                            "inner-auth-eap",
                                            "credential",
                                            "tunneled-credential"
                                        ],
                                        "type": "str"
                                    },
                                    "index": {
                                        "required": false,
                                        "revision": {
                                            "6.0.0": true,
                                            "6.2.0": true,
                                            "6.2.1": true,
                                            "6.2.2": true,
                                            "6.2.3": true,
                                            "6.2.5": true,
                                            "6.2.6": true,
                                            "6.2.7": true,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.0": true,
                                            "6.4.1": true,
                                            "6.4.2": true,
                                            "6.4.3": true,
                                            "6.4.4": true,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "int"
                                    },
                                    "val": {
                                        "required": false,
                                        "revision": {
                                            "6.0.0": true,
                                            "6.2.0": true,
                                            "6.2.1": true,
                                            "6.2.2": true,
                                            "6.2.3": true,
                                            "6.2.5": true,
                                            "6.2.6": true,
                                            "6.2.7": true,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.0": true,
                                            "6.4.1": true,
                                            "6.4.2": true,
                                            "6.4.3": true,
                                            "6.4.4": true,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "choices": [
                                            "eap-identity",
                                            "eap-md5",
                                            "eap-tls",
                                            "eap-ttls",
                                            "eap-peap",
                                            "eap-sim",
                                            "eap-aka",
                                            "eap-aka-prime",
                                            "non-eap-pap",
                                            "non-eap-chap",
                                            "non-eap-mschap",
                                            "non-eap-mschapv2",
                                            "cred-sim",
                                            "cred-usim",
                                            "cred-nfc",
                                            "cred-hardware-token",
                                            "cred-softoken",
                                            "cred-certificate",
                                            "cred-user-pwd",
                                            "cred-none",
                                            "cred-vendor-specific",
                                            "tun-cred-sim",
                                            "tun-cred-usim",
                                            "tun-cred-nfc",
                                            "tun-cred-hardware-token",
                                            "tun-cred-softoken",
                                            "tun-cred-certificate",
                                            "tun-cred-user-pwd",
                                            "tun-cred-anonymous",
                                            "tun-cred-vendor-specific"
                                        ],
                                        "type": "str"
                                    }
                                },
                                "elements": "dict"
                            },
                            "index": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "method": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "eap-identity",
                                    "eap-md5",
                                    "eap-tls",
                                    "eap-ttls",
                                    "eap-peap",
                                    "eap-sim",
                                    "eap-aka",
                                    "eap-aka-prime"
                                ],
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "encoding": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "nai-realm": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "hotspot20_anqpnairealm_nailist": {
        "stated": true,
        "options": {
            "eap-method": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "auth-param": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "id": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "non-eap-inner-auth",
                                    "inner-auth-eap",
                                    "credential",
                                    "tunneled-credential"
                                ],
                                "type": "str"
                            },
                            "index": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "val": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "eap-identity",
                                    "eap-md5",
                                    "eap-tls",
                                    "eap-ttls",
                                    "eap-peap",
                                    "eap-sim",
                                    "eap-aka",
                                    "eap-aka-prime",
                                    "non-eap-pap",
                                    "non-eap-chap",
                                    "non-eap-mschap",
                                    "non-eap-mschapv2",
                                    "cred-sim",
                                    "cred-usim",
                                    "cred-nfc",
                                    "cred-hardware-token",
                                    "cred-softoken",
                                    "cred-certificate",
                                    "cred-user-pwd",
                                    "cred-none",
                                    "cred-vendor-specific",
                                    "tun-cred-sim",
                                    "tun-cred-usim",
                                    "tun-cred-nfc",
                                    "tun-cred-hardware-token",
                                    "tun-cred-softoken",
                                    "tun-cred-certificate",
                                    "tun-cred-user-pwd",
                                    "tun-cred-anonymous",
                                    "tun-cred-vendor-specific"
                                ],
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "index": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "method": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "eap-identity",
                            "eap-md5",
                            "eap-tls",
                            "eap-ttls",
                            "eap-peap",
                            "eap-sim",
                            "eap-aka",
                            "eap-aka-prime"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "encoding": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "nai-realm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "hotspot20_anqpnairealm_nailist_eapmethod": {
        "stated": true,
        "options": {
            "auth-param": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "non-eap-inner-auth",
                            "inner-auth-eap",
                            "credential",
                            "tunneled-credential"
                        ],
                        "type": "str"
                    },
                    "index": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "val": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "eap-identity",
                            "eap-md5",
                            "eap-tls",
                            "eap-ttls",
                            "eap-peap",
                            "eap-sim",
                            "eap-aka",
                            "eap-aka-prime",
                            "non-eap-pap",
                            "non-eap-chap",
                            "non-eap-mschap",
                            "non-eap-mschapv2",
                            "cred-sim",
                            "cred-usim",
                            "cred-nfc",
                            "cred-hardware-token",
                            "cred-softoken",
                            "cred-certificate",
                            "cred-user-pwd",
                            "cred-none",
                            "cred-vendor-specific",
                            "tun-cred-sim",
                            "tun-cred-usim",
                            "tun-cred-nfc",
                            "tun-cred-hardware-token",
                            "tun-cred-softoken",
                            "tun-cred-certificate",
                            "tun-cred-user-pwd",
                            "tun-cred-anonymous",
                            "tun-cred-vendor-specific"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "index": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "method": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "eap-identity",
                    "eap-md5",
                    "eap-tls",
                    "eap-ttls",
                    "eap-peap",
                    "eap-sim",
                    "eap-aka",
                    "eap-aka-prime"
                ],
                "type": "str"
            }
        }
    },
    "hotspot20_anqpnairealm_nailist_eapmethod_authparam": {
        "stated": true,
        "options": {
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "non-eap-inner-auth",
                    "inner-auth-eap",
                    "credential",
                    "tunneled-credential"
                ],
                "type": "str"
            },
            "index": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "val": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "eap-identity",
                    "eap-md5",
                    "eap-tls",
                    "eap-ttls",
                    "eap-peap",
                    "eap-sim",
                    "eap-aka",
                    "eap-aka-prime",
                    "non-eap-pap",
                    "non-eap-chap",
                    "non-eap-mschap",
                    "non-eap-mschapv2",
                    "cred-sim",
                    "cred-usim",
                    "cred-nfc",
                    "cred-hardware-token",
                    "cred-softoken",
                    "cred-certificate",
                    "cred-user-pwd",
                    "cred-none",
                    "cred-vendor-specific",
                    "tun-cred-sim",
                    "tun-cred-usim",
                    "tun-cred-nfc",
                    "tun-cred-hardware-token",
                    "tun-cred-softoken",
                    "tun-cred-certificate",
                    "tun-cred-user-pwd",
                    "tun-cred-anonymous",
                    "tun-cred-vendor-specific"
                ],
                "type": "str"
            }
        }
    },
    "hotspot20_anqpnetworkauthtype": {
        "stated": true,
        "options": {
            "auth-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "acceptance-of-terms",
                    "online-enrollment",
                    "http-redirection",
                    "dns-redirection"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "url": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "hotspot20_anqproamingconsortium": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "oi-list": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "comment": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "index": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "oi": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "hotspot20_anqproamingconsortium_oilist": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "index": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "oi": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "hotspot20_anqpvenuename": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "value-list": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "index": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "lang": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "value": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "hotspot20_anqpvenuename_valuelist": {
        "stated": true,
        "options": {
            "index": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "lang": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "value": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "hotspot20_anqpvenueurl": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "value-list": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "index": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "number": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "value": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "hotspot20_anqpvenueurl_valuelist": {
        "stated": true,
        "options": {
            "index": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "number": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "value": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "hotspot20_h2qpadviceofcharge": {
        "stated": true,
        "options": {
            "aoc-list": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "nai-realm": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "nai-realm-encoding": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "plan-info": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "currency": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": false,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "info-file": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": false,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "lang": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": false,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": false,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "time-based",
                            "volume-based",
                            "time-and-volume-based",
                            "unlimited"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "hotspot20_h2qpadviceofcharge_aoclist": {
        "stated": true,
        "options": {
            "nai-realm": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "nai-realm-encoding": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "plan-info": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "currency": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "info-file": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "lang": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "time-based",
                    "volume-based",
                    "time-and-volume-based",
                    "unlimited"
                ],
                "type": "str"
            }
        }
    },
    "hotspot20_h2qpadviceofcharge_aoclist_planinfo": {
        "stated": true,
        "options": {
            "currency": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "info-file": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "lang": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "hotspot20_h2qpconncapability": {
        "stated": true,
        "options": {
            "esp-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "closed",
                    "open",
                    "unknown"
                ],
                "type": "str"
            },
            "ftp-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "closed",
                    "open",
                    "unknown"
                ],
                "type": "str"
            },
            "http-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "closed",
                    "open",
                    "unknown"
                ],
                "type": "str"
            },
            "icmp-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "closed",
                    "open",
                    "unknown"
                ],
                "type": "str"
            },
            "ikev2-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "closed",
                    "open",
                    "unknown"
                ],
                "type": "str"
            },
            "ikev2-xx-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "closed",
                    "open",
                    "unknown"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "pptp-vpn-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "closed",
                    "open",
                    "unknown"
                ],
                "type": "str"
            },
            "ssh-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "closed",
                    "open",
                    "unknown"
                ],
                "type": "str"
            },
            "tls-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "closed",
                    "open",
                    "unknown"
                ],
                "type": "str"
            },
            "voip-tcp-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "closed",
                    "open",
                    "unknown"
                ],
                "type": "str"
            },
            "voip-udp-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "closed",
                    "open",
                    "unknown"
                ],
                "type": "str"
            }
        }
    },
    "hotspot20_h2qpoperatorname": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "value-list": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "index": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "lang": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "value": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "hotspot20_h2qpoperatorname_valuelist": {
        "stated": true,
        "options": {
            "index": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "lang": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "value": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "hotspot20_h2qposuprovider": {
        "stated": true,
        "options": {
            "friendly-name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "friendly-name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "index": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "lang": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "icon": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "osu-method": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "oma-dm",
                    "soap-xml-spp",
                    "reserved"
                ],
                "elements": "str"
            },
            "osu-nai": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "server-uri": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "service-description": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "lang": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "service-description": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "service-id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "hotspot20_h2qposuprovider_friendlyname": {
        "stated": true,
        "options": {
            "friendly-name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "index": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "lang": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "hotspot20_h2qposuprovider_servicedescription": {
        "stated": true,
        "options": {
            "lang": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "service-description": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "service-id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "hotspot20_h2qposuprovidernai": {
        "stated": true,
        "options": {
            "nai-list": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "osu-nai": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "hotspot20_h2qposuprovidernai_nailist": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "osu-nai": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "hotspot20_h2qptermsandconditions": {
        "stated": true,
        "options": {
            "filename": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "timestamp": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "url": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "hotspot20_h2qpwanmetric": {
        "stated": true,
        "options": {
            "downlink-load": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "downlink-speed": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "link-at-capacity": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "link-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "down",
                    "up",
                    "in-test"
                ],
                "type": "str"
            },
            "load-measurement-duration": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "symmetric-wan-link": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "asymmetric",
                    "symmetric"
                ],
                "type": "str"
            },
            "uplink-load": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "uplink-speed": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "hotspot20_hsprofile": {
        "stated": true,
        "options": {
            "3gpp-plmn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "access-network-asra": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "access-network-esr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "access-network-internet": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "access-network-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "private-network",
                    "private-network-with-guest-access",
                    "chargeable-public-network",
                    "free-public-network",
                    "personal-device-network",
                    "emergency-services-only-network",
                    "test-or-experimental",
                    "wildcard"
                ],
                "type": "str"
            },
            "access-network-uesa": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "anqp-domain-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "bss-transition": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "conn-cap": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "deauth-request-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "dgaf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "domain-name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "gas-comeback-delay": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "gas-fragmentation-limit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "hessid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ip-addr-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "l2tif": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "nai-realm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "network-auth": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "oper-friendly-name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "osu-provider": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "osu-ssid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "pame-bi": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "proxy-arp": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "qos-map": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "roaming-consortium": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "venue-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "unspecified",
                    "assembly",
                    "business",
                    "educational",
                    "factory",
                    "institutional",
                    "mercantile",
                    "residential",
                    "storage",
                    "utility",
                    "vehicular",
                    "outdoor"
                ],
                "type": "str"
            },
            "venue-name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "venue-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "unspecified",
                    "arena",
                    "stadium",
                    "passenger-terminal",
                    "amphitheater",
                    "amusement-park",
                    "place-of-worship",
                    "convention-center",
                    "library",
                    "museum",
                    "restaurant",
                    "theater",
                    "bar",
                    "coffee-shop",
                    "zoo-or-aquarium",
                    "emergency-center",
                    "doctor-office",
                    "bank",
                    "fire-station",
                    "police-station",
                    "post-office",
                    "professional-office",
                    "research-facility",
                    "attorney-office",
                    "primary-school",
                    "secondary-school",
                    "university-or-college",
                    "factory",
                    "hospital",
                    "long-term-care-facility",
                    "rehab-center",
                    "group-home",
                    "prison-or-jail",
                    "retail-store",
                    "grocery-market",
                    "auto-service-station",
                    "shopping-mall",
                    "gas-station",
                    "private",
                    "hotel-or-motel",
                    "dormitory",
                    "boarding-house",
                    "automobile",
                    "airplane",
                    "bus",
                    "ferry",
                    "ship-or-boat",
                    "train",
                    "motor-bike",
                    "muni-mesh-network",
                    "city-park",
                    "rest-area",
                    "traffic-control",
                    "bus-stop",
                    "kiosk"
                ],
                "type": "str"
            },
            "wan-metrics": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "wnm-sleep-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "advice-of-charge": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "oper-icon": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "osu-provider-nai": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "release": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "terms-and-conditions": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "venue-url": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "hotspot20_icon": {
        "stated": true,
        "options": {
            "icon-list": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "file": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "height": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "lang": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "bmp",
                            "gif",
                            "jpeg",
                            "png",
                            "tiff"
                        ],
                        "type": "str"
                    },
                    "width": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "hotspot20_icon_iconlist": {
        "stated": true,
        "options": {
            "file": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "height": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "lang": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "bmp",
                    "gif",
                    "jpeg",
                    "png",
                    "tiff"
                ],
                "type": "str"
            },
            "width": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "hotspot20_qosmap": {
        "stated": true,
        "options": {
            "dscp-except": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "dscp": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "index": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "up": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "dscp-range": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "high": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "index": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "low": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "up": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "hotspot20_qosmap_dscpexcept": {
        "stated": true,
        "options": {
            "dscp": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "index": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "up": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "hotspot20_qosmap_dscprange": {
        "stated": true,
        "options": {
            "high": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "index": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "low": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "up": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "icap_profile": {
        "stated": true,
        "options": {
            "methods": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "delete",
                    "get",
                    "head",
                    "options",
                    "post",
                    "put",
                    "trace",
                    "other",
                    "connect"
                ],
                "elements": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "replacemsg-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "request-failure": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "error",
                    "bypass"
                ],
                "type": "str"
            },
            "request-path": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "request-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "response": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "response-failure": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "error",
                    "bypass"
                ],
                "type": "str"
            },
            "response-path": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "response-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "streaming-content-bypass": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "icap-headers": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "base64-encoding": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "content": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "preview": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "preview-data-length": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "response-req-hdr": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "respmod-default-action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "bypass",
                    "forward"
                ],
                "type": "str"
            },
            "respmod-forward-rules": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "bypass",
                            "forward"
                        ],
                        "type": "str"
                    },
                    "header-group": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "case-sensitivity": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "header": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "header-name": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            }
                        },
                        "elements": "dict"
                    },
                    "host": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "http-resp-status-code": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "204-response": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "204-size-limit": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "chunk-encap": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "extension-feature": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "scan-progress"
                ],
                "elements": "str"
            },
            "file-transfer": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "ssh",
                    "ftp"
                ],
                "elements": "str"
            },
            "file-transfer-failure": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "error",
                    "bypass"
                ],
                "type": "str"
            },
            "file-transfer-path": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "file-transfer-server": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "icap-block-log": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "scan-progress-interval": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "timeout": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "comment": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "icap_profile_icapheaders": {
        "stated": true,
        "options": {
            "base64-encoding": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "content": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "icap_profile_respmodforwardrules": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "bypass",
                    "forward"
                ],
                "type": "str"
            },
            "header-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "case-sensitivity": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "header": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "header-name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "host": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "http-resp-status-code": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "icap_profile_respmodforwardrules_headergroup": {
        "stated": true,
        "options": {
            "case-sensitivity": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "header": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "header-name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "icap_server": {
        "stated": true,
        "options": {
            "ip-address": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ip-version": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "4",
                    "6"
                ],
                "type": "str"
            },
            "ip6-address": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "max-connections": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "secure": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-cert": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "addr-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "fqdn",
                    "ip4",
                    "ip6"
                ],
                "type": "str"
            },
            "fqdn": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "healthcheck": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "healthcheck-service": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "ips_baseline_sensor": {
        "stated": true,
        "options": {
            "block-malicious-url": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "comment": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "entries": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "pass",
                            "block",
                            "reset",
                            "default"
                        ],
                        "type": "str"
                    },
                    "application": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "raw"
                    },
                    "cve": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "raw"
                    },
                    "exempt-ip": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "list",
                        "options": {
                            "dst-ip": {
                                "required": false,
                                "revision": {
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": false,
                                    "7.0.4": false,
                                    "7.0.5": false,
                                    "7.0.6": false,
                                    "7.0.7": false,
                                    "7.0.8": false,
                                    "7.0.9": false,
                                    "7.2.1": false,
                                    "7.2.2": false,
                                    "7.2.3": false,
                                    "7.2.4": false,
                                    "7.4.0": false,
                                    "7.4.1": false
                                },
                                "type": "str"
                            },
                            "id": {
                                "required": false,
                                "revision": {
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": false,
                                    "7.0.4": false,
                                    "7.0.5": false,
                                    "7.0.6": false,
                                    "7.0.7": false,
                                    "7.0.8": false,
                                    "7.0.9": false,
                                    "7.2.1": false,
                                    "7.2.2": false,
                                    "7.2.3": false,
                                    "7.2.4": false,
                                    "7.4.0": false,
                                    "7.4.1": false
                                },
                                "type": "int"
                            },
                            "src-ip": {
                                "required": false,
                                "revision": {
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": false,
                                    "7.0.4": false,
                                    "7.0.5": false,
                                    "7.0.6": false,
                                    "7.0.7": false,
                                    "7.0.8": false,
                                    "7.0.9": false,
                                    "7.2.1": false,
                                    "7.2.2": false,
                                    "7.2.3": false,
                                    "7.2.4": false,
                                    "7.4.0": false,
                                    "7.4.1": false
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "location": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "raw"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "log-attack-context": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "log-packet": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "os": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "raw"
                    },
                    "protocol": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "raw"
                    },
                    "quarantine": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "none",
                            "attacker",
                            "both",
                            "interface"
                        ],
                        "type": "str"
                    },
                    "quarantine-expiry": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "quarantine-log": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "rate-count": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "rate-duration": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "rate-mode": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "periodical",
                            "continuous"
                        ],
                        "type": "str"
                    },
                    "rate-track": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "none",
                            "src-ip",
                            "dest-ip",
                            "dhcp-client-mac",
                            "dns-domain"
                        ],
                        "type": "str"
                    },
                    "rule": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "severity": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "raw"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable",
                            "default"
                        ],
                        "type": "str"
                    },
                    "tags": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "extended-log": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "filter": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "pass",
                            "block",
                            "default",
                            "reset"
                        ],
                        "type": "str"
                    },
                    "application": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "raw"
                    },
                    "application(real)": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "location": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "raw"
                    },
                    "location(real)": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable",
                            "default"
                        ],
                        "type": "str"
                    },
                    "log-packet": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable",
                            "default"
                        ],
                        "type": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "os": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "raw"
                    },
                    "os(real)": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "protocol": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "raw"
                    },
                    "protocol(real)": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "quarantine": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "none",
                            "attacker",
                            "both",
                            "interface"
                        ],
                        "type": "str"
                    },
                    "quarantine-expiry": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "quarantine-log": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "severity": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "raw"
                    },
                    "severity(real)": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable",
                            "default"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "log": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "override": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "pass",
                            "block",
                            "reset"
                        ],
                        "type": "str"
                    },
                    "exempt-ip": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "list",
                        "options": {
                            "dst-ip": {
                                "required": false,
                                "revision": {
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": false,
                                    "7.0.4": false,
                                    "7.0.5": false,
                                    "7.0.6": false,
                                    "7.0.7": false,
                                    "7.0.8": false,
                                    "7.0.9": false,
                                    "7.2.1": false,
                                    "7.2.2": false,
                                    "7.2.3": false,
                                    "7.2.4": false,
                                    "7.4.0": false,
                                    "7.4.1": false
                                },
                                "type": "str"
                            },
                            "id": {
                                "required": false,
                                "revision": {
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": false,
                                    "7.0.4": false,
                                    "7.0.5": false,
                                    "7.0.6": false,
                                    "7.0.7": false,
                                    "7.0.8": false,
                                    "7.0.9": false,
                                    "7.2.1": false,
                                    "7.2.2": false,
                                    "7.2.3": false,
                                    "7.2.4": false,
                                    "7.4.0": false,
                                    "7.4.1": false
                                },
                                "type": "int"
                            },
                            "src-ip": {
                                "required": false,
                                "revision": {
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": false,
                                    "7.0.4": false,
                                    "7.0.5": false,
                                    "7.0.6": false,
                                    "7.0.7": false,
                                    "7.0.8": false,
                                    "7.0.9": false,
                                    "7.2.1": false,
                                    "7.2.2": false,
                                    "7.2.3": false,
                                    "7.2.4": false,
                                    "7.4.0": false,
                                    "7.4.1": false
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "log-packet": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "quarantine": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "none",
                            "attacker",
                            "both",
                            "interface"
                        ],
                        "type": "str"
                    },
                    "quarantine-expiry": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "quarantine-log": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "rule-id": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "replacemsg-group": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "scan-botnet-connections": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "block",
                    "monitor"
                ],
                "type": "str"
            }
        }
    },
    "ips_baseline_sensor_entries": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "pass",
                    "block",
                    "reset",
                    "default"
                ],
                "type": "str"
            },
            "application": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "cve": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "exempt-ip": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "dst-ip": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "src-ip": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "id": {
                "required": true,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "location": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "log": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "log-attack-context": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "log-packet": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "os": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "quarantine": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "none",
                    "attacker",
                    "both",
                    "interface"
                ],
                "type": "str"
            },
            "quarantine-expiry": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "quarantine-log": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "rate-count": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "rate-duration": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "rate-mode": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "periodical",
                    "continuous"
                ],
                "type": "str"
            },
            "rate-track": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "none",
                    "src-ip",
                    "dest-ip",
                    "dhcp-client-mac",
                    "dns-domain"
                ],
                "type": "str"
            },
            "rule": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "severity": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "status": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable",
                    "default"
                ],
                "type": "str"
            },
            "tags": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "ips_baseline_sensor_entries_exemptip": {
        "stated": true,
        "options": {
            "dst-ip": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "src-ip": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "ips_baseline_sensor_filter": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "pass",
                    "block",
                    "default",
                    "reset"
                ],
                "type": "str"
            },
            "application": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "application(real)": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "location": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "location(real)": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "log": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable",
                    "default"
                ],
                "type": "str"
            },
            "log-packet": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable",
                    "default"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "os": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "os(real)": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "protocol(real)": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "quarantine": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "none",
                    "attacker",
                    "both",
                    "interface"
                ],
                "type": "str"
            },
            "quarantine-expiry": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "quarantine-log": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "severity": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "severity(real)": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable",
                    "default"
                ],
                "type": "str"
            }
        }
    },
    "ips_baseline_sensor_override": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "pass",
                    "block",
                    "reset"
                ],
                "type": "str"
            },
            "exempt-ip": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "dst-ip": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "src-ip": {
                        "required": false,
                        "revision": {
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "log": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "log-packet": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "quarantine": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "none",
                    "attacker",
                    "both",
                    "interface"
                ],
                "type": "str"
            },
            "quarantine-expiry": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "quarantine-log": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "rule-id": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "ips_baseline_sensor_override_exemptip": {
        "stated": true,
        "options": {
            "dst-ip": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "src-ip": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "ips_custom": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "block",
                    "pass"
                ],
                "type": "str"
            },
            "application": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "location": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "log-packet": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "os": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "rule-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "severity": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sig-name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "signature": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tag": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "ips_sensor": {
        "stated": true,
        "options": {
            "block-malicious-url": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "entries": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "pass",
                            "block",
                            "reset",
                            "default"
                        ],
                        "type": "str"
                    },
                    "application": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "cve": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "default-action": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "block",
                            "pass",
                            "all",
                            "drop"
                        ],
                        "type": "str"
                    },
                    "default-status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable",
                            "all"
                        ],
                        "type": "str"
                    },
                    "exempt-ip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "dst-ip": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": false,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": false,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "src-ip": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": false,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "last-modified": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "location": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "log-attack-context": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "log-packet": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "os": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "position": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "header",
                            "footer"
                        ],
                        "type": "str"
                    },
                    "protocol": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "quarantine": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "attacker",
                            "both",
                            "interface"
                        ],
                        "type": "str"
                    },
                    "quarantine-expiry": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "quarantine-log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "rate-count": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "rate-duration": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "rate-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "periodical",
                            "continuous"
                        ],
                        "type": "str"
                    },
                    "rate-track": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "src-ip",
                            "dest-ip",
                            "dhcp-client-mac",
                            "dns-domain"
                        ],
                        "type": "str"
                    },
                    "rule": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "severity": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable",
                            "default"
                        ],
                        "type": "str"
                    },
                    "tags": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "vuln-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    }
                },
                "elements": "dict"
            },
            "extended-log": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "filter": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "pass",
                            "block",
                            "default",
                            "reset"
                        ],
                        "type": "str"
                    },
                    "application": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "application(real)": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "location": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "location(real)": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable",
                            "default"
                        ],
                        "type": "str"
                    },
                    "log-packet": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable",
                            "default"
                        ],
                        "type": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "os": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "os(real)": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "protocol": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "protocol(real)": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "quarantine": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "attacker",
                            "both",
                            "interface"
                        ],
                        "type": "str"
                    },
                    "quarantine-expiry": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "quarantine-log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "severity": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "severity(real)": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable",
                            "default"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "override": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "pass",
                            "block",
                            "reset"
                        ],
                        "type": "str"
                    },
                    "exempt-ip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "dst-ip": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": false,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": false,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "src-ip": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": false,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "log-packet": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "quarantine": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "attacker",
                            "both",
                            "interface"
                        ],
                        "type": "str"
                    },
                    "quarantine-expiry": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "quarantine-log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "rule-id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "replacemsg-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "scan-botnet-connections": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "block",
                    "monitor"
                ],
                "type": "str"
            }
        }
    },
    "ips_sensor_entries": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "block",
                    "reset",
                    "default"
                ],
                "type": "str"
            },
            "application": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "cve": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "default-action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "block",
                    "pass",
                    "all",
                    "drop"
                ],
                "type": "str"
            },
            "default-status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "all"
                ],
                "type": "str"
            },
            "exempt-ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "dst-ip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "src-ip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "last-modified": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "location": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "log-attack-context": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "log-packet": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "os": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "position": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "header",
                    "footer"
                ],
                "type": "str"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "quarantine": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "attacker",
                    "both",
                    "interface"
                ],
                "type": "str"
            },
            "quarantine-expiry": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "quarantine-log": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "rate-count": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "rate-duration": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "rate-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "periodical",
                    "continuous"
                ],
                "type": "str"
            },
            "rate-track": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "src-ip",
                    "dest-ip",
                    "dhcp-client-mac",
                    "dns-domain"
                ],
                "type": "str"
            },
            "rule": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "severity": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "default"
                ],
                "type": "str"
            },
            "tags": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "vuln-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "ips_sensor_entries_exemptip": {
        "stated": true,
        "options": {
            "dst-ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "src-ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "log_customfield": {
        "stated": true,
        "options": {
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "value": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "log_npuserver": {
        "stated": false,
        "options": {
            "log-processing": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "may-drop",
                    "no-drop"
                ],
                "type": "str"
            },
            "log-processor": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "hardware",
                    "host"
                ],
                "type": "str"
            },
            "netflow-ver": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "v9",
                    "v10"
                ],
                "type": "str"
            },
            "server-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "group-name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "log-format": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "syslog",
                            "netflow"
                        ],
                        "type": "str"
                    },
                    "log-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "per-session",
                            "per-nat-mapping",
                            "per-session-ending"
                        ],
                        "type": "str"
                    },
                    "log-tx-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "multicast",
                            "roundrobin"
                        ],
                        "type": "str"
                    },
                    "server-number": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "server-start-id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "sw-log-flags": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "log-gen-event": {
                        "required": false,
                        "revision": {
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "log-user-info": {
                        "required": false,
                        "revision": {
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "server-info": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "dest-port": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ip-family": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "v4",
                            "v6"
                        ],
                        "type": "str"
                    },
                    "ipv4-server": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ipv6-server": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "source-port": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "template-tx-timeout": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "syslog-facility": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "syslog-severity": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "log_npuserver_servergroup": {
        "stated": true,
        "options": {
            "group-name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "log-format": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "syslog",
                    "netflow"
                ],
                "type": "str"
            },
            "log-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "per-session",
                    "per-nat-mapping",
                    "per-session-ending"
                ],
                "type": "str"
            },
            "log-tx-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "multicast",
                    "roundrobin"
                ],
                "type": "str"
            },
            "server-number": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "server-start-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "sw-log-flags": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "log-gen-event": {
                "required": false,
                "revision": {
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "log-user-info": {
                "required": false,
                "revision": {
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "log_npuserver_serverinfo": {
        "stated": true,
        "options": {
            "dest-port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip-family": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "v4",
                    "v6"
                ],
                "type": "str"
            },
            "ipv4-server": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipv6-server": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "source-port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "template-tx-timeout": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "vdom": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "metafields_system_admin_user": {
        "stated": false,
        "options": {
            "importance": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "optional",
                    "required"
                ],
                "type": "str"
            },
            "length": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "mpskprofile": {
        "stated": true,
        "options": {
            "mpsk-concurrent-clients": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mpsk-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "mpsk-key": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "list",
                        "options": {
                            "comment": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "concurrent-client-limit-type": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "default",
                                    "unlimited",
                                    "specified"
                                ],
                                "type": "str"
                            },
                            "concurrent-clients": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "mac": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "mpsk-schedules": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            },
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "passphrase": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "no_log": true,
                                "type": "raw"
                            },
                            "pmk": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            }
                        },
                        "elements": "dict"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vlan-id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "vlan-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "no-vlan",
                            "fixed-vlan"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ssid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "mpskprofile_mpskgroup": {
        "stated": true,
        "options": {
            "mpsk-key": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "list",
                "options": {
                    "comment": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "concurrent-client-limit-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "default",
                            "unlimited",
                            "specified"
                        ],
                        "type": "str"
                    },
                    "concurrent-clients": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "mac": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "mpsk-schedules": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "passphrase": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "pmk": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    }
                },
                "elements": "dict"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vlan-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "vlan-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "no-vlan",
                    "fixed-vlan"
                ],
                "type": "str"
            }
        }
    },
    "mpskprofile_mpskgroup_mpskkey": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "concurrent-client-limit-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "default",
                    "unlimited",
                    "specified"
                ],
                "type": "str"
            },
            "concurrent-clients": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mac": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "mpsk-schedules": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "passphrase": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "pmk": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "nacprofile": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "onboarding-vlan": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "pkg_authentication_rule": {
        "stated": true,
        "options": {
            "active-auth-method": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "comments": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ip-based": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "http",
                    "ftp",
                    "socks",
                    "ssh"
                ],
                "type": "str"
            },
            "srcaddr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcaddr6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "sso-auth-method": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "transaction-based": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "web-auth-cookie": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "web-portal": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dstaddr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dstaddr6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcintf": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "cors-depth": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "cors-stateful": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "pkg_authentication_setting": {
        "stated": false,
        "options": {
            "active-auth-scheme": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "auth-https": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "captive-portal": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "captive-portal-ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "captive-portal-ip6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "captive-portal-port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "captive-portal-ssl-port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "captive-portal-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "fqdn",
                    "ip"
                ],
                "type": "str"
            },
            "captive-portal6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "rewrite-https-port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "sso-auth-scheme": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dev-range": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "user-cert-ca": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "cert-auth": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "cert-captive-portal": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cert-captive-portal-ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cert-captive-portal-port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "cookie-max-age": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "cookie-refresh-div": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip-auth-cookie": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "persistent-cookie": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "update-time": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "pkg_central_dnat": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "pkg_central_dnat6": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "pkg_firewall_acl": {
        "stated": true,
        "options": {
            "comments": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "dstaddr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "interface": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "policyid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "service": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "srcaddr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "pkg_firewall_acl6": {
        "stated": true,
        "options": {
            "comments": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "dstaddr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "interface": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "policyid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "service": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "srcaddr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "pkg_firewall_centralsnatmap": {
        "stated": true,
        "options": {
            "dst-addr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dstintf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "nat": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "nat-ippool": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "nat-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "orig-addr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "orig-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "policyid": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "srcintf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "comments": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dst-addr6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "nat-ippool6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "orig-addr6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ipv4",
                    "ipv6"
                ],
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "nat46": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "nat64": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dst-port": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "pkg_firewall_consolidated_policy": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "deny",
                    "accept",
                    "ipsec"
                ],
                "type": "str"
            },
            "app-category": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "app-group": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "application": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "application-list": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "auto-asic-offload": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "av-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cifs-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "comments": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "diffserv-forward": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "diffserv-reverse": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "diffservcode-forward": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "diffservcode-rev": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dlp-sensor": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dnsfilter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dstaddr4": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dstaddr6": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dstintf": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "emailfilter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "fixedport": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "groups": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "http-policy-redirect": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "icap-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "inbound": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "inspection-mode": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "proxy",
                    "flow"
                ],
                "type": "str"
            },
            "internet-service": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service-custom": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-custom-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service-src-custom": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src-custom-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ippool": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ips-sensor": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "logtraffic": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "all",
                    "utm"
                ],
                "type": "str"
            },
            "logtraffic-start": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mms-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "nat": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "outbound": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "per-ip-shaper": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "policyid": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "poolname4": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "poolname6": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "profile-group": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "profile-protocol-options": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "profile-type": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "single",
                    "group"
                ],
                "type": "str"
            },
            "schedule": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "service": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "session-ttl": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "srcaddr4": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcaddr6": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcintf": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ssh-filter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "ssh-policy-redirect": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-ssh-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tcp-mss-receiver": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tcp-mss-sender": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "traffic-shaper": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "traffic-shaper-reverse": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "url-category": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "users": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "utm-status": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "voip-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vpntunnel": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "waf-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "wanopt": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "wanopt-detection": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "active",
                    "passive",
                    "off"
                ],
                "type": "str"
            },
            "wanopt-passive-opt": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "default",
                    "transparent",
                    "non-transparent"
                ],
                "type": "str"
            },
            "wanopt-peer": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "wanopt-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "webcache": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "webcache-https": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "webfilter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "webproxy-forward-server": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "webproxy-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "captive-portal-exempt": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dstaddr-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fsso-groups": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "global-label": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "internet-service-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service-src-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "service-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "srcaddr-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "_policy_block": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "pkg_firewall_consolidated_policy_sectionvalue": {
        "stated": true,
        "options": {
            "attr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "label",
                    "global-label"
                ],
                "type": "str"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "pkg_firewall_dospolicy": {
        "stated": true,
        "options": {
            "anomaly": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "pass",
                            "block",
                            "proxy"
                        ],
                        "type": "str"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "quarantine": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "attacker",
                            "both",
                            "interface"
                        ],
                        "type": "str"
                    },
                    "quarantine-expiry": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "quarantine-log": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "threshold": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "threshold(default)": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "synproxy_tos": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "0",
                            "10",
                            "12",
                            "14",
                            "18",
                            "20",
                            "22",
                            "26",
                            "28",
                            "30",
                            "34",
                            "36",
                            "38",
                            "40",
                            "46",
                            "255"
                        ],
                        "type": "str"
                    },
                    "synproxy_ttl": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "32",
                            "64",
                            "128",
                            "255"
                        ],
                        "type": "str"
                    },
                    "synproxy_tcp_sack": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "synproxy_tcp_window": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "4096",
                            "8192",
                            "16384",
                            "32768"
                        ],
                        "type": "str"
                    },
                    "synproxy_tcp_timestamp": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "synproxy_tcp_mss": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "0",
                            "256",
                            "512",
                            "1024",
                            "1300",
                            "1360",
                            "1460",
                            "1500"
                        ],
                        "type": "str"
                    },
                    "synproxy_tcp_windowscale": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "0",
                            "1",
                            "2",
                            "3",
                            "4",
                            "5",
                            "6",
                            "7",
                            "8",
                            "9",
                            "10",
                            "11",
                            "12",
                            "13",
                            "14"
                        ],
                        "type": "str"
                    },
                    "synproxy-tos": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "0",
                            "10",
                            "12",
                            "14",
                            "18",
                            "20",
                            "22",
                            "26",
                            "28",
                            "30",
                            "34",
                            "36",
                            "38",
                            "40",
                            "46",
                            "255"
                        ],
                        "type": "str"
                    },
                    "synproxy-tcp-window": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "4096",
                            "8192",
                            "16384",
                            "32768"
                        ],
                        "type": "str"
                    },
                    "synproxy-tcp-windowscale": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "0",
                            "1",
                            "2",
                            "3",
                            "4",
                            "5",
                            "6",
                            "7",
                            "8",
                            "9",
                            "10",
                            "11",
                            "12",
                            "13",
                            "14"
                        ],
                        "type": "str"
                    },
                    "synproxy-tcp-timestamp": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "synproxy-ttl": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "32",
                            "64",
                            "128",
                            "255"
                        ],
                        "type": "str"
                    },
                    "synproxy-tcp-mss": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "0",
                            "256",
                            "512",
                            "1024",
                            "1300",
                            "1360",
                            "1460",
                            "1500"
                        ],
                        "type": "str"
                    },
                    "synproxy-tcp-sack": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "comments": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dstaddr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "interface": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "policyid": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "service": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcaddr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "pkg_firewall_dospolicy6": {
        "stated": true,
        "options": {
            "anomaly": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "pass",
                            "block",
                            "proxy"
                        ],
                        "type": "str"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "quarantine": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "attacker",
                            "both",
                            "interface"
                        ],
                        "type": "str"
                    },
                    "quarantine-expiry": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "quarantine-log": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "threshold": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "threshold(default)": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "synproxy_tos": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "0",
                            "10",
                            "12",
                            "14",
                            "18",
                            "20",
                            "22",
                            "26",
                            "28",
                            "30",
                            "34",
                            "36",
                            "38",
                            "40",
                            "46",
                            "255"
                        ],
                        "type": "str"
                    },
                    "synproxy_ttl": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "32",
                            "64",
                            "128",
                            "255"
                        ],
                        "type": "str"
                    },
                    "synproxy_tcp_sack": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "synproxy_tcp_window": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "4096",
                            "8192",
                            "16384",
                            "32768"
                        ],
                        "type": "str"
                    },
                    "synproxy_tcp_timestamp": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "synproxy_tcp_mss": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "0",
                            "256",
                            "512",
                            "1024",
                            "1300",
                            "1360",
                            "1460",
                            "1500"
                        ],
                        "type": "str"
                    },
                    "synproxy_tcp_windowscale": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "0",
                            "1",
                            "2",
                            "3",
                            "4",
                            "5",
                            "6",
                            "7",
                            "8",
                            "9",
                            "10",
                            "11",
                            "12",
                            "13",
                            "14"
                        ],
                        "type": "str"
                    },
                    "synproxy-tos": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "0",
                            "10",
                            "12",
                            "14",
                            "18",
                            "20",
                            "22",
                            "26",
                            "28",
                            "30",
                            "34",
                            "36",
                            "38",
                            "40",
                            "46",
                            "255"
                        ],
                        "type": "str"
                    },
                    "synproxy-tcp-window": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "4096",
                            "8192",
                            "16384",
                            "32768"
                        ],
                        "type": "str"
                    },
                    "synproxy-tcp-windowscale": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "0",
                            "1",
                            "2",
                            "3",
                            "4",
                            "5",
                            "6",
                            "7",
                            "8",
                            "9",
                            "10",
                            "11",
                            "12",
                            "13",
                            "14"
                        ],
                        "type": "str"
                    },
                    "synproxy-tcp-timestamp": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "synproxy-ttl": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "32",
                            "64",
                            "128",
                            "255"
                        ],
                        "type": "str"
                    },
                    "synproxy-tcp-mss": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "0",
                            "256",
                            "512",
                            "1024",
                            "1300",
                            "1360",
                            "1460",
                            "1500"
                        ],
                        "type": "str"
                    },
                    "synproxy-tcp-sack": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "comments": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dstaddr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "interface": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "policyid": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "service": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcaddr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "pkg_firewall_dospolicy6_anomaly": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "block",
                    "proxy"
                ],
                "type": "str"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "quarantine": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "attacker",
                    "both",
                    "interface"
                ],
                "type": "str"
            },
            "quarantine-expiry": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "quarantine-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "threshold": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "threshold(default)": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "synproxy_tos": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "0",
                    "10",
                    "12",
                    "14",
                    "18",
                    "20",
                    "22",
                    "26",
                    "28",
                    "30",
                    "34",
                    "36",
                    "38",
                    "40",
                    "46",
                    "255"
                ],
                "type": "str"
            },
            "synproxy_ttl": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "32",
                    "64",
                    "128",
                    "255"
                ],
                "type": "str"
            },
            "synproxy_tcp_sack": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "synproxy_tcp_window": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "4096",
                    "8192",
                    "16384",
                    "32768"
                ],
                "type": "str"
            },
            "synproxy_tcp_timestamp": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "synproxy_tcp_mss": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "0",
                    "256",
                    "512",
                    "1024",
                    "1300",
                    "1360",
                    "1460",
                    "1500"
                ],
                "type": "str"
            },
            "synproxy_tcp_windowscale": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "0",
                    "1",
                    "2",
                    "3",
                    "4",
                    "5",
                    "6",
                    "7",
                    "8",
                    "9",
                    "10",
                    "11",
                    "12",
                    "13",
                    "14"
                ],
                "type": "str"
            },
            "synproxy-tos": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "0",
                    "10",
                    "12",
                    "14",
                    "18",
                    "20",
                    "22",
                    "26",
                    "28",
                    "30",
                    "34",
                    "36",
                    "38",
                    "40",
                    "46",
                    "255"
                ],
                "type": "str"
            },
            "synproxy-tcp-window": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "4096",
                    "8192",
                    "16384",
                    "32768"
                ],
                "type": "str"
            },
            "synproxy-tcp-windowscale": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "0",
                    "1",
                    "2",
                    "3",
                    "4",
                    "5",
                    "6",
                    "7",
                    "8",
                    "9",
                    "10",
                    "11",
                    "12",
                    "13",
                    "14"
                ],
                "type": "str"
            },
            "synproxy-tcp-timestamp": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "synproxy-ttl": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "32",
                    "64",
                    "128",
                    "255"
                ],
                "type": "str"
            },
            "synproxy-tcp-mss": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "0",
                    "256",
                    "512",
                    "1024",
                    "1300",
                    "1360",
                    "1460",
                    "1500"
                ],
                "type": "str"
            },
            "synproxy-tcp-sack": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "pkg_firewall_dospolicy_anomaly": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "block",
                    "proxy"
                ],
                "type": "str"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "quarantine": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "attacker",
                    "both",
                    "interface"
                ],
                "type": "str"
            },
            "quarantine-expiry": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "quarantine-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "threshold": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "threshold(default)": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "synproxy_tos": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "0",
                    "10",
                    "12",
                    "14",
                    "18",
                    "20",
                    "22",
                    "26",
                    "28",
                    "30",
                    "34",
                    "36",
                    "38",
                    "40",
                    "46",
                    "255"
                ],
                "type": "str"
            },
            "synproxy_ttl": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "32",
                    "64",
                    "128",
                    "255"
                ],
                "type": "str"
            },
            "synproxy_tcp_sack": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "synproxy_tcp_window": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "4096",
                    "8192",
                    "16384",
                    "32768"
                ],
                "type": "str"
            },
            "synproxy_tcp_timestamp": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "synproxy_tcp_mss": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "0",
                    "256",
                    "512",
                    "1024",
                    "1300",
                    "1360",
                    "1460",
                    "1500"
                ],
                "type": "str"
            },
            "synproxy_tcp_windowscale": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "0",
                    "1",
                    "2",
                    "3",
                    "4",
                    "5",
                    "6",
                    "7",
                    "8",
                    "9",
                    "10",
                    "11",
                    "12",
                    "13",
                    "14"
                ],
                "type": "str"
            },
            "synproxy-tos": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "0",
                    "10",
                    "12",
                    "14",
                    "18",
                    "20",
                    "22",
                    "26",
                    "28",
                    "30",
                    "34",
                    "36",
                    "38",
                    "40",
                    "46",
                    "255"
                ],
                "type": "str"
            },
            "synproxy-tcp-window": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "4096",
                    "8192",
                    "16384",
                    "32768"
                ],
                "type": "str"
            },
            "synproxy-tcp-windowscale": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "0",
                    "1",
                    "2",
                    "3",
                    "4",
                    "5",
                    "6",
                    "7",
                    "8",
                    "9",
                    "10",
                    "11",
                    "12",
                    "13",
                    "14"
                ],
                "type": "str"
            },
            "synproxy-tcp-timestamp": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "synproxy-ttl": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "32",
                    "64",
                    "128",
                    "255"
                ],
                "type": "str"
            },
            "synproxy-tcp-mss": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "0",
                    "256",
                    "512",
                    "1024",
                    "1300",
                    "1360",
                    "1460",
                    "1500"
                ],
                "type": "str"
            },
            "synproxy-tcp-sack": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "pkg_firewall_explicitproxypolicy": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "deny",
                    "accept"
                ],
                "type": "str"
            },
            "active-auth-method": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "ntlm",
                    "basic",
                    "digest",
                    "form",
                    "none",
                    "negotiate"
                ],
                "type": "str"
            },
            "application-list": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "av-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "casi-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "comments": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "disclaimer": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "domain",
                    "policy",
                    "user"
                ],
                "type": "str"
            },
            "dlp-sensor": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "dstaddr": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "dstaddr-negate": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dstaddr6": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "dstintf": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "global-label": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "icap-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "identity-based": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "identity-based-policy": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "application-list": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "av-profile": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "casi-profile": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "disclaimer": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "domain",
                            "policy",
                            "user"
                        ],
                        "type": "str"
                    },
                    "dlp-sensor": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "groups": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "icap-profile": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "ips-sensor": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "logtraffic": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "all",
                            "utm"
                        ],
                        "type": "str"
                    },
                    "logtraffic-start": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "mms-profile": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "profile-group": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "profile-protocol-options": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "profile-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "single",
                            "group"
                        ],
                        "type": "str"
                    },
                    "replacemsg-override-group": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "scan-botnet-connections": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "block",
                            "monitor"
                        ],
                        "type": "str"
                    },
                    "schedule": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "spamfilter-profile": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "ssl-ssh-profile": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "users": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "utm-status": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "waf-profile": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "webfilter-profile": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "ip-based": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ips-sensor": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "label": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "logtraffic": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "all",
                    "utm"
                ],
                "type": "str"
            },
            "logtraffic-start": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mms-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "policyid": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "profile-group": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "profile-protocol-options": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "profile-type": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "single",
                    "group"
                ],
                "type": "str"
            },
            "proxy": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "web",
                    "ftp",
                    "wanopt"
                ],
                "type": "str"
            },
            "replacemsg-override-group": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "require-tfa": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "scan-botnet-connections": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "block",
                    "monitor"
                ],
                "type": "str"
            },
            "schedule": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "service": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "service-negate": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "spamfilter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "srcaddr": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "srcaddr-negate": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "srcaddr6": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "ssl-ssh-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "sso-auth-method": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "fsso",
                    "rsso",
                    "none"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tags": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "transaction-based": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "transparent": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "utm-status": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "waf-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "web-auth-cookie": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "webcache": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "webcache-https": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "any",
                    "enable"
                ],
                "type": "str"
            },
            "webfilter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "webproxy-forward-server": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "webproxy-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "pkg_firewall_explicitproxypolicy_identitybasedpolicy": {
        "stated": true,
        "options": {
            "application-list": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "av-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "casi-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "disclaimer": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "domain",
                    "policy",
                    "user"
                ],
                "type": "str"
            },
            "dlp-sensor": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "groups": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "icap-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "ips-sensor": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "logtraffic": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "all",
                    "utm"
                ],
                "type": "str"
            },
            "logtraffic-start": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mms-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "profile-group": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "profile-protocol-options": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "profile-type": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "single",
                    "group"
                ],
                "type": "str"
            },
            "replacemsg-override-group": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "scan-botnet-connections": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "block",
                    "monitor"
                ],
                "type": "str"
            },
            "schedule": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "spamfilter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "ssl-ssh-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "users": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "utm-status": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "waf-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "webfilter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "pkg_firewall_explicitproxypolicy_sectionvalue": {
        "stated": true,
        "options": {
            "attr": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "label",
                    "global-label"
                ],
                "type": "str"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "pkg_firewall_hyperscalepolicy": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "deny",
                    "accept"
                ],
                "type": "str"
            },
            "auto-asic-offload": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "cgn-eif": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "cgn-eim": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "cgn-log-server-grp": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "cgn-resource-quota": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "cgn-session-quota": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "comments": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "delay-tcp-npu-session": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dstaddr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "dstaddr-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dstaddr6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "dstintf": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "firewall-session-dirty": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "check-all",
                    "check-new"
                ],
                "type": "str"
            },
            "global-label": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "ippool": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "label": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "nat": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "policy-offload": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "policyid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "poolname": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "poolname6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "send-deny-packet": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "service": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "service-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "srcaddr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "srcaddr-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "srcaddr6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "srcintf": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tcp-timeout-pid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "traffic-shaper": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "traffic-shaper-reverse": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "udp-timeout-pid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "pkg_firewall_hyperscalepolicy46": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "deny",
                    "accept"
                ],
                "type": "str"
            },
            "cgn-log-server-grp": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "comments": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "dstaddr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "dstintf": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "policy-offload": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "policyid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "service": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "srcaddr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "srcintf": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tcp-timeout-pid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "traffic-shaper": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "traffic-shaper-reverse": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "udp-timeout-pid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "pkg_firewall_hyperscalepolicy6": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "deny",
                    "accept",
                    "ipsec"
                ],
                "type": "str"
            },
            "auto-asic-offload": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "cgn-log-server-grp": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "comments": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "dstaddr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "dstaddr-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dstintf": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "policy-offload": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "policyid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "service": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "service-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "srcaddr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "srcaddr-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "srcintf": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tcp-timeout-pid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "traffic-shaper": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "traffic-shaper-reverse": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "udp-timeout-pid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "pkg_firewall_hyperscalepolicy64": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "deny",
                    "accept"
                ],
                "type": "str"
            },
            "cgn-eif": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "cgn-eim": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "cgn-log-server-grp": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "cgn-resource-quota": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "cgn-session-quota": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "comments": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "dstaddr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "dstintf": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "ippool": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "policy-offload": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "policyid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "poolname": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "service": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "srcaddr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "srcintf": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tcp-timeout-pid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "traffic-shaper": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "traffic-shaper-reverse": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "udp-timeout-pid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "pkg_firewall_interfacepolicy": {
        "stated": true,
        "options": {
            "address-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "ipv4",
                    "ipv6"
                ],
                "type": "str"
            },
            "application-list": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "application-list-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "av-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "av-profile-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "comments": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "dlp-sensor": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "dlp-sensor-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dsri": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dstaddr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "interface": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "ips-sensor": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "ips-sensor-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "label": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "logtraffic": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "all",
                    "utm"
                ],
                "type": "str"
            },
            "policyid": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "scan-botnet-connections": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "block",
                    "monitor"
                ],
                "type": "str"
            },
            "service": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "spamfilter-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "spamfilter-profile-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "srcaddr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "webfilter-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "webfilter-profile-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "emailfilter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "emailfilter-profile-status": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "casi-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "casi-profile-status": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dlp-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "dlp-profile-status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "pkg_firewall_interfacepolicy6": {
        "stated": true,
        "options": {
            "address-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "ipv4",
                    "ipv6"
                ],
                "type": "str"
            },
            "application-list": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "application-list-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "av-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "av-profile-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "comments": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "dlp-sensor": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "dlp-sensor-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dsri": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dstaddr6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "interface": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "ips-sensor": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "ips-sensor-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "label": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "logtraffic": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "all",
                    "utm"
                ],
                "type": "str"
            },
            "policyid": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "scan-botnet-connections": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "block",
                    "monitor"
                ],
                "type": "str"
            },
            "service6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "spamfilter-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "spamfilter-profile-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "srcaddr6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "webfilter-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "webfilter-profile-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "emailfilter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "emailfilter-profile-status": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "casi-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "casi-profile-status": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dlp-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "dlp-profile-status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "pkg_firewall_interfacepolicy6_sectionvalue": {
        "stated": true,
        "options": {
            "attr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "label",
                    "global-label"
                ],
                "type": "str"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "pkg_firewall_interfacepolicy_sectionvalue": {
        "stated": true,
        "options": {
            "attr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "label",
                    "global-label"
                ],
                "type": "str"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "pkg_firewall_localinpolicy": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "deny",
                    "accept"
                ],
                "type": "str"
            },
            "dstaddr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ha-mgmt-intf-only": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "intf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "policyid": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "schedule": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "service": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcaddr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "comments": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dstaddr-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "service-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "srcaddr-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "virtual-patch": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "pkg_firewall_localinpolicy6": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "deny",
                    "accept"
                ],
                "type": "str"
            },
            "dstaddr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "intf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "policyid": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "schedule": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "service": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcaddr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "comments": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dstaddr-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "service-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "srcaddr-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "virtual-patch": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "pkg_firewall_multicastpolicy": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "deny",
                    "accept"
                ],
                "type": "str"
            },
            "auto-asic-offload": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dnat": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dstaddr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dstintf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "end-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "logtraffic": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "snat": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "snat-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "srcaddr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcintf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "start-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "comments": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "traffic-shaper": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "pkg_firewall_multicastpolicy6": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "deny",
                    "accept"
                ],
                "type": "str"
            },
            "auto-asic-offload": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dstaddr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dstintf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "end-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "logtraffic": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "srcaddr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcintf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "start-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "comments": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "pkg_firewall_policy": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "deny",
                    "accept",
                    "ipsec",
                    "ssl-vpn",
                    "redirect",
                    "isolate"
                ],
                "type": "str"
            },
            "app-category": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "application": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "application-list": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "auth-cert": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "auth-path": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "auth-redirect-addr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "auto-asic-offload": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "av-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "block-notification": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "captive-portal-exempt": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "capture-packet": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "comments": {
                "required": false,
                "type": "raw"
            },
            "custom-log-fields": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "delay-tcp-npu-session": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "devices": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "diffserv-forward": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "diffserv-reverse": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "diffservcode-forward": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "diffservcode-rev": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "disclaimer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "user",
                    "domain",
                    "policy"
                ],
                "type": "str"
            },
            "dlp-sensor": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dnsfilter-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dscp-match": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dscp-negate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dscp-value": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "dsri": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dstaddr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dstaddr-negate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dstintf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "firewall-session-dirty": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "check-all",
                    "check-new"
                ],
                "type": "str"
            },
            "fixedport": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fsso": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fsso-agent-for-ntlm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "global-label": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "groups": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "gtp-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "icap-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "identity-based-route": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "inbound": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service-custom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-negate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ippool": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ips-sensor": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "label": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "learning-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "logtraffic": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "all",
                    "utm"
                ],
                "type": "str"
            },
            "logtraffic-start": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "match-vip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mms-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "nat": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "natinbound": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "natip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "natoutbound": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ntlm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ntlm-enabled-browsers": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ntlm-guest": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "outbound": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "per-ip-shaper": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "permit-any-host": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "permit-stun-host": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "policyid": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "poolname": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "profile-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "profile-protocol-options": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "profile-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "single",
                    "group"
                ],
                "type": "str"
            },
            "radius-mac-auth-bypass": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "redirect-url": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "replacemsg-override-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "rsso": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "rtp-addr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "rtp-nat": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "scan-botnet-connections": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "block",
                    "monitor"
                ],
                "type": "str"
            },
            "schedule": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "schedule-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "send-deny-packet": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "service": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "service-negate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "session-ttl": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "spamfilter-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "srcaddr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcaddr-negate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "srcintf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ssl-mirror": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-mirror-intf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ssl-ssh-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "tcp-mss-receiver": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tcp-mss-sender": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tcp-session-without-syn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "all",
                    "data-only",
                    "disable"
                ],
                "type": "str"
            },
            "timeout-send-rst": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "traffic-shaper": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "traffic-shaper-reverse": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "url-category": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "users": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "utm-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vlan-cos-fwd": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "vlan-cos-rev": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "voip-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vpn_dst_node": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "host": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "seq": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "subnet": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "vpn_src_node": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "host": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "seq": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "subnet": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "vpntunnel": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "waf-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "wanopt": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "wanopt-detection": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "active",
                    "passive",
                    "off"
                ],
                "type": "str"
            },
            "wanopt-passive-opt": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "default",
                    "transparent",
                    "non-transparent"
                ],
                "type": "str"
            },
            "wanopt-peer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "wanopt-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "wccp": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "webcache": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "webcache-https": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "ssl-server",
                    "any",
                    "enable"
                ],
                "type": "str"
            },
            "webfilter-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "wsso": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "anti-replay": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "app-group": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "cifs-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "email-collect": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "emailfilter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "fsso-groups": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "geoip-anycast": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "http-policy-redirect": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "inspection-mode": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "proxy",
                    "flow"
                ],
                "type": "str"
            },
            "internet-service-custom-group": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-group": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service-src-custom": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src-custom-group": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src-group": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src-id": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src-negate": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "match-vip-only": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "np-acceleration": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "reputation-direction": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "source",
                    "destination"
                ],
                "type": "str"
            },
            "reputation-minimum": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ssh-filter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ssh-policy-redirect": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tos": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tos-mask": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tos-negate": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "vlan-filter": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "webproxy-forward-server": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "webproxy-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "np-accelation": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "delay-tcp-npu-sessoin": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "casi-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "best-route": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "decrypted-traffic-mirror": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dstaddr6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "geoip-match": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "physical-location",
                    "registered-location"
                ],
                "type": "str"
            },
            "internet-service-name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src-name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "poolname6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "src-vendor-mac": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcaddr6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "file-filter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "policy-offload": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "cgn-session-quota": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "cgn-eif": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "cgn-log-server-grp": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cgn-eim": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "cgn-resource-quota": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "dynamic-shaping": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "passive-wan-health-measurement": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "videofilter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ztna-ems-tag": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ztna-geo-tag": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ztna-status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "_policy_block": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "dlp-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "fec": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "nat46": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "nat64": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "pfcp-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "policy-expiry": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "policy-expiry-date": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sctp-filter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sgt": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "sgt-check": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tcp-timeout-pid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "udp-timeout-pid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "diffserv-copy": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dstaddr6-negate": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service6": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service6-custom": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service6-custom-group": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service6-group": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service6-name": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service6-negate": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service6-src": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service6-src-custom": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service6-src-custom-group": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service6-src-group": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service6-src-name": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service6-src-negate": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "network-service-dynamic": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "network-service-src-dynamic": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "reputation-direction6": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "source",
                    "destination"
                ],
                "type": "str"
            },
            "reputation-minimum6": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "srcaddr6-negate": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ip-version-type": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ips-voip-filter": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "pcp-inbound": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "pcp-outbound": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "pcp-poolname": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "policy-behaviour-type": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "policy-expiry-date-utc": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ztna-device-ownership": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ztna-ems-tag-secondary": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ztna-policy-redirect": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ztna-tags-match-logic": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "or",
                    "and"
                ],
                "type": "str"
            },
            "casb-profile": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "virtual-patch-profile": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "object position": {
                "required": false,
                "type": "list",
                "elements": "str"
            }
        }
    },
    "pkg_firewall_policy46": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "deny",
                    "accept"
                ],
                "type": "str"
            },
            "comments": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dstaddr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dstintf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "fixedport": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "logtraffic": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "per-ip-shaper": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "permit-any-host": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "policyid": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "schedule": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "service": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcaddr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcintf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "tcp-mss-receiver": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tcp-mss-sender": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "traffic-shaper": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "traffic-shaper-reverse": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ippool": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "logtraffic-start": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "poolname": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cgn-log-server-grp": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "policy-offload": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "pkg_firewall_policy6": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "deny",
                    "accept",
                    "ipsec",
                    "ssl-vpn"
                ],
                "type": "str"
            },
            "app-category": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "application": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "application-list": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "auto-asic-offload": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "av-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "comments": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "custom-log-fields": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "devices": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "diffserv-forward": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "diffserv-reverse": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "diffservcode-forward": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "diffservcode-rev": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dlp-sensor": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dscp-match": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dscp-negate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dscp-value": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "dsri": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dstaddr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dstaddr-negate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dstintf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "firewall-session-dirty": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "check-all",
                    "check-new"
                ],
                "type": "str"
            },
            "fixedport": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "global-label": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "groups": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "icap-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "inbound": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ippool": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ips-sensor": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "label": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "logtraffic": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "all",
                    "utm"
                ],
                "type": "str"
            },
            "logtraffic-start": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mms-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "nat": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "natinbound": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "natoutbound": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "np-accelation": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "outbound": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "per-ip-shaper": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "policyid": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "poolname": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "profile-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "profile-protocol-options": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "profile-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "single",
                    "group"
                ],
                "type": "str"
            },
            "replacemsg-override-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "rsso": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "schedule": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "send-deny-packet": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "service": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "service-negate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "session-ttl": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "spamfilter-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "srcaddr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcaddr-negate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "srcintf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ssl-mirror": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-mirror-intf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ssl-ssh-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "tcp-mss-receiver": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tcp-mss-sender": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tcp-session-without-syn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "all",
                    "data-only",
                    "disable"
                ],
                "type": "str"
            },
            "timeout-send-rst": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "traffic-shaper": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "traffic-shaper-reverse": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "url-category": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "users": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "utm-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vlan-cos-fwd": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "vlan-cos-rev": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "voip-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vpntunnel": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "webfilter-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "anti-replay": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "app-group": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "cifs-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dnsfilter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "emailfilter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "http-policy-redirect": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "inspection-mode": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "proxy",
                    "flow"
                ],
                "type": "str"
            },
            "np-acceleration": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssh-filter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "ssh-policy-redirect": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tos": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tos-mask": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tos-negate": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "vlan-filter": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "waf-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "webcache": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "webcache-https": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "webproxy-forward-server": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "webproxy-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "casi-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "fsso-groups": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "decrypted-traffic-mirror": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "cgn-log-server-grp": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "policy-offload": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "_policy_block": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "pkg_firewall_policy64": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "deny",
                    "accept"
                ],
                "type": "str"
            },
            "comments": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dstaddr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dstintf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "fixedport": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ippool": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "logtraffic": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "per-ip-shaper": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "permit-any-host": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "policyid": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "poolname": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "schedule": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "service": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcaddr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcintf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "tcp-mss-receiver": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tcp-mss-sender": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "traffic-shaper": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "traffic-shaper-reverse": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "logtraffic-start": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "policy-offload": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "cgn-session-quota": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "cgn-eif": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "cgn-log-server-grp": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cgn-resource-quota": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "cgn-eim": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "pkg_firewall_policy6_sectionvalue": {
        "stated": true,
        "options": {
            "attr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "label",
                    "global-label"
                ],
                "type": "str"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "pkg_firewall_policy_sectionvalue": {
        "stated": true,
        "options": {
            "attr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "label",
                    "global-label"
                ],
                "type": "str"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "pkg_firewall_policy_vpndstnode": {
        "stated": true,
        "options": {
            "host": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "seq": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "subnet": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "pkg_firewall_policy_vpnsrcnode": {
        "stated": true,
        "options": {
            "host": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "seq": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "subnet": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "pkg_firewall_proxypolicy": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "accept",
                    "deny",
                    "redirect"
                ],
                "type": "str"
            },
            "application-list": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "av-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "comments": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "disclaimer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "domain",
                    "policy",
                    "user"
                ],
                "type": "str"
            },
            "dlp-sensor": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dstaddr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dstaddr-negate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dstaddr6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dstintf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "global-label": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "groups": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "http-tunnel-auth": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "icap-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "internet-service": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service-custom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-negate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ips-sensor": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "label": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "logtraffic": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "all",
                    "utm"
                ],
                "type": "str"
            },
            "logtraffic-start": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mms-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "policyid": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "poolname": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "profile-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "profile-protocol-options": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "profile-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "single",
                    "group"
                ],
                "type": "str"
            },
            "proxy": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "explicit-web",
                    "transparent-web",
                    "ftp",
                    "wanopt",
                    "ssh",
                    "ssh-tunnel",
                    "access-proxy"
                ],
                "type": "str"
            },
            "redirect-url": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "replacemsg-override-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "scan-botnet-connections": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "block",
                    "monitor"
                ],
                "type": "str"
            },
            "schedule": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "service": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "service-negate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "spamfilter-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "srcaddr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcaddr-negate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "srcaddr6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcintf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ssl-ssh-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "transparent": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "users": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "utm-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "waf-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "webcache": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "webcache-https": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "webfilter-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "webproxy-forward-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "webproxy-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cifs-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "emailfilter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "internet-service-custom-group": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-group": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "session-ttl": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ssh-filter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "ssh-policy-redirect": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "decrypted-traffic-mirror": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "internet-service-name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "file-filter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "access-proxy": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "device-ownership": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "videofilter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "voip-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "ztna-ems-tag": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "access-proxy6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "block-notification": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dlp-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "sctp-filter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "ztna-tags-match-logic": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "or",
                    "and"
                ],
                "type": "str"
            }
        }
    },
    "pkg_firewall_proxypolicy_sectionvalue": {
        "stated": true,
        "options": {
            "attr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "label",
                    "global-label"
                ],
                "type": "str"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "pkg_firewall_securitypolicy": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "deny",
                    "accept"
                ],
                "type": "str"
            },
            "app-category": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "app-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "application": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "application-list": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "av-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cifs-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "comments": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dlp-sensor": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dnsfilter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dstaddr4": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dstaddr6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dstintf": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "emailfilter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "enforce-default-app-port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "groups": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "icap-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "internet-service": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service-custom": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-custom-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service-src": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service-src-custom": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src-custom-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ips-sensor": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "logtraffic": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "all",
                    "utm"
                ],
                "type": "str"
            },
            "logtraffic-start": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mms-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "policyid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "profile-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "profile-protocol-options": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "profile-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "single",
                    "group"
                ],
                "type": "str"
            },
            "schedule": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "service": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "service-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "srcaddr4": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcaddr6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcintf": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ssh-filter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ssl-ssh-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "url-category": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "users": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "utm-status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "voip-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "webfilter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "fsso-groups": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "global-label": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "send-deny-packet": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dstaddr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "internet-service-name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "internet-service-src-name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "srcaddr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "dstaddr-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "file-filter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "srcaddr-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "learning-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "videofilter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "_policy_block": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "dlp-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "nat46": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "nat64": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sctp-filter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "internet-service6": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service6-custom": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "internet-service6-custom-group": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "internet-service6-group": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "internet-service6-name": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "internet-service6-negate": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service6-src": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service6-src-custom": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "internet-service6-src-custom-group": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "internet-service6-src-group": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "internet-service6-src-name": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "internet-service6-src-negate": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "pkg_firewall_securitypolicy_sectionvalue": {
        "stated": true,
        "options": {
            "attr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "label",
                    "global-label"
                ],
                "type": "str"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "pkg_firewall_shapingpolicy": {
        "stated": true,
        "options": {
            "app-category": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "application": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dstaddr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dstaddr6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dstintf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "groups": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip-version": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "4",
                    "6"
                ],
                "type": "str"
            },
            "per-ip-shaper": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "schedule": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "service": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcaddr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcaddr6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "traffic-shaper": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "traffic-shaper-reverse": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "url-category": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "users": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "app-group": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "class-id": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "diffserv-forward": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "diffserv-reverse": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "diffservcode-forward": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "diffservcode-rev": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "internet-service": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service-custom": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-custom-group": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-group": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-id": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service-src-custom": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src-custom-group": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src-group": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src-id": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "srcintf": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "tos": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tos-mask": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tos-negate": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "internet-service-name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src-name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "cos": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cos-mask": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "traffic-type": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "forwarding",
                    "local-in",
                    "local-out"
                ],
                "type": "str"
            }
        }
    },
    "pkg_footer_policy": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "deny",
                    "accept",
                    "ipsec",
                    "ssl-vpn",
                    "redirect",
                    "isolate"
                ],
                "type": "str"
            },
            "active-auth-method": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ntlm",
                    "basic",
                    "digest",
                    "form"
                ],
                "type": "str"
            },
            "anti-replay": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "app-category": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "app-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "application": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "application-charts": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "top10-app",
                    "top10-p2p-user",
                    "top10-media-user"
                ],
                "elements": "str"
            },
            "application-list": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "auth-cert": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "auth-method": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "basic",
                    "digest",
                    "ntlm",
                    "fsae",
                    "form",
                    "fsso",
                    "rsso"
                ],
                "type": "str"
            },
            "auth-path": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "auth-portal": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "auth-redirect-addr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "auto-asic-offload": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "av-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "bandwidth": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "block-notification": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "captive-portal-exempt": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "capture-packet": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "casi-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "central-nat": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "cifs-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "client-reputation": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "client-reputation-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "learning",
                    "monitoring"
                ],
                "type": "str"
            },
            "comments": {
                "required": false,
                "type": "raw"
            },
            "custom-log-fields": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "deep-inspection-options": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "delay-tcp-npu-session": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "delay-tcp-npu-sessoin": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "device-detection-portal": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "devices": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "diffserv-forward": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "diffserv-reverse": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "diffservcode-forward": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "diffservcode-rev": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "disclaimer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "user",
                    "domain",
                    "policy"
                ],
                "type": "str"
            },
            "dlp-sensor": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dnsfilter-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dponly": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dscp-match": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dscp-negate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dscp-value": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dsri": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dstaddr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dstaddr-negate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dstaddr6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dstintf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dynamic-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dynamic-profile-access": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "imap",
                    "smtp",
                    "pop3",
                    "http",
                    "ftp",
                    "im",
                    "nntp",
                    "imaps",
                    "smtps",
                    "pop3s",
                    "https",
                    "ftps",
                    "ssh"
                ],
                "elements": "str"
            },
            "dynamic-profile-fallthrough": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dynamic-profile-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "email-collect": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "email-collection-portal": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "emailfilter-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "endpoint-check": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "endpoint-compliance": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "endpoint-keepalive-interface": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "endpoint-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "failed-connection": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fall-through-unauthenticated": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "firewall-session-dirty": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "check-all",
                    "check-new"
                ],
                "type": "str"
            },
            "fixedport": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "forticlient-compliance-devices": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "windows-pc",
                    "mac",
                    "iphone-ipad",
                    "android"
                ],
                "elements": "str"
            },
            "forticlient-compliance-enforcement-portal": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fsae": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fsae-server-for-ntlm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "fsso": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fsso-agent-for-ntlm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "geo-location": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "geoip-anycast": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "global-label": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "groups": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "gtp-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "http-policy-redirect": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "icap-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "identity-based": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "identity-based-policy": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": false,
                    "6.2.2": false,
                    "6.2.3": false,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "deny",
                            "accept"
                        ],
                        "type": "str"
                    },
                    "application-charts": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "list",
                        "choices": [
                            "top10-app",
                            "top10-p2p-user",
                            "top10-media-user"
                        ],
                        "elements": "str"
                    },
                    "application-list": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "av-profile": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "capture-packet": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "deep-inspection-options": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "devices": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "dlp-sensor": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "dstaddr": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "dstaddr-negate": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "endpoint-compliance": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "groups": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "icap-profile": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "ips-sensor": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "logtraffic": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable",
                            "all",
                            "utm"
                        ],
                        "type": "str"
                    },
                    "logtraffic-app": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "logtraffic-start": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "mms-profile": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "per-ip-shaper": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "profile-group": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "profile-protocol-options": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "profile-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "single",
                            "group"
                        ],
                        "type": "str"
                    },
                    "replacemsg-group": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "schedule": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "send-deny-packet": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "service": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "service-negate": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "spamfilter-profile": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "sslvpn-portal": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "sslvpn-realm": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "traffic-shaper": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "traffic-shaper-reverse": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "users": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "utm-status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "voip-profile": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "webfilter-profile": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "identity-based-route": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "identity-from": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auth",
                    "device"
                ],
                "type": "str"
            },
            "inbound": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "inspection-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "proxy",
                    "flow"
                ],
                "type": "str"
            },
            "internet-service": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service-custom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-custom-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-negate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service-src": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service-src-custom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src-custom-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src-negate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ip-based": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ippool": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ips-sensor": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "label": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "learning-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "log-unmatched-traffic": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "logtraffic": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "all",
                    "utm"
                ],
                "type": "str"
            },
            "logtraffic-app": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "logtraffic-start": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "match-vip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mms-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "nat": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "natinbound": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "natip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "natoutbound": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "np-acceleration": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ntlm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ntlm-enabled-browsers": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ntlm-guest": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "outbound": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "per-ip-shaper": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "permit-any-host": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "permit-stun-host": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "policyid": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "poolname": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "profile-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "profile-protocol-options": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "profile-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "single",
                    "group"
                ],
                "type": "str"
            },
            "radius-mac-auth-bypass": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "redirect-url": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "replacemsg-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "replacemsg-override-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "reputation-direction": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "source",
                    "destination"
                ],
                "type": "str"
            },
            "reputation-minimum": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "require-tfa": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "rsso": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "rtp-addr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "rtp-nat": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "scan-botnet-connections": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "block",
                    "monitor"
                ],
                "type": "str"
            },
            "schedule": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "schedule-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "send-deny-packet": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "service": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "service-negate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "session-ttl": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "sessions": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "spamfilter-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcaddr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcaddr-negate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "srcaddr6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcintf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ssh-filter-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ssh-policy-redirect": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-mirror": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-mirror-intf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ssl-ssh-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sslvpn-auth": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "any",
                    "local",
                    "radius",
                    "ldap",
                    "tacacs+"
                ],
                "type": "str"
            },
            "sslvpn-ccert": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sslvpn-cipher": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "any",
                    "high",
                    "medium"
                ],
                "type": "str"
            },
            "sso-auth-method": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "fsso",
                    "rsso"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "tcp-mss-receiver": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tcp-mss-sender": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tcp-reset": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tcp-session-without-syn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "all",
                    "data-only",
                    "disable"
                ],
                "type": "str"
            },
            "timeout-send-rst": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tos": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tos-mask": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tos-negate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "traffic-shaper": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "traffic-shaper-reverse": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "transaction-based": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "url-category": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "users": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "utm-inspection-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "proxy",
                    "flow"
                ],
                "type": "str"
            },
            "utm-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vlan-cos-fwd": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "vlan-cos-rev": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "vlan-filter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "voip-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vpntunnel": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "waf-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "wanopt": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "wanopt-detection": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "active",
                    "passive",
                    "off"
                ],
                "type": "str"
            },
            "wanopt-passive-opt": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "default",
                    "transparent",
                    "non-transparent"
                ],
                "type": "str"
            },
            "wanopt-peer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "wanopt-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "wccp": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "web-auth-cookie": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "webcache": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "webcache-https": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "ssl-server",
                    "any",
                    "enable"
                ],
                "type": "str"
            },
            "webfilter-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "webproxy-forward-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "webproxy-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "wsso": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fsso-groups": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "match-vip-only": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "np-accelation": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "best-route": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "decrypted-traffic-mirror": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "geoip-match": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "physical-location",
                    "registered-location"
                ],
                "type": "str"
            },
            "internet-service-name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src-name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "poolname6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "src-vendor-mac": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "vendor-mac": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "file-filter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cgn-eif": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "cgn-eim": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "cgn-log-server-grp": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "cgn-resource-quota": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "cgn-session-quota": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "policy-offload": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dynamic-shaping": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "passive-wan-health-measurement": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "videofilter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ztna-ems-tag": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ztna-geo-tag": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ztna-status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "access-proxy": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dlp-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dynamic-bypass": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fec": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "force-proxy": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "http-tunnel-auth": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ia-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "isolator-server": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "log-http-transaction": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "all",
                    "utm"
                ],
                "type": "str"
            },
            "max-session-per-user": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "nat46": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "nat64": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "pass-through": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "pfcp-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "policy-expiry": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "policy-expiry-date": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "reverse-cache": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sctp-filter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sgt": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "sgt-check": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tcp-timeout-pid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "transparent": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "explicit-web",
                    "transparent",
                    "explicit-ftp",
                    "ssh-tunnel",
                    "ssh",
                    "wanopt",
                    "access-proxy"
                ],
                "type": "str"
            },
            "udp-timeout-pid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ztna-tags-match-logic": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "or",
                    "and"
                ],
                "type": "str"
            },
            "uuid-idx": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "device-ownership": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssh-policy-check": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "diffserv-copy": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dstaddr6-negate": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service6": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service6-custom": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service6-custom-group": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service6-group": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service6-name": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service6-negate": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service6-src": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service6-src-custom": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service6-src-custom-group": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service6-src-group": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service6-src-name": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service6-src-negate": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "network-service-dynamic": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "network-service-src-dynamic": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "reputation-direction6": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "source",
                    "destination"
                ],
                "type": "str"
            },
            "reputation-minimum6": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "srcaddr6-negate": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "_policy_block": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "isolator-profile": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "policy-expiry-date-utc": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ztna-device-ownership": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ztna-policy-redirect": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ip-version-type": {
                "required": false,
                "revision": {
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ips-voip-filter": {
                "required": false,
                "revision": {
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "policy-behaviour-type": {
                "required": false,
                "revision": {
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "pcp-inbound": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "pcp-outbound": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "pcp-poolname": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ztna-ems-tag-secondary": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "casb-profile": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "extended-log": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "implicit-proxy-detection": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "virtual-patch-profile": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "pkg_footer_policy6": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "deny",
                    "accept",
                    "ipsec",
                    "ssl-vpn"
                ],
                "type": "str"
            },
            "anti-replay": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "app-category": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "app-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "application": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "application-charts": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "top10-app",
                    "top10-p2p-user",
                    "top10-media-user"
                ],
                "elements": "str"
            },
            "application-list": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "auto-asic-offload": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "av-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "casi-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "cifs-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "comments": {
                "required": false,
                "type": "str"
            },
            "custom-log-fields": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "deep-inspection-options": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "device-detection-portal": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "devices": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "diffserv-forward": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "diffserv-reverse": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "diffservcode-forward": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "diffservcode-rev": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dlp-sensor": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dnsfilter-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dscp-match": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dscp-negate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dscp-value": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dsri": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dstaddr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dstaddr-negate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dstintf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dynamic-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dynamic-profile-access": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "imap",
                    "smtp",
                    "pop3",
                    "http",
                    "ftp",
                    "im",
                    "nntp",
                    "imaps",
                    "smtps",
                    "pop3s",
                    "https",
                    "ftps"
                ],
                "elements": "str"
            },
            "dynamic-profile-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "email-collection-portal": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "emailfilter-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "firewall-session-dirty": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "check-all",
                    "check-new"
                ],
                "type": "str"
            },
            "fixedport": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fsae": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "global-label": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "groups": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "http-policy-redirect": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "icap-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "identity-based": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "identity-based-policy6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": false,
                    "6.2.2": false,
                    "6.2.3": false,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "deny",
                            "accept"
                        ],
                        "type": "str"
                    },
                    "application-list": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "av-profile": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "deep-inspection-options": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "devices": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "dlp-sensor": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "endpoint-compliance": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "groups": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "icap-profile": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "ips-sensor": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "logtraffic": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable",
                            "all",
                            "utm"
                        ],
                        "type": "str"
                    },
                    "mms-profile": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "per-ip-shaper": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "profile-group": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "profile-protocol-options": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "profile-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "single",
                            "group"
                        ],
                        "type": "str"
                    },
                    "replacemsg-group": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "schedule": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "send-deny-packet": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "service": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "service-negate": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "spamfilter-profile": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "sslvpn-portal": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "sslvpn-realm": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "traffic-shaper": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "traffic-shaper-reverse": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "utm-status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "voip-profile": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "webfilter-profile": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "identity-from": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auth",
                    "device"
                ],
                "type": "str"
            },
            "inbound": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "inspection-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "proxy",
                    "flow"
                ],
                "type": "str"
            },
            "ippool": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ips-sensor": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "label": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "logtraffic": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "all",
                    "utm"
                ],
                "type": "str"
            },
            "logtraffic-start": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mms-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "nat": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "natinbound": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "natoutbound": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "np-accelation": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "np-acceleration": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "outbound": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "per-ip-shaper": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "policyid": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "poolname": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "profile-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "profile-protocol-options": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "profile-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "single",
                    "group"
                ],
                "type": "str"
            },
            "replacemsg-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "replacemsg-override-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "rsso": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "schedule": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "send-deny-packet": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "service": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "service-negate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "session-ttl": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "spamfilter-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcaddr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcaddr-negate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "srcintf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ssh-filter-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ssh-policy-redirect": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-mirror": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-mirror-intf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ssl-ssh-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "sslvpn-auth": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "any",
                    "local",
                    "radius",
                    "ldap",
                    "tacacs+"
                ],
                "type": "str"
            },
            "sslvpn-ccert": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sslvpn-cipher": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "any",
                    "high",
                    "medium"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "tcp-mss-receiver": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tcp-mss-sender": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tcp-session-without-syn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "all",
                    "data-only",
                    "disable"
                ],
                "type": "str"
            },
            "timeout-send-rst": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tos": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tos-mask": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tos-negate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "traffic-shaper": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "traffic-shaper-reverse": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "url-category": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "users": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "utm-inspection-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "proxy",
                    "flow"
                ],
                "type": "str"
            },
            "utm-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vlan-cos-fwd": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "vlan-cos-rev": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "vlan-filter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "voip-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "vpntunnel": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "webfilter-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "waf-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "webcache": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "webcache-https": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "webproxy-forward-server": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "webproxy-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "fsso-groups": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "decrypted-traffic-mirror": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "file-filter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "cgn-log-server-grp": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "policy-offload": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "_policy_block": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "pkg_footer_shapingpolicy": {
        "stated": true,
        "options": {
            "app-category": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "app-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "application": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "class-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "diffserv-forward": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "diffserv-reverse": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "diffservcode-forward": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "diffservcode-rev": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dstaddr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dstaddr6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dstintf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "groups": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "internet-service": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service-custom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-custom-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service-src-custom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src-custom-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ip-version": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "4",
                    "6"
                ],
                "type": "str"
            },
            "per-ip-shaper": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "schedule": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "service": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcaddr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcaddr6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcintf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tos": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tos-mask": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tos-negate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "traffic-shaper": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "traffic-shaper-reverse": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "url-category": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "users": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "internet-service-name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src-name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "class-id-reverse": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "service-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "service",
                    "internet-service"
                ],
                "type": "str"
            },
            "uuid-idx": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "cos": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cos-mask": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "traffic-type": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "forwarding",
                    "local-in",
                    "local-out"
                ],
                "type": "str"
            }
        }
    },
    "pkg_header_policy": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "deny",
                    "accept",
                    "ipsec",
                    "ssl-vpn",
                    "redirect",
                    "isolate"
                ],
                "type": "str"
            },
            "active-auth-method": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ntlm",
                    "basic",
                    "digest",
                    "form"
                ],
                "type": "str"
            },
            "anti-replay": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "app-category": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "app-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "application": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "application-charts": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "top10-app",
                    "top10-p2p-user",
                    "top10-media-user"
                ],
                "elements": "str"
            },
            "application-list": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "auth-cert": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "auth-method": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "basic",
                    "digest",
                    "ntlm",
                    "fsae",
                    "form",
                    "fsso",
                    "rsso"
                ],
                "type": "str"
            },
            "auth-path": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "auth-portal": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "auth-redirect-addr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "auto-asic-offload": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "av-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "bandwidth": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "block-notification": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "captive-portal-exempt": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "capture-packet": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "casi-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "central-nat": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "cifs-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "client-reputation": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "client-reputation-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "learning",
                    "monitoring"
                ],
                "type": "str"
            },
            "comments": {
                "required": false,
                "type": "raw"
            },
            "custom-log-fields": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "deep-inspection-options": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "delay-tcp-npu-session": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "delay-tcp-npu-sessoin": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "device-detection-portal": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "devices": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "diffserv-forward": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "diffserv-reverse": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "diffservcode-forward": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "diffservcode-rev": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "disclaimer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "user",
                    "domain",
                    "policy"
                ],
                "type": "str"
            },
            "dlp-sensor": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dnsfilter-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dponly": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dscp-match": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dscp-negate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dscp-value": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dsri": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dstaddr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dstaddr-negate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dstaddr6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dstintf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dynamic-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dynamic-profile-access": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "imap",
                    "smtp",
                    "pop3",
                    "http",
                    "ftp",
                    "im",
                    "nntp",
                    "imaps",
                    "smtps",
                    "pop3s",
                    "https",
                    "ftps",
                    "ssh"
                ],
                "elements": "str"
            },
            "dynamic-profile-fallthrough": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dynamic-profile-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "email-collect": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "email-collection-portal": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "emailfilter-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "endpoint-check": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "endpoint-compliance": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "endpoint-keepalive-interface": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "endpoint-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "failed-connection": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fall-through-unauthenticated": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "firewall-session-dirty": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "check-all",
                    "check-new"
                ],
                "type": "str"
            },
            "fixedport": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "forticlient-compliance-devices": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "windows-pc",
                    "mac",
                    "iphone-ipad",
                    "android"
                ],
                "elements": "str"
            },
            "forticlient-compliance-enforcement-portal": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fsae": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fsae-server-for-ntlm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "fsso": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fsso-agent-for-ntlm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "geo-location": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "geoip-anycast": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "global-label": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "groups": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "gtp-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "http-policy-redirect": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "icap-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "identity-based": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "identity-based-policy": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": false,
                    "6.2.2": false,
                    "6.2.3": false,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "deny",
                            "accept"
                        ],
                        "type": "str"
                    },
                    "application-charts": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "list",
                        "choices": [
                            "top10-app",
                            "top10-p2p-user",
                            "top10-media-user"
                        ],
                        "elements": "str"
                    },
                    "application-list": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "av-profile": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "capture-packet": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "deep-inspection-options": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "devices": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "dlp-sensor": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "dstaddr": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "dstaddr-negate": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "endpoint-compliance": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "groups": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "icap-profile": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "ips-sensor": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "logtraffic": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable",
                            "all",
                            "utm"
                        ],
                        "type": "str"
                    },
                    "logtraffic-app": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "logtraffic-start": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "mms-profile": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "per-ip-shaper": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "profile-group": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "profile-protocol-options": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "profile-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "single",
                            "group"
                        ],
                        "type": "str"
                    },
                    "replacemsg-group": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "schedule": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "send-deny-packet": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "service": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "service-negate": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "spamfilter-profile": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "sslvpn-portal": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "sslvpn-realm": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "traffic-shaper": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "traffic-shaper-reverse": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "users": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "utm-status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "voip-profile": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "webfilter-profile": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "identity-based-route": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "identity-from": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auth",
                    "device"
                ],
                "type": "str"
            },
            "inbound": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "inspection-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "proxy",
                    "flow"
                ],
                "type": "str"
            },
            "internet-service": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service-custom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-custom-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-negate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service-src": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service-src-custom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src-custom-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src-negate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ip-based": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ippool": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ips-sensor": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "label": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "learning-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "log-unmatched-traffic": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "logtraffic": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "all",
                    "utm"
                ],
                "type": "str"
            },
            "logtraffic-app": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "logtraffic-start": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "match-vip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mms-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "nat": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "natinbound": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "natip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "natoutbound": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "np-acceleration": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ntlm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ntlm-enabled-browsers": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ntlm-guest": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "outbound": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "per-ip-shaper": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "permit-any-host": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "permit-stun-host": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "policyid": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "poolname": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "profile-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "profile-protocol-options": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "profile-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "single",
                    "group"
                ],
                "type": "str"
            },
            "radius-mac-auth-bypass": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "redirect-url": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "replacemsg-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "replacemsg-override-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "reputation-direction": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "source",
                    "destination"
                ],
                "type": "str"
            },
            "reputation-minimum": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "require-tfa": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "rsso": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "rtp-addr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "rtp-nat": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "scan-botnet-connections": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "block",
                    "monitor"
                ],
                "type": "str"
            },
            "schedule": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "schedule-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "send-deny-packet": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "service": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "service-negate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "session-ttl": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "sessions": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "spamfilter-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcaddr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcaddr-negate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "srcaddr6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcintf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ssh-filter-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ssh-policy-redirect": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-mirror": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-mirror-intf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ssl-ssh-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sslvpn-auth": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "any",
                    "local",
                    "radius",
                    "ldap",
                    "tacacs+"
                ],
                "type": "str"
            },
            "sslvpn-ccert": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sslvpn-cipher": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "any",
                    "high",
                    "medium"
                ],
                "type": "str"
            },
            "sso-auth-method": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "fsso",
                    "rsso"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "tcp-mss-receiver": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tcp-mss-sender": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tcp-reset": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tcp-session-without-syn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "all",
                    "data-only",
                    "disable"
                ],
                "type": "str"
            },
            "timeout-send-rst": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tos": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tos-mask": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tos-negate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "traffic-shaper": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "traffic-shaper-reverse": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "transaction-based": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "url-category": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "users": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "utm-inspection-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "proxy",
                    "flow"
                ],
                "type": "str"
            },
            "utm-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vlan-cos-fwd": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "vlan-cos-rev": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "vlan-filter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "voip-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vpntunnel": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "waf-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "wanopt": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "wanopt-detection": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "active",
                    "passive",
                    "off"
                ],
                "type": "str"
            },
            "wanopt-passive-opt": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "default",
                    "transparent",
                    "non-transparent"
                ],
                "type": "str"
            },
            "wanopt-peer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "wanopt-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "wccp": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "web-auth-cookie": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "webcache": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "webcache-https": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "ssl-server",
                    "any",
                    "enable"
                ],
                "type": "str"
            },
            "webfilter-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "webproxy-forward-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "webproxy-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "wsso": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fsso-groups": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "match-vip-only": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "np-accelation": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "best-route": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "decrypted-traffic-mirror": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "geoip-match": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "physical-location",
                    "registered-location"
                ],
                "type": "str"
            },
            "internet-service-name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src-name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "poolname6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "src-vendor-mac": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "vendor-mac": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "file-filter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cgn-eif": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "cgn-eim": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "cgn-log-server-grp": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "cgn-resource-quota": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "cgn-session-quota": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "policy-offload": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dynamic-shaping": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "passive-wan-health-measurement": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "videofilter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ztna-ems-tag": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ztna-geo-tag": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ztna-status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "access-proxy": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dlp-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dynamic-bypass": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fec": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "force-proxy": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "http-tunnel-auth": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ia-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "isolator-server": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "log-http-transaction": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "all",
                    "utm"
                ],
                "type": "str"
            },
            "max-session-per-user": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "nat46": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "nat64": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "pass-through": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "pfcp-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "policy-expiry": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "policy-expiry-date": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "reverse-cache": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sctp-filter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sgt": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "sgt-check": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tcp-timeout-pid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "transparent": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "explicit-web",
                    "transparent",
                    "explicit-ftp",
                    "ssh-tunnel",
                    "ssh",
                    "wanopt",
                    "access-proxy"
                ],
                "type": "str"
            },
            "udp-timeout-pid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ztna-tags-match-logic": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "or",
                    "and"
                ],
                "type": "str"
            },
            "uuid-idx": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "device-ownership": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssh-policy-check": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "diffserv-copy": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dstaddr6-negate": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service6": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service6-custom": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service6-custom-group": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service6-group": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service6-name": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service6-negate": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service6-src": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service6-src-custom": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service6-src-custom-group": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service6-src-group": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service6-src-name": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service6-src-negate": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "network-service-dynamic": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "network-service-src-dynamic": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "reputation-direction6": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "source",
                    "destination"
                ],
                "type": "str"
            },
            "reputation-minimum6": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "srcaddr6-negate": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "_policy_block": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "isolator-profile": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "policy-expiry-date-utc": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ztna-device-ownership": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ztna-policy-redirect": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ip-version-type": {
                "required": false,
                "revision": {
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ips-voip-filter": {
                "required": false,
                "revision": {
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "policy-behaviour-type": {
                "required": false,
                "revision": {
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "pcp-inbound": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "pcp-outbound": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "pcp-poolname": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ztna-ems-tag-secondary": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "casb-profile": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "extended-log": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "implicit-proxy-detection": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "virtual-patch-profile": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "pkg_header_policy6": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "deny",
                    "accept",
                    "ipsec",
                    "ssl-vpn"
                ],
                "type": "str"
            },
            "anti-replay": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "app-category": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "app-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "application": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "application-charts": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "top10-app",
                    "top10-p2p-user",
                    "top10-media-user"
                ],
                "elements": "str"
            },
            "application-list": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "auto-asic-offload": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "av-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "casi-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "cifs-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "comments": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "custom-log-fields": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "deep-inspection-options": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "device-detection-portal": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "devices": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "diffserv-forward": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "diffserv-reverse": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "diffservcode-forward": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "diffservcode-rev": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dlp-sensor": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dnsfilter-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dscp-match": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dscp-negate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dscp-value": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dsri": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dstaddr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dstaddr-negate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dstintf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dynamic-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dynamic-profile-access": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "imap",
                    "smtp",
                    "pop3",
                    "http",
                    "ftp",
                    "im",
                    "nntp",
                    "imaps",
                    "smtps",
                    "pop3s",
                    "https",
                    "ftps"
                ],
                "elements": "str"
            },
            "dynamic-profile-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "email-collection-portal": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "emailfilter-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "firewall-session-dirty": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "check-all",
                    "check-new"
                ],
                "type": "str"
            },
            "fixedport": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fsae": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "global-label": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "groups": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "http-policy-redirect": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "icap-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "identity-based": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "identity-based-policy6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": false,
                    "6.2.2": false,
                    "6.2.3": false,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "deny",
                            "accept"
                        ],
                        "type": "str"
                    },
                    "application-list": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "av-profile": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "deep-inspection-options": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "devices": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "dlp-sensor": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "endpoint-compliance": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "groups": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "icap-profile": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "ips-sensor": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "logtraffic": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable",
                            "all",
                            "utm"
                        ],
                        "type": "str"
                    },
                    "mms-profile": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "per-ip-shaper": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "profile-group": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "profile-protocol-options": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "profile-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "single",
                            "group"
                        ],
                        "type": "str"
                    },
                    "replacemsg-group": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "schedule": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "send-deny-packet": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "service": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "service-negate": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "spamfilter-profile": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "sslvpn-portal": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "sslvpn-realm": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "traffic-shaper": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "traffic-shaper-reverse": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "utm-status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "voip-profile": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "webfilter-profile": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "identity-from": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auth",
                    "device"
                ],
                "type": "str"
            },
            "inbound": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "inspection-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "proxy",
                    "flow"
                ],
                "type": "str"
            },
            "ippool": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ips-sensor": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "label": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "logtraffic": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "all",
                    "utm"
                ],
                "type": "str"
            },
            "logtraffic-start": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mms-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "nat": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "natinbound": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "natoutbound": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "np-accelation": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "np-acceleration": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "outbound": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "per-ip-shaper": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "policyid": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "poolname": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "profile-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "profile-protocol-options": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "profile-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "single",
                    "group"
                ],
                "type": "str"
            },
            "replacemsg-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "replacemsg-override-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "rsso": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "schedule": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "send-deny-packet": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "service": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "service-negate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "session-ttl": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "spamfilter-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcaddr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcaddr-negate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "srcintf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ssh-filter-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ssh-policy-redirect": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-mirror": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-mirror-intf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ssl-ssh-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "sslvpn-auth": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "any",
                    "local",
                    "radius",
                    "ldap",
                    "tacacs+"
                ],
                "type": "str"
            },
            "sslvpn-ccert": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sslvpn-cipher": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "any",
                    "high",
                    "medium"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "tcp-mss-receiver": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tcp-mss-sender": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tcp-session-without-syn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "all",
                    "data-only",
                    "disable"
                ],
                "type": "str"
            },
            "timeout-send-rst": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tos": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tos-mask": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tos-negate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "traffic-shaper": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "traffic-shaper-reverse": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "url-category": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "users": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "utm-inspection-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "proxy",
                    "flow"
                ],
                "type": "str"
            },
            "utm-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vlan-cos-fwd": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "vlan-cos-rev": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "vlan-filter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "voip-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "vpntunnel": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "webfilter-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "waf-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "webcache": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "webcache-https": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "webproxy-forward-server": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "webproxy-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "fsso-groups": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "decrypted-traffic-mirror": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "file-filter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "cgn-log-server-grp": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "policy-offload": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "_policy_block": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "pkg_header_shapingpolicy": {
        "stated": true,
        "options": {
            "app-category": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "app-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "application": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "class-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "diffserv-forward": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "diffserv-reverse": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "diffservcode-forward": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "diffservcode-rev": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dstaddr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dstaddr6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dstintf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "groups": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "internet-service": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service-custom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-custom-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service-src-custom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src-custom-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ip-version": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "4",
                    "6"
                ],
                "type": "str"
            },
            "per-ip-shaper": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "schedule": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "service": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcaddr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcaddr6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcintf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tos": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tos-mask": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tos-negate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "traffic-shaper": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "traffic-shaper-reverse": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "url-category": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "users": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "internet-service-name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src-name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "class-id-reverse": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "service-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "service",
                    "internet-service"
                ],
                "type": "str"
            },
            "uuid-idx": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "cos": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cos-mask": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "traffic-type": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "forwarding",
                    "local-in",
                    "local-out"
                ],
                "type": "str"
            }
        }
    },
    "pkg_user_nacpolicy": {
        "stated": true,
        "options": {
            "category": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "device",
                    "firewall-user",
                    "ems-tag",
                    "vulnerability"
                ],
                "type": "str"
            },
            "description": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ems-tag": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "family": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "host": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "hw-vendor": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "hw-version": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "mac": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "os": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "src": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ssid-policy": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sw-version": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "user": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "user-group": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "severity": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "pm_config_meta_reference": {
        "stated": true,
        "options": {
            "package list": {
                "required": false,
                "revision": {
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "7.2.4": true,
                            "7.4.0": false,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "7.2.4": true,
                            "7.4.0": false,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "pm_config_metafields_firewall_address": {
        "stated": false,
        "options": {
            "importance": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "optional",
                    "required"
                ],
                "type": "str"
            },
            "length": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "pm_config_metafields_firewall_addrgrp": {
        "stated": false,
        "options": {
            "importance": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "optional",
                    "required"
                ],
                "type": "str"
            },
            "length": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "pm_config_metafields_firewall_centralsnatmap": {
        "stated": false,
        "options": {
            "importance": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "optional",
                    "required"
                ],
                "type": "str"
            },
            "length": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "pm_config_metafields_firewall_policy": {
        "stated": false,
        "options": {
            "importance": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "optional",
                    "required"
                ],
                "type": "str"
            },
            "length": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "pm_config_metafields_firewall_service_custom": {
        "stated": false,
        "options": {
            "importance": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "optional",
                    "required"
                ],
                "type": "str"
            },
            "length": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "pm_config_metafields_firewall_service_group": {
        "stated": false,
        "options": {
            "importance": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "optional",
                    "required"
                ],
                "type": "str"
            },
            "length": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "pm_config_pblock_firewall_consolidated_policy": {
        "stated": true,
        "options": {
            "_policy_block": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "deny",
                    "accept",
                    "ipsec"
                ],
                "type": "str"
            },
            "app-category": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "app-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "application": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "application-list": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "auto-asic-offload": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "av-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "captive-portal-exempt": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "cifs-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "comments": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "diffserv-forward": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "diffserv-reverse": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "diffservcode-forward": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "diffservcode-rev": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dlp-sensor": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dnsfilter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dstaddr-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dstaddr4": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dstaddr6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dstintf": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "emailfilter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "fixedport": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fsso-groups": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "global-label": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "groups": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "http-policy-redirect": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "icap-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "inbound": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "inspection-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "proxy",
                    "flow"
                ],
                "type": "str"
            },
            "internet-service": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service-custom": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-custom-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service-src": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service-src-custom": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src-custom-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ippool": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ips-sensor": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "logtraffic": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "all",
                    "utm"
                ],
                "type": "str"
            },
            "logtraffic-start": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mms-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "nat": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "outbound": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "per-ip-shaper": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "policyid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "poolname4": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "poolname6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "profile-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "profile-protocol-options": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "profile-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "single",
                    "group"
                ],
                "type": "str"
            },
            "schedule": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "service": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "service-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "session-ttl": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "srcaddr-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "srcaddr4": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcaddr6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcintf": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ssh-filter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "ssh-policy-redirect": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-ssh-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tcp-mss-receiver": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tcp-mss-sender": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "traffic-shaper": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "traffic-shaper-reverse": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "url-category": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "users": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "utm-status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "voip-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vpntunnel": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "waf-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "wanopt": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "wanopt-detection": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "active",
                    "passive",
                    "off"
                ],
                "type": "str"
            },
            "wanopt-passive-opt": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "default",
                    "transparent",
                    "non-transparent"
                ],
                "type": "str"
            },
            "wanopt-peer": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "wanopt-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "webcache": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "webcache-https": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "webfilter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "webproxy-forward-server": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "webproxy-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "pm_config_pblock_firewall_consolidated_policy_sectionvalue": {
        "stated": true,
        "options": {
            "attr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "label",
                    "global-label"
                ],
                "type": "str"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "pm_config_pblock_firewall_policy": {
        "stated": true,
        "options": {
            "_policy_block": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "deny",
                    "accept",
                    "ipsec",
                    "ssl-vpn",
                    "redirect",
                    "isolate"
                ],
                "type": "str"
            },
            "anti-replay": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "application-list": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "auth-cert": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "auth-path": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "auth-redirect-addr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "auto-asic-offload": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "av-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "block-notification": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "captive-portal-exempt": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "capture-packet": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "cifs-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "comments": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "custom-log-fields": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "decrypted-traffic-mirror": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "delay-tcp-npu-session": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "diffserv-forward": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "diffserv-reverse": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "diffservcode-forward": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "diffservcode-rev": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "disclaimer": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "user",
                    "domain",
                    "policy"
                ],
                "type": "str"
            },
            "dlp-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dnsfilter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dsri": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dstaddr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dstaddr-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dstaddr6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dstintf": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dynamic-shaping": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "email-collect": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "emailfilter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "fec": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "file-filter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "firewall-session-dirty": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "check-all",
                    "check-new"
                ],
                "type": "str"
            },
            "fixedport": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fsso-agent-for-ntlm": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "fsso-groups": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "geoip-anycast": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "geoip-match": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "physical-location",
                    "registered-location"
                ],
                "type": "str"
            },
            "global-label": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "groups": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "gtp-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "http-policy-redirect": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "icap-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "identity-based-route": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "inbound": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "inspection-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "proxy",
                    "flow"
                ],
                "type": "str"
            },
            "internet-service": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service-custom": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-custom-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service-src": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service-src-custom": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src-custom-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src-name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ippool": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ips-sensor": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "label": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "logtraffic": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "all",
                    "utm"
                ],
                "type": "str"
            },
            "logtraffic-start": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "match-vip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "match-vip-only": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "nat": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "nat46": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "nat64": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "natinbound": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "natip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "natoutbound": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "np-acceleration": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ntlm": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ntlm-enabled-browsers": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ntlm-guest": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "outbound": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "passive-wan-health-measurement": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "per-ip-shaper": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "permit-any-host": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "permit-stun-host": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "pfcp-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "policy-expiry": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "policy-expiry-date": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "policyid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "poolname": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "poolname6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "profile-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "profile-protocol-options": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "profile-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "single",
                    "group"
                ],
                "type": "str"
            },
            "radius-mac-auth-bypass": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "redirect-url": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "replacemsg-override-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "reputation-direction": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "source",
                    "destination"
                ],
                "type": "str"
            },
            "reputation-minimum": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "rtp-addr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "rtp-nat": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "schedule": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "schedule-timeout": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sctp-filter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "send-deny-packet": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "service": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "service-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "session-ttl": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "sgt": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "sgt-check": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "src-vendor-mac": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcaddr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcaddr-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "srcaddr6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcintf": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ssh-filter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ssh-policy-redirect": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-ssh-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tcp-mss-receiver": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tcp-mss-sender": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tcp-session-without-syn": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "all",
                    "data-only",
                    "disable"
                ],
                "type": "str"
            },
            "timeout-send-rst": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tos": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tos-mask": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tos-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "traffic-shaper": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "traffic-shaper-reverse": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "users": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "utm-status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "videofilter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vlan-cos-fwd": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "vlan-cos-rev": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "vlan-filter": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "voip-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vpntunnel": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "waf-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "wanopt": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "wanopt-detection": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "active",
                    "passive",
                    "off"
                ],
                "type": "str"
            },
            "wanopt-passive-opt": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "default",
                    "transparent",
                    "non-transparent"
                ],
                "type": "str"
            },
            "wanopt-peer": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "wanopt-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "wccp": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "webcache": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "webcache-https": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "ssl-server",
                    "any",
                    "enable"
                ],
                "type": "str"
            },
            "webfilter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "webproxy-forward-server": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "webproxy-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ztna-ems-tag": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ztna-geo-tag": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ztna-status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "policy-offload": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "cgn-session-quota": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tcp-timeout-pid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "udp-timeout-pid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "dlp-sensor": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cgn-eif": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "cgn-log-server-grp": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cgn-resource-quota": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "cgn-eim": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mms-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "app-category": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "rsso": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "best-route": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fsso": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "url-category": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "app-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ssl-mirror-intf": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "wsso": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-mirror": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "application": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dscp-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "learning-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "devices": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "dscp-value": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "spamfilter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "scan-botnet-connections": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "block",
                    "monitor"
                ],
                "type": "str"
            },
            "dscp-match": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "diffserv-copy": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dstaddr6-negate": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service6": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service6-custom": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service6-custom-group": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service6-group": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service6-name": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service6-negate": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service6-src": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service6-src-custom": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service6-src-custom-group": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service6-src-group": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service6-src-name": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service6-src-negate": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "network-service-dynamic": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "network-service-src-dynamic": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "reputation-direction6": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "source",
                    "destination"
                ],
                "type": "str"
            },
            "reputation-minimum6": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "srcaddr6-negate": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ip-version-type": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ips-voip-filter": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "pcp-inbound": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "pcp-outbound": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "pcp-poolname": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "policy-behaviour-type": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "policy-expiry-date-utc": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ztna-device-ownership": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ztna-ems-tag-secondary": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ztna-policy-redirect": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ztna-tags-match-logic": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "or",
                    "and"
                ],
                "type": "str"
            },
            "casb-profile": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "virtual-patch-profile": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "pm_config_pblock_firewall_policy6": {
        "stated": true,
        "options": {
            "_policy_block": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "deny",
                    "accept",
                    "ipsec",
                    "ssl-vpn"
                ],
                "type": "str"
            },
            "anti-replay": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "app-category": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "app-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "application": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "application-list": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "auto-asic-offload": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "av-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cgn-log-server-grp": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cifs-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "comments": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "custom-log-fields": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "diffserv-forward": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "diffserv-reverse": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "diffservcode-forward": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "diffservcode-rev": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dlp-sensor": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dnsfilter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dsri": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dstaddr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dstaddr-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dstintf": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "emailfilter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "firewall-session-dirty": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "check-all",
                    "check-new"
                ],
                "type": "str"
            },
            "fixedport": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fsso-groups": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "global-label": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "groups": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "http-policy-redirect": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "icap-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "inbound": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "inspection-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "proxy",
                    "flow"
                ],
                "type": "str"
            },
            "ippool": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ips-sensor": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "label": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "logtraffic": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "all",
                    "utm"
                ],
                "type": "str"
            },
            "logtraffic-start": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mms-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "nat": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "natinbound": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "natoutbound": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "np-acceleration": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "outbound": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "per-ip-shaper": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "policy-offload": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "policyid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "poolname": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "profile-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "profile-protocol-options": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "profile-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "single",
                    "group"
                ],
                "type": "str"
            },
            "replacemsg-override-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "rsso": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "schedule": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "send-deny-packet": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "service": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "service-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "session-ttl": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "srcaddr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcaddr-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "srcintf": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ssh-filter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "ssh-policy-redirect": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-mirror": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-mirror-intf": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ssl-ssh-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tcp-mss-receiver": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tcp-mss-sender": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tcp-session-without-syn": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "all",
                    "data-only",
                    "disable"
                ],
                "type": "str"
            },
            "timeout-send-rst": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tos": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tos-mask": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tos-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "traffic-shaper": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "traffic-shaper-reverse": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "url-category": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "users": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "utm-status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vlan-cos-fwd": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "vlan-cos-rev": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "vlan-filter": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "voip-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vpntunnel": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "waf-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "webcache": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "webcache-https": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "webfilter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "webproxy-forward-server": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "webproxy-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dscp-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "devices": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "dscp-value": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "spamfilter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "dscp-match": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "pm_config_pblock_firewall_policy6_sectionvalue": {
        "stated": true,
        "options": {
            "attr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "label",
                    "global-label"
                ],
                "type": "str"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "pm_config_pblock_firewall_policy_sectionvalue": {
        "stated": true,
        "options": {
            "attr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "label",
                    "global-label"
                ],
                "type": "str"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "pm_config_pblock_firewall_securitypolicy": {
        "stated": true,
        "options": {
            "_policy_block": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "deny",
                    "accept"
                ],
                "type": "str"
            },
            "app-category": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "app-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "application": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "application-list": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "av-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cifs-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "comments": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dlp-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "dnsfilter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dstaddr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "dstaddr-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dstaddr6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dstintf": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "emailfilter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "enforce-default-app-port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "file-filter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "fsso-groups": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "global-label": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "groups": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "icap-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "internet-service": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service-custom": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-custom-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "internet-service-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service-src": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service-src-custom": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src-custom-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src-name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "internet-service-src-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ips-sensor": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "learning-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "logtraffic": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "all",
                    "utm"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "nat46": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "nat64": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "policyid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "profile-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "profile-protocol-options": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "profile-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "single",
                    "group"
                ],
                "type": "str"
            },
            "schedule": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sctp-filter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "send-deny-packet": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "service": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "service-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "srcaddr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "srcaddr-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "srcaddr6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcintf": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ssh-filter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ssl-ssh-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "url-category": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "users": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "utm-status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "videofilter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "voip-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "webfilter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dlp-sensor": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "mms-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "internet-service-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "logtraffic-start": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "srcaddr4": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dstaddr4": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-src-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service6": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service6-custom": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "internet-service6-custom-group": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "internet-service6-group": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "internet-service6-name": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "internet-service6-negate": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service6-src": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service6-src-custom": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "internet-service6-src-custom-group": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "internet-service6-src-group": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "internet-service6-src-name": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "internet-service6-src-negate": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "pm_config_pblock_firewall_securitypolicy_sectionvalue": {
        "stated": true,
        "options": {
            "attr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "label",
                    "global-label"
                ],
                "type": "str"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "pm_config_reset_database": {
        "stated": true,
        "options": {
            "mr": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "version": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "pm_config_upgrade": {
        "stated": true,
        "options": {}
    },
    "pm_config_workspace_commit": {
        "stated": true,
        "options": {}
    },
    "pm_config_workspace_lock": {
        "stated": true,
        "options": {}
    },
    "pm_config_workspace_unlock": {
        "stated": true,
        "options": {}
    },
    "pm_devprof_adom": {
        "stated": false,
        "options": {
            "description": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "enabled options": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "none",
                    "dns",
                    "ntp",
                    "email",
                    "admin",
                    "snmp",
                    "repmsg",
                    "ftgd",
                    "log"
                ],
                "elements": "str"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "oid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "scope member": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "devprof"
                ],
                "type": "str"
            }
        }
    },
    "pm_devprof_pkg": {
        "stated": true,
        "options": {
            "description": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "enabled options": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "none",
                    "dns",
                    "ntp",
                    "email",
                    "admin",
                    "snmp",
                    "repmsg",
                    "ftgd",
                    "log"
                ],
                "elements": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "oid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "scope member": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "devprof"
                ],
                "type": "str"
            }
        }
    },
    "pm_devprof_scopemember": {
        "stated": true,
        "options": {
            "name": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vdom": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "pm_pblock_adom": {
        "stated": false,
        "options": {
            "name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "oid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "package settings": {
                "required": false,
                "type": "dict",
                "options": {
                    "central-nat": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "consolidated-firewall-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "fwpolicy-implicit-log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "fwpolicy6-implicit-log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "inspection-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "proxy",
                            "flow"
                        ],
                        "type": "str"
                    },
                    "ngfw-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "profile-based",
                            "policy-based"
                        ],
                        "type": "str"
                    },
                    "policy-offload-level": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "default",
                            "dos-offload",
                            "full-offload"
                        ],
                        "type": "str"
                    },
                    "ssl-ssh-profile": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                }
            },
            "type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pblock"
                ],
                "type": "str"
            }
        }
    },
    "pm_pblock_obj": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "oid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "package settings": {
                "required": false,
                "type": "dict",
                "options": {
                    "central-nat": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "consolidated-firewall-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "fwpolicy-implicit-log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "fwpolicy6-implicit-log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "inspection-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "proxy",
                            "flow"
                        ],
                        "type": "str"
                    },
                    "ngfw-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "profile-based",
                            "policy-based"
                        ],
                        "type": "str"
                    },
                    "policy-offload-level": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "default",
                            "dos-offload",
                            "full-offload"
                        ],
                        "type": "str"
                    },
                    "ssl-ssh-profile": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                }
            },
            "type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pblock"
                ],
                "type": "str"
            }
        }
    },
    "pm_pkg": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "obj ver": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "oid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "package setting": {
                "required": false,
                "type": "dict",
                "options": {
                    "central-nat": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "consolidated-firewall-mode": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "fwpolicy-implicit-log": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "fwpolicy6-implicit-log": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "inspection-mode": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "proxy",
                            "flow"
                        ],
                        "type": "str"
                    },
                    "ngfw-mode": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "profile-based",
                            "policy-based"
                        ],
                        "type": "str"
                    },
                    "ssl-ssh-profile": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    }
                }
            },
            "scope member": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pkg",
                    "folder"
                ],
                "type": "str"
            },
            "package settings": {
                "required": false,
                "type": "dict",
                "options": {
                    "central-nat": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "consolidated-firewall-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "fwpolicy-implicit-log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "fwpolicy6-implicit-log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "inspection-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "proxy",
                            "flow"
                        ],
                        "type": "str"
                    },
                    "ngfw-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "profile-based",
                            "policy-based"
                        ],
                        "type": "str"
                    },
                    "policy-offload-level": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "default",
                            "dos-offload",
                            "full-offload"
                        ],
                        "type": "str"
                    },
                    "ssl-ssh-profile": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                }
            }
        }
    },
    "pm_pkg_adom": {
        "stated": false,
        "options": {
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "obj ver": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "oid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "package setting": {
                "required": false,
                "type": "dict",
                "options": {
                    "central-nat": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "consolidated-firewall-mode": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "fwpolicy-implicit-log": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "fwpolicy6-implicit-log": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "inspection-mode": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "proxy",
                            "flow"
                        ],
                        "type": "str"
                    },
                    "ngfw-mode": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "profile-based",
                            "policy-based"
                        ],
                        "type": "str"
                    },
                    "ssl-ssh-profile": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    }
                }
            },
            "scope member": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pkg",
                    "folder"
                ],
                "type": "str"
            },
            "package settings": {
                "required": false,
                "type": "dict",
                "options": {
                    "central-nat": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "consolidated-firewall-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "fwpolicy-implicit-log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "fwpolicy6-implicit-log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "inspection-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "proxy",
                            "flow"
                        ],
                        "type": "str"
                    },
                    "ngfw-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "profile-based",
                            "policy-based"
                        ],
                        "type": "str"
                    },
                    "policy-offload-level": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "default",
                            "dos-offload",
                            "full-offload"
                        ],
                        "type": "str"
                    },
                    "ssl-ssh-profile": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                }
            }
        }
    },
    "pm_pkg_global": {
        "stated": false,
        "options": {
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "obj ver": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "oid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "package setting": {
                "required": false,
                "type": "dict",
                "options": {
                    "central-nat": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "consolidated-firewall-mode": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "fwpolicy-implicit-log": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "fwpolicy6-implicit-log": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "inspection-mode": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "proxy",
                            "flow"
                        ],
                        "type": "str"
                    },
                    "ngfw-mode": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "profile-based",
                            "policy-based"
                        ],
                        "type": "str"
                    },
                    "ssl-ssh-profile": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    }
                }
            },
            "scope member": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pkg",
                    "folder"
                ],
                "type": "str"
            },
            "package settings": {
                "required": false,
                "type": "dict",
                "options": {
                    "central-nat": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "consolidated-firewall-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "fwpolicy-implicit-log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "fwpolicy6-implicit-log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "inspection-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "proxy",
                            "flow"
                        ],
                        "type": "str"
                    },
                    "ngfw-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "profile-based",
                            "policy-based"
                        ],
                        "type": "str"
                    },
                    "policy-offload-level": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "default",
                            "dos-offload",
                            "full-offload"
                        ],
                        "type": "str"
                    },
                    "ssl-ssh-profile": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                }
            }
        }
    },
    "pm_pkg_scopemember": {
        "stated": true,
        "options": {
            "name": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vdom": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "pm_wanprof_adom": {
        "stated": false,
        "options": {
            "description": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "oid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "scope member": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "wanprof"
                ],
                "type": "str"
            }
        }
    },
    "pm_wanprof_pkg": {
        "stated": true,
        "options": {
            "description": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "oid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "scope member": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "wanprof"
                ],
                "type": "str"
            }
        }
    },
    "pm_wanprof_scopemember": {
        "stated": true,
        "options": {
            "name": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vdom": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "qosprofile": {
        "stated": true,
        "options": {
            "bandwidth-admission-control": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "bandwidth-capacity": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "burst": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "call-admission-control": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "call-capacity": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "downlink": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "downlink-sta": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "dscp-wmm-be": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dscp-wmm-bk": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dscp-wmm-mapping": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dscp-wmm-vi": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dscp-wmm-vo": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "uplink": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "uplink-sta": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "wmm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "wmm-uapsd": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "wmm-be-dscp": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "wmm-bk-dscp": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "wmm-dscp-marking": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "wmm-vi-dscp": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "wmm-vo-dscp": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "region": {
        "stated": true,
        "options": {
            "comments": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "grayscale": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "image-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "gif",
                    "jpeg",
                    "png"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "opacity": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "router_accesslist": {
        "stated": true,
        "options": {
            "comments": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "rule": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "permit",
                            "deny"
                        ],
                        "type": "str"
                    },
                    "exact-match": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "flags": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "prefix": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "wildcard": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "router_accesslist6": {
        "stated": true,
        "options": {
            "comments": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "rule": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "permit",
                            "deny"
                        ],
                        "type": "str"
                    },
                    "exact-match": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "flags": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "prefix6": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "router_accesslist6_rule": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "permit",
                    "deny"
                ],
                "type": "str"
            },
            "exact-match": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "flags": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "prefix6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "router_accesslist_rule": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "permit",
                    "deny"
                ],
                "type": "str"
            },
            "exact-match": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "flags": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "prefix": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "wildcard": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "router_aspathlist": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "rule": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "deny",
                            "permit"
                        ],
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "regexp": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "router_aspathlist_rule": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "deny",
                    "permit"
                ],
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "regexp": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "router_communitylist": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "rule": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "deny",
                            "permit"
                        ],
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "match": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "regexp": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "standard",
                    "expanded"
                ],
                "type": "str"
            }
        }
    },
    "router_communitylist_rule": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "deny",
                    "permit"
                ],
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "match": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "regexp": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "router_prefixlist": {
        "stated": true,
        "options": {
            "comments": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "rule": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "permit",
                            "deny"
                        ],
                        "type": "str"
                    },
                    "flags": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ge": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "le": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "prefix": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "router_prefixlist6": {
        "stated": true,
        "options": {
            "comments": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "rule": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "permit",
                            "deny"
                        ],
                        "type": "str"
                    },
                    "flags": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ge": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "le": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "prefix6": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "router_prefixlist6_rule": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "permit",
                    "deny"
                ],
                "type": "str"
            },
            "flags": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ge": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "le": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "prefix6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "router_prefixlist_rule": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "permit",
                    "deny"
                ],
                "type": "str"
            },
            "flags": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ge": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "le": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "prefix": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "router_routemap": {
        "stated": true,
        "options": {
            "comments": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "rule": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "permit",
                            "deny"
                        ],
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "match-as-path": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "match-community": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "match-community-exact": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "match-flags": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "match-interface": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "match-ip-address": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "match-ip-nexthop": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "match-ip6-address": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "match-ip6-nexthop": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "match-metric": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "match-origin": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "egp",
                            "igp",
                            "incomplete"
                        ],
                        "type": "str"
                    },
                    "match-route-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "1",
                            "2",
                            "none",
                            "external-type1",
                            "external-type2"
                        ],
                        "type": "str"
                    },
                    "match-tag": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "match-vrf": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "set-aggregator-as": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "set-aggregator-ip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "set-aspath": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "set-aspath-action": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "prepend",
                            "replace"
                        ],
                        "type": "str"
                    },
                    "set-atomic-aggregate": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "set-community": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "set-community-additive": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "set-community-delete": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "set-dampening-max-suppress": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "set-dampening-reachability-half-life": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "set-dampening-reuse": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "set-dampening-suppress": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "set-dampening-unreachability-half-life": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "set-extcommunity-rt": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "set-extcommunity-soo": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "set-flags": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "set-ip-nexthop": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "set-ip6-nexthop": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "set-ip6-nexthop-local": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "set-local-preference": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "set-metric": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "set-metric-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "1",
                            "2",
                            "none",
                            "external-type1",
                            "external-type2"
                        ],
                        "type": "str"
                    },
                    "set-origin": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "egp",
                            "igp",
                            "incomplete"
                        ],
                        "type": "str"
                    },
                    "set-originator-id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "set-priority": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "set-route-tag": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "set-tag": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "set-weight": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "match-extcommunity": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "match-extcommunity-exact": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "set-ip-prefsrc": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "set-vpnv4-nexthop": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "router_routemap_rule": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "permit",
                    "deny"
                ],
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "match-as-path": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "match-community": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "match-community-exact": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "match-flags": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "match-interface": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "match-ip-address": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "match-ip-nexthop": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "match-ip6-address": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "match-ip6-nexthop": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "match-metric": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "match-origin": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "egp",
                    "igp",
                    "incomplete"
                ],
                "type": "str"
            },
            "match-route-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "1",
                    "2",
                    "none",
                    "external-type1",
                    "external-type2"
                ],
                "type": "str"
            },
            "match-tag": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "match-vrf": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "set-aggregator-as": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "set-aggregator-ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "set-aspath": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "set-aspath-action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "prepend",
                    "replace"
                ],
                "type": "str"
            },
            "set-atomic-aggregate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "set-community": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "set-community-additive": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "set-community-delete": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "set-dampening-max-suppress": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "set-dampening-reachability-half-life": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "set-dampening-reuse": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "set-dampening-suppress": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "set-dampening-unreachability-half-life": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "set-extcommunity-rt": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "set-extcommunity-soo": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "set-flags": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "set-ip-nexthop": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "set-ip6-nexthop": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "set-ip6-nexthop-local": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "set-local-preference": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "set-metric": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "set-metric-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "1",
                    "2",
                    "none",
                    "external-type1",
                    "external-type2"
                ],
                "type": "str"
            },
            "set-origin": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "egp",
                    "igp",
                    "incomplete"
                ],
                "type": "str"
            },
            "set-originator-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "set-priority": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "set-route-tag": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "set-tag": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "set-weight": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "match-extcommunity": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "match-extcommunity-exact": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "set-ip-prefsrc": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "set-vpnv4-nexthop": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "securityconsole_abort": {
        "stated": true,
        "options": {
            "adom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "securityconsole_assign_package": {
        "stated": true,
        "options": {
            "flags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "none",
                    "cp_all_objs",
                    "copy_assigned_pkg",
                    "unassign"
                ],
                "elements": "str"
            },
            "pkg": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "target": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "adom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "excluded": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "pkg": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "securityconsole_cliprof_check": {
        "stated": true,
        "options": {
            "adom": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cliprof": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "scope": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "securityconsole_import_dev_objs": {
        "stated": true,
        "options": {
            "add_mappings": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "adom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dst_name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dst_parent": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "if_all_objs": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "all",
                    "filter"
                ],
                "type": "str"
            },
            "if_all_policy": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "import_action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "do",
                    "policy_search",
                    "obj_search"
                ],
                "type": "str"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "position": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "bottom",
                    "top"
                ],
                "type": "str"
            },
            "vdom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "securityconsole_install_device": {
        "stated": true,
        "options": {
            "adom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dev_rev_comments": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "flags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "none",
                    "preview",
                    "auto_lock_ws"
                ],
                "elements": "str"
            },
            "scope": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "securityconsole_install_objects_v2": {
        "stated": true,
        "options": {
            "adom": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "category": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "objects": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "list",
                "elements": "str"
            },
            "scope": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "securityconsole_install_package": {
        "stated": true,
        "options": {
            "adom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "adom_rev_comments": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "adom_rev_name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dev_rev_comments": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "flags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "none",
                    "cp_all_objs",
                    "preview",
                    "generate_rev",
                    "copy_assigned_pkg",
                    "unassign",
                    "ifpolicy_only",
                    "no_ifpolicy",
                    "objs_only",
                    "auto_lock_ws",
                    "check_pkg_st",
                    "copy_only"
                ],
                "elements": "str"
            },
            "pkg": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "scope": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "securityconsole_install_preview": {
        "stated": true,
        "options": {
            "adom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "device": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "flags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "none",
                    "json",
                    "default_cfg"
                ],
                "elements": "str"
            },
            "vdoms": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "securityconsole_package_cancel_install": {
        "stated": true,
        "options": {
            "adom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "securityconsole_package_clone": {
        "stated": true,
        "options": {
            "adom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dst_name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dst_parent": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "pkg": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "scope": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "securityconsole_package_commit": {
        "stated": true,
        "options": {
            "adom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "scope": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "securityconsole_package_move": {
        "stated": true,
        "options": {
            "adom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dst_name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dst_parent": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "pkg": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "securityconsole_pblock_clone": {
        "stated": true,
        "options": {
            "adom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dst_name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "pblock": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "securityconsole_preview_result": {
        "stated": true,
        "options": {
            "adom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "device": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "securityconsole_reinstall_package": {
        "stated": true,
        "options": {
            "adom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "flags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "none",
                    "cp_all_objs",
                    "preview",
                    "generate_rev",
                    "copy_assigned_pkg",
                    "unassign",
                    "ifpolicy_only",
                    "no_ifpolicy",
                    "objs_only",
                    "auto_lock_ws",
                    "check_pkg_st",
                    "copy_only"
                ],
                "elements": "str"
            },
            "target": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "pkg": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "scope": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "vdom": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "securityconsole_sign_certificate_template": {
        "stated": true,
        "options": {
            "adom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "scope": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "template": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "securityconsole_template_cli_preview": {
        "stated": true,
        "options": {
            "adom": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "filename": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "pkg": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "scope": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "spamfilter_bwl": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "entries": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "spam",
                            "clear",
                            "reject"
                        ],
                        "type": "str"
                    },
                    "addr-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "ipv4",
                            "ipv6"
                        ],
                        "type": "str"
                    },
                    "email-pattern": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "ip4-subnet": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "ip6-subnet": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "pattern-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "wildcard",
                            "regexp"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "ip",
                            "email"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "spamfilter_bwl_entries": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "spam",
                    "clear",
                    "reject"
                ],
                "type": "str"
            },
            "addr-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "ipv4",
                    "ipv6"
                ],
                "type": "str"
            },
            "email-pattern": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "ip4-subnet": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "ip6-subnet": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "pattern-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "wildcard",
                    "regexp"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "ip",
                    "email"
                ],
                "type": "str"
            }
        }
    },
    "spamfilter_bword": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "entries": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "spam",
                            "clear"
                        ],
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "language": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "western",
                            "simch",
                            "trach",
                            "japanese",
                            "korean",
                            "french",
                            "thai",
                            "spanish"
                        ],
                        "type": "str"
                    },
                    "pattern": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "pattern-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "wildcard",
                            "regexp"
                        ],
                        "type": "str"
                    },
                    "score": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "where": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "subject",
                            "body",
                            "all"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "spamfilter_bword_entries": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "spam",
                    "clear"
                ],
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "language": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "western",
                    "simch",
                    "trach",
                    "japanese",
                    "korean",
                    "french",
                    "thai",
                    "spanish"
                ],
                "type": "str"
            },
            "pattern": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "pattern-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "wildcard",
                    "regexp"
                ],
                "type": "str"
            },
            "score": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "where": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "subject",
                    "body",
                    "all"
                ],
                "type": "str"
            }
        }
    },
    "spamfilter_dnsbl": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "entries": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "spam",
                            "reject"
                        ],
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "server": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "spamfilter_dnsbl_entries": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "spam",
                    "reject"
                ],
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "spamfilter_iptrust": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "entries": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "addr-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "ipv4",
                            "ipv6"
                        ],
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "ip4-subnet": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "ip6-subnet": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "spamfilter_iptrust_entries": {
        "stated": true,
        "options": {
            "addr-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "ipv4",
                    "ipv6"
                ],
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "ip4-subnet": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "ip6-subnet": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "spamfilter_mheader": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "entries": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "spam",
                            "clear"
                        ],
                        "type": "str"
                    },
                    "fieldbody": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "fieldname": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "pattern-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "wildcard",
                            "regexp"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "spamfilter_mheader_entries": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "spam",
                    "clear"
                ],
                "type": "str"
            },
            "fieldbody": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "fieldname": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "pattern-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "wildcard",
                    "regexp"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "spamfilter_profile": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "external": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "flow-based": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "options": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "choices": [
                    "bannedword",
                    "spamemailbwl",
                    "spamfsip",
                    "spamfssubmit",
                    "spamfschksum",
                    "spamfsurl",
                    "spamhelodns",
                    "spamipbwl",
                    "spamraddrdns",
                    "spamrbl",
                    "spamhdrcheck",
                    "spamfsphish",
                    "spambwl"
                ],
                "elements": "str"
            },
            "replacemsg-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "spam-bwl-table": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "spam-bword-table": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "spam-bword-threshold": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "spam-filtering": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "spam-iptrust-table": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "spam-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "spam-log-fortiguard-response": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "spam-mheader-table": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "spam-rbl-table": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "gmail": {
                "required": false,
                "type": "dict",
                "options": {
                    "log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "imap": {
                "required": false,
                "type": "dict",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "pass",
                            "tag"
                        ],
                        "type": "str"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "tag-msg": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "tag-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "list",
                        "choices": [
                            "subject",
                            "header",
                            "spaminfo"
                        ],
                        "elements": "str"
                    }
                }
            },
            "mapi": {
                "required": false,
                "type": "dict",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "pass",
                            "discard"
                        ],
                        "type": "str"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "msn-hotmail": {
                "required": false,
                "type": "dict",
                "options": {
                    "log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "pop3": {
                "required": false,
                "type": "dict",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "pass",
                            "tag"
                        ],
                        "type": "str"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "tag-msg": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "tag-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "list",
                        "choices": [
                            "subject",
                            "header",
                            "spaminfo"
                        ],
                        "elements": "str"
                    }
                }
            },
            "smtp": {
                "required": false,
                "type": "dict",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "pass",
                            "tag",
                            "discard"
                        ],
                        "type": "str"
                    },
                    "hdrip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "local-override": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "tag-msg": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "tag-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "list",
                        "choices": [
                            "subject",
                            "header",
                            "spaminfo"
                        ],
                        "elements": "str"
                    }
                }
            },
            "yahoo-mail": {
                "required": false,
                "type": "dict",
                "options": {
                    "log": {
                        "required": false,
                        "revision": {
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            }
        }
    },
    "spamfilter_profile_gmail": {
        "stated": false,
        "options": {
            "log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "spamfilter_profile_imap": {
        "stated": false,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "pass",
                    "tag"
                ],
                "type": "str"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tag-msg": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "tag-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "choices": [
                    "subject",
                    "header",
                    "spaminfo"
                ],
                "elements": "str"
            }
        }
    },
    "spamfilter_profile_mapi": {
        "stated": false,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "pass",
                    "discard"
                ],
                "type": "str"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "spamfilter_profile_msnhotmail": {
        "stated": false,
        "options": {
            "log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "spamfilter_profile_pop3": {
        "stated": false,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "pass",
                    "tag"
                ],
                "type": "str"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tag-msg": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "tag-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "choices": [
                    "subject",
                    "header",
                    "spaminfo"
                ],
                "elements": "str"
            }
        }
    },
    "spamfilter_profile_smtp": {
        "stated": false,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "pass",
                    "tag",
                    "discard"
                ],
                "type": "str"
            },
            "hdrip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "local-override": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tag-msg": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "tag-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "choices": [
                    "subject",
                    "header",
                    "spaminfo"
                ],
                "elements": "str"
            }
        }
    },
    "spamfilter_profile_yahoomail": {
        "stated": false,
        "options": {
            "log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "sshfilter_profile": {
        "stated": true,
        "options": {
            "block": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "x11",
                    "shell",
                    "exec",
                    "port-forward",
                    "tun-forward",
                    "sftp",
                    "unknown",
                    "scp"
                ],
                "elements": "str"
            },
            "default-command-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "x11",
                    "shell",
                    "exec",
                    "port-forward",
                    "tun-forward",
                    "sftp",
                    "unknown",
                    "scp"
                ],
                "elements": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "shell-commands": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "block",
                            "allow"
                        ],
                        "type": "str"
                    },
                    "alert": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "pattern": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "severity": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "low",
                            "medium",
                            "high",
                            "critical"
                        ],
                        "type": "str"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "regex",
                            "simple"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "file-filter": {
                "required": false,
                "type": "dict",
                "options": {
                    "entries": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "action": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "log",
                                    "block"
                                ],
                                "type": "str"
                            },
                            "comment": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "direction": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "any",
                                    "incoming",
                                    "outgoing"
                                ],
                                "type": "str"
                            },
                            "file-type": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            },
                            "filter": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "password-protected": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "any",
                                    "yes"
                                ],
                                "type": "str"
                            },
                            "protocol": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "choices": [
                                    "ssh"
                                ],
                                "elements": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "scan-archive-contents": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            }
        }
    },
    "sshfilter_profile_filefilter": {
        "stated": false,
        "options": {
            "entries": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "log",
                            "block"
                        ],
                        "type": "str"
                    },
                    "comment": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "direction": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "any",
                            "incoming",
                            "outgoing"
                        ],
                        "type": "str"
                    },
                    "file-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "filter": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "password-protected": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "any",
                            "yes"
                        ],
                        "type": "str"
                    },
                    "protocol": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "ssh"
                        ],
                        "elements": "str"
                    }
                },
                "elements": "dict"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "scan-archive-contents": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "sshfilter_profile_filefilter_entries": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "log",
                    "block"
                ],
                "type": "str"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "direction": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "any",
                    "incoming",
                    "outgoing"
                ],
                "type": "str"
            },
            "file-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "filter": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "password-protected": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "any",
                    "yes"
                ],
                "type": "str"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "ssh"
                ],
                "elements": "str"
            }
        }
    },
    "sshfilter_profile_shellcommands": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "block",
                    "allow"
                ],
                "type": "str"
            },
            "alert": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "pattern": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "severity": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "low",
                    "medium",
                    "high",
                    "critical"
                ],
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "regex",
                    "simple"
                ],
                "type": "str"
            }
        }
    },
    "switchcontroller_acl_group": {
        "stated": true,
        "options": {
            "ingress": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "name": {
                "required": true,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "switchcontroller_acl_ingress": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "type": "dict",
                "options": {
                    "count": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "drop": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "classifier": {
                "required": false,
                "type": "dict",
                "options": {
                    "dst-ip-prefix": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "dst-mac": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "src-ip-prefix": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "src-mac": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vlan": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                }
            },
            "description": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "switchcontroller_acl_ingress_action": {
        "stated": false,
        "options": {
            "count": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "drop": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "switchcontroller_acl_ingress_classifier": {
        "stated": false,
        "options": {
            "dst-ip-prefix": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dst-mac": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "src-ip-prefix": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "src-mac": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vlan": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "switchcontroller_customcommand": {
        "stated": true,
        "options": {
            "command": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "command-name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "description": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "switchcontroller_dsl_policy": {
        "stated": true,
        "options": {
            "append_padding": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "cpe-aele": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "cpe-aele-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ELE_M0",
                    "ELE_DS",
                    "ELE_PB",
                    "ELE_MIN"
                ],
                "type": "str"
            },
            "cs": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "A43",
                    "B43",
                    "A43C",
                    "V43"
                ],
                "elements": "str"
            },
            "ds-bitswap": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "pause-frame": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auto-30a",
                    "auto-17a",
                    "auto-12ab"
                ],
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "Procend",
                    "Proscend"
                ],
                "type": "str"
            },
            "us-bitswap": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "switchcontroller_dynamicportpolicy": {
        "stated": true,
        "options": {
            "description": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "policy": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "802-1x": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "bounce-port-link": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "category": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "device",
                            "interface-tag"
                        ],
                        "type": "str"
                    },
                    "description": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "family": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "host": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "hw-vendor": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "interface-tags": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "lldp-profile": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "mac": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "qos-policy": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vlan-policy": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "switchcontroller_dynamicportpolicy_policy": {
        "stated": true,
        "options": {
            "802-1x": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "bounce-port-link": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "category": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "device",
                    "interface-tag"
                ],
                "type": "str"
            },
            "description": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "family": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "host": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "hw-vendor": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "interface-tags": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "lldp-profile": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "mac": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "qos-policy": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vlan-policy": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "switchcontroller_fortilinksettings": {
        "stated": true,
        "options": {
            "fortilink": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": false,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "inactive-timer": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "link-down-flush": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "nac-ports": {
                "required": false,
                "type": "dict",
                "options": {
                    "lan-segment": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disabled",
                            "enabled"
                        ],
                        "type": "str"
                    },
                    "member-change": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "nac-lan-interface": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "nac-segment-vlans": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "onboarding-vlan": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "parent-key": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "str"
                    },
                    "bounce-nac-port": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "name": {
                "required": true,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "access-vlan-mode": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "legacy",
                    "fail-open",
                    "fail-close"
                ],
                "type": "str"
            }
        }
    },
    "switchcontroller_fortilinksettings_nacports": {
        "stated": false,
        "options": {
            "lan-segment": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disabled",
                    "enabled"
                ],
                "type": "str"
            },
            "member-change": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "nac-lan-interface": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "nac-segment-vlans": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "onboarding-vlan": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "parent-key": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "str"
            },
            "bounce-nac-port": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "switchcontroller_lldpprofile": {
        "stated": true,
        "options": {
            "802.1-tlvs": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "port-vlan-id"
                ],
                "elements": "str"
            },
            "802.3-tlvs": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "max-frame-size",
                    "power-negotiation"
                ],
                "elements": "str"
            },
            "auto-isl": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "auto-isl-hello-timer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "auto-isl-port-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "auto-isl-receive-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "custom-tlvs": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "information-string": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "oui": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "subtype": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "med-network-policy": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "dscp": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "priority": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "vlan": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "vlan-intf": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "assign-vlan": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "med-tlvs": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "inventory-management",
                    "network-policy",
                    "power-management",
                    "location-identification"
                ],
                "elements": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "med-location-service": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "sys-location-id": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "auto-mclag-icl": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "auto-isl-auth": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "legacy",
                    "strict",
                    "relax"
                ],
                "type": "str"
            },
            "auto-isl-auth-encrypt": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "mixed",
                    "must"
                ],
                "type": "str"
            },
            "auto-isl-auth-identity": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "auto-isl-auth-macsec-profile": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "auto-isl-auth-reauth": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "auto-isl-auth-user": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "switchcontroller_lldpprofile_customtlvs": {
        "stated": true,
        "options": {
            "information-string": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "oui": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "subtype": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "switchcontroller_lldpprofile_medlocationservice": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sys-location-id": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "switchcontroller_lldpprofile_mednetworkpolicy": {
        "stated": true,
        "options": {
            "dscp": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "priority": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "vlan": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "vlan-intf": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "assign-vlan": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "switchcontroller_macpolicy": {
        "stated": true,
        "options": {
            "bounce-port-link": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "count": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "description": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "traffic-policy": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vlan": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "drop": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "switchcontroller_managedswitch": {
        "stated": true,
        "options": {
            "_platform": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "description": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ports": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "allowed-vlans": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "allowed-vlans-all": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "arp-inspection-trust": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "untrusted",
                            "trusted"
                        ],
                        "type": "str"
                    },
                    "bundle": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "description": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "dhcp-snoop-option82-trust": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "dhcp-snooping": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "trusted",
                            "untrusted"
                        ],
                        "type": "str"
                    },
                    "discard-mode": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "all-untagged",
                            "all-tagged"
                        ],
                        "type": "str"
                    },
                    "edge-port": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "igmp-snooping": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "igmps-flood-reports": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "igmps-flood-traffic": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "lacp-speed": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "slow",
                            "fast"
                        ],
                        "type": "str"
                    },
                    "learning-limit": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "lldp-profile": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "lldp-status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "rx-only",
                            "tx-only",
                            "tx-rx"
                        ],
                        "type": "str"
                    },
                    "loop-guard": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disabled",
                            "enabled"
                        ],
                        "type": "str"
                    },
                    "loop-guard-timeout": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "max-bundle": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "mclag": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "member-withdrawal-behavior": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "forward",
                            "block"
                        ],
                        "type": "str"
                    },
                    "members": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "min-bundle": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "mode": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "static",
                            "lacp-passive",
                            "lacp-active"
                        ],
                        "type": "str"
                    },
                    "poe-pre-standard-detection": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "poe-status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "port-name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "port-owner": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "port-security-policy": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "port-selection-criteria": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "src-mac",
                            "dst-mac",
                            "src-dst-mac",
                            "src-ip",
                            "dst-ip",
                            "src-dst-ip"
                        ],
                        "type": "str"
                    },
                    "qos-policy": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sample-direction": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "rx",
                            "tx",
                            "both"
                        ],
                        "type": "str"
                    },
                    "sflow-counter-interval": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "sflow-sample-rate": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "sflow-sampler": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disabled",
                            "enabled"
                        ],
                        "type": "str"
                    },
                    "stp-bpdu-guard": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disabled",
                            "enabled"
                        ],
                        "type": "str"
                    },
                    "stp-bpdu-guard-timeout": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "stp-root-guard": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disabled",
                            "enabled"
                        ],
                        "type": "str"
                    },
                    "stp-state": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disabled",
                            "enabled"
                        ],
                        "type": "str"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "physical",
                            "trunk"
                        ],
                        "type": "str"
                    },
                    "untagged-vlans": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "vlan": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "export-to-pool-flag": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "mac-addr": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "packet-sample-rate": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "packet-sampler": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disabled",
                            "enabled"
                        ],
                        "type": "str"
                    },
                    "sticky-mac": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "storm-control-policy": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "dot1x-enable": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "max-miss-heartbeats": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "access-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "normal",
                            "nac",
                            "dynamic",
                            "static"
                        ],
                        "type": "str"
                    },
                    "ip-source-guard": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "mclag-icl-port": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "p2p-port": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "aggregator-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "bandwidth",
                            "count"
                        ],
                        "type": "str"
                    },
                    "rpvst-port": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disabled",
                            "enabled"
                        ],
                        "type": "str"
                    },
                    "flow-control": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "tx",
                            "rx",
                            "both"
                        ],
                        "type": "str"
                    },
                    "media-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "pause-meter": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "pause-meter-resume": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "25%",
                            "50%",
                            "75%"
                        ],
                        "type": "str"
                    },
                    "trunk-member": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "fec-capable": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "fec-state": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disabled",
                            "cl74",
                            "cl91"
                        ],
                        "type": "str"
                    },
                    "matched-dpp-intf-tags": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "matched-dpp-policy": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "port-policy": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "down",
                            "up"
                        ],
                        "type": "str"
                    },
                    "dsl-profile": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "flap-duration": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "flap-rate": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "flap-timeout": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "flapguard": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "interface-tags": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "poe-max-power": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "poe-standard": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "igmp-snooping-flood-reports": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "mcast-snooping-flood-traffic": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "link-status": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "down",
                            "up"
                        ],
                        "type": "str"
                    },
                    "poe-mode-bt-cabable": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "poe-port-mode": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ieee802-3af",
                            "ieee802-3at",
                            "ieee802-3bt"
                        ],
                        "type": "str"
                    },
                    "poe-port-power": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "normal",
                            "perpetual",
                            "perpetual-fast"
                        ],
                        "type": "str"
                    },
                    "poe-port-priority": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "critical-priority",
                            "high-priority",
                            "low-priority",
                            "medium-priority"
                        ],
                        "type": "str"
                    },
                    "acl-group": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "dhcp-snoop-option82-override": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "circuit-id": {
                                "required": false,
                                "revision": {
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "remote-id": {
                                "required": false,
                                "revision": {
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "vlan-name": {
                                "required": false,
                                "revision": {
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "fortiswitch-acls": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "isl-peer-device-sn": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "authenticated-port": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "encrypted-port": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ptp-status": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "restricted-auth-port": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "switch-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "override-snmp-community": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "override-snmp-sysinfo": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "override-snmp-trap-threshold": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "override-snmp-user": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "poe-detection-type": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "remote-log": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "csv": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "facility": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "kernel",
                            "user",
                            "mail",
                            "daemon",
                            "auth",
                            "syslog",
                            "lpr",
                            "news",
                            "uucp",
                            "cron",
                            "authpriv",
                            "ftp",
                            "ntp",
                            "audit",
                            "alert",
                            "clock",
                            "local0",
                            "local1",
                            "local2",
                            "local3",
                            "local4",
                            "local5",
                            "local6",
                            "local7"
                        ],
                        "type": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "port": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "server": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "severity": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "emergency",
                            "alert",
                            "critical",
                            "error",
                            "warning",
                            "notification",
                            "information",
                            "debug"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "snmp-community": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "events": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "list",
                        "choices": [
                            "cpu-high",
                            "mem-low",
                            "log-full",
                            "intf-ip",
                            "ent-conf-change"
                        ],
                        "elements": "str"
                    },
                    "hosts": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "list",
                        "options": {
                            "id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.0": false,
                                    "6.4.1": false,
                                    "6.4.2": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.0": false,
                                    "7.0.1": false,
                                    "7.0.2": false,
                                    "7.0.3": false,
                                    "7.0.4": false,
                                    "7.0.5": false,
                                    "7.0.6": false,
                                    "7.0.7": false,
                                    "7.0.8": false,
                                    "7.0.9": false,
                                    "7.2.0": false,
                                    "7.2.1": false,
                                    "7.2.2": false,
                                    "7.2.3": false,
                                    "7.2.4": false,
                                    "7.4.0": false,
                                    "7.4.1": false
                                },
                                "type": "int"
                            },
                            "ip": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.0": false,
                                    "6.4.1": false,
                                    "6.4.2": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.0": false,
                                    "7.0.1": false,
                                    "7.0.2": false,
                                    "7.0.3": false,
                                    "7.0.4": false,
                                    "7.0.5": false,
                                    "7.0.6": false,
                                    "7.0.7": false,
                                    "7.0.8": false,
                                    "7.0.9": false,
                                    "7.2.0": false,
                                    "7.2.1": false,
                                    "7.2.2": false,
                                    "7.2.3": false,
                                    "7.2.4": false,
                                    "7.4.0": false,
                                    "7.4.1": false
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "query-v1-port": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "query-v1-status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "query-v2c-port": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "query-v2c-status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "trap-v1-lport": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "trap-v1-rport": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "trap-v1-status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "trap-v2c-lport": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "trap-v2c-rport": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "trap-v2c-status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "snmp-user": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "auth-proto": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "md5",
                            "sha"
                        ],
                        "type": "str"
                    },
                    "auth-pwd": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "raw"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "priv-proto": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "des",
                            "aes"
                        ],
                        "type": "str"
                    },
                    "priv-pwd": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "raw"
                    },
                    "queries": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "query-port": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "security-level": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "no-auth-no-priv",
                            "auth-no-priv",
                            "auth-priv"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "mclag-igmp-snooping-aware": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ip-source-guard": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "binding-entry": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "list",
                        "options": {
                            "entry-name": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.0": false,
                                    "7.0.1": false,
                                    "7.0.2": false,
                                    "7.0.3": false,
                                    "7.0.4": false,
                                    "7.0.5": false,
                                    "7.0.6": false,
                                    "7.0.7": false,
                                    "7.0.8": false,
                                    "7.0.9": false,
                                    "7.2.0": false,
                                    "7.2.1": false,
                                    "7.2.2": false,
                                    "7.2.3": false,
                                    "7.2.4": false,
                                    "7.4.0": false,
                                    "7.4.1": false
                                },
                                "type": "str"
                            },
                            "ip": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.0": false,
                                    "7.0.1": false,
                                    "7.0.2": false,
                                    "7.0.3": false,
                                    "7.0.4": false,
                                    "7.0.5": false,
                                    "7.0.6": false,
                                    "7.0.7": false,
                                    "7.0.8": false,
                                    "7.0.9": false,
                                    "7.2.0": false,
                                    "7.2.1": false,
                                    "7.2.2": false,
                                    "7.2.3": false,
                                    "7.2.4": false,
                                    "7.4.0": false,
                                    "7.4.1": false
                                },
                                "type": "str"
                            },
                            "mac": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.0": false,
                                    "7.0.1": false,
                                    "7.0.2": false,
                                    "7.0.3": false,
                                    "7.0.4": false,
                                    "7.0.5": false,
                                    "7.0.6": false,
                                    "7.0.7": false,
                                    "7.0.8": false,
                                    "7.0.9": false,
                                    "7.2.0": false,
                                    "7.2.1": false,
                                    "7.2.2": false,
                                    "7.2.3": false,
                                    "7.2.4": false,
                                    "7.4.0": false,
                                    "7.4.1": false
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "description": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "port": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "l3-discovered": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "qos-drop-policy": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "taildrop",
                    "random-early-detection"
                ],
                "type": "str"
            },
            "qos-red-probability": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "switch-dhcp_opt43_key": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "str"
            },
            "tdr-supported": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "custom-command": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "command-entry": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "command-name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "firmware-provision": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "firmware-provision-version": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dhcp-server-access-list": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "global"
                ],
                "type": "str"
            },
            "firmware-provision-latest": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "once"
                ],
                "type": "str"
            },
            "dhcp-snooping-static-client": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "ip": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "mac": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "port": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vlan": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "ptp-profile": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "ptp-status": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "route-offload": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "route-offload-mclag": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "route-offload-router": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "router-ip": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vlan-name": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "switchcontroller_managedswitch_8021xsettings": {
        "stated": false,
        "options": {}
    },
    "switchcontroller_managedswitch_customcommand": {
        "stated": true,
        "options": {
            "command-entry": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "command-name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "switchcontroller_managedswitch_dhcpsnoopingstaticclient": {
        "stated": true,
        "options": {
            "ip": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "mac": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "port": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vlan": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "switchcontroller_managedswitch_igmpsnooping": {
        "stated": false,
        "options": {}
    },
    "switchcontroller_managedswitch_ipsourceguard": {
        "stated": true,
        "options": {
            "binding-entry": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "entry-name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "ip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "mac": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "description": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "switchcontroller_managedswitch_ipsourceguard_bindingentry": {
        "stated": true,
        "options": {
            "entry-name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "mac": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "switchcontroller_managedswitch_mirror": {
        "stated": true,
        "options": {}
    },
    "switchcontroller_managedswitch_ports": {
        "stated": true,
        "options": {
            "allowed-vlans": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "allowed-vlans-all": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "arp-inspection-trust": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "untrusted",
                    "trusted"
                ],
                "type": "str"
            },
            "bundle": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "description": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dhcp-snoop-option82-trust": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dhcp-snooping": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "trusted",
                    "untrusted"
                ],
                "type": "str"
            },
            "discard-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "all-untagged",
                    "all-tagged"
                ],
                "type": "str"
            },
            "edge-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "igmp-snooping": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "igmps-flood-reports": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "igmps-flood-traffic": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "lacp-speed": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "slow",
                    "fast"
                ],
                "type": "str"
            },
            "learning-limit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "lldp-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "lldp-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "rx-only",
                    "tx-only",
                    "tx-rx"
                ],
                "type": "str"
            },
            "loop-guard": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disabled",
                    "enabled"
                ],
                "type": "str"
            },
            "loop-guard-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "max-bundle": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mclag": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "member-withdrawal-behavior": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "forward",
                    "block"
                ],
                "type": "str"
            },
            "members": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "min-bundle": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "static",
                    "lacp-passive",
                    "lacp-active"
                ],
                "type": "str"
            },
            "poe-pre-standard-detection": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "poe-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "port-name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "port-owner": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "port-security-policy": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "port-selection-criteria": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "src-mac",
                    "dst-mac",
                    "src-dst-mac",
                    "src-ip",
                    "dst-ip",
                    "src-dst-ip"
                ],
                "type": "str"
            },
            "qos-policy": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sample-direction": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "rx",
                    "tx",
                    "both"
                ],
                "type": "str"
            },
            "sflow-counter-interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "sflow-sample-rate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "sflow-sampler": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disabled",
                    "enabled"
                ],
                "type": "str"
            },
            "stp-bpdu-guard": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disabled",
                    "enabled"
                ],
                "type": "str"
            },
            "stp-bpdu-guard-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "stp-root-guard": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disabled",
                    "enabled"
                ],
                "type": "str"
            },
            "stp-state": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disabled",
                    "enabled"
                ],
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "physical",
                    "trunk"
                ],
                "type": "str"
            },
            "untagged-vlans": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "vlan": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "export-to-pool-flag": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "mac-addr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": false,
                    "6.2.3": false,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "packet-sample-rate": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "packet-sampler": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disabled",
                    "enabled"
                ],
                "type": "str"
            },
            "sticky-mac": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "storm-control-policy": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "dot1x-enable": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "max-miss-heartbeats": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "access-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "normal",
                    "nac",
                    "dynamic",
                    "static"
                ],
                "type": "str"
            },
            "ip-source-guard": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mclag-icl-port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "p2p-port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "aggregator-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "bandwidth",
                    "count"
                ],
                "type": "str"
            },
            "rpvst-port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disabled",
                    "enabled"
                ],
                "type": "str"
            },
            "flow-control": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "tx",
                    "rx",
                    "both"
                ],
                "type": "str"
            },
            "media-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "pause-meter": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "pause-meter-resume": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "25%",
                    "50%",
                    "75%"
                ],
                "type": "str"
            },
            "trunk-member": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fec-capable": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fec-state": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disabled",
                    "cl74",
                    "cl91"
                ],
                "type": "str"
            },
            "matched-dpp-intf-tags": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "matched-dpp-policy": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "port-policy": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "down",
                    "up"
                ],
                "type": "str"
            },
            "dsl-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "flap-duration": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "flap-rate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "flap-timeout": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "flapguard": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "interface-tags": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "poe-max-power": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "poe-standard": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "igmp-snooping-flood-reports": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mcast-snooping-flood-traffic": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "link-status": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "down",
                    "up"
                ],
                "type": "str"
            },
            "poe-mode-bt-cabable": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "poe-port-mode": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ieee802-3af",
                    "ieee802-3at",
                    "ieee802-3bt"
                ],
                "type": "str"
            },
            "poe-port-power": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "normal",
                    "perpetual",
                    "perpetual-fast"
                ],
                "type": "str"
            },
            "poe-port-priority": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "critical-priority",
                    "high-priority",
                    "low-priority",
                    "medium-priority"
                ],
                "type": "str"
            },
            "acl-group": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dhcp-snoop-option82-override": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "circuit-id": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "remote-id": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vlan-name": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "fortiswitch-acls": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "isl-peer-device-sn": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "authenticated-port": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "encrypted-port": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "ptp-status": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "restricted-auth-port": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "switchcontroller_managedswitch_ports_dhcpsnoopoption82override": {
        "stated": true,
        "options": {
            "circuit-id": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "remote-id": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vlan-name": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "switchcontroller_managedswitch_remotelog": {
        "stated": true,
        "options": {
            "csv": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "facility": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "kernel",
                    "user",
                    "mail",
                    "daemon",
                    "auth",
                    "syslog",
                    "lpr",
                    "news",
                    "uucp",
                    "cron",
                    "authpriv",
                    "ftp",
                    "ntp",
                    "audit",
                    "alert",
                    "clock",
                    "local0",
                    "local1",
                    "local2",
                    "local3",
                    "local4",
                    "local5",
                    "local6",
                    "local7"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "server": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "severity": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "emergency",
                    "alert",
                    "critical",
                    "error",
                    "warning",
                    "notification",
                    "information",
                    "debug"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "switchcontroller_managedswitch_routeoffloadrouter": {
        "stated": true,
        "options": {
            "router-ip": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "vlan-name": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "switchcontroller_managedswitch_snmpcommunity": {
        "stated": true,
        "options": {
            "events": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "choices": [
                    "cpu-high",
                    "mem-low",
                    "log-full",
                    "intf-ip",
                    "ent-conf-change"
                ],
                "elements": "str"
            },
            "hosts": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "ip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "query-v1-port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "query-v1-status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "query-v2c-port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "query-v2c-status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "trap-v1-lport": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "trap-v1-rport": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "trap-v1-status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "trap-v2c-lport": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "trap-v2c-rport": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "trap-v2c-status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "switchcontroller_managedswitch_snmpcommunity_hosts": {
        "stated": true,
        "options": {
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "switchcontroller_managedswitch_snmpsysinfo": {
        "stated": false,
        "options": {
            "contact-info": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "description": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "engine-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "location": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "switchcontroller_managedswitch_snmptrapthreshold": {
        "stated": false,
        "options": {
            "trap-high-cpu-threshold": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "trap-log-full-threshold": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "trap-low-memory-threshold": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            }
        }
    },
    "switchcontroller_managedswitch_snmpuser": {
        "stated": true,
        "options": {
            "auth-proto": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "md5",
                    "sha"
                ],
                "type": "str"
            },
            "auth-pwd": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "priv-proto": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "des",
                    "aes"
                ],
                "type": "str"
            },
            "priv-pwd": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "queries": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "query-port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "security-level": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "no-auth-no-priv",
                    "auth-no-priv",
                    "auth-priv"
                ],
                "type": "str"
            }
        }
    },
    "switchcontroller_managedswitch_staticmac": {
        "stated": true,
        "options": {}
    },
    "switchcontroller_managedswitch_stormcontrol": {
        "stated": false,
        "options": {}
    },
    "switchcontroller_managedswitch_stpinstance": {
        "stated": true,
        "options": {}
    },
    "switchcontroller_managedswitch_stpsettings": {
        "stated": false,
        "options": {}
    },
    "switchcontroller_managedswitch_switchlog": {
        "stated": false,
        "options": {}
    },
    "switchcontroller_managedswitch_switchstpsettings": {
        "stated": false,
        "options": {}
    },
    "switchcontroller_ptp_profile": {
        "stated": true,
        "options": {
            "description": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "domain": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "mode": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "transparent-e2e",
                    "transparent-p2p"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "pdelay-req-interval": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "1sec",
                    "2sec",
                    "4sec",
                    "8sec",
                    "16sec",
                    "32sec"
                ],
                "type": "str"
            },
            "ptp-profile": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "C37.238-2017"
                ],
                "type": "str"
            },
            "transport": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "l2-mcast"
                ],
                "type": "str"
            }
        }
    },
    "switchcontroller_qos_dot1pmap": {
        "stated": true,
        "options": {
            "description": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "priority-0": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue-0",
                    "queue-1",
                    "queue-2",
                    "queue-3",
                    "queue-4",
                    "queue-5",
                    "queue-6",
                    "queue-7"
                ],
                "type": "str"
            },
            "priority-1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue-0",
                    "queue-1",
                    "queue-2",
                    "queue-3",
                    "queue-4",
                    "queue-5",
                    "queue-6",
                    "queue-7"
                ],
                "type": "str"
            },
            "priority-2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue-0",
                    "queue-1",
                    "queue-2",
                    "queue-3",
                    "queue-4",
                    "queue-5",
                    "queue-6",
                    "queue-7"
                ],
                "type": "str"
            },
            "priority-3": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue-0",
                    "queue-1",
                    "queue-2",
                    "queue-3",
                    "queue-4",
                    "queue-5",
                    "queue-6",
                    "queue-7"
                ],
                "type": "str"
            },
            "priority-4": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue-0",
                    "queue-1",
                    "queue-2",
                    "queue-3",
                    "queue-4",
                    "queue-5",
                    "queue-6",
                    "queue-7"
                ],
                "type": "str"
            },
            "priority-5": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue-0",
                    "queue-1",
                    "queue-2",
                    "queue-3",
                    "queue-4",
                    "queue-5",
                    "queue-6",
                    "queue-7"
                ],
                "type": "str"
            },
            "priority-6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue-0",
                    "queue-1",
                    "queue-2",
                    "queue-3",
                    "queue-4",
                    "queue-5",
                    "queue-6",
                    "queue-7"
                ],
                "type": "str"
            },
            "priority-7": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue-0",
                    "queue-1",
                    "queue-2",
                    "queue-3",
                    "queue-4",
                    "queue-5",
                    "queue-6",
                    "queue-7"
                ],
                "type": "str"
            },
            "egress-pri-tagging": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "switchcontroller_qos_ipdscpmap": {
        "stated": true,
        "options": {
            "description": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "map": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "cos-queue": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "diffserv": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "CS0",
                            "CS1",
                            "AF11",
                            "AF12",
                            "AF13",
                            "CS2",
                            "AF21",
                            "AF22",
                            "AF23",
                            "CS3",
                            "AF31",
                            "AF32",
                            "AF33",
                            "CS4",
                            "AF41",
                            "AF42",
                            "AF43",
                            "CS5",
                            "EF",
                            "CS6",
                            "CS7"
                        ],
                        "elements": "str"
                    },
                    "ip-precedence": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "network-control",
                            "internetwork-control",
                            "critic-ecp",
                            "flashoverride",
                            "flash",
                            "immediate",
                            "priority",
                            "routine"
                        ],
                        "elements": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "value": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "switchcontroller_qos_ipdscpmap_map": {
        "stated": true,
        "options": {
            "cos-queue": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "diffserv": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "CS0",
                    "CS1",
                    "AF11",
                    "AF12",
                    "AF13",
                    "CS2",
                    "AF21",
                    "AF22",
                    "AF23",
                    "CS3",
                    "AF31",
                    "AF32",
                    "AF33",
                    "CS4",
                    "AF41",
                    "AF42",
                    "AF43",
                    "CS5",
                    "EF",
                    "CS6",
                    "CS7"
                ],
                "elements": "str"
            },
            "ip-precedence": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "network-control",
                    "internetwork-control",
                    "critic-ecp",
                    "flashoverride",
                    "flash",
                    "immediate",
                    "priority",
                    "routine"
                ],
                "elements": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "value": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "switchcontroller_qos_qospolicy": {
        "stated": true,
        "options": {
            "default-cos": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "queue-policy": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "trust-dot1p-map": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "trust-ip-dscp-map": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "switchcontroller_qos_queuepolicy": {
        "stated": true,
        "options": {
            "cos-queue": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "description": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "drop-policy": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "taildrop",
                            "weighted-random-early-detection"
                        ],
                        "type": "str"
                    },
                    "max-rate": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "min-rate": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "weight": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "max-rate-percent": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "min-rate-percent": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ecn": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "schedule": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "strict",
                    "round-robin",
                    "weighted"
                ],
                "type": "str"
            },
            "rate-by": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "kbps",
                    "percent"
                ],
                "type": "str"
            }
        }
    },
    "switchcontroller_qos_queuepolicy_cosqueue": {
        "stated": true,
        "options": {
            "description": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "drop-policy": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "taildrop",
                    "weighted-random-early-detection"
                ],
                "type": "str"
            },
            "max-rate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "min-rate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "weight": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "max-rate-percent": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "min-rate-percent": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ecn": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "switchcontroller_securitypolicy_8021x": {
        "stated": true,
        "options": {
            "auth-fail-vlan": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "auth-fail-vlan-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "auth-fail-vlanid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "eap-passthru": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "guest-auth-delay": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "guest-vlan": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "guest-vlan-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "guest-vlanid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mac-auth-bypass": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "open-auth": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "policy-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "802.1X"
                ],
                "type": "str"
            },
            "radius-timeout-overwrite": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "security-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "802.1X",
                    "802.1X-mac-based"
                ],
                "type": "str"
            },
            "user-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "framevid-apply": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "eap-auto-untagged-vlans": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "authserver-timeout-period": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "authserver-timeout-vlan": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "authserver-timeout-vlanid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "switchcontroller_securitypolicy_captiveportal": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": false,
                    "6.2.3": false,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "policy-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": false,
                    "6.2.3": false,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "captive-portal"
                ],
                "type": "str"
            },
            "vlan": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": false,
                    "6.2.3": false,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "switchcontroller_switchinterfacetag": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "switchcontroller_trafficpolicy": {
        "stated": true,
        "options": {
            "cos-queue": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "description": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "guaranteed-bandwidth": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "guaranteed-burst": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "id": {
                "required": true,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "maximum-burst": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "policer-status": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ingress",
                    "egress"
                ],
                "type": "str"
            }
        }
    },
    "switchcontroller_vlanpolicy": {
        "stated": true,
        "options": {
            "allowed-vlans": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "allowed-vlans-all": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "description": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "discard-mode": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "all-untagged",
                    "all-tagged"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "untagged-vlans": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "vlan": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "sys_api_sdnconnector": {
        "stated": true,
        "options": {
            "adom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "command": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "connector_name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "sys_cloud_orchest": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "deploy",
                    "undeploy",
                    "status"
                ],
                "type": "str"
            },
            "adom": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "adom_oid": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "sys_generate_wsdl": {
        "stated": true,
        "options": {
            "endpoint": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "target": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "sys_hitcount": {
        "stated": true,
        "options": {
            "adom": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "adom_oid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "pkg": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "pkg_oid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "sys_login_challenge": {
        "stated": true,
        "options": {
            "answer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "session": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "sys_login_user": {
        "stated": true,
        "options": {
            "passwd": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "str"
            },
            "user": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "sys_logout": {
        "stated": true,
        "options": {}
    },
    "sys_proxy_json": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "get",
                    "post",
                    "put",
                    "delete"
                ],
                "type": "str"
            },
            "payload": {
                "required": false,
                "type": "dict"
            },
            "resource": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "target": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "elements": "str"
            },
            "timeout": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "sys_reboot": {
        "stated": true,
        "options": {
            "message": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "sys_task_result": {
        "stated": true,
        "options": {
            "taskid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "system_admin_group": {
        "stated": true,
        "options": {
            "member": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_admin_group_member": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_admin_ldap": {
        "stated": true,
        "options": {
            "adom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "adom-name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "adom-attr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "attributes": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ca-cert": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cnid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "connect-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "dn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "filter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "memberof-attr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "password": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "profile-attr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "secondary-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "secure": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "starttls",
                    "ldaps"
                ],
                "type": "str"
            },
            "server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tertiary-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "simple",
                    "anonymous",
                    "regular"
                ],
                "type": "str"
            },
            "username": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "adom-access": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "all",
                    "specify"
                ],
                "type": "str"
            }
        }
    },
    "system_admin_ldap_adom": {
        "stated": true,
        "options": {
            "adom-name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_admin_profile": {
        "stated": true,
        "options": {
            "adom-lock": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "read",
                    "read-write"
                ],
                "type": "str"
            },
            "adom-policy-packages": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "read",
                    "read-write"
                ],
                "type": "str"
            },
            "adom-switch": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "read",
                    "read-write"
                ],
                "type": "str"
            },
            "app-filter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "assignment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "read",
                    "read-write"
                ],
                "type": "str"
            },
            "change-password": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "config-retrieve": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "read",
                    "read-write"
                ],
                "type": "str"
            },
            "config-revert": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "read",
                    "read-write"
                ],
                "type": "str"
            },
            "consistency-check": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "read",
                    "read-write"
                ],
                "type": "str"
            },
            "datamask": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "datamask-custom-fields": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "field-category": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "log",
                            "fortiview",
                            "alert",
                            "ueba",
                            "all"
                        ],
                        "elements": "str"
                    },
                    "field-name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "field-status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "field-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "string",
                            "ip",
                            "mac",
                            "email",
                            "unknown"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "datamask-custom-priority": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "datamask-fields": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "user",
                    "srcip",
                    "srcname",
                    "srcmac",
                    "dstip",
                    "dstname",
                    "email",
                    "message",
                    "domain"
                ],
                "elements": "str"
            },
            "datamask-key": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "deploy-management": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "read",
                    "read-write"
                ],
                "type": "str"
            },
            "description": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "device-ap": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "read",
                    "read-write"
                ],
                "type": "str"
            },
            "device-config": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "read",
                    "read-write"
                ],
                "type": "str"
            },
            "device-forticlient": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "read",
                    "read-write"
                ],
                "type": "str"
            },
            "device-fortiswitch": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "read",
                    "read-write"
                ],
                "type": "str"
            },
            "device-manager": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "read",
                    "read-write"
                ],
                "type": "str"
            },
            "device-op": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "read",
                    "read-write"
                ],
                "type": "str"
            },
            "device-policy-package-lock": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "read",
                    "read-write"
                ],
                "type": "str"
            },
            "device-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "read",
                    "read-write"
                ],
                "type": "str"
            },
            "device-revision-deletion": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "read",
                    "read-write"
                ],
                "type": "str"
            },
            "device-wan-link-load-balance": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "read",
                    "read-write"
                ],
                "type": "str"
            },
            "event-management": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "read",
                    "read-write"
                ],
                "type": "str"
            },
            "fgd-center-advanced": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "read",
                    "read-write"
                ],
                "type": "str"
            },
            "fgd-center-fmw-mgmt": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "read",
                    "read-write"
                ],
                "type": "str"
            },
            "fgd-center-licensing": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "read",
                    "read-write"
                ],
                "type": "str"
            },
            "fgd_center": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "read",
                    "read-write"
                ],
                "type": "str"
            },
            "global-policy-packages": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "read",
                    "read-write"
                ],
                "type": "str"
            },
            "import-policy-packages": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "read",
                    "read-write"
                ],
                "type": "str"
            },
            "intf-mapping": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "read",
                    "read-write"
                ],
                "type": "str"
            },
            "ips-filter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "log-viewer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "read",
                    "read-write"
                ],
                "type": "str"
            },
            "policy-objects": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "read",
                    "read-write"
                ],
                "type": "str"
            },
            "profileid": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "read-passwd": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "read",
                    "read-write"
                ],
                "type": "str"
            },
            "realtime-monitor": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "read",
                    "read-write"
                ],
                "type": "str"
            },
            "report-viewer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "read",
                    "read-write"
                ],
                "type": "str"
            },
            "scope": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "global",
                    "adom"
                ],
                "type": "str"
            },
            "set-install-targets": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "read",
                    "read-write"
                ],
                "type": "str"
            },
            "system-setting": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "read",
                    "read-write"
                ],
                "type": "str"
            },
            "term-access": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "read",
                    "read-write"
                ],
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "system",
                    "restricted"
                ],
                "type": "str"
            },
            "vpn-manager": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "read",
                    "read-write"
                ],
                "type": "str"
            },
            "web-filter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "datamask-unmasked-time": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "super-user-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "allow-to-install": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "extension-access": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "read",
                    "read-write"
                ],
                "type": "str"
            },
            "fabric-viewer": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "read",
                    "read-write"
                ],
                "type": "str"
            },
            "run-report": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "read",
                    "read-write"
                ],
                "type": "str"
            },
            "script-access": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "read",
                    "read-write"
                ],
                "type": "str"
            },
            "triage-events": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "read",
                    "read-write"
                ],
                "type": "str"
            },
            "update-incidents": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "read",
                    "read-write"
                ],
                "type": "str"
            },
            "ips-objects": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "read",
                    "read-write"
                ],
                "type": "str"
            },
            "ipv6_trusthost1": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipv6_trusthost10": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipv6_trusthost2": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipv6_trusthost3": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipv6_trusthost4": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipv6_trusthost5": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipv6_trusthost6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipv6_trusthost7": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipv6_trusthost8": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipv6_trusthost9": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "rpc-permit": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "read-write",
                    "none",
                    "read"
                ],
                "type": "str"
            },
            "trusthost1": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "trusthost10": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "trusthost2": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "trusthost3": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "trusthost4": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "trusthost5": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "trusthost6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "trusthost7": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "trusthost8": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "trusthost9": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ips-baseline-cfg": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "none",
                    "read",
                    "read-write"
                ],
                "type": "str"
            },
            "ips-baseline-ovrd": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "device-fortiextender": {
                "required": false,
                "revision": {
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "read",
                    "read-write"
                ],
                "type": "str"
            },
            "ips-lock": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "read",
                    "read-write"
                ],
                "type": "str"
            }
        }
    },
    "system_admin_profile_datamaskcustomfields": {
        "stated": true,
        "options": {
            "field-category": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "log",
                    "fortiview",
                    "alert",
                    "ueba",
                    "all"
                ],
                "elements": "str"
            },
            "field-name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "field-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "field-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "string",
                    "ip",
                    "mac",
                    "email",
                    "unknown"
                ],
                "type": "str"
            }
        }
    },
    "system_admin_radius": {
        "stated": true,
        "options": {
            "auth-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "any",
                    "pap",
                    "chap",
                    "mschap2"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "nas-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "secondary-secret": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "secondary-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "secret": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_admin_setting": {
        "stated": false,
        "options": {
            "access-banner": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "admin-https-redirect": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "admin-login-max": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "admin_server_cert": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "allow_register": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "auto-update": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "banner-message": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "chassis-mgmt": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "chassis-update-interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "device_sync_status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "gui-theme": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "blue",
                    "green",
                    "red",
                    "melongene",
                    "spring",
                    "summer",
                    "autumn",
                    "winter",
                    "space",
                    "calla-lily",
                    "binary-tunnel",
                    "diving",
                    "dreamy",
                    "technology",
                    "landscape",
                    "twilight",
                    "canyon",
                    "northern-light",
                    "astronomy",
                    "fish",
                    "penguin",
                    "panda",
                    "polar-bear",
                    "parrot",
                    "cave",
                    "mountain",
                    "zebra",
                    "contrast-dark",
                    "circuit-board",
                    "mars",
                    "blue-sea",
                    "mariner",
                    "jade",
                    "neutrino",
                    "dark-matter",
                    "forest",
                    "cat",
                    "graphite"
                ],
                "type": "str"
            },
            "http_port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "https_port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "idle_timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "install-ifpolicy-only": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mgmt-addr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "mgmt-fqdn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "objects-force-deletion": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "offline_mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "register_passwd": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "sdwan-monitor-history": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "shell-access": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "shell-password": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "show-add-multiple": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "show-adom-devman": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "show-checkbox-in-table": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "show-device-import-export": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "show-hostname": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "show_automatic_script": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "show_grouping_script": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "show_schedule_script": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "show_tcl_script": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "unreg_dev_opt": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "add_no_service",
                    "ignore",
                    "add_allow_service"
                ],
                "type": "str"
            },
            "webadmin_language": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auto_detect",
                    "english",
                    "simplified_chinese",
                    "traditional_chinese",
                    "japanese",
                    "korean",
                    "spanish",
                    "french"
                ],
                "type": "str"
            },
            "show-fct-manager": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sdwan-skip-unmapped-input-device": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "auth-addr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "auth-port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "idle_timeout_api": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "idle_timeout_gui": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "central-ftgd-local-cat-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "idle_timeout_sso": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "preferred-fgfm-intf": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "traffic-shaping-history": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fsw-ignore-platform-check": {
                "required": false,
                "revision": {
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "rtm-max-monitor-by-days": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "rtm-temp-file-limit": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "firmware-upgrade-check": {
                "required": false,
                "revision": {
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "system_admin_tacacs": {
        "stated": true,
        "options": {
            "authen-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auto",
                    "ascii",
                    "pap",
                    "chap",
                    "mschap"
                ],
                "type": "str"
            },
            "authorization": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "key": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "secondary-key": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "secondary-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tertiary-key": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "tertiary-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_admin_user": {
        "stated": true,
        "options": {
            "adom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "adom-name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "adom-exclude": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "adom-name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "app-filter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "app-filter-name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "avatar": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ca": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "change-password": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dashboard": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "column": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "diskio-content-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "util",
                            "iops",
                            "blks"
                        ],
                        "type": "str"
                    },
                    "diskio-period": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "1hour",
                            "8hour",
                            "24hour"
                        ],
                        "type": "str"
                    },
                    "log-rate-period": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "2min",
                            "1hour",
                            "6hours"
                        ],
                        "type": "str"
                    },
                    "log-rate-topn": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "1",
                            "2",
                            "3",
                            "4",
                            "5"
                        ],
                        "type": "str"
                    },
                    "log-rate-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "log",
                            "device"
                        ],
                        "type": "str"
                    },
                    "moduleid": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "num-entries": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "refresh-interval": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "res-cpu-display": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "average",
                            "each"
                        ],
                        "type": "str"
                    },
                    "res-period": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "10min",
                            "hour",
                            "day"
                        ],
                        "type": "str"
                    },
                    "res-view-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "real-time",
                            "history"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "close",
                            "open"
                        ],
                        "type": "str"
                    },
                    "tabid": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "time-period": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "1hour",
                            "8hour",
                            "24hour"
                        ],
                        "type": "str"
                    },
                    "widget-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "top-lograte",
                            "sysres",
                            "sysinfo",
                            "licinfo",
                            "jsconsole",
                            "sysop",
                            "alert",
                            "statistics",
                            "rpteng",
                            "raid",
                            "logrecv",
                            "devsummary",
                            "logdb-perf",
                            "logdb-lag",
                            "disk-io",
                            "log-rcvd-fwd"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "dashboard-tabs": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "tabid": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "description": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dev-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "email-address": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ext-auth-accprofile-override": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ext-auth-adom-override": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ext-auth-group-match": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "first-name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "force-password-change": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "hidden": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ips-filter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "ips-filter-name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "ipv6_trusthost1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipv6_trusthost10": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipv6_trusthost2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipv6_trusthost3": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipv6_trusthost4": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipv6_trusthost5": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipv6_trusthost6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipv6_trusthost7": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipv6_trusthost8": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipv6_trusthost9": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "last-name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ldap-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "meta-data": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "fieldlength": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "fieldname": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "fieldvalue": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "importance": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "optional",
                            "required"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disabled",
                            "enabled"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "mobile-number": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "pager-number": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "password": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "password-expire": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "phone-number": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "policy-package": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "policy-package-name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "profileid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "radius_server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "restrict-access": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "restrict-dev-vdom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "dev-vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "rpc-permit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "read-write",
                    "none",
                    "read",
                    "from-profile"
                ],
                "type": "str"
            },
            "ssh-public-key1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "ssh-public-key2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "ssh-public-key3": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "subject": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tacacs-plus-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "trusthost1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "trusthost10": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "trusthost2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "trusthost3": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "trusthost4": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "trusthost5": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "trusthost6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "trusthost7": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "trusthost8": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "trusthost9": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "two-factor-auth": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "password",
                    "ftc-ftm",
                    "ftc-email",
                    "ftc-sms"
                ],
                "type": "str"
            },
            "user_type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "local",
                    "radius",
                    "ldap",
                    "tacacs-plus",
                    "pki-auth",
                    "group",
                    "sso",
                    "api"
                ],
                "type": "str"
            },
            "userid": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "web-filter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "web-filter-name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "wildcard": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "login-max": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "use-global-theme": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "user-theme": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "blue",
                    "green",
                    "red",
                    "melongene",
                    "spring",
                    "summer",
                    "autumn",
                    "winter",
                    "circuit-board",
                    "calla-lily",
                    "binary-tunnel",
                    "mars",
                    "blue-sea",
                    "technology",
                    "landscape",
                    "twilight",
                    "canyon",
                    "northern-light",
                    "astronomy",
                    "fish",
                    "penguin",
                    "mountain",
                    "panda",
                    "parrot",
                    "cave",
                    "zebra",
                    "contrast-dark",
                    "mariner",
                    "jade",
                    "neutrino",
                    "dark-matter",
                    "forest",
                    "cat",
                    "graphite"
                ],
                "type": "str"
            },
            "adom-access": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "all",
                    "specify",
                    "exclude",
                    "per-adom-profile"
                ],
                "type": "str"
            },
            "fingerprint": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "th-from-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "th6-from-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "cors-allow-origin": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_admin_user_adom": {
        "stated": true,
        "options": {
            "adom-name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_admin_user_adomexclude": {
        "stated": true,
        "options": {
            "adom-name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "system_admin_user_appfilter": {
        "stated": true,
        "options": {
            "app-filter-name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_admin_user_dashboard": {
        "stated": true,
        "options": {
            "column": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "diskio-content-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "util",
                    "iops",
                    "blks"
                ],
                "type": "str"
            },
            "diskio-period": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "1hour",
                    "8hour",
                    "24hour"
                ],
                "type": "str"
            },
            "log-rate-period": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "2min",
                    "1hour",
                    "6hours"
                ],
                "type": "str"
            },
            "log-rate-topn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "1",
                    "2",
                    "3",
                    "4",
                    "5"
                ],
                "type": "str"
            },
            "log-rate-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "log",
                    "device"
                ],
                "type": "str"
            },
            "moduleid": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "num-entries": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "refresh-interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "res-cpu-display": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "average",
                    "each"
                ],
                "type": "str"
            },
            "res-period": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "10min",
                    "hour",
                    "day"
                ],
                "type": "str"
            },
            "res-view-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "real-time",
                    "history"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "close",
                    "open"
                ],
                "type": "str"
            },
            "tabid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "time-period": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "1hour",
                    "8hour",
                    "24hour"
                ],
                "type": "str"
            },
            "widget-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "top-lograte",
                    "sysres",
                    "sysinfo",
                    "licinfo",
                    "jsconsole",
                    "sysop",
                    "alert",
                    "statistics",
                    "rpteng",
                    "raid",
                    "logrecv",
                    "devsummary",
                    "logdb-perf",
                    "logdb-lag",
                    "disk-io",
                    "log-rcvd-fwd"
                ],
                "type": "str"
            }
        }
    },
    "system_admin_user_dashboardtabs": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tabid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "system_admin_user_ipsfilter": {
        "stated": true,
        "options": {
            "ips-filter-name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_admin_user_metadata": {
        "stated": true,
        "options": {
            "fieldlength": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fieldname": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "fieldvalue": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "importance": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "optional",
                    "required"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disabled",
                    "enabled"
                ],
                "type": "str"
            }
        }
    },
    "system_admin_user_policypackage": {
        "stated": true,
        "options": {
            "policy-package-name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_admin_user_restrictdevvdom": {
        "stated": true,
        "options": {
            "dev-vdom": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "system_admin_user_webfilter": {
        "stated": true,
        "options": {
            "web-filter-name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_alertconsole": {
        "stated": false,
        "options": {
            "period": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "1",
                    "2",
                    "3",
                    "4",
                    "5",
                    "6",
                    "7"
                ],
                "type": "str"
            },
            "severity-level": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "debug",
                    "information",
                    "notify",
                    "warning",
                    "error",
                    "critical",
                    "alert",
                    "emergency"
                ],
                "elements": "str"
            }
        }
    },
    "system_alertemail": {
        "stated": false,
        "options": {
            "authentication": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fromaddress": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "fromname": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "smtppassword": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "smtpport": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "smtpserver": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "smtpuser": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_alertevent": {
        "stated": true,
        "options": {
            "alert-destination": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "from": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "smtp-name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "snmp-name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "syslog-name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "to": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "mail",
                            "snmp",
                            "syslog"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "enable-generic-text": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "enable",
                    "disable"
                ],
                "elements": "str"
            },
            "enable-severity-filter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "enable",
                    "disable"
                ],
                "elements": "str"
            },
            "event-time-period": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "0.5",
                    "1",
                    "3",
                    "6",
                    "12",
                    "24",
                    "72",
                    "168"
                ],
                "type": "str"
            },
            "generic-text": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "num-events": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "1",
                    "5",
                    "10",
                    "50",
                    "100"
                ],
                "type": "str"
            },
            "severity-filter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "high",
                    "medium-high",
                    "medium",
                    "medium-low",
                    "low"
                ],
                "type": "str"
            },
            "severity-level-comp": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    ">=",
                    "=",
                    "<="
                ],
                "elements": "str"
            },
            "severity-level-logs": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "no-check",
                    "information",
                    "notify",
                    "warning",
                    "error",
                    "critical",
                    "alert",
                    "emergency"
                ],
                "elements": "str"
            }
        }
    },
    "system_alertevent_alertdestination": {
        "stated": true,
        "options": {
            "from": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "smtp-name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "snmp-name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "syslog-name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "to": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "mail",
                    "snmp",
                    "syslog"
                ],
                "type": "str"
            }
        }
    },
    "system_autodelete": {
        "stated": false,
        "options": {
            "dlp-files-auto-deletion": {
                "required": false,
                "type": "dict",
                "options": {
                    "retention": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "days",
                            "weeks",
                            "months"
                        ],
                        "type": "str"
                    },
                    "runat": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "value": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                }
            },
            "log-auto-deletion": {
                "required": false,
                "type": "dict",
                "options": {
                    "retention": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "days",
                            "weeks",
                            "months"
                        ],
                        "type": "str"
                    },
                    "runat": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "value": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                }
            },
            "quarantine-files-auto-deletion": {
                "required": false,
                "type": "dict",
                "options": {
                    "retention": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "days",
                            "weeks",
                            "months"
                        ],
                        "type": "str"
                    },
                    "runat": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "value": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                }
            },
            "report-auto-deletion": {
                "required": false,
                "type": "dict",
                "options": {
                    "retention": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "days",
                            "weeks",
                            "months"
                        ],
                        "type": "str"
                    },
                    "runat": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "value": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                }
            },
            "status-fake": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "system_autodelete_dlpfilesautodeletion": {
        "stated": false,
        "options": {
            "retention": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "days",
                    "weeks",
                    "months"
                ],
                "type": "str"
            },
            "runat": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "value": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "system_autodelete_logautodeletion": {
        "stated": false,
        "options": {
            "retention": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "days",
                    "weeks",
                    "months"
                ],
                "type": "str"
            },
            "runat": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "value": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "system_autodelete_quarantinefilesautodeletion": {
        "stated": false,
        "options": {
            "retention": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "days",
                    "weeks",
                    "months"
                ],
                "type": "str"
            },
            "runat": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "value": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "system_autodelete_reportautodeletion": {
        "stated": false,
        "options": {
            "retention": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "days",
                    "weeks",
                    "months"
                ],
                "type": "str"
            },
            "runat": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "value": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "system_backup_allsettings": {
        "stated": false,
        "options": {
            "cert": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "crptpasswd": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "directory": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "passwd": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "sftp",
                    "ftp",
                    "scp"
                ],
                "type": "str"
            },
            "server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "time": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "user": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "week_days": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "monday",
                    "tuesday",
                    "wednesday",
                    "thursday",
                    "friday",
                    "saturday",
                    "sunday"
                ],
                "elements": "str"
            }
        }
    },
    "system_certificate_ca": {
        "stated": true,
        "options": {
            "ca": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_certificate_crl": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "crl": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "http-url": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "update-interval": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "system_certificate_local": {
        "stated": true,
        "options": {
            "certificate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "csr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "password": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "private-key": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            }
        }
    },
    "system_certificate_oftp": {
        "stated": false,
        "options": {
            "certificate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "custom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "password": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "private-key": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "local": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "default",
                    "custom",
                    "local"
                ],
                "type": "str"
            }
        }
    },
    "system_certificate_remote": {
        "stated": true,
        "options": {
            "cert": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_certificate_ssh": {
        "stated": true,
        "options": {
            "certificate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "private-key": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            }
        }
    },
    "system_connector": {
        "stated": false,
        "options": {
            "fsso-refresh-interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fsso-sess-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "px-refresh-interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "px-svr-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "conn-refresh-interval": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "cloud-orchest-refresh-interval": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "system_csf": {
        "stated": false,
        "options": {
            "accept-auth-by-cert": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "authorization-request-type": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "certificate",
                    "serial"
                ],
                "type": "str"
            },
            "certificate": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "configuration-sync": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "default",
                    "local"
                ],
                "type": "str"
            },
            "downstream-access": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "downstream-accprofile": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "fabric-connector": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "accprofile": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "configuration-write-access": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "serial": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "fabric-object-unification": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "local",
                    "default"
                ],
                "type": "str"
            },
            "fabric-workers": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "file-mgmt": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "file-quota": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "file-quota-warning": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "fixed-key": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "no_log": true,
                "type": "list",
                "elements": "str"
            },
            "forticloud-account-enforcement": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "group-name": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "group-password": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "no_log": true,
                "type": "list",
                "elements": "str"
            },
            "log-unification": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "saml-configuration-sync": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "local",
                    "default"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "trusted-list": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "accept",
                            "deny"
                        ],
                        "type": "str"
                    },
                    "authorization-type": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "serial",
                            "certificate"
                        ],
                        "type": "str"
                    },
                    "certificate": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "downstream-authorization": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ha-members": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "index": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "serial": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "upstream": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "upstream-port": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "system_csf_fabricconnector": {
        "stated": true,
        "options": {
            "accprofile": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "configuration-write-access": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "serial": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_csf_trustedlist": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "accept",
                    "deny"
                ],
                "type": "str"
            },
            "authorization-type": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "serial",
                    "certificate"
                ],
                "type": "str"
            },
            "certificate": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "downstream-authorization": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ha-members": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "index": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": true,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "serial": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_customlanguage": {
        "stated": true,
        "options": {
            "comments": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "filename": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_dhcp_server": {
        "stated": true,
        "options": {
            "auto-configuration": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "conflicted-ip-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ddns-auth": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "tsig"
                ],
                "type": "str"
            },
            "ddns-key": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "ddns-keyname": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "str"
            },
            "ddns-server-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ddns-ttl": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ddns-update": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ddns-update-override": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ddns-zone": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "default-gateway": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dns-server1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dns-server2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dns-server3": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dns-service": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "default",
                    "specify",
                    "local"
                ],
                "type": "str"
            },
            "domain": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "exclude-range": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "end-ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "start-ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vci-match": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "vci-string": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "lease-time": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "uci-match": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "uci-string": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    }
                },
                "elements": "dict"
            },
            "filename": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "forticlient-on-net-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "interface": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ip-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "range",
                    "usrgrp"
                ],
                "type": "str"
            },
            "ip-range": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "end-ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "start-ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vci-match": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "vci-string": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "lease-time": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "uci-match": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "uci-string": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    }
                },
                "elements": "dict"
            },
            "ipsec-lease-hold": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "lease-time": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mac-acl-default-action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "assign",
                    "block"
                ],
                "type": "str"
            },
            "netmask": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "next-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ntp-server1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ntp-server2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ntp-server3": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ntp-service": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "default",
                    "specify",
                    "local"
                ],
                "type": "str"
            },
            "options": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "code": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "hex",
                            "string",
                            "ip",
                            "fqdn"
                        ],
                        "type": "str"
                    },
                    "value": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vci-match": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "vci-string": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "uci-match": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "uci-string": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    }
                },
                "elements": "dict"
            },
            "reserved-address": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "assign",
                            "block",
                            "reserved"
                        ],
                        "type": "str"
                    },
                    "description": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "mac": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "circuit-id": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "circuit-id-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "hex",
                            "string"
                        ],
                        "type": "str"
                    },
                    "remote-id": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "remote-id-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "hex",
                            "string"
                        ],
                        "type": "str"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "mac",
                            "option82"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "server-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "regular",
                    "ipsec"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tftp-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "timezone": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "00",
                    "01",
                    "02",
                    "03",
                    "04",
                    "05",
                    "06",
                    "07",
                    "08",
                    "09",
                    "10",
                    "11",
                    "12",
                    "13",
                    "14",
                    "15",
                    "16",
                    "17",
                    "18",
                    "19",
                    "20",
                    "21",
                    "22",
                    "23",
                    "24",
                    "25",
                    "26",
                    "27",
                    "28",
                    "29",
                    "30",
                    "31",
                    "32",
                    "33",
                    "34",
                    "35",
                    "36",
                    "37",
                    "38",
                    "39",
                    "40",
                    "41",
                    "42",
                    "43",
                    "44",
                    "45",
                    "46",
                    "47",
                    "48",
                    "49",
                    "50",
                    "51",
                    "52",
                    "53",
                    "54",
                    "55",
                    "56",
                    "57",
                    "58",
                    "59",
                    "60",
                    "61",
                    "62",
                    "63",
                    "64",
                    "65",
                    "66",
                    "67",
                    "68",
                    "69",
                    "70",
                    "71",
                    "72",
                    "73",
                    "74",
                    "75",
                    "76",
                    "77",
                    "78",
                    "79",
                    "80",
                    "81",
                    "82",
                    "83",
                    "84",
                    "85",
                    "86",
                    "87"
                ],
                "type": "str"
            },
            "timezone-option": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "default",
                    "specify"
                ],
                "type": "str"
            },
            "vci-match": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "vci-string": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "wifi-ac1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "wifi-ac2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "wifi-ac3": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "wins-server1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "wins-server2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dns-server4": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "wifi-ac-service": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "specify",
                    "local"
                ],
                "type": "str"
            },
            "auto-managed-status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dhcp-settings-from-fortiipam": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "relay-agent": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "shared-subnet": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "system_dhcp_server_excluderange": {
        "stated": true,
        "options": {
            "end-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "start-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vci-match": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "vci-string": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "lease-time": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "uci-match": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "uci-string": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "system_dhcp_server_iprange": {
        "stated": true,
        "options": {
            "end-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "start-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vci-match": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "vci-string": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "lease-time": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "uci-match": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "uci-string": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "system_dhcp_server_options": {
        "stated": true,
        "options": {
            "code": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "hex",
                    "string",
                    "ip",
                    "fqdn"
                ],
                "type": "str"
            },
            "value": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vci-match": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "vci-string": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "uci-match": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "uci-string": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "system_dhcp_server_reservedaddress": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "assign",
                    "block",
                    "reserved"
                ],
                "type": "str"
            },
            "description": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "mac": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "circuit-id": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "circuit-id-type": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "hex",
                    "string"
                ],
                "type": "str"
            },
            "remote-id": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "remote-id-type": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "hex",
                    "string"
                ],
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "mac",
                    "option82"
                ],
                "type": "str"
            }
        }
    },
    "system_dm": {
        "stated": false,
        "options": {
            "concurrent-install-image-limit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "concurrent-install-limit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "concurrent-install-script-limit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "discover-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "dpm-logsize": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fgfm-sock-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fgfm_keepalive_itvl": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "force-remote-diff": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fortiap-refresh-cnt": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fortiap-refresh-itvl": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fortiext-refresh-cnt": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "install-image-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "install-tunnel-retry-itvl": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "max-revs": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "nr-retry": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "retry": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "retry-intvl": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "rollback-allow-reboot": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "script-logsize": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "skip-scep-check": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "skip-tunnel-fcp-req": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "verify-install": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "optimal",
                    "enable"
                ],
                "type": "str"
            },
            "fgfm-install-refresh-count": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "conf-merge-after-script": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "log-autoupdate": {
                "required": false,
                "revision": {
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fgfm-auto-retrieve-timeout": {
                "required": false,
                "revision": {
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": true
                },
                "type": "int"
            },
            "install-fds-timeout": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "system_dns": {
        "stated": false,
        "options": {
            "ip6-primary": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ip6-secondary": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "primary": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "secondary": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_docker": {
        "stated": false,
        "options": {
            "fortiportal": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fortiwlm": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sdwancontroller": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "qa",
                    "dev"
                ],
                "type": "str"
            },
            "cpu": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "default-address-pool_base": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "default-address-pool_size": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fortiauthenticator": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fortisigconverter": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mem": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "docker-user-login-max": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fortisoar": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fortiaiops": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "policyanalyzer": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "universalconnector": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fsmcollector": {
                "required": false,
                "revision": {
                    "7.0.1": true,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "system_externalresource": {
        "stated": true,
        "options": {
            "category": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "comments": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "refresh-rate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "resource": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "category",
                    "address",
                    "domain",
                    "malware",
                    "url",
                    "mac-address"
                ],
                "type": "str"
            },
            "password": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "source-ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "username": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "interface": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "interface-select-method": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auto",
                    "sdwan",
                    "specify"
                ],
                "type": "str"
            },
            "user-agent": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "uuid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "server-identity-check": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "basic",
                    "full"
                ],
                "type": "str"
            },
            "update-method": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "feed",
                    "push"
                ],
                "type": "str"
            }
        }
    },
    "system_fips": {
        "stated": false,
        "options": {
            "entropy-token": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "enable",
                    "disable",
                    "dynamic"
                ],
                "type": "str"
            },
            "re-seed-interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "system_fortiguard": {
        "stated": false,
        "options": {
            "antispam-cache": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "antispam-cache-mpercent": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "antispam-cache-ttl": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "antispam-expiration": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "antispam-force-off": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "antispam-license": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "antispam-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "auto-join-forticloud": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ddns-server-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ddns-server-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "load-balance-servers": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "outbreak-prevention-cache": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "outbreak-prevention-cache-mpercent": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "outbreak-prevention-cache-ttl": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "outbreak-prevention-expiration": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "outbreak-prevention-force-off": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "outbreak-prevention-license": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "outbreak-prevention-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "53",
                    "80",
                    "8888",
                    "443"
                ],
                "type": "str"
            },
            "sdns-server-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "sdns-server-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "service-account-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "source-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "source-ip6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "update-server-location": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "any",
                    "usa",
                    "automatic",
                    "eu"
                ],
                "type": "str"
            },
            "webfilter-cache": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "webfilter-cache-ttl": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "webfilter-expiration": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "webfilter-force-off": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "webfilter-license": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "webfilter-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "udp",
                    "http",
                    "https"
                ],
                "type": "str"
            },
            "proxy-password": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "proxy-server-ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "proxy-server-port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "proxy-username": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sandbox-region": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "avquery-cache-ttl": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "avquery-timeout": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "avquery-cache": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "avquery-cache-mpercent": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "avquery-license": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "avquery-force-off": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fortiguard-anycast": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fortiguard-anycast-source": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "fortinet",
                    "aws",
                    "debug"
                ],
                "type": "str"
            },
            "interface": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "interface-select-method": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auto",
                    "sdwan",
                    "specify"
                ],
                "type": "str"
            },
            "sdns-options": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "include-question-section"
                ],
                "elements": "str"
            },
            "anycast-sdns-server-ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "anycast-sdns-server-port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "persistent-connection": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "update-build-proxy": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "update-extdb": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "update-ffdb": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "update-uwdb": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "videofilter-expiration": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "videofilter-license": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ddns-server-ip6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vdom": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "auto-firmware-upgrade": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "auto-firmware-upgrade-day": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "sunday",
                    "monday",
                    "tuesday",
                    "wednesday",
                    "thursday",
                    "friday",
                    "saturday"
                ],
                "elements": "str"
            },
            "auto-firmware-upgrade-end-hour": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "auto-firmware-upgrade-start-hour": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "sandbox-inline-scan": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "auto-firmware-upgrade-delay": {
                "required": false,
                "revision": {
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "gui-prompt-auto-upgrade": {
                "required": false,
                "revision": {
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "FDS-license-expiring-days": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "antispam-cache-mpermille": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "outbreak-prevention-cache-mpermille": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "update-dldb": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "system_fortiview_autocache": {
        "stated": false,
        "options": {
            "aggressive-fortiview": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "system_fortiview_setting": {
        "stated": false,
        "options": {
            "not-scanned-apps": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "exclude",
                    "include"
                ],
                "type": "str"
            },
            "resolve-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "data-source": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auto",
                    "cache-only",
                    "log-and-cache"
                ],
                "type": "str"
            }
        }
    },
    "system_geoipcountry": {
        "stated": true,
        "options": {
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_geoipoverride": {
        "stated": true,
        "options": {
            "description": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ip-range": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "end-ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "start-ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ip6-range": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "end-ip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "start-ip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "system_geoipoverride_ip6range": {
        "stated": true,
        "options": {
            "end-ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "start-ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_geoipoverride_iprange": {
        "stated": true,
        "options": {
            "end-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "start-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_global": {
        "stated": false,
        "options": {
            "admin-lockout-duration": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "admin-lockout-threshold": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "adom-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "normal",
                    "advanced"
                ],
                "type": "str"
            },
            "adom-rev-auto-delete": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "by-revisions",
                    "by-days"
                ],
                "type": "str"
            },
            "adom-rev-max-backup-revisions": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "adom-rev-max-days": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "adom-rev-max-revisions": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "adom-select": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "adom-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "clt-cert-req": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "optional"
                ],
                "type": "str"
            },
            "console-output": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "standard",
                    "more"
                ],
                "type": "str"
            },
            "country-flag": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "create-revision": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "daylightsavetime": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "default-disk-quota": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": false,
                    "6.2.2": false,
                    "6.2.3": false,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "detect-unregistered-log-device": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "device-view-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "regular",
                    "tree"
                ],
                "type": "str"
            },
            "dh-params": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "1024",
                    "1536",
                    "2048",
                    "3072",
                    "4096",
                    "6144",
                    "8192"
                ],
                "type": "str"
            },
            "disable-module": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "fortiview-noc",
                    "none",
                    "fortirecorder",
                    "siem",
                    "soc",
                    "ai"
                ],
                "elements": "str"
            },
            "enc-algorithm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "low",
                    "medium",
                    "high",
                    "custom"
                ],
                "type": "str"
            },
            "faz-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fgfm-local-cert": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "fgfm-ssl-protocol": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "sslv3",
                    "tlsv1.0",
                    "tlsv1.1",
                    "tlsv1.2",
                    "tlsv1.3"
                ],
                "type": "str"
            },
            "ha-member-auto-grouping": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "hitcount_concurrent": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "hitcount_interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "hostname": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "import-ignore-addr-cmt": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "language": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "english",
                    "simch",
                    "japanese",
                    "korean",
                    "spanish",
                    "trach"
                ],
                "type": "str"
            },
            "latitude": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ldap-cache-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ldapconntimeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "lock-preempt": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "log-checksum": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "md5",
                    "md5-auth"
                ],
                "type": "str"
            },
            "log-forward-cache-size": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "longitude": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "max-log-forward": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "max-running-reports": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "oftp-ssl-protocol": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "sslv3",
                    "tlsv1.0",
                    "tlsv1.1",
                    "tlsv1.2",
                    "tlsv1.3"
                ],
                "type": "str"
            },
            "partial-install": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "partial-install-force": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "partial-install-rev": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "perform-improve-by-ha": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "policy-hit-count": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "policy-object-in-dual-pane": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "pre-login-banner": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "pre-login-banner-message": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "remoteauthtimeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "search-all-adoms": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-low-encryption": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-protocol": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "tlsv1.2",
                    "tlsv1.1",
                    "tlsv1.0",
                    "sslv3",
                    "tlsv1.3"
                ],
                "elements": "str"
            },
            "ssl-static-key-ciphers": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "task-list-size": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tftp": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "timezone": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "00",
                    "01",
                    "02",
                    "03",
                    "04",
                    "05",
                    "06",
                    "07",
                    "08",
                    "09",
                    "10",
                    "11",
                    "12",
                    "13",
                    "14",
                    "15",
                    "16",
                    "17",
                    "18",
                    "19",
                    "20",
                    "21",
                    "22",
                    "23",
                    "24",
                    "25",
                    "26",
                    "27",
                    "28",
                    "29",
                    "30",
                    "31",
                    "32",
                    "33",
                    "34",
                    "35",
                    "36",
                    "37",
                    "38",
                    "39",
                    "40",
                    "41",
                    "42",
                    "43",
                    "44",
                    "45",
                    "46",
                    "47",
                    "48",
                    "49",
                    "50",
                    "51",
                    "52",
                    "53",
                    "54",
                    "55",
                    "56",
                    "57",
                    "58",
                    "59",
                    "60",
                    "61",
                    "62",
                    "63",
                    "64",
                    "65",
                    "66",
                    "67",
                    "68",
                    "69",
                    "70",
                    "71",
                    "72",
                    "73",
                    "74",
                    "75",
                    "76",
                    "77",
                    "78",
                    "79",
                    "80",
                    "81",
                    "82",
                    "83",
                    "84",
                    "85",
                    "86",
                    "87",
                    "88",
                    "89",
                    "90",
                    "91"
                ],
                "type": "str"
            },
            "tunnel-mtu": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "usg": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "vdom-mirror": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "webservice-proto": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "tlsv1.2",
                    "tlsv1.1",
                    "tlsv1.0",
                    "sslv3",
                    "sslv2",
                    "tlsv1.3"
                ],
                "elements": "str"
            },
            "workflow-max-sessions": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "workspace-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disabled",
                    "normal",
                    "workflow",
                    "per-adom"
                ],
                "type": "str"
            },
            "clone-name-option": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "default",
                    "keep"
                ],
                "type": "str"
            },
            "fgfm-ca-cert": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "mc-policy-disabled-adoms": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "adom-name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "policy-object-icon": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "private-data-encryption": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "per-policy-lock": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "multiple-steps-upgrade-in-autolink": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "object-revision-db-max": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "object-revision-mandatory-note": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "object-revision-object-max": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "object-revision-status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "normalized-intf-zone-only": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-cipher-suites": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "cipher": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "priority": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "version": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "tls1.2-or-below",
                            "tls1.3"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "gui-curl-timeout": {
                "required": false,
                "revision": {
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "table-entry-blink": {
                "required": false,
                "revision": {
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "contentpack-fgt-install": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "gui-polling-interval": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "no-copy-permission-check": {
                "required": false,
                "revision": {
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "admin-lockout-method": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ip",
                    "user"
                ],
                "type": "str"
            },
            "fgfm-cert-exclusive": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "workspace-unlock-after-install": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "log-checksum-upload": {
                "required": false,
                "revision": {
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "apache-mode": {
                "required": false,
                "revision": {
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": true
                },
                "choices": [
                    "event",
                    "prefork"
                ],
                "type": "str"
            },
            "no-vip-value-check": {
                "required": false,
                "revision": {
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fortiservice-port": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "management-ip": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "management-port": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "save-last-hit-in-adomdb": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "system_guiact": {
        "stated": false,
        "options": {
            "backup_all": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "backup_conf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "eventlog_msg": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "eventlog_path": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "reboot": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "reset2default": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "restore_all": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "restore_conf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "time": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "system_ha": {
        "stated": false,
        "options": {
            "clusterid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "file-quota": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "hb-interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "hb-lost-threshold": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "standalone",
                    "master",
                    "slave",
                    "primary",
                    "secondary"
                ],
                "type": "str"
            },
            "password": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "peer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ip6": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "serial-number": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "local-cert": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "failover-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "manual",
                    "vrrp"
                ],
                "type": "str"
            },
            "monitored-interfaces": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "interface-name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "monitored-ips": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "interface": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "priority": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "unicast": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "vip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vrrp-adv-interval": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "vrrp-interface": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vip-interface": {
                "required": false,
                "revision": {
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_ha_monitoredinterfaces": {
        "stated": true,
        "options": {
            "interface-name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_ha_monitoredips": {
        "stated": true,
        "options": {
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "interface": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_ha_peer": {
        "stated": true,
        "options": {
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ip6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "serial-number": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_hascheduledcheck": {
        "stated": false,
        "options": {
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "time": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "week_days": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "monday",
                    "tuesday",
                    "wednesday",
                    "thursday",
                    "friday",
                    "saturday",
                    "sunday"
                ],
                "elements": "str"
            }
        }
    },
    "system_interface": {
        "stated": true,
        "options": {
            "alias": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "allowaccess": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "ping",
                    "https",
                    "ssh",
                    "snmp",
                    "http",
                    "webservice",
                    "https-logging",
                    "soc-fabric",
                    "fabric"
                ],
                "elements": "str"
            },
            "description": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipv6": {
                "required": false,
                "type": "dict",
                "options": {
                    "ip6-address": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ip6-allowaccess": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "ping",
                            "https",
                            "ssh",
                            "snmp",
                            "http",
                            "webservice",
                            "https-logging",
                            "fabric"
                        ],
                        "elements": "str"
                    },
                    "ip6-autoconf": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "mtu": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "serviceaccess": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "fgtupdates",
                    "fclupdates",
                    "webfilter-antispam"
                ],
                "elements": "str"
            },
            "speed": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auto",
                    "10full",
                    "10half",
                    "100full",
                    "100half",
                    "1000full",
                    "10000full",
                    "1g/full",
                    "2.5g/full",
                    "5g/full",
                    "10g/full",
                    "14g/full",
                    "20g/full",
                    "25g/full",
                    "40g/full",
                    "50g/full",
                    "56g/full",
                    "100g/full",
                    "1g/half"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "down",
                    "up",
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "rating-service-ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "update-service-ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "aggregate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "interface": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "lacp-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "active"
                ],
                "type": "str"
            },
            "lacp-speed": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "slow",
                    "fast"
                ],
                "type": "str"
            },
            "link-up-delay": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "member": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "interface-name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "min-links": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "min-links-down": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "operational",
                    "administrative"
                ],
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "vlan",
                    "physical",
                    "aggregate"
                ],
                "type": "str"
            },
            "vlan-protocol": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "8021q",
                    "8021ad"
                ],
                "type": "str"
            },
            "vlanid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "lldp": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "system_interface_ipv6": {
        "stated": false,
        "options": {
            "ip6-address": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ip6-allowaccess": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "ping",
                    "https",
                    "ssh",
                    "snmp",
                    "http",
                    "webservice",
                    "https-logging",
                    "fabric"
                ],
                "elements": "str"
            },
            "ip6-autoconf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "system_interface_member": {
        "stated": true,
        "options": {
            "interface-name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_localinpolicy": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "drop",
                    "reject",
                    "accept"
                ],
                "type": "str"
            },
            "dport": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "dst": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "intf": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "tcp",
                    "udp",
                    "tcp_udp"
                ],
                "type": "str"
            },
            "src": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_localinpolicy6": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "drop",
                    "reject",
                    "accept"
                ],
                "type": "str"
            },
            "dport": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "dst": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "intf": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "tcp",
                    "udp",
                    "tcp_udp"
                ],
                "type": "str"
            },
            "src": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_locallog_disk_filter": {
        "stated": false,
        "options": {
            "devcfg": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "devops": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "diskquota": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dvm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ediscovery": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "epmgr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "event": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "eventmgmt": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "faz": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fazha": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fazsys": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fgd": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fgfm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fips": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fmgws": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fmlmgr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fmwmgr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fortiview": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "glbcfg": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ha": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "hcache": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "iolog": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "logd": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "logdb": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "logdev": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "logfile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "enable",
                    "disable"
                ],
                "type": "str"
            },
            "logging": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "lrmgr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "objcfg": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "report": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "rev": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "rtmon": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "scfw": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "scply": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "scrmgr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "scvpn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "system": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "webport": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "incident": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "aid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "docker": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "controller": {
                "required": false,
                "revision": {
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "system_locallog_disk_setting": {
        "stated": false,
        "options": {
            "diskfull": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "overwrite",
                    "nolog"
                ],
                "type": "str"
            },
            "log-disk-full-percentage": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "max-log-file-size": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "roll-day": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "sunday",
                    "monday",
                    "tuesday",
                    "wednesday",
                    "thursday",
                    "friday",
                    "saturday"
                ],
                "elements": "str"
            },
            "roll-schedule": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "daily",
                    "weekly"
                ],
                "type": "str"
            },
            "roll-time": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "server-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "FTP",
                    "SFTP",
                    "SCP"
                ],
                "type": "str"
            },
            "severity": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "emergency",
                    "alert",
                    "critical",
                    "error",
                    "warning",
                    "notification",
                    "information",
                    "debug"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "upload": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "upload-delete-files": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "upload-time": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "uploaddir": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "uploadip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "uploadpass": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "uploadport": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "uploadsched": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "uploadtype": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "event"
                ],
                "elements": "str"
            },
            "uploaduser": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "uploadzip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "log-disk-quota": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "max-log-file-num": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "system_locallog_fortianalyzer2_filter": {
        "stated": false,
        "options": {
            "devcfg": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "devops": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "diskquota": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dvm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ediscovery": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "epmgr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "event": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "eventmgmt": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "faz": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fazha": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fazsys": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fgd": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fgfm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fips": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fmgws": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fmlmgr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fmwmgr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fortiview": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "glbcfg": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ha": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "hcache": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "iolog": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "logd": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "logdb": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "logdev": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "logfile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "enable",
                    "disable"
                ],
                "type": "str"
            },
            "logging": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "lrmgr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "objcfg": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "report": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "rev": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "rtmon": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "scfw": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "scply": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "scrmgr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "scvpn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "system": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "webport": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "incident": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "aid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "docker": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "controller": {
                "required": false,
                "revision": {
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "system_locallog_fortianalyzer2_setting": {
        "stated": false,
        "options": {
            "reliable": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "secure-connection": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "server-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": false,
                    "6.2.3": false,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "severity": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "emergency",
                    "alert",
                    "critical",
                    "error",
                    "warning",
                    "notification",
                    "information",
                    "debug"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "realtime",
                    "upload"
                ],
                "type": "str"
            },
            "upload-time": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "server": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "peer-cert-cn": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_locallog_fortianalyzer3_filter": {
        "stated": false,
        "options": {
            "devcfg": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "devops": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "diskquota": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dvm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ediscovery": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "epmgr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "event": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "eventmgmt": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "faz": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fazha": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fazsys": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fgd": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fgfm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fips": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fmgws": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fmlmgr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fmwmgr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fortiview": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "glbcfg": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ha": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "hcache": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "iolog": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "logd": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "logdb": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "logdev": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "logfile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "enable",
                    "disable"
                ],
                "type": "str"
            },
            "logging": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "lrmgr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "objcfg": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "report": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "rev": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "rtmon": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "scfw": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "scply": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "scrmgr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "scvpn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "system": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "webport": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "incident": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "aid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "docker": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "controller": {
                "required": false,
                "revision": {
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "system_locallog_fortianalyzer3_setting": {
        "stated": false,
        "options": {
            "reliable": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "secure-connection": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "server-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": false,
                    "6.2.3": false,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "severity": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "emergency",
                    "alert",
                    "critical",
                    "error",
                    "warning",
                    "notification",
                    "information",
                    "debug"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "realtime",
                    "upload"
                ],
                "type": "str"
            },
            "upload-time": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "server": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "peer-cert-cn": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_locallog_fortianalyzer_filter": {
        "stated": false,
        "options": {
            "devcfg": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "devops": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "diskquota": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dvm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ediscovery": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "epmgr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "event": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "eventmgmt": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "faz": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fazha": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fazsys": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fgd": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fgfm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fips": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fmgws": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fmlmgr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fmwmgr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fortiview": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "glbcfg": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ha": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "hcache": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "iolog": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "logd": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "logdb": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "logdev": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "logfile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "enable",
                    "disable"
                ],
                "type": "str"
            },
            "logging": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "lrmgr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "objcfg": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "report": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "rev": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "rtmon": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "scfw": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "scply": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "scrmgr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "scvpn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "system": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "webport": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "incident": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "aid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "docker": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "controller": {
                "required": false,
                "revision": {
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "system_locallog_fortianalyzer_setting": {
        "stated": false,
        "options": {
            "reliable": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "secure-connection": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "server-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": false,
                    "6.2.3": false,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "severity": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "emergency",
                    "alert",
                    "critical",
                    "error",
                    "warning",
                    "notification",
                    "information",
                    "debug"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "realtime",
                    "upload"
                ],
                "type": "str"
            },
            "upload-time": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "server": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "peer-cert-cn": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_locallog_memory_filter": {
        "stated": false,
        "options": {
            "devcfg": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "devops": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "diskquota": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dvm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ediscovery": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "epmgr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "event": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "eventmgmt": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "faz": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fazha": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fazsys": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fgd": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fgfm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fips": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fmgws": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fmlmgr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fmwmgr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fortiview": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "glbcfg": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ha": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "hcache": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "iolog": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "logd": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "logdb": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "logdev": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "logfile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "enable",
                    "disable"
                ],
                "type": "str"
            },
            "logging": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "lrmgr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "objcfg": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "report": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "rev": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "rtmon": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "scfw": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "scply": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "scrmgr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "scvpn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "system": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "webport": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "incident": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "aid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "docker": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "controller": {
                "required": false,
                "revision": {
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "system_locallog_memory_setting": {
        "stated": false,
        "options": {
            "diskfull": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "overwrite",
                    "nolog"
                ],
                "type": "str"
            },
            "severity": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "emergency",
                    "alert",
                    "critical",
                    "error",
                    "warning",
                    "notification",
                    "information",
                    "debug"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "system_locallog_setting": {
        "stated": false,
        "options": {
            "log-interval-dev-no-logging": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "log-interval-disk-full": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "log-interval-gbday-exceeded": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "log-daemon-crash": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "no-log-detection-threshold": {
                "required": false,
                "revision": {
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "log-interval-adom-perf-stats": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "system_locallog_syslogd2_filter": {
        "stated": false,
        "options": {
            "devcfg": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "devops": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "diskquota": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dvm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ediscovery": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "epmgr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "event": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "eventmgmt": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "faz": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fazha": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fazsys": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fgd": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fgfm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fips": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fmgws": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fmlmgr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fmwmgr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fortiview": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "glbcfg": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ha": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "hcache": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "iolog": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "logd": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "logdb": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "logdev": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "logfile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "enable",
                    "disable"
                ],
                "type": "str"
            },
            "logging": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "lrmgr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "objcfg": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "report": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "rev": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "rtmon": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "scfw": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "scply": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "scrmgr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "scvpn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "system": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "webport": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "incident": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "aid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "docker": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "controller": {
                "required": false,
                "revision": {
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "system_locallog_syslogd2_setting": {
        "stated": false,
        "options": {
            "csv": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "facility": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "kernel",
                    "user",
                    "ntp",
                    "audit",
                    "alert",
                    "clock",
                    "mail",
                    "daemon",
                    "auth",
                    "syslog",
                    "lpr",
                    "news",
                    "uucp",
                    "cron",
                    "authpriv",
                    "ftp",
                    "local0",
                    "local1",
                    "local2",
                    "local3",
                    "local4",
                    "local5",
                    "local6",
                    "local7"
                ],
                "type": "str"
            },
            "severity": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "emergency",
                    "alert",
                    "critical",
                    "error",
                    "warning",
                    "notification",
                    "information",
                    "debug"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "syslog-name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cert": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "reliable": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "secure-connection": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "system_locallog_syslogd3_filter": {
        "stated": false,
        "options": {
            "devcfg": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "devops": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "diskquota": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dvm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ediscovery": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "epmgr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "event": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "eventmgmt": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "faz": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fazha": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fazsys": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fgd": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fgfm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fips": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fmgws": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fmlmgr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fmwmgr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fortiview": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "glbcfg": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ha": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "hcache": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "iolog": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "logd": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "logdb": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "logdev": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "logfile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "enable",
                    "disable"
                ],
                "type": "str"
            },
            "logging": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "lrmgr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "objcfg": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "report": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "rev": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "rtmon": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "scfw": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "scply": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "scrmgr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "scvpn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "system": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "webport": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "incident": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "aid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "docker": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "controller": {
                "required": false,
                "revision": {
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "system_locallog_syslogd3_setting": {
        "stated": false,
        "options": {
            "csv": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "facility": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "kernel",
                    "user",
                    "ntp",
                    "audit",
                    "alert",
                    "clock",
                    "mail",
                    "daemon",
                    "auth",
                    "syslog",
                    "lpr",
                    "news",
                    "uucp",
                    "cron",
                    "authpriv",
                    "ftp",
                    "local0",
                    "local1",
                    "local2",
                    "local3",
                    "local4",
                    "local5",
                    "local6",
                    "local7"
                ],
                "type": "str"
            },
            "severity": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "emergency",
                    "alert",
                    "critical",
                    "error",
                    "warning",
                    "notification",
                    "information",
                    "debug"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "syslog-name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cert": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "reliable": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "secure-connection": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "system_locallog_syslogd_filter": {
        "stated": false,
        "options": {
            "devcfg": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "devops": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "diskquota": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dvm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ediscovery": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "epmgr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "event": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "eventmgmt": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "faz": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fazha": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fazsys": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fgd": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fgfm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fips": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fmgws": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fmlmgr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fmwmgr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fortiview": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "glbcfg": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ha": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "hcache": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "iolog": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "logd": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "logdb": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "logdev": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "logfile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "enable",
                    "disable"
                ],
                "type": "str"
            },
            "logging": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "lrmgr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "objcfg": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "report": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "rev": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "rtmon": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "scfw": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "scply": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "scrmgr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "scvpn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "system": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "webport": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "incident": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "aid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "docker": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "controller": {
                "required": false,
                "revision": {
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "system_locallog_syslogd_setting": {
        "stated": false,
        "options": {
            "csv": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "facility": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "kernel",
                    "user",
                    "ntp",
                    "audit",
                    "alert",
                    "clock",
                    "mail",
                    "daemon",
                    "auth",
                    "syslog",
                    "lpr",
                    "news",
                    "uucp",
                    "cron",
                    "authpriv",
                    "ftp",
                    "local0",
                    "local1",
                    "local2",
                    "local3",
                    "local4",
                    "local5",
                    "local6",
                    "local7"
                ],
                "type": "str"
            },
            "severity": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "emergency",
                    "alert",
                    "critical",
                    "error",
                    "warning",
                    "notification",
                    "information",
                    "debug"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "syslog-name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cert": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "reliable": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "secure-connection": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "system_log_alert": {
        "stated": false,
        "options": {
            "max-alert-count": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "system_log_devicedisable": {
        "stated": true,
        "options": {
            "TTL": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "device": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "system_log_fospolicystats": {
        "stated": false,
        "options": {
            "retention-days": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "sampling-interval": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "system_log_interfacestats": {
        "stated": false,
        "options": {
            "retention-days": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "sampling-interval": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "billing-report": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "system_log_ioc": {
        "stated": false,
        "options": {
            "notification": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "notification-throttle": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "rescan-max-runner": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "rescan-run-at": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "rescan-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "system_log_maildomain": {
        "stated": true,
        "options": {
            "devices": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "domain": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "vdom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_log_ratelimit": {
        "stated": false,
        "options": {
            "device": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "device": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "filter-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "devid"
                        ],
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "ratelimit": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "device-ratelimit-default": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "manual"
                ],
                "type": "str"
            },
            "system-ratelimit": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ratelimits": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "filter": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "filter-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "devid",
                            "adom"
                        ],
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ratelimit": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "system_log_ratelimit_device": {
        "stated": true,
        "options": {
            "device": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "filter-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "devid"
                ],
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "ratelimit": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            }
        }
    },
    "system_log_ratelimit_ratelimits": {
        "stated": true,
        "options": {
            "filter": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "filter-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "devid",
                    "adom"
                ],
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ratelimit": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "system_log_settings": {
        "stated": false,
        "options": {
            "FAC-custom-field1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "FAZ-custom-field1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "FCH-custom-field1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "FCT-custom-field1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "FDD-custom-field1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "FGT-custom-field1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "FMG-custom-field1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "FML-custom-field1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "FPX-custom-field1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "FSA-custom-field1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "FWB-custom-field1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "browse-max-logfiles": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "dns-resolve-dstip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "download-max-logs": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ha-auto-migrate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "import-max-logfiles": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "log-file-archive-name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "basic",
                    "extended"
                ],
                "type": "str"
            },
            "rolling-analyzer": {
                "required": false,
                "type": "dict",
                "options": {
                    "days": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "sun",
                            "mon",
                            "tue",
                            "wed",
                            "thu",
                            "fri",
                            "sat"
                        ],
                        "elements": "str"
                    },
                    "del-files": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "directory": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "file-size": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "gzip-format": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "hour": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "ip2": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "ip3": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "log-format": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "native",
                            "text",
                            "csv"
                        ],
                        "type": "str"
                    },
                    "min": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "password": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "password2": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "password3": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "server-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ftp",
                            "sftp",
                            "scp"
                        ],
                        "type": "str"
                    },
                    "upload": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "upload-hour": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "upload-mode": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "backup",
                            "mirror"
                        ],
                        "type": "str"
                    },
                    "upload-trigger": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "on-roll",
                            "on-schedule"
                        ],
                        "type": "str"
                    },
                    "username": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "username2": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "username3": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "when": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "daily",
                            "weekly"
                        ],
                        "type": "str"
                    },
                    "port": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "port2": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "port3": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "rolling-upgrade-status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "server": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "server2": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "server3": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                }
            },
            "rolling-local": {
                "required": false,
                "type": "dict",
                "options": {
                    "days": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "sun",
                            "mon",
                            "tue",
                            "wed",
                            "thu",
                            "fri",
                            "sat"
                        ],
                        "elements": "str"
                    },
                    "del-files": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "directory": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "file-size": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "gzip-format": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "hour": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "ip2": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "ip3": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "log-format": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "native",
                            "text",
                            "csv"
                        ],
                        "type": "str"
                    },
                    "min": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "password": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "password2": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "password3": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "server-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ftp",
                            "sftp",
                            "scp"
                        ],
                        "type": "str"
                    },
                    "upload": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "upload-hour": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "upload-mode": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "backup",
                            "mirror"
                        ],
                        "type": "str"
                    },
                    "upload-trigger": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "on-roll",
                            "on-schedule"
                        ],
                        "type": "str"
                    },
                    "username": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "username2": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "username3": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "when": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "daily",
                            "weekly"
                        ],
                        "type": "str"
                    },
                    "port": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "port2": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "port3": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "rolling-upgrade-status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "server": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "server2": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "server3": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                }
            },
            "rolling-regular": {
                "required": false,
                "type": "dict",
                "options": {
                    "days": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "sun",
                            "mon",
                            "tue",
                            "wed",
                            "thu",
                            "fri",
                            "sat"
                        ],
                        "elements": "str"
                    },
                    "del-files": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "directory": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "file-size": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "gzip-format": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "hour": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "ip2": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "ip3": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "log-format": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "native",
                            "text",
                            "csv"
                        ],
                        "type": "str"
                    },
                    "min": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "password": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "password2": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "password3": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "server-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ftp",
                            "sftp",
                            "scp"
                        ],
                        "type": "str"
                    },
                    "upload": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "upload-hour": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "upload-mode": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "backup",
                            "mirror"
                        ],
                        "type": "str"
                    },
                    "upload-trigger": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "on-roll",
                            "on-schedule"
                        ],
                        "type": "str"
                    },
                    "username": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "username2": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "username3": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "when": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "daily",
                            "weekly"
                        ],
                        "type": "str"
                    },
                    "port": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "port2": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "port3": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "rolling-upgrade-status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "server": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "server2": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "server3": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                }
            },
            "sync-search-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "keep-dev-logs": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "device-auto-detect": {
                "required": false,
                "revision": {
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "unencrypted-logging": {
                "required": false,
                "revision": {
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "system_log_settings_rollinganalyzer": {
        "stated": false,
        "options": {
            "days": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "sun",
                    "mon",
                    "tue",
                    "wed",
                    "thu",
                    "fri",
                    "sat"
                ],
                "elements": "str"
            },
            "del-files": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "directory": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "file-size": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "gzip-format": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "hour": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "ip2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "ip3": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "log-format": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "native",
                    "text",
                    "csv"
                ],
                "type": "str"
            },
            "min": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "password": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "password2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "password3": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "server-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ftp",
                    "sftp",
                    "scp"
                ],
                "type": "str"
            },
            "upload": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "upload-hour": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "upload-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "backup",
                    "mirror"
                ],
                "type": "str"
            },
            "upload-trigger": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "on-roll",
                    "on-schedule"
                ],
                "type": "str"
            },
            "username": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "username2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "username3": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "when": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "daily",
                    "weekly"
                ],
                "type": "str"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "port2": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "port3": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "rolling-upgrade-status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "server": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "server2": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "server3": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_log_settings_rollinglocal": {
        "stated": false,
        "options": {
            "days": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "sun",
                    "mon",
                    "tue",
                    "wed",
                    "thu",
                    "fri",
                    "sat"
                ],
                "elements": "str"
            },
            "del-files": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "directory": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "file-size": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "gzip-format": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "hour": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "ip2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "ip3": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "log-format": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "native",
                    "text",
                    "csv"
                ],
                "type": "str"
            },
            "min": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "password": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "password2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "password3": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "server-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ftp",
                    "sftp",
                    "scp"
                ],
                "type": "str"
            },
            "upload": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "upload-hour": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "upload-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "backup",
                    "mirror"
                ],
                "type": "str"
            },
            "upload-trigger": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "on-roll",
                    "on-schedule"
                ],
                "type": "str"
            },
            "username": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "username2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "username3": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "when": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "daily",
                    "weekly"
                ],
                "type": "str"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "port2": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "port3": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "rolling-upgrade-status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "server": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "server2": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "server3": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_log_settings_rollingregular": {
        "stated": false,
        "options": {
            "days": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "sun",
                    "mon",
                    "tue",
                    "wed",
                    "thu",
                    "fri",
                    "sat"
                ],
                "elements": "str"
            },
            "del-files": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "directory": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "file-size": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "gzip-format": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "hour": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "ip2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "ip3": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "log-format": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "native",
                    "text",
                    "csv"
                ],
                "type": "str"
            },
            "min": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "password": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "password2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "password3": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "server-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ftp",
                    "sftp",
                    "scp"
                ],
                "type": "str"
            },
            "upload": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "upload-hour": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "upload-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "backup",
                    "mirror"
                ],
                "type": "str"
            },
            "upload-trigger": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "on-roll",
                    "on-schedule"
                ],
                "type": "str"
            },
            "username": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "username2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "username3": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "when": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "daily",
                    "weekly"
                ],
                "type": "str"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "port2": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "port3": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "rolling-upgrade-status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "server": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "server2": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "server3": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_log_topology": {
        "stated": false,
        "options": {
            "max-depth": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "max-depth-share": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "system_logfetch_clientprofile": {
        "stated": true,
        "options": {
            "client-adom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "data-range": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "custom"
                ],
                "type": "str"
            },
            "data-range-value": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "device-filter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "adom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "device": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "end-time": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "index-fetch-logs": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "log-filter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "field": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "oper": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "=",
                            "!=",
                            "<",
                            ">",
                            "<=",
                            ">=",
                            "contain",
                            "not-contain",
                            "match"
                        ],
                        "type": "str"
                    },
                    "value": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "log-filter-logic": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "and",
                    "or"
                ],
                "type": "str"
            },
            "log-filter-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "password": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "no_log": true,
                "type": "raw"
            },
            "secure-connection": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "server-adom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "server-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "start-time": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "sync-adom-config": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "user": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "peer-cert-cn": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "system_logfetch_clientprofile_devicefilter": {
        "stated": true,
        "options": {
            "adom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "device": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "vdom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "system_logfetch_clientprofile_logfilter": {
        "stated": true,
        "options": {
            "field": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "oper": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "=",
                    "!=",
                    "<",
                    ">",
                    "<=",
                    ">=",
                    "contain",
                    "not-contain",
                    "match"
                ],
                "type": "str"
            },
            "value": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "system_logfetch_serversettings": {
        "stated": false,
        "options": {
            "max-conn-per-session": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "max-sessions": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "session-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            }
        }
    },
    "system_mail": {
        "stated": true,
        "options": {
            "auth": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "passwd": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "secure-option": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "default",
                    "none",
                    "smtps",
                    "starttls"
                ],
                "type": "str"
            },
            "server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "user": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "auth-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "psk",
                    "certificate"
                ],
                "type": "str"
            },
            "local-cert": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "from": {
                "required": false,
                "revision": {
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_mcpolicydisabledadoms": {
        "stated": true,
        "options": {
            "adom-name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_meta": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sys_meta_fields": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "fieldlength": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "importance": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "optional",
                            "required"
                        ],
                        "type": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "system_meta_sysmetafields": {
        "stated": true,
        "options": {
            "fieldlength": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "importance": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "optional",
                    "required"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_metadata_admins": {
        "stated": true,
        "options": {
            "fieldlength": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "20",
                    "50",
                    "255"
                ],
                "type": "str"
            },
            "fieldname": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "importance": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "optional",
                    "required"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disabled",
                    "enabled"
                ],
                "type": "str"
            }
        }
    },
    "system_npu": {
        "stated": false,
        "options": {
            "capwap-offload": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dedicated-management-affinity": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dedicated-management-cpu": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fastpath": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fp-anomaly": {
                "required": false,
                "type": "dict",
                "options": {
                    "esp-minlen-err": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "icmp-csum-err": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "icmp-minlen-err": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "ipv4-csum-err": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "ipv4-ihl-err": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "ipv4-len-err": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "ipv4-opt-err": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "ipv4-ttlzero-err": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "ipv4-ver-err": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "ipv6-exthdr-len-err": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "ipv6-exthdr-order-err": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "ipv6-ihl-err": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "ipv6-plen-zero": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "ipv6-ver-err": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "tcp-csum-err": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "tcp-hlen-err": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "tcp-plen-err": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "udp-csum-err": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "udp-hlen-err": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "udp-len-err": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "udp-plen-err": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "udplite-cover-err": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "udplite-csum-err": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "unknproto-minlen-err": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "tcp-fin-only": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "ipv4-optsecurity": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "ipv6-optralert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "tcp-syn-fin": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "ipv4-proto-err": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "ipv6-saddr-err": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "icmp-frag": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "ipv4-optssrr": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "ipv6-opthomeaddr": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "udp-land": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "ipv6-optinvld": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "tcp-fin-noack": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "ipv6-proto-err": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "tcp-land": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "ipv4-unknopt": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "ipv4-optstream": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "ipv6-optjumbo": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "icmp-land": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "tcp-winnuke": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "ipv6-daddr-err": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "ipv4-land": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "ipv6-opttunnel": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "tcp-no-flag": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "ipv6-land": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "ipv4-optlsrr": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "ipv4-opttimestamp": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "ipv4-optrr": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "ipv6-optnsap": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "ipv6-unknopt": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "tcp-syn-data": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "ipv6-optendpid": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "gtpu-plen-err": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "vxlan-minlen-err": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "capwap-minlen-err": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "gre-csum-err": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "nvgre-minlen-err": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "sctp-l4len-err": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "tcp-hlenvsl4len-err": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "sctp-crc-err": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "sctp-clen-err": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    },
                    "uesp-minlen-err": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "drop",
                            "trap-to-host"
                        ],
                        "type": "str"
                    }
                }
            },
            "gtp-enhanced-cpu-range": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "0",
                    "1",
                    "2"
                ],
                "type": "str"
            },
            "gtp-enhanced-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "host-shortcut-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "bi-directional",
                    "host-shortcut"
                ],
                "type": "str"
            },
            "htx-gtse-quota": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "100Mbps",
                    "200Mbps",
                    "300Mbps",
                    "400Mbps",
                    "500Mbps",
                    "600Mbps",
                    "700Mbps",
                    "800Mbps",
                    "900Mbps",
                    "1Gbps",
                    "2Gbps",
                    "4Gbps",
                    "8Gbps",
                    "10Gbps"
                ],
                "type": "str"
            },
            "intf-shaping-offload": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "iph-rsvd-re-cksum": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ipsec-dec-subengine-mask": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipsec-enc-subengine-mask": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipsec-inbound-cache": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ipsec-mtu-override": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ipsec-over-vlink": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "isf-np-queues": {
                "required": false,
                "type": "dict",
                "options": {
                    "cos0": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "cos1": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "cos2": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "cos3": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "cos4": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "cos5": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "cos6": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "cos7": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                }
            },
            "lag-out-port-select": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mcast-session-accounting": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "session-based",
                    "tpe-based"
                ],
                "type": "str"
            },
            "np6-cps-optimization-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "per-session-accounting": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "enable",
                    "disable",
                    "enable-by-log",
                    "all-enable",
                    "traffic-log-only"
                ],
                "type": "str"
            },
            "port-cpu-map": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "cpu-core": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "interface": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "port-npu-map": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "interface": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "npu-group-index": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "priority-protocol": {
                "required": false,
                "type": "dict",
                "options": {
                    "bfd": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "bgp": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "slbc": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "qos-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "priority",
                    "round-robin"
                ],
                "type": "str"
            },
            "rdp-offload": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "recover-np6-link": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "session-denied-offload": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sse-backpressure": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "strip-clear-text-padding": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "strip-esp-padding": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sw-eh-hash": {
                "required": false,
                "type": "dict",
                "options": {
                    "computation": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "xor16",
                            "xor8",
                            "xor4",
                            "crc16"
                        ],
                        "type": "str"
                    },
                    "destination-ip-lower-16": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "include",
                            "exclude"
                        ],
                        "type": "str"
                    },
                    "destination-ip-upper-16": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "include",
                            "exclude"
                        ],
                        "type": "str"
                    },
                    "destination-port": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "include",
                            "exclude"
                        ],
                        "type": "str"
                    },
                    "ip-protocol": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "include",
                            "exclude"
                        ],
                        "type": "str"
                    },
                    "netmask-length": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "source-ip-lower-16": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "include",
                            "exclude"
                        ],
                        "type": "str"
                    },
                    "source-ip-upper-16": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "include",
                            "exclude"
                        ],
                        "type": "str"
                    },
                    "source-port": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "include",
                            "exclude"
                        ],
                        "type": "str"
                    }
                }
            },
            "sw-np-bandwidth": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "0G",
                    "2G",
                    "4G",
                    "5G",
                    "6G",
                    "7G",
                    "8G",
                    "9G"
                ],
                "type": "str"
            },
            "switch-np-hash": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "src-ip",
                    "dst-ip",
                    "src-dst-ip"
                ],
                "type": "str"
            },
            "uesp-offload": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "np-queues": {
                "required": false,
                "type": "dict",
                "options": {
                    "ethernet-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "queue": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "type": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "weight": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            }
                        },
                        "elements": "dict"
                    },
                    "ip-protocol": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "protocol": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "queue": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "weight": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            }
                        },
                        "elements": "dict"
                    },
                    "ip-service": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "dport": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "protocol": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "queue": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "sport": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "weight": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            }
                        },
                        "elements": "dict"
                    },
                    "profile": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "cos0": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "cos1": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "cos2": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "cos3": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "cos4": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "cos5": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "cos6": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "cos7": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp0": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp1": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp10": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp11": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp12": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp13": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp14": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp15": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp16": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp17": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp18": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp19": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp2": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp20": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp21": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp22": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp23": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp24": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp25": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp26": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp27": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp28": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp29": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp3": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp30": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp31": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp32": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp33": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp34": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp35": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp36": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp37": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp38": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp39": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp4": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp40": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp41": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp42": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp43": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp44": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp45": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp46": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp47": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp48": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp49": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp5": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp50": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp51": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp52": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp53": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp54": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp55": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp56": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp57": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp58": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp59": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp6": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp60": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp61": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp62": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp63": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp7": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp8": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "dscp9": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "queue0",
                                    "queue1",
                                    "queue2",
                                    "queue3",
                                    "queue4",
                                    "queue5",
                                    "queue6",
                                    "queue7"
                                ],
                                "type": "str"
                            },
                            "id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "type": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "cos",
                                    "dscp"
                                ],
                                "type": "str"
                            },
                            "weight": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            }
                        },
                        "elements": "dict"
                    },
                    "scheduler": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "mode": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "none",
                                    "priority",
                                    "round-robin"
                                ],
                                "type": "str"
                            },
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    }
                }
            },
            "udp-timeout-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "udp-idle": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "qtm-buf-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "6ch",
                    "4ch"
                ],
                "type": "str"
            },
            "default-qos-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "policing",
                    "shaping",
                    "policing-enhanced"
                ],
                "type": "str"
            },
            "tcp-rst-timeout": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ipsec-local-uesp-port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "htab-dedi-queue-nr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "double-level-mcast-offload": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dse-timeout": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ippool-overload-low": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "pba-eim": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disallow",
                    "allow"
                ],
                "type": "str"
            },
            "policy-offload-level": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "dos-offload",
                    "full-offload"
                ],
                "type": "str"
            },
            "max-session-timeout": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "port-path-option": {
                "required": false,
                "type": "dict",
                "options": {
                    "ports-using-npu": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    }
                }
            },
            "vlan-lookup-cache": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dos-options": {
                "required": false,
                "type": "dict",
                "options": {
                    "npu-dos-meter-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "local",
                            "global"
                        ],
                        "type": "str"
                    },
                    "npu-dos-synproxy-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "synack2ack",
                            "pass-synack"
                        ],
                        "type": "str"
                    },
                    "npu-dos-tpe-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "hash-tbl-spread": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tcp-timeout-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "close-wait": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "fin-wait": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "syn-sent": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "syn-wait": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "tcp-idle": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "time-wait": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "ip-reassembly": {
                "required": false,
                "type": "dict",
                "options": {
                    "max-timeout": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "min-timeout": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "gtp-support": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "htx-icmp-csum-chk": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "drop"
                ],
                "type": "str"
            },
            "hpe": {
                "required": false,
                "type": "dict",
                "options": {
                    "all-protocol": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "arp-max": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "enable-shaper": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "esp-max": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "high-priority": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "icmp-max": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ip-frag-max": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ip-others-max": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "l2-others-max": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "pri-type-max": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "sctp-max": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "tcp-max": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "tcpfin-rst-max": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "tcpsyn-ack-max": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "tcpsyn-max": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "udp-max": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "enable-queue-shaper": {
                        "required": false,
                        "revision": {
                            "7.0.9": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": true,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "exception-code": {
                        "required": false,
                        "revision": {
                            "7.0.9": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": true,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "fragment-with-sess": {
                        "required": false,
                        "revision": {
                            "7.0.9": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": true,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "fragment-without-session": {
                        "required": false,
                        "revision": {
                            "7.0.9": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": true,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "queue-shaper-max": {
                        "required": false,
                        "revision": {
                            "7.0.9": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": true,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    }
                }
            },
            "dsw-dts-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "wait",
                            "drop",
                            "drop_tmr_0",
                            "drop_tmr_1",
                            "enque",
                            "enque_0",
                            "enque_1"
                        ],
                        "type": "str"
                    },
                    "min-limit": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "profile-id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "step": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "hash-config": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "5-tuple",
                    "src-ip",
                    "src-dst-ip"
                ],
                "type": "str"
            },
            "ipsec-ob-np-sel": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "RR",
                    "rr",
                    "Packet",
                    "Hash"
                ],
                "type": "str"
            },
            "napi-break-interval": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "background-sse-scan": {
                "required": false,
                "type": "dict",
                "options": {
                    "scan": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "stats-update-interval": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "udp-keepalive-interval": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "scan-stale": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "scan-vt": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "stats-qual-access": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "stats-qual-duration": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "udp-qual-access": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "udp-qual-duration": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                }
            },
            "inbound-dscp-copy-port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "session-acct-interval": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "htab-msg-queue": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "idle",
                    "data",
                    "dedicated"
                ],
                "type": "str"
            },
            "dsw-queue-dts-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "iport": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "EIF0",
                            "eif0",
                            "EIF1",
                            "eif1",
                            "EIF2",
                            "eif2",
                            "EIF3",
                            "eif3",
                            "EIF4",
                            "eif4",
                            "EIF5",
                            "eif5",
                            "EIF6",
                            "eif6",
                            "EIF7",
                            "eif7",
                            "HTX0",
                            "htx0",
                            "HTX1",
                            "htx1",
                            "SSE0",
                            "sse0",
                            "SSE1",
                            "sse1",
                            "SSE2",
                            "sse2",
                            "SSE3",
                            "sse3",
                            "RLT",
                            "rlt",
                            "DFR",
                            "dfr",
                            "IPSECI",
                            "ipseci",
                            "IPSECO",
                            "ipseco",
                            "IPTI",
                            "ipti",
                            "IPTO",
                            "ipto",
                            "VEP0",
                            "vep0",
                            "VEP2",
                            "vep2",
                            "VEP4",
                            "vep4",
                            "VEP6",
                            "vep6",
                            "IVS",
                            "ivs",
                            "L2TI1",
                            "l2ti1",
                            "L2TO",
                            "l2to",
                            "L2TI0",
                            "l2ti0",
                            "PLE",
                            "ple",
                            "SPATH",
                            "spath",
                            "QTM",
                            "qtm"
                        ],
                        "type": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "oport": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "EIF0",
                            "eif0",
                            "EIF1",
                            "eif1",
                            "EIF2",
                            "eif2",
                            "EIF3",
                            "eif3",
                            "EIF4",
                            "eif4",
                            "EIF5",
                            "eif5",
                            "EIF6",
                            "eif6",
                            "EIF7",
                            "eif7",
                            "HRX",
                            "hrx",
                            "SSE0",
                            "sse0",
                            "SSE1",
                            "sse1",
                            "SSE2",
                            "sse2",
                            "SSE3",
                            "sse3",
                            "RLT",
                            "rlt",
                            "DFR",
                            "dfr",
                            "IPSECI",
                            "ipseci",
                            "IPSECO",
                            "ipseco",
                            "IPTI",
                            "ipti",
                            "IPTO",
                            "ipto",
                            "VEP0",
                            "vep0",
                            "VEP2",
                            "vep2",
                            "VEP4",
                            "vep4",
                            "VEP6",
                            "vep6",
                            "IVS",
                            "ivs",
                            "L2TI1",
                            "l2ti1",
                            "L2TO",
                            "l2to",
                            "L2TI0",
                            "l2ti0",
                            "PLE",
                            "ple",
                            "SYNK",
                            "sync",
                            "NSS",
                            "nss",
                            "TSK",
                            "tsk",
                            "QTM",
                            "qtm",
                            "l2tO"
                        ],
                        "type": "str"
                    },
                    "profile-id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "queue-select": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "hw-ha-scan-interval": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ippool-overload-high": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "nat46-force-ipv4-packet-forwarding": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "prp-port-out": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "isf-np-rx-tr-distr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "port-flow",
                    "round-robin",
                    "randomized"
                ],
                "type": "str"
            },
            "mcast-session-counting6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "session-based",
                    "tpe-based"
                ],
                "type": "str"
            },
            "prp-port-in": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "rps-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "per-policy-accounting": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mcast-session-counting": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "session-based",
                    "tpe-based"
                ],
                "type": "str"
            },
            "inbound-dscp-copy": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ipsec-host-dfclr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "process-icmp-by-host": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dedicated-tx-npu": {
                "required": false,
                "revision": {
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ull-port-mode": {
                "required": false,
                "revision": {
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "10G",
                    "25G"
                ],
                "type": "str"
            },
            "sse-ha-scan": {
                "required": false,
                "type": "dict",
                "options": {
                    "gap": {
                        "required": false,
                        "revision": {
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "max-session-cnt": {
                        "required": false,
                        "revision": {
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "min-duration": {
                        "required": false,
                        "revision": {
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                }
            },
            "hash-ipv6-sel": {
                "required": false,
                "revision": {
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip-fragment-offload": {
                "required": false,
                "revision": {
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ple-non-syn-tcp-action": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "forward",
                    "drop"
                ],
                "type": "str"
            },
            "npu-group-effective-scope": {
                "required": false,
                "revision": {
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ipsec-STS-timeout": {
                "required": false,
                "revision": {
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "1",
                    "2",
                    "3",
                    "4",
                    "5",
                    "6",
                    "7",
                    "8",
                    "9",
                    "10"
                ],
                "type": "str"
            },
            "ipsec-throughput-msg-frequency": {
                "required": false,
                "revision": {
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "32KB",
                    "64KB",
                    "128KB",
                    "256KB",
                    "512KB",
                    "1MB",
                    "2MB",
                    "4MB",
                    "8MB",
                    "16MB",
                    "32MB",
                    "64MB",
                    "128MB",
                    "256MB",
                    "512MB",
                    "1GB"
                ],
                "type": "str"
            },
            "ipt-STS-timeout": {
                "required": false,
                "revision": {
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "1",
                    "2",
                    "3",
                    "4",
                    "5",
                    "6",
                    "7",
                    "8",
                    "9",
                    "10"
                ],
                "type": "str"
            },
            "ipt-throughput-msg-frequency": {
                "required": false,
                "revision": {
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "32KB",
                    "64KB",
                    "128KB",
                    "256KB",
                    "512KB",
                    "1MB",
                    "2MB",
                    "4MB",
                    "8MB",
                    "16MB",
                    "32MB",
                    "64MB",
                    "128MB",
                    "256MB",
                    "512MB",
                    "1GB"
                ],
                "type": "str"
            },
            "prp-session-clear-mode": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "blocking",
                    "non-blocking",
                    "do-not-clear"
                ],
                "type": "str"
            },
            "shaping-stats": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sw-tr-hash": {
                "required": false,
                "type": "dict",
                "options": {
                    "draco15": {
                        "required": false,
                        "revision": {
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "tcp-udp-port": {
                        "required": false,
                        "revision": {
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "include",
                            "exclude"
                        ],
                        "type": "str"
                    }
                }
            },
            "default-tcp-refresh-dir": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "both",
                    "outgoing",
                    "incoming"
                ],
                "type": "str"
            },
            "default-udp-refresh-dir": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "both",
                    "outgoing",
                    "incoming"
                ],
                "type": "str"
            }
        }
    },
    "system_npu_backgroundssescan": {
        "stated": false,
        "options": {
            "scan": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "stats-update-interval": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "udp-keepalive-interval": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "scan-stale": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "scan-vt": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "stats-qual-access": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "stats-qual-duration": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "udp-qual-access": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "udp-qual-duration": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "system_npu_dosoptions": {
        "stated": false,
        "options": {
            "npu-dos-meter-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "local",
                    "global"
                ],
                "type": "str"
            },
            "npu-dos-synproxy-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "synack2ack",
                    "pass-synack"
                ],
                "type": "str"
            },
            "npu-dos-tpe-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "system_npu_dswdtsprofile": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "wait",
                    "drop",
                    "drop_tmr_0",
                    "drop_tmr_1",
                    "enque",
                    "enque_0",
                    "enque_1"
                ],
                "type": "str"
            },
            "min-limit": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "profile-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "step": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "system_npu_dswqueuedtsprofile": {
        "stated": true,
        "options": {
            "iport": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "EIF0",
                    "eif0",
                    "EIF1",
                    "eif1",
                    "EIF2",
                    "eif2",
                    "EIF3",
                    "eif3",
                    "EIF4",
                    "eif4",
                    "EIF5",
                    "eif5",
                    "EIF6",
                    "eif6",
                    "EIF7",
                    "eif7",
                    "HTX0",
                    "htx0",
                    "HTX1",
                    "htx1",
                    "SSE0",
                    "sse0",
                    "SSE1",
                    "sse1",
                    "SSE2",
                    "sse2",
                    "SSE3",
                    "sse3",
                    "RLT",
                    "rlt",
                    "DFR",
                    "dfr",
                    "IPSECI",
                    "ipseci",
                    "IPSECO",
                    "ipseco",
                    "IPTI",
                    "ipti",
                    "IPTO",
                    "ipto",
                    "VEP0",
                    "vep0",
                    "VEP2",
                    "vep2",
                    "VEP4",
                    "vep4",
                    "VEP6",
                    "vep6",
                    "IVS",
                    "ivs",
                    "L2TI1",
                    "l2ti1",
                    "L2TO",
                    "l2to",
                    "L2TI0",
                    "l2ti0",
                    "PLE",
                    "ple",
                    "SPATH",
                    "spath",
                    "QTM",
                    "qtm"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "oport": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "EIF0",
                    "eif0",
                    "EIF1",
                    "eif1",
                    "EIF2",
                    "eif2",
                    "EIF3",
                    "eif3",
                    "EIF4",
                    "eif4",
                    "EIF5",
                    "eif5",
                    "EIF6",
                    "eif6",
                    "EIF7",
                    "eif7",
                    "HRX",
                    "hrx",
                    "SSE0",
                    "sse0",
                    "SSE1",
                    "sse1",
                    "SSE2",
                    "sse2",
                    "SSE3",
                    "sse3",
                    "RLT",
                    "rlt",
                    "DFR",
                    "dfr",
                    "IPSECI",
                    "ipseci",
                    "IPSECO",
                    "ipseco",
                    "IPTI",
                    "ipti",
                    "IPTO",
                    "ipto",
                    "VEP0",
                    "vep0",
                    "VEP2",
                    "vep2",
                    "VEP4",
                    "vep4",
                    "VEP6",
                    "vep6",
                    "IVS",
                    "ivs",
                    "L2TI1",
                    "l2ti1",
                    "L2TO",
                    "l2to",
                    "L2TI0",
                    "l2ti0",
                    "PLE",
                    "ple",
                    "SYNK",
                    "sync",
                    "NSS",
                    "nss",
                    "TSK",
                    "tsk",
                    "QTM",
                    "qtm",
                    "l2tO"
                ],
                "type": "str"
            },
            "profile-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "queue-select": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "system_npu_fpanomaly": {
        "stated": false,
        "options": {
            "esp-minlen-err": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "icmp-csum-err": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "icmp-minlen-err": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "ipv4-csum-err": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "ipv4-ihl-err": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "ipv4-len-err": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "ipv4-opt-err": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "ipv4-ttlzero-err": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "ipv4-ver-err": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "ipv6-exthdr-len-err": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "ipv6-exthdr-order-err": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "ipv6-ihl-err": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "ipv6-plen-zero": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "ipv6-ver-err": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "tcp-csum-err": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "tcp-hlen-err": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "tcp-plen-err": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "udp-csum-err": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "udp-hlen-err": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "udp-len-err": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "udp-plen-err": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "udplite-cover-err": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "udplite-csum-err": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "unknproto-minlen-err": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "tcp-fin-only": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "ipv4-optsecurity": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "ipv6-optralert": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "tcp-syn-fin": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "ipv4-proto-err": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "ipv6-saddr-err": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "icmp-frag": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "ipv4-optssrr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "ipv6-opthomeaddr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "udp-land": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "ipv6-optinvld": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "tcp-fin-noack": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "ipv6-proto-err": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "tcp-land": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "ipv4-unknopt": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "ipv4-optstream": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "ipv6-optjumbo": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "icmp-land": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "tcp-winnuke": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "ipv6-daddr-err": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "ipv4-land": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "ipv6-opttunnel": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "tcp-no-flag": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "ipv6-land": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "ipv4-optlsrr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "ipv4-opttimestamp": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "ipv4-optrr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "ipv6-optnsap": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "ipv6-unknopt": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "tcp-syn-data": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "ipv6-optendpid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "gtpu-plen-err": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "vxlan-minlen-err": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "capwap-minlen-err": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "gre-csum-err": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "nvgre-minlen-err": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "sctp-l4len-err": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "tcp-hlenvsl4len-err": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "sctp-crc-err": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "sctp-clen-err": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            },
            "uesp-minlen-err": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "drop",
                    "trap-to-host"
                ],
                "type": "str"
            }
        }
    },
    "system_npu_hpe": {
        "stated": false,
        "options": {
            "all-protocol": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "arp-max": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "enable-shaper": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "esp-max": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "high-priority": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "icmp-max": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip-frag-max": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip-others-max": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "l2-others-max": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "pri-type-max": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "sctp-max": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tcp-max": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tcpfin-rst-max": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tcpsyn-ack-max": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tcpsyn-max": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "udp-max": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "enable-queue-shaper": {
                "required": false,
                "revision": {
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "exception-code": {
                "required": false,
                "revision": {
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "fragment-with-sess": {
                "required": false,
                "revision": {
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "fragment-without-session": {
                "required": false,
                "revision": {
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "queue-shaper-max": {
                "required": false,
                "revision": {
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            }
        }
    },
    "system_npu_ipreassembly": {
        "stated": false,
        "options": {
            "max-timeout": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "min-timeout": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "system_npu_isfnpqueues": {
        "stated": false,
        "options": {
            "cos0": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cos1": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cos2": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cos3": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cos4": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cos5": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cos6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cos7": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_npu_npqueues": {
        "stated": false,
        "options": {
            "ethernet-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "queue": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "weight": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "ip-protocol": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "protocol": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "queue": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "weight": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "ip-service": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "dport": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "protocol": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "queue": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "sport": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "weight": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "cos0": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "cos1": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "cos2": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "cos3": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "cos4": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "cos5": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "cos6": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "cos7": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp0": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp1": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp10": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp11": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp12": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp13": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp14": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp15": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp16": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp17": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp18": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp19": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp2": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp20": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp21": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp22": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp23": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp24": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp25": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp26": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp27": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp28": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp29": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp3": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp30": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp31": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp32": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp33": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp34": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp35": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp36": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp37": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp38": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp39": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp4": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp40": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp41": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp42": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp43": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp44": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp45": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp46": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp47": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp48": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp49": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp5": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp50": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp51": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp52": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp53": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp54": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp55": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp56": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp57": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp58": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp59": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp6": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp60": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp61": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp62": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp63": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp7": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp8": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "dscp9": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "queue0",
                            "queue1",
                            "queue2",
                            "queue3",
                            "queue4",
                            "queue5",
                            "queue6",
                            "queue7"
                        ],
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "cos",
                            "dscp"
                        ],
                        "type": "str"
                    },
                    "weight": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "scheduler": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "priority",
                            "round-robin"
                        ],
                        "type": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "system_npu_npqueues_ethernettype": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "queue": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "weight": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "system_npu_npqueues_ipprotocol": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "queue": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "weight": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "system_npu_npqueues_ipservice": {
        "stated": true,
        "options": {
            "dport": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "queue": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "sport": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "weight": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "system_npu_npqueues_profile": {
        "stated": true,
        "options": {
            "cos0": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "cos1": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "cos2": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "cos3": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "cos4": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "cos5": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "cos6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "cos7": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp0": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp1": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp10": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp11": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp12": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp13": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp14": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp15": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp16": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp17": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp18": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp19": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp2": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp20": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp21": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp22": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp23": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp24": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp25": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp26": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp27": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp28": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp29": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp3": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp30": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp31": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp32": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp33": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp34": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp35": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp36": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp37": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp38": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp39": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp4": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp40": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp41": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp42": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp43": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp44": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp45": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp46": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp47": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp48": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp49": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp5": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp50": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp51": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp52": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp53": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp54": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp55": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp56": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp57": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp58": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp59": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp60": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp61": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp62": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp63": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp7": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp8": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "dscp9": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "queue0",
                    "queue1",
                    "queue2",
                    "queue3",
                    "queue4",
                    "queue5",
                    "queue6",
                    "queue7"
                ],
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "cos",
                    "dscp"
                ],
                "type": "str"
            },
            "weight": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "system_npu_npqueues_scheduler": {
        "stated": true,
        "options": {
            "mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "priority",
                    "round-robin"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_npu_portcpumap": {
        "stated": true,
        "options": {
            "cpu-core": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "interface": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_npu_portnpumap": {
        "stated": true,
        "options": {
            "interface": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "npu-group-index": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "system_npu_portpathoption": {
        "stated": false,
        "options": {
            "ports-using-npu": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "system_npu_priorityprotocol": {
        "stated": false,
        "options": {
            "bfd": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "bgp": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "slbc": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "system_npu_ssehascan": {
        "stated": false,
        "options": {
            "gap": {
                "required": false,
                "revision": {
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "max-session-cnt": {
                "required": false,
                "revision": {
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "min-duration": {
                "required": false,
                "revision": {
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "system_npu_swehhash": {
        "stated": false,
        "options": {
            "computation": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "xor16",
                    "xor8",
                    "xor4",
                    "crc16"
                ],
                "type": "str"
            },
            "destination-ip-lower-16": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "include",
                    "exclude"
                ],
                "type": "str"
            },
            "destination-ip-upper-16": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "include",
                    "exclude"
                ],
                "type": "str"
            },
            "destination-port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "include",
                    "exclude"
                ],
                "type": "str"
            },
            "ip-protocol": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "include",
                    "exclude"
                ],
                "type": "str"
            },
            "netmask-length": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "source-ip-lower-16": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "include",
                    "exclude"
                ],
                "type": "str"
            },
            "source-ip-upper-16": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "include",
                    "exclude"
                ],
                "type": "str"
            },
            "source-port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "include",
                    "exclude"
                ],
                "type": "str"
            }
        }
    },
    "system_npu_swtrhash": {
        "stated": false,
        "options": {
            "draco15": {
                "required": false,
                "revision": {
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tcp-udp-port": {
                "required": false,
                "revision": {
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "include",
                    "exclude"
                ],
                "type": "str"
            }
        }
    },
    "system_npu_tcptimeoutprofile": {
        "stated": true,
        "options": {
            "close-wait": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fin-wait": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "syn-sent": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "syn-wait": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tcp-idle": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "time-wait": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "system_npu_udptimeoutprofile": {
        "stated": true,
        "options": {
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "udp-idle": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "system_ntp": {
        "stated": false,
        "options": {
            "ntpserver": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "authentication": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "key": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "key-id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "int"
                    },
                    "ntpv3": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "server": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "maxpoll": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "minpoll": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sync_interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            }
        }
    },
    "system_ntp_ntpserver": {
        "stated": true,
        "options": {
            "authentication": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "key": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "key-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "int"
            },
            "ntpv3": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "maxpoll": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "minpoll": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "system_objecttag": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "system_objecttagging": {
        "stated": true,
        "options": {
            "address": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "optional",
                    "mandatory",
                    "disable"
                ],
                "type": "str"
            },
            "category": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "color": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "device": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "optional",
                    "mandatory",
                    "disable"
                ],
                "type": "str"
            },
            "interface": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "optional",
                    "mandatory",
                    "disable"
                ],
                "type": "str"
            },
            "multiple": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "system_passwordpolicy": {
        "stated": false,
        "options": {
            "change-4-characters": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "expire": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "minimum-length": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "must-contain": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "upper-case-letter",
                    "lower-case-letter",
                    "number",
                    "non-alphanumeric"
                ],
                "elements": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "system_replacemsggroup": {
        "stated": true,
        "options": {
            "admin": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "buffer": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "format": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "text",
                            "html",
                            "wml"
                        ],
                        "type": "str"
                    },
                    "header": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "http",
                            "8bit"
                        ],
                        "type": "str"
                    },
                    "msg-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "alertmail": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "buffer": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "format": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "text",
                            "html",
                            "wml"
                        ],
                        "type": "str"
                    },
                    "header": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "http",
                            "8bit"
                        ],
                        "type": "str"
                    },
                    "msg-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "auth": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "buffer": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "format": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "text",
                            "html",
                            "wml"
                        ],
                        "type": "str"
                    },
                    "header": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "http",
                            "8bit"
                        ],
                        "type": "str"
                    },
                    "msg-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "custom-message": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "buffer": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "format": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "text",
                            "html",
                            "wml"
                        ],
                        "type": "str"
                    },
                    "header": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "http",
                            "8bit"
                        ],
                        "type": "str"
                    },
                    "msg-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "device-detection-portal": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "buffer": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "format": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "text",
                            "html",
                            "wml"
                        ],
                        "type": "str"
                    },
                    "header": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "http",
                            "8bit"
                        ],
                        "type": "str"
                    },
                    "msg-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "ec": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "buffer": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "format": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "none",
                            "text",
                            "html",
                            "wml"
                        ],
                        "type": "str"
                    },
                    "header": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "none",
                            "http",
                            "8bit"
                        ],
                        "type": "str"
                    },
                    "msg-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "fortiguard-wf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "buffer": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "format": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "text",
                            "html",
                            "wml"
                        ],
                        "type": "str"
                    },
                    "header": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "http",
                            "8bit"
                        ],
                        "type": "str"
                    },
                    "msg-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "ftp": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "buffer": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "format": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "text",
                            "html",
                            "wml"
                        ],
                        "type": "str"
                    },
                    "header": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "http",
                            "8bit"
                        ],
                        "type": "str"
                    },
                    "msg-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "group-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "default",
                    "utm",
                    "auth",
                    "ec",
                    "captive-portal"
                ],
                "type": "str"
            },
            "http": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "buffer": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "format": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "text",
                            "html",
                            "wml"
                        ],
                        "type": "str"
                    },
                    "header": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "http",
                            "8bit"
                        ],
                        "type": "str"
                    },
                    "msg-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "icap": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "buffer": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "format": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "text",
                            "html",
                            "wml"
                        ],
                        "type": "str"
                    },
                    "header": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "http",
                            "8bit"
                        ],
                        "type": "str"
                    },
                    "msg-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "mail": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "buffer": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "format": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "text",
                            "html",
                            "wml"
                        ],
                        "type": "str"
                    },
                    "header": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "http",
                            "8bit"
                        ],
                        "type": "str"
                    },
                    "msg-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "mm1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "add-smil": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "charset": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "us-ascii",
                            "utf-8"
                        ],
                        "type": "str"
                    },
                    "class": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "personal",
                            "advertisement",
                            "information",
                            "automatic",
                            "not-included"
                        ],
                        "type": "str"
                    },
                    "format": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "text",
                            "html",
                            "wml"
                        ],
                        "type": "str"
                    },
                    "from": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "from-sender": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "header": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "http",
                            "8bit"
                        ],
                        "type": "str"
                    },
                    "image": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "message": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "msg-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "priority": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "low",
                            "normal",
                            "high",
                            "not-included"
                        ],
                        "type": "str"
                    },
                    "rsp-status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ok",
                            "err-unspecified",
                            "err-srv-denied",
                            "err-msg-fmt-corrupt",
                            "err-snd-addr-unresolv",
                            "err-msg-not-found",
                            "err-net-prob",
                            "err-content-not-accept",
                            "err-unsupp-msg"
                        ],
                        "type": "str"
                    },
                    "rsp-text": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sender-visibility": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "hide",
                            "show",
                            "not-specified"
                        ],
                        "type": "str"
                    },
                    "smil-part": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "subject": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "mm3": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "add-html": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "charset": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "us-ascii",
                            "utf-8"
                        ],
                        "type": "str"
                    },
                    "format": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "text",
                            "html",
                            "wml"
                        ],
                        "type": "str"
                    },
                    "from": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "from-sender": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "header": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "http",
                            "8bit"
                        ],
                        "type": "str"
                    },
                    "html-part": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "image": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "message": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "msg-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "priority": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "low",
                            "normal",
                            "high",
                            "not-included"
                        ],
                        "type": "str"
                    },
                    "subject": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "mm4": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "add-smil": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "charset": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "us-ascii",
                            "utf-8"
                        ],
                        "type": "str"
                    },
                    "class": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "personal",
                            "advertisement",
                            "informational",
                            "auto",
                            "not-included"
                        ],
                        "type": "str"
                    },
                    "domain": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "format": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "text",
                            "html",
                            "wml"
                        ],
                        "type": "str"
                    },
                    "from": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "from-sender": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "header": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "http",
                            "8bit"
                        ],
                        "type": "str"
                    },
                    "image": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "message": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "msg-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "priority": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "low",
                            "normal",
                            "high",
                            "not-included"
                        ],
                        "type": "str"
                    },
                    "rsp-status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ok",
                            "err-unspecified",
                            "err-srv-denied",
                            "err-msg-fmt-corrupt",
                            "err-snd-addr-unresolv",
                            "err-net-prob",
                            "err-content-not-accept",
                            "err-unsupp-msg"
                        ],
                        "type": "str"
                    },
                    "smil-part": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "subject": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "mm7": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "add-smil": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "addr-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "rfc2822-addr",
                            "number",
                            "short-code"
                        ],
                        "type": "str"
                    },
                    "allow-content-adaptation": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "charset": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "us-ascii",
                            "utf-8"
                        ],
                        "type": "str"
                    },
                    "class": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "personal",
                            "advertisement",
                            "informational",
                            "auto",
                            "not-included"
                        ],
                        "type": "str"
                    },
                    "format": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "text",
                            "html",
                            "wml"
                        ],
                        "type": "str"
                    },
                    "from": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "from-sender": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "header": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "http",
                            "8bit"
                        ],
                        "type": "str"
                    },
                    "image": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "message": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "msg-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "priority": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "low",
                            "normal",
                            "high",
                            "not-included"
                        ],
                        "type": "str"
                    },
                    "rsp-status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "success",
                            "partial-success",
                            "client-err",
                            "oper-restrict",
                            "addr-err",
                            "addr-not-found",
                            "content-refused",
                            "msg-id-not-found",
                            "link-id-not-found",
                            "msg-fmt-corrupt",
                            "app-id-not-found",
                            "repl-app-id-not-found",
                            "srv-err",
                            "not-possible",
                            "msg-rejected",
                            "multiple-addr-not-supp",
                            "app-addr-not-supp",
                            "gen-service-err",
                            "improper-ident",
                            "unsupp-ver",
                            "unsupp-oper",
                            "validation-err",
                            "service-err",
                            "service-unavail",
                            "service-denied",
                            "app-denied"
                        ],
                        "type": "str"
                    },
                    "smil-part": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "subject": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "mms": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "buffer": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "charset": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "us-ascii",
                            "utf-8"
                        ],
                        "type": "str"
                    },
                    "format": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "text",
                            "html",
                            "wml"
                        ],
                        "type": "str"
                    },
                    "header": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "http",
                            "8bit"
                        ],
                        "type": "str"
                    },
                    "image": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "msg-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "nac-quar": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "buffer": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "format": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "text",
                            "html",
                            "wml"
                        ],
                        "type": "str"
                    },
                    "header": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "http",
                            "8bit"
                        ],
                        "type": "str"
                    },
                    "msg-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "nntp": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "buffer": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "format": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "text",
                            "html",
                            "wml"
                        ],
                        "type": "str"
                    },
                    "header": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "http",
                            "8bit"
                        ],
                        "type": "str"
                    },
                    "msg-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "spam": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "buffer": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "format": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "text",
                            "html",
                            "wml"
                        ],
                        "type": "str"
                    },
                    "header": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "http",
                            "8bit"
                        ],
                        "type": "str"
                    },
                    "msg-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "sslvpn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "buffer": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "format": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "text",
                            "html",
                            "wml"
                        ],
                        "type": "str"
                    },
                    "header": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "http",
                            "8bit"
                        ],
                        "type": "str"
                    },
                    "msg-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "traffic-quota": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "buffer": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "format": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "text",
                            "html",
                            "wml"
                        ],
                        "type": "str"
                    },
                    "header": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "http",
                            "8bit"
                        ],
                        "type": "str"
                    },
                    "msg-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "utm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "buffer": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "format": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "text",
                            "html",
                            "wml"
                        ],
                        "type": "str"
                    },
                    "header": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "http",
                            "8bit"
                        ],
                        "type": "str"
                    },
                    "msg-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "webproxy": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "buffer": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "format": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "text",
                            "html",
                            "wml"
                        ],
                        "type": "str"
                    },
                    "header": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "http",
                            "8bit"
                        ],
                        "type": "str"
                    },
                    "msg-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "automation": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "buffer": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "format": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "text",
                            "html"
                        ],
                        "type": "str"
                    },
                    "header": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "http",
                            "8bit"
                        ],
                        "type": "str"
                    },
                    "msg-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "system_replacemsggroup_admin": {
        "stated": true,
        "options": {
            "buffer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "format": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "text",
                    "html",
                    "wml"
                ],
                "type": "str"
            },
            "header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http",
                    "8bit"
                ],
                "type": "str"
            },
            "msg-type": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_replacemsggroup_alertmail": {
        "stated": true,
        "options": {
            "buffer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "format": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "text",
                    "html",
                    "wml"
                ],
                "type": "str"
            },
            "header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http",
                    "8bit"
                ],
                "type": "str"
            },
            "msg-type": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": false,
                "revision": {
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "system_replacemsggroup_auth": {
        "stated": true,
        "options": {
            "buffer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "format": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "text",
                    "html",
                    "wml"
                ],
                "type": "str"
            },
            "header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http",
                    "8bit"
                ],
                "type": "str"
            },
            "msg-type": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_replacemsggroup_automation": {
        "stated": true,
        "options": {
            "buffer": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "format": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "text",
                    "html"
                ],
                "type": "str"
            },
            "header": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http",
                    "8bit"
                ],
                "type": "str"
            },
            "msg-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_replacemsggroup_custommessage": {
        "stated": true,
        "options": {
            "buffer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "format": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "text",
                    "html",
                    "wml"
                ],
                "type": "str"
            },
            "header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http",
                    "8bit"
                ],
                "type": "str"
            },
            "msg-type": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_replacemsggroup_devicedetectionportal": {
        "stated": true,
        "options": {
            "buffer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "format": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "text",
                    "html",
                    "wml"
                ],
                "type": "str"
            },
            "header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http",
                    "8bit"
                ],
                "type": "str"
            },
            "msg-type": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_replacemsggroup_ec": {
        "stated": true,
        "options": {
            "buffer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "format": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "none",
                    "text",
                    "html",
                    "wml"
                ],
                "type": "str"
            },
            "header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "none",
                    "http",
                    "8bit"
                ],
                "type": "str"
            },
            "msg-type": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "system_replacemsggroup_fortiguardwf": {
        "stated": true,
        "options": {
            "buffer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "format": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "text",
                    "html",
                    "wml"
                ],
                "type": "str"
            },
            "header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http",
                    "8bit"
                ],
                "type": "str"
            },
            "msg-type": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_replacemsggroup_ftp": {
        "stated": true,
        "options": {
            "buffer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "format": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "text",
                    "html",
                    "wml"
                ],
                "type": "str"
            },
            "header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http",
                    "8bit"
                ],
                "type": "str"
            },
            "msg-type": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_replacemsggroup_http": {
        "stated": true,
        "options": {
            "buffer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "format": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "text",
                    "html",
                    "wml"
                ],
                "type": "str"
            },
            "header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http",
                    "8bit"
                ],
                "type": "str"
            },
            "msg-type": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_replacemsggroup_icap": {
        "stated": true,
        "options": {
            "buffer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "format": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "text",
                    "html",
                    "wml"
                ],
                "type": "str"
            },
            "header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http",
                    "8bit"
                ],
                "type": "str"
            },
            "msg-type": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_replacemsggroup_mail": {
        "stated": true,
        "options": {
            "buffer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "format": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "text",
                    "html",
                    "wml"
                ],
                "type": "str"
            },
            "header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http",
                    "8bit"
                ],
                "type": "str"
            },
            "msg-type": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_replacemsggroup_mm1": {
        "stated": true,
        "options": {
            "add-smil": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "charset": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "us-ascii",
                    "utf-8"
                ],
                "type": "str"
            },
            "class": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "personal",
                    "advertisement",
                    "information",
                    "automatic",
                    "not-included"
                ],
                "type": "str"
            },
            "format": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "text",
                    "html",
                    "wml"
                ],
                "type": "str"
            },
            "from": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "from-sender": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http",
                    "8bit"
                ],
                "type": "str"
            },
            "image": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "message": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "msg-type": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "priority": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "low",
                    "normal",
                    "high",
                    "not-included"
                ],
                "type": "str"
            },
            "rsp-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ok",
                    "err-unspecified",
                    "err-srv-denied",
                    "err-msg-fmt-corrupt",
                    "err-snd-addr-unresolv",
                    "err-msg-not-found",
                    "err-net-prob",
                    "err-content-not-accept",
                    "err-unsupp-msg"
                ],
                "type": "str"
            },
            "rsp-text": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sender-visibility": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "hide",
                    "show",
                    "not-specified"
                ],
                "type": "str"
            },
            "smil-part": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "subject": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_replacemsggroup_mm3": {
        "stated": true,
        "options": {
            "add-html": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "charset": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "us-ascii",
                    "utf-8"
                ],
                "type": "str"
            },
            "format": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "text",
                    "html",
                    "wml"
                ],
                "type": "str"
            },
            "from": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "from-sender": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http",
                    "8bit"
                ],
                "type": "str"
            },
            "html-part": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "image": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "message": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "msg-type": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "priority": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "low",
                    "normal",
                    "high",
                    "not-included"
                ],
                "type": "str"
            },
            "subject": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_replacemsggroup_mm4": {
        "stated": true,
        "options": {
            "add-smil": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "charset": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "us-ascii",
                    "utf-8"
                ],
                "type": "str"
            },
            "class": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "personal",
                    "advertisement",
                    "informational",
                    "auto",
                    "not-included"
                ],
                "type": "str"
            },
            "domain": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "format": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "text",
                    "html",
                    "wml"
                ],
                "type": "str"
            },
            "from": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "from-sender": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http",
                    "8bit"
                ],
                "type": "str"
            },
            "image": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "message": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "msg-type": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "priority": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "low",
                    "normal",
                    "high",
                    "not-included"
                ],
                "type": "str"
            },
            "rsp-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ok",
                    "err-unspecified",
                    "err-srv-denied",
                    "err-msg-fmt-corrupt",
                    "err-snd-addr-unresolv",
                    "err-net-prob",
                    "err-content-not-accept",
                    "err-unsupp-msg"
                ],
                "type": "str"
            },
            "smil-part": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "subject": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_replacemsggroup_mm7": {
        "stated": true,
        "options": {
            "add-smil": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "addr-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "rfc2822-addr",
                    "number",
                    "short-code"
                ],
                "type": "str"
            },
            "allow-content-adaptation": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "charset": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "us-ascii",
                    "utf-8"
                ],
                "type": "str"
            },
            "class": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "personal",
                    "advertisement",
                    "informational",
                    "auto",
                    "not-included"
                ],
                "type": "str"
            },
            "format": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "text",
                    "html",
                    "wml"
                ],
                "type": "str"
            },
            "from": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "from-sender": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http",
                    "8bit"
                ],
                "type": "str"
            },
            "image": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "message": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "msg-type": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "priority": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "low",
                    "normal",
                    "high",
                    "not-included"
                ],
                "type": "str"
            },
            "rsp-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "success",
                    "partial-success",
                    "client-err",
                    "oper-restrict",
                    "addr-err",
                    "addr-not-found",
                    "content-refused",
                    "msg-id-not-found",
                    "link-id-not-found",
                    "msg-fmt-corrupt",
                    "app-id-not-found",
                    "repl-app-id-not-found",
                    "srv-err",
                    "not-possible",
                    "msg-rejected",
                    "multiple-addr-not-supp",
                    "app-addr-not-supp",
                    "gen-service-err",
                    "improper-ident",
                    "unsupp-ver",
                    "unsupp-oper",
                    "validation-err",
                    "service-err",
                    "service-unavail",
                    "service-denied",
                    "app-denied"
                ],
                "type": "str"
            },
            "smil-part": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "subject": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_replacemsggroup_mms": {
        "stated": true,
        "options": {
            "buffer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "charset": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "us-ascii",
                    "utf-8"
                ],
                "type": "str"
            },
            "format": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "text",
                    "html",
                    "wml"
                ],
                "type": "str"
            },
            "header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http",
                    "8bit"
                ],
                "type": "str"
            },
            "image": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "msg-type": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_replacemsggroup_nacquar": {
        "stated": true,
        "options": {
            "buffer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "format": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "text",
                    "html",
                    "wml"
                ],
                "type": "str"
            },
            "header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http",
                    "8bit"
                ],
                "type": "str"
            },
            "msg-type": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": false,
                "revision": {
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "system_replacemsggroup_nntp": {
        "stated": true,
        "options": {
            "buffer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "format": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "text",
                    "html",
                    "wml"
                ],
                "type": "str"
            },
            "header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http",
                    "8bit"
                ],
                "type": "str"
            },
            "msg-type": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_replacemsggroup_spam": {
        "stated": true,
        "options": {
            "buffer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "format": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "text",
                    "html",
                    "wml"
                ],
                "type": "str"
            },
            "header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http",
                    "8bit"
                ],
                "type": "str"
            },
            "msg-type": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_replacemsggroup_sslvpn": {
        "stated": true,
        "options": {
            "buffer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "format": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "text",
                    "html",
                    "wml"
                ],
                "type": "str"
            },
            "header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http",
                    "8bit"
                ],
                "type": "str"
            },
            "msg-type": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_replacemsggroup_trafficquota": {
        "stated": true,
        "options": {
            "buffer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "format": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "text",
                    "html",
                    "wml"
                ],
                "type": "str"
            },
            "header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http",
                    "8bit"
                ],
                "type": "str"
            },
            "msg-type": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_replacemsggroup_utm": {
        "stated": true,
        "options": {
            "buffer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "format": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "text",
                    "html",
                    "wml"
                ],
                "type": "str"
            },
            "header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http",
                    "8bit"
                ],
                "type": "str"
            },
            "msg-type": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_replacemsggroup_webproxy": {
        "stated": true,
        "options": {
            "buffer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "format": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "text",
                    "html",
                    "wml"
                ],
                "type": "str"
            },
            "header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "http",
                    "8bit"
                ],
                "type": "str"
            },
            "msg-type": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_replacemsgimage": {
        "stated": true,
        "options": {
            "image-base64": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "image-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "gif",
                    "jpg",
                    "tiff",
                    "png"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_report_autocache": {
        "stated": false,
        "options": {
            "aggressive-schedule": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "order": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "oldest-first"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sche-rpt-only": {
                "required": false,
                "revision": {
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "system_report_estbrowsetime": {
        "stated": false,
        "options": {
            "max-read-time": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "system_report_group": {
        "stated": true,
        "options": {
            "adom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "case-insensitive": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "chart-alternative": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "chart-name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "chart-replace": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "group-by": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "var-expression": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "var-name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "var-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "integer",
                            "string",
                            "enum",
                            "ip"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "group-id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "report-like": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_report_group_chartalternative": {
        "stated": true,
        "options": {
            "chart-name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "chart-replace": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_report_group_groupby": {
        "stated": true,
        "options": {
            "var-expression": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "var-name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "var-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "integer",
                    "string",
                    "enum",
                    "ip"
                ],
                "type": "str"
            }
        }
    },
    "system_report_setting": {
        "stated": false,
        "options": {
            "aggregate-report": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "hcache-lossless": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ldap-cache-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "max-table-rows": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "report-priority": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "high",
                    "low",
                    "auto"
                ],
                "type": "str"
            },
            "template-auto-install": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "default",
                    "english"
                ],
                "type": "str"
            },
            "week-start": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "sun",
                    "mon"
                ],
                "type": "str"
            },
            "capwap-port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "capwap-service": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "exclude-capwap": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "by-port",
                    "by-service"
                ],
                "type": "str"
            },
            "max-rpt-pdf-rows": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "system_route": {
        "stated": true,
        "options": {
            "device": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dst": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "gateway": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "seq_num": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "system_route6": {
        "stated": true,
        "options": {
            "device": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dst": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "gateway": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "prio": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "system_saml": {
        "stated": false,
        "options": {
            "acs-url": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cert": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "entity-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "idp-cert": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "idp-entity-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "idp-single-logout-url": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "idp-single-sign-on-url": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "login-auto-redirect": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "role": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "IDP",
                    "SP",
                    "FAB-SP"
                ],
                "type": "str"
            },
            "server-address": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "service-providers": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "idp-entity-id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "idp-single-logout-url": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "idp-single-sign-on-url": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "prefix": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sp-cert": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sp-entity-id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sp-single-logout-url": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sp-single-sign-on-url": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sp-adom": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sp-profile": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "sls-url": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "default-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "fabric-idp": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "dev-id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "idp-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "idp-entity-id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "idp-single-logout-url": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "idp-single-sign-on-url": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "idp-status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "forticloud-sso": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "user-auto-create": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "auth-request-signed": {
                "required": false,
                "revision": {
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "want-assertions-signed": {
                "required": false,
                "revision": {
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "system_saml_fabricidp": {
        "stated": true,
        "options": {
            "dev-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "idp-cert": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "idp-entity-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "idp-single-logout-url": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "idp-single-sign-on-url": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "idp-status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "system_sdnconnector": {
        "stated": true,
        "options": {
            "_local_cert": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "access-key": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "str"
            },
            "azure-region": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "global",
                    "china",
                    "germany",
                    "usgov",
                    "local"
                ],
                "type": "str"
            },
            "client-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "client-secret": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "compartment-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "external-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "gcp-project": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "key-passwd": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "login-endpoint": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "nic": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "public-ip": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "resource-group": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "nsx-cert-fingerprint": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "oci-cert": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "oci-fingerprint": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "oci-region": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "phoenix",
                    "ashburn",
                    "frankfurt",
                    "london",
                    "toronto"
                ],
                "type": "str"
            },
            "password": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "private-key": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "str"
            },
            "region": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "resource-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "resource-url": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "rest-interface": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "mgmt",
                    "sync"
                ],
                "type": "str"
            },
            "rest-password": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "rest-sport": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "rest-ssl": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "route": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "route-table": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "route": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "next-hop": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "resource-group": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "subscription-id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "secret-key": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "server-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "service-account": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "subscription-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tenant-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "aci",
                    "aws",
                    "nsx",
                    "nuage",
                    "azure",
                    "gcp",
                    "oci",
                    "openstack",
                    "kubernetes",
                    "vmware",
                    "acs",
                    "alicloud",
                    "sepm",
                    "aci-direct",
                    "ibm",
                    "nutanix",
                    "sap"
                ],
                "type": "str"
            },
            "update-interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "use-metadata-iam": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "user-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "username": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vmx-image-url": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vmx-service-name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vpc-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "domain": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ha-status": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "last-update": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "oci-region-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "commercial",
                    "government"
                ],
                "type": "str"
            },
            "secret-token": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "str"
            },
            "updating": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "server-ip": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "group-name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "api-key": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "compute-generation": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ibm-region": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "us-south",
                    "us-east",
                    "germany",
                    "great-britain",
                    "japan",
                    "australia",
                    "dallas",
                    "washington-dc",
                    "london",
                    "frankfurt",
                    "sydney",
                    "tokyo",
                    "osaka",
                    "toronto",
                    "sao-paulo",
                    "dallas-private",
                    "washington-dc-private",
                    "london-private",
                    "frankfurt-private",
                    "sydney-private",
                    "tokyo-private",
                    "osaka-private",
                    "toronto-private",
                    "sao-paulo-private"
                ],
                "type": "str"
            },
            "ibm-region-gen1": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "us-south",
                    "us-east",
                    "germany",
                    "great-britain",
                    "japan",
                    "australia"
                ],
                "type": "str"
            },
            "ibm-region-gen2": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "us-south",
                    "us-east",
                    "great-britain"
                ],
                "type": "str"
            },
            "vcenter-password": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "vcenter-server": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vcenter-username": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "server-list": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "external-account-list": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "region-list": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "role-arn": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "external-id": {
                        "required": false,
                        "revision": {
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "forwarding-rule": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "rule-name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "target": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "gcp-project-list": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "gcp-zone-list": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "verify-certificate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "alt-resource-ip": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "server-ca-cert": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "server-cert": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "compartment-list": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "compartment-id": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "oci-region-list": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "region": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "proxy": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_sdnconnector_compartmentlist": {
        "stated": true,
        "options": {
            "compartment-id": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_sdnconnector_externalaccountlist": {
        "stated": true,
        "options": {
            "region-list": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "role-arn": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "external-id": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_sdnconnector_externalip": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_sdnconnector_forwardingrule": {
        "stated": true,
        "options": {
            "rule-name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "target": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_sdnconnector_gcpprojectlist": {
        "stated": true,
        "options": {
            "gcp-zone-list": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_sdnconnector_nic": {
        "stated": true,
        "options": {
            "ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "public-ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "resource-group": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_sdnconnector_nic_ip": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "public-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "resource-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_sdnconnector_ociregionlist": {
        "stated": true,
        "options": {
            "region": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_sdnconnector_route": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_sdnconnector_routetable": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "route": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "next-hop": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "resource-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "subscription-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_sdnconnector_routetable_route": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "next-hop": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_sdnproxy": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "password": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "no_log": true,
                "type": "list",
                "elements": "str"
            },
            "server": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "server-port": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "type": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "general",
                    "fortimanager"
                ],
                "type": "str"
            },
            "username": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_smsserver": {
        "stated": true,
        "options": {
            "mail-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_sniffer": {
        "stated": true,
        "options": {
            "host": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "interface": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipv6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "max-packet-count": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "non-ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vlan": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_snmp_community": {
        "stated": true,
        "options": {
            "events": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "disk_low",
                    "ha_switch",
                    "intf_ip_chg",
                    "sys_reboot",
                    "cpu_high",
                    "mem_low",
                    "log-alert",
                    "log-rate",
                    "log-data-rate",
                    "lic-gbday",
                    "lic-dev-quota",
                    "cpu-high-exclude-nice"
                ],
                "elements": "str"
            },
            "hosts": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "interface": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "hosts6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "interface": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "query_v1_port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "query_v1_status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "query_v2c_port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "query_v2c_status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "trap_v1_rport": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "trap_v1_status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "trap_v2c_rport": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "trap_v2c_status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "system_snmp_community_hosts": {
        "stated": true,
        "options": {
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "interface": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_snmp_community_hosts6": {
        "stated": true,
        "options": {
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "interface": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_snmp_sysinfo": {
        "stated": false,
        "options": {
            "contact_info": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "description": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "engine-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "location": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "trap-cpu-high-exclude-nice-threshold": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "trap-high-cpu-threshold": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "trap-low-memory-threshold": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "system_snmp_user": {
        "stated": true,
        "options": {
            "auth-proto": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "md5",
                    "sha"
                ],
                "type": "str"
            },
            "auth-pwd": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "events": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "disk_low",
                    "ha_switch",
                    "intf_ip_chg",
                    "sys_reboot",
                    "cpu_high",
                    "mem_low",
                    "log-alert",
                    "log-rate",
                    "log-data-rate",
                    "lic-gbday",
                    "lic-dev-quota",
                    "cpu-high-exclude-nice"
                ],
                "elements": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "notify-hosts": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "notify-hosts6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "priv-proto": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "aes",
                    "des"
                ],
                "type": "str"
            },
            "priv-pwd": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "queries": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "query-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "security-level": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "no-auth-no-priv",
                    "auth-no-priv",
                    "auth-priv"
                ],
                "type": "str"
            }
        }
    },
    "system_socfabric": {
        "stated": false,
        "options": {
            "name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "psk": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "role": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "member",
                    "supervisor"
                ],
                "type": "str"
            },
            "secure-connection": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "supervisor": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "trusted-list": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "id": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "serial": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "system_socfabric_trustedlist": {
        "stated": true,
        "options": {
            "id": {
                "required": true,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "serial": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_sql": {
        "stated": false,
        "options": {
            "background-rebuild": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "custom-index": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "case-sensitive": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "device-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "FortiGate",
                            "FortiManager",
                            "FortiClient",
                            "FortiMail",
                            "FortiWeb",
                            "FortiCache",
                            "FortiSandbox",
                            "FortiDDoS",
                            "FortiAuthenticator",
                            "FortiProxy"
                        ],
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "index-field": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "log-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "app-ctrl",
                            "attack",
                            "content",
                            "dlp",
                            "emailfilter",
                            "event",
                            "generic",
                            "history",
                            "traffic",
                            "virus",
                            "voip",
                            "webfilter",
                            "netscan",
                            "fct-event",
                            "fct-traffic",
                            "fct-netscan",
                            "waf",
                            "gtp",
                            "dns",
                            "ssh",
                            "ssl",
                            "file-filter",
                            "asset",
                            "protocol",
                            "siem",
                            "ztna",
                            "security"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "database-name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "database-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "mysql",
                    "postgres"
                ],
                "type": "str"
            },
            "device-count-high": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "event-table-partition-time": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fct-table-partition-time": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "logtype": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "none",
                    "app-ctrl",
                    "attack",
                    "content",
                    "dlp",
                    "emailfilter",
                    "event",
                    "generic",
                    "history",
                    "traffic",
                    "virus",
                    "voip",
                    "webfilter",
                    "netscan",
                    "fct-event",
                    "fct-traffic",
                    "fct-netscan",
                    "waf",
                    "gtp",
                    "dns",
                    "ssh",
                    "ssl",
                    "file-filter",
                    "asset",
                    "protocol",
                    "siem",
                    "ztna",
                    "security"
                ],
                "elements": "str"
            },
            "password": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "prompt-sql-upgrade": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "rebuild-event": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "rebuild-event-start-time": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "start-time": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "local"
                ],
                "type": "str"
            },
            "text-search-index": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "traffic-table-partition-time": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ts-index-field": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "category": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "value": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "username": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "utm-table-partition-time": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "custom-skipidx": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "device-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "FortiGate",
                            "FortiManager",
                            "FortiClient",
                            "FortiMail",
                            "FortiWeb",
                            "FortiSandbox",
                            "FortiProxy"
                        ],
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "index-field": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "log-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "app-ctrl",
                            "attack",
                            "content",
                            "dlp",
                            "emailfilter",
                            "event",
                            "generic",
                            "history",
                            "traffic",
                            "virus",
                            "voip",
                            "webfilter",
                            "netscan",
                            "fct-event",
                            "fct-traffic",
                            "fct-netscan",
                            "waf",
                            "gtp",
                            "dns",
                            "ssh",
                            "ssl",
                            "file-filter",
                            "asset",
                            "protocol",
                            "siem",
                            "ztna",
                            "security"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "compress-table-min-age": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "system_sql_customindex": {
        "stated": true,
        "options": {
            "case-sensitive": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "device-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "FortiGate",
                    "FortiManager",
                    "FortiClient",
                    "FortiMail",
                    "FortiWeb",
                    "FortiCache",
                    "FortiSandbox",
                    "FortiDDoS",
                    "FortiAuthenticator",
                    "FortiProxy"
                ],
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "index-field": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "log-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "app-ctrl",
                    "attack",
                    "content",
                    "dlp",
                    "emailfilter",
                    "event",
                    "generic",
                    "history",
                    "traffic",
                    "virus",
                    "voip",
                    "webfilter",
                    "netscan",
                    "fct-event",
                    "fct-traffic",
                    "fct-netscan",
                    "waf",
                    "gtp",
                    "dns",
                    "ssh",
                    "ssl",
                    "file-filter",
                    "asset",
                    "protocol",
                    "siem",
                    "ztna",
                    "security"
                ],
                "type": "str"
            }
        }
    },
    "system_sql_customskipidx": {
        "stated": true,
        "options": {
            "device-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "FortiGate",
                    "FortiManager",
                    "FortiClient",
                    "FortiMail",
                    "FortiWeb",
                    "FortiSandbox",
                    "FortiProxy"
                ],
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "index-field": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "log-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "app-ctrl",
                    "attack",
                    "content",
                    "dlp",
                    "emailfilter",
                    "event",
                    "generic",
                    "history",
                    "traffic",
                    "virus",
                    "voip",
                    "webfilter",
                    "netscan",
                    "fct-event",
                    "fct-traffic",
                    "fct-netscan",
                    "waf",
                    "gtp",
                    "dns",
                    "ssh",
                    "ssl",
                    "file-filter",
                    "asset",
                    "protocol",
                    "siem",
                    "ztna",
                    "security"
                ],
                "type": "str"
            }
        }
    },
    "system_sql_tsindexfield": {
        "stated": true,
        "options": {
            "category": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "value": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_sslciphersuites": {
        "stated": true,
        "options": {
            "cipher": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "priority": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "version": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "tls1.2-or-below",
                    "tls1.3"
                ],
                "type": "str"
            }
        }
    },
    "system_syslog": {
        "stated": true,
        "options": {
            "ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "local-cert": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "peer-cert-cn": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "reliable": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "secure-connection": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "system_virtualwirepair": {
        "stated": true,
        "options": {
            "member": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "elements": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vlan-filter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "wildcard-vlan": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "poweron-bypass": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "poweroff-bypass": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "outer-vlan-id": {
                "required": false,
                "revision": {
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "system_webproxy": {
        "stated": false,
        "options": {
            "address": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "proxy",
                    "tunnel"
                ],
                "type": "str"
            },
            "password": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "username": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_workflow_approvalmatrix": {
        "stated": true,
        "options": {
            "adom-name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "approver": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "member": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "seq_num": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "mail-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "notify": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "system_workflow_approvalmatrix_approver": {
        "stated": true,
        "options": {
            "member": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "seq_num": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "template": {
        "stated": true,
        "options": {
            "description": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "modification-time": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "script": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "provision": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "cli",
                    "jinja"
                ],
                "type": "str"
            },
            "variables": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "templategroup": {
        "stated": true,
        "options": {
            "description": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "member": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "elements": "str"
            },
            "modification-time": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "variables": {
                "required": false,
                "revision": {
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "um_image_upgrade": {
        "stated": true,
        "options": {
            "adom": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "create_task": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "device": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "flags": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "f_boot_alt_partition",
                    "f_skip_retrieve",
                    "f_skip_multi_steps",
                    "f_skip_fortiguard_img",
                    "f_preview"
                ],
                "type": "str"
            },
            "image": {
                "required": false,
                "type": "dict",
                "options": {
                    "build": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "model": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "release": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                }
            },
            "schedule_time": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "um_image_upgrade_ext": {
        "stated": true,
        "options": {
            "create_task": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "device": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "flags": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "f_boot_alt_partition",
                    "f_skip_retrieve",
                    "f_skip_multi_steps",
                    "f_skip_fortiguard_img",
                    "f_preview"
                ],
                "type": "str"
            },
            "image": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "schedule_time": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "user_adgrp": {
        "stated": true,
        "options": {
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "server-name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "polling-id": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "connector-source": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "user_certificate": {
        "stated": true,
        "options": {
            "common-name": {
                "required": false,
                "revision": {
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "issuer": {
                "required": false,
                "revision": {
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": false,
                "revision": {
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "single-certificate",
                    "trusted-issuer"
                ],
                "type": "str"
            }
        }
    },
    "user_clearpass": {
        "stated": true,
        "options": {
            "client": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "password": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "server": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "user": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "user_connector": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "user_device": {
        "stated": true,
        "options": {
            "alias": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "avatar": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "category": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "android-device",
                    "blackberry-device",
                    "fortinet-device",
                    "ios-device",
                    "windows-device",
                    "amazon-device"
                ],
                "type": "str"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dynamic_mapping": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "_scope": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "vdom": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "avatar": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "category": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "android-device",
                            "blackberry-device",
                            "fortinet-device",
                            "ios-device",
                            "windows-device",
                            "amazon-device"
                        ],
                        "type": "str"
                    },
                    "comment": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "mac": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "master-device": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "tags": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ipad",
                            "iphone",
                            "gaming-console",
                            "blackberry-phone",
                            "blackberry-playbook",
                            "linux-pc",
                            "mac",
                            "windows-pc",
                            "android-phone",
                            "android-tablet",
                            "media-streaming",
                            "windows-phone",
                            "fortinet-device",
                            "ip-phone",
                            "router-nat-device",
                            "other-network-device",
                            "windows-tablet",
                            "printer",
                            "forticam",
                            "fortifone",
                            "unknown"
                        ],
                        "type": "str"
                    },
                    "user": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "family": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "hardware-vendor": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "hardware-version": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "os": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "software-version": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "mac": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "master-device": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tagging": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "category": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "tags": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    }
                },
                "elements": "dict"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ipad",
                    "iphone",
                    "gaming-console",
                    "blackberry-phone",
                    "blackberry-playbook",
                    "linux-pc",
                    "mac",
                    "windows-pc",
                    "android-phone",
                    "android-tablet",
                    "media-streaming",
                    "windows-phone",
                    "fortinet-device",
                    "ip-phone",
                    "router-nat-device",
                    "other-network-device",
                    "windows-tablet",
                    "printer",
                    "forticam",
                    "fortifone",
                    "unknown"
                ],
                "type": "str"
            },
            "user": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tags": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "user_device_dynamicmapping": {
        "stated": true,
        "options": {
            "_scope": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "avatar": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "category": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "android-device",
                    "blackberry-device",
                    "fortinet-device",
                    "ios-device",
                    "windows-device",
                    "amazon-device"
                ],
                "type": "str"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "mac": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "master-device": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ipad",
                    "iphone",
                    "gaming-console",
                    "blackberry-phone",
                    "blackberry-playbook",
                    "linux-pc",
                    "mac",
                    "windows-pc",
                    "android-phone",
                    "android-tablet",
                    "media-streaming",
                    "windows-phone",
                    "fortinet-device",
                    "ip-phone",
                    "router-nat-device",
                    "other-network-device",
                    "windows-tablet",
                    "printer",
                    "forticam",
                    "fortifone",
                    "unknown"
                ],
                "type": "str"
            },
            "user": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "family": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "hardware-vendor": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "hardware-version": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "os": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "software-version": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "user_device_tagging": {
        "stated": true,
        "options": {
            "category": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "user_deviceaccesslist": {
        "stated": true,
        "options": {
            "default-action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "deny",
                    "accept"
                ],
                "type": "str"
            },
            "device-list": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "deny",
                            "accept"
                        ],
                        "type": "str"
                    },
                    "device": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "user_deviceaccesslist_devicelist": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "deny",
                    "accept"
                ],
                "type": "str"
            },
            "device": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            }
        }
    },
    "user_devicecategory": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "desc": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "user_devicegroup": {
        "stated": true,
        "options": {
            "_if_unmanaged": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "dynamic_mapping": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "_if_unmanaged": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "_scope": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "list",
                        "options": {
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": false,
                                    "7.2.3": false,
                                    "7.2.4": false,
                                    "7.4.0": false,
                                    "7.4.1": false
                                },
                                "type": "str"
                            },
                            "vdom": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": false,
                                    "7.2.3": false,
                                    "7.2.4": false,
                                    "7.4.0": false,
                                    "7.4.1": false
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "comment": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "member": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "list",
                        "elements": "str"
                    }
                },
                "elements": "dict"
            },
            "member": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "elements": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "tagging": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "category": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "tags": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "raw"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "user_devicegroup_dynamicmapping": {
        "stated": true,
        "options": {
            "_if_unmanaged": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "_scope": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "member": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            }
        }
    },
    "user_devicegroup_tagging": {
        "stated": true,
        "options": {
            "category": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "tags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            }
        }
    },
    "user_domaincontroller": {
        "stated": true,
        "options": {
            "domain-name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "extra-server": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ip-address": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "port": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "source-ip-address": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "source-port": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "ip-address": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ldap-server": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ad-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "ds",
                    "lds"
                ],
                "type": "str"
            },
            "adlds-dn": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "adlds-ip-address": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "adlds-ip6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "adlds-port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "dns-srv-lookup": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "hostname": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "interface": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "interface-select-method": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auto",
                    "sdwan",
                    "specify"
                ],
                "type": "str"
            },
            "ip6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "password": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "replication-port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "source-ip-address": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "source-ip6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "source-port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "username": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "change-detection": {
                "required": false,
                "revision": {
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "change-detection-period": {
                "required": false,
                "revision": {
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "user_domaincontroller_extraserver": {
        "stated": true,
        "options": {
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip-address": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "source-ip-address": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "source-port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "user_exchange": {
        "stated": true,
        "options": {
            "addr-type": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "ipv4",
                    "ipv6"
                ],
                "type": "str"
            },
            "auth-level": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "low",
                    "medium",
                    "normal",
                    "high",
                    "connect",
                    "call",
                    "packet",
                    "integrity",
                    "privacy"
                ],
                "type": "str"
            },
            "auth-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "spnego",
                    "ntlm",
                    "kerberos"
                ],
                "type": "str"
            },
            "connect-protocol": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "rpc-over-tcp",
                    "rpc-over-http",
                    "rpc-over-https"
                ],
                "type": "str"
            },
            "domain-name": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "http-auth-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ntlm",
                    "basic"
                ],
                "type": "str"
            },
            "ip": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ip6": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "kdc-ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "password": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "server-name": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ssl-min-proto-version": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "default",
                    "TLSv1-1",
                    "TLSv1-2",
                    "SSLv3",
                    "TLSv1",
                    "TLSv1-3"
                ],
                "type": "str"
            },
            "username": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "auto-discover-kdc": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "user_flexvm": {
        "stated": true,
        "options": {
            "config": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "folder": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "password": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "str"
            },
            "program": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "user": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "user_fortitoken": {
        "stated": true,
        "options": {
            "comments": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "license": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "os-ver": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "reg-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "serial-number": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "lock",
                    "active"
                ],
                "type": "str"
            }
        }
    },
    "user_fsso": {
        "stated": true,
        "options": {
            "_gui_meta": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dynamic_mapping": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "_gui_meta": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "_scope": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "vdom": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "ldap-server": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "password": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "password2": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "password3": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "password4": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "password5": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "port": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "port2": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "port3": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "port4": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "port5": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "server": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "server2": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "server3": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "server4": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "server5": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "source-ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "source-ip6": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ssl": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ssl-trusted-cert": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "default",
                            "fortiems",
                            "fortinac",
                            "fortiems-cloud"
                        ],
                        "type": "str"
                    },
                    "user-info-server": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "ldap-poll": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ldap-poll-filter": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ldap-poll-interval": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "group-poll-interval": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "interface": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "interface-select-method": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "auto",
                            "sdwan",
                            "specify"
                        ],
                        "type": "str"
                    },
                    "logon-timeout": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "sni": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ssl-server-host-ip-check": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "ldap-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "password": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "password2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "password3": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "password4": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "password5": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "port2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "port3": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "port4": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "port5": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "server2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "server3": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "server4": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "server5": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "source-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "source-ip6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ldap-poll": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ldap-poll-filter": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ldap-poll-interval": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ssl": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-trusted-cert": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "default",
                    "fortiems",
                    "fortinac",
                    "fortiems-cloud"
                ],
                "type": "str"
            },
            "user-info-server": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "group-poll-interval": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "interface": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "interface-select-method": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auto",
                    "sdwan",
                    "specify"
                ],
                "type": "str"
            },
            "logon-timeout": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "sni": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ssl-server-host-ip-check": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "user_fsso_dynamicmapping": {
        "stated": true,
        "options": {
            "_gui_meta": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "_scope": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "ldap-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "password": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "password2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "password3": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "password4": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "password5": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "port2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "port3": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "port4": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "port5": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "server2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "server3": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "server4": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "server5": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "source-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "source-ip6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ssl": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-trusted-cert": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "default",
                    "fortiems",
                    "fortinac",
                    "fortiems-cloud"
                ],
                "type": "str"
            },
            "user-info-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ldap-poll": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ldap-poll-filter": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ldap-poll-interval": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "group-poll-interval": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "interface": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "interface-select-method": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auto",
                    "sdwan",
                    "specify"
                ],
                "type": "str"
            },
            "logon-timeout": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "sni": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ssl-server-host-ip-check": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "user_fssopolling": {
        "stated": true,
        "options": {
            "_gui_meta": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "adgrp": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "default-domain": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ldap-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "logon-history": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "password": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "polling-frequency": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "user": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "smb-ntlmv1-auth": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "smbv1": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "user_fssopolling_adgrp": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "user_group": {
        "stated": true,
        "options": {
            "auth-concurrent-override": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "auth-concurrent-value": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "authtimeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "company": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "optional",
                    "mandatory",
                    "disabled"
                ],
                "type": "str"
            },
            "email": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "expire": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "expire-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "immediately",
                    "first-successful-login"
                ],
                "type": "str"
            },
            "group-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "firewall",
                    "directory-service",
                    "fsso-service",
                    "guest",
                    "rsso"
                ],
                "type": "str"
            },
            "guest": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "comment": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "company": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "email": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "expiration": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "mobile-phone": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "password": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "sponsor": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "user-id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "group": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "http-digest-realm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "match": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "_gui_meta": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "group-name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "server-name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "max-accounts": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "member": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "elements": "str"
            },
            "mobile-phone": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "multiple-guest-add": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "password": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auto-generate",
                    "specify",
                    "disable"
                ],
                "no_log": true,
                "type": "str"
            },
            "sms-custom-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sms-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "fortiguard",
                    "custom"
                ],
                "type": "str"
            },
            "sponsor": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "optional",
                    "mandatory",
                    "disabled"
                ],
                "type": "str"
            },
            "sso-attribute-value": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "user-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "email",
                    "auto-generate",
                    "specify"
                ],
                "type": "str"
            },
            "user-name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dynamic_mapping": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "_scope": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "vdom": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "auth-concurrent-override": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "auth-concurrent-value": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "authtimeout": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "company": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "optional",
                            "mandatory",
                            "disabled"
                        ],
                        "type": "str"
                    },
                    "email": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "expire": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "expire-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "immediately",
                            "first-successful-login"
                        ],
                        "type": "str"
                    },
                    "group-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "firewall",
                            "directory-service",
                            "fsso-service",
                            "guest",
                            "rsso"
                        ],
                        "type": "str"
                    },
                    "guest": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "comment": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "company": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "email": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "expiration": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "group": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "mobile-phone": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "password": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "no_log": true,
                                "type": "raw"
                            },
                            "sponsor": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "user-id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "http-digest-realm": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ldap-memberof": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "logic-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "or",
                            "and"
                        ],
                        "type": "str"
                    },
                    "match": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "_gui_meta": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "group-name": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "server-name": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "max-accounts": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "member": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "mobile-phone": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "multiple-guest-add": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "password": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "auto-generate",
                            "specify",
                            "disable"
                        ],
                        "no_log": true,
                        "type": "str"
                    },
                    "redir-url": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sms-custom-server": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sms-server": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "fortiguard",
                            "custom"
                        ],
                        "type": "str"
                    },
                    "sponsor": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "optional",
                            "mandatory",
                            "disabled"
                        ],
                        "type": "str"
                    },
                    "sslvpn-bookmarks-group": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "sslvpn-cache-cleaner": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "sslvpn-client-check": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "forticlient",
                            "forticlient-av",
                            "forticlient-fw",
                            "3rdAV",
                            "3rdFW"
                        ],
                        "elements": "str"
                    },
                    "sslvpn-ftp": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "sslvpn-http": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "sslvpn-os-check": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "sslvpn-os-check-list": {
                        "required": false,
                        "type": "dict",
                        "options": {
                            "action": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "allow",
                                    "check-up-to-date",
                                    "deny"
                                ],
                                "type": "str"
                            },
                            "latest-patch-level": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "tolerance": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            }
                        }
                    },
                    "sslvpn-portal": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "sslvpn-portal-heading": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sslvpn-rdp": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "sslvpn-samba": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "sslvpn-split-tunneling": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "sslvpn-ssh": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "sslvpn-telnet": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "sslvpn-tunnel": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "sslvpn-tunnel-endip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sslvpn-tunnel-ip-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "range",
                            "usrgrp"
                        ],
                        "type": "str"
                    },
                    "sslvpn-tunnel-startip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sslvpn-virtual-desktop": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "sslvpn-vnc": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "sslvpn-webapp": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "sso-attribute-value": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "user-id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "email",
                            "auto-generate",
                            "specify"
                        ],
                        "type": "str"
                    },
                    "user-name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "user_group_dynamicmapping": {
        "stated": true,
        "options": {
            "_scope": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "auth-concurrent-override": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "auth-concurrent-value": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "authtimeout": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "company": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "optional",
                    "mandatory",
                    "disabled"
                ],
                "type": "str"
            },
            "email": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "expire": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "expire-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "immediately",
                    "first-successful-login"
                ],
                "type": "str"
            },
            "group-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "firewall",
                    "directory-service",
                    "fsso-service",
                    "guest",
                    "rsso"
                ],
                "type": "str"
            },
            "guest": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "comment": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "company": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "email": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "expiration": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "group": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "mobile-phone": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "password": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "sponsor": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "user-id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "http-digest-realm": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ldap-memberof": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "logic-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "or",
                    "and"
                ],
                "type": "str"
            },
            "match": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "_gui_meta": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "group-name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "server-name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "max-accounts": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "member": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "mobile-phone": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "multiple-guest-add": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "password": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auto-generate",
                    "specify",
                    "disable"
                ],
                "no_log": true,
                "type": "str"
            },
            "redir-url": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sms-custom-server": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sms-server": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "fortiguard",
                    "custom"
                ],
                "type": "str"
            },
            "sponsor": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "optional",
                    "mandatory",
                    "disabled"
                ],
                "type": "str"
            },
            "sslvpn-bookmarks-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "sslvpn-cache-cleaner": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sslvpn-client-check": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "forticlient",
                    "forticlient-av",
                    "forticlient-fw",
                    "3rdAV",
                    "3rdFW"
                ],
                "elements": "str"
            },
            "sslvpn-ftp": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sslvpn-http": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sslvpn-os-check": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sslvpn-os-check-list": {
                "required": false,
                "type": "dict",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "check-up-to-date",
                            "deny"
                        ],
                        "type": "str"
                    },
                    "latest-patch-level": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "tolerance": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                }
            },
            "sslvpn-portal": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "sslvpn-portal-heading": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sslvpn-rdp": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sslvpn-samba": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sslvpn-split-tunneling": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sslvpn-ssh": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sslvpn-telnet": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sslvpn-tunnel": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sslvpn-tunnel-endip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sslvpn-tunnel-ip-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "range",
                    "usrgrp"
                ],
                "type": "str"
            },
            "sslvpn-tunnel-startip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sslvpn-virtual-desktop": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sslvpn-vnc": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sslvpn-webapp": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sso-attribute-value": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "user-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "email",
                    "auto-generate",
                    "specify"
                ],
                "type": "str"
            },
            "user-name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "user_group_dynamicmapping_guest": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "company": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "email": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "expiration": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "mobile-phone": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "password": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "no_log": true,
                "type": "raw"
            },
            "sponsor": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "user-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "user_group_dynamicmapping_match": {
        "stated": true,
        "options": {
            "_gui_meta": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "group-name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "server-name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "user_group_dynamicmapping_sslvpnoschecklist": {
        "stated": false,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "allow",
                    "check-up-to-date",
                    "deny"
                ],
                "type": "str"
            },
            "latest-patch-level": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "tolerance": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            }
        }
    },
    "user_group_guest": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "company": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "email": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "expiration": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "mobile-phone": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "password": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "sponsor": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "user-id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "group": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "user_group_match": {
        "stated": true,
        "options": {
            "_gui_meta": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "group-name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "server-name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "user_json": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "user_krbkeytab": {
        "stated": true,
        "options": {
            "keytab": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "str"
            },
            "ldap-server": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "pac-data": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "principal": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "password": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "no_log": true,
                "type": "raw"
            }
        }
    },
    "user_ldap": {
        "stated": true,
        "options": {
            "account-key-filter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "str"
            },
            "account-key-processing": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "same",
                    "strip"
                ],
                "type": "str"
            },
            "ca-cert": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cnid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dynamic_mapping": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "_scope": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "vdom": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "account-key-filter": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "str"
                    },
                    "account-key-name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "str"
                    },
                    "account-key-processing": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "same",
                            "strip"
                        ],
                        "type": "str"
                    },
                    "ca-cert": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "cnid": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "dn": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "filter": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "group": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "group-filter": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "group-member-check": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "user-attr",
                            "group-object",
                            "posix-group-object"
                        ],
                        "type": "str"
                    },
                    "group-object-filter": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "group-object-search-base": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "group-search-base": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "member-attr": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "obtain-user-info": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "password": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "password-expiry-warning": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "password-renewal": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "port": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "retrieve-protection-profile": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "search-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "nested",
                            "recursive"
                        ],
                        "elements": "str"
                    },
                    "secondary-server": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "secure": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "starttls",
                            "ldaps"
                        ],
                        "type": "str"
                    },
                    "server": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "server-identity-check": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "source-ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ssl-min-proto-version": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "default",
                            "TLSv1",
                            "TLSv1-1",
                            "TLSv1-2",
                            "SSLv3",
                            "TLSv1-3"
                        ],
                        "type": "str"
                    },
                    "tertiary-server": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "simple",
                            "anonymous",
                            "regular"
                        ],
                        "type": "str"
                    },
                    "user-info-exchange-server": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "username": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "two-factor": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "fortitoken-cloud"
                        ],
                        "type": "str"
                    },
                    "interface": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "interface-select-method": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "auto",
                            "sdwan",
                            "specify"
                        ],
                        "type": "str"
                    },
                    "two-factor-authentication": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "fortitoken",
                            "email",
                            "sms"
                        ],
                        "type": "str"
                    },
                    "two-factor-notification": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "email",
                            "sms"
                        ],
                        "type": "str"
                    },
                    "antiphish": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "password-attr": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "str"
                    },
                    "source-port": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "client-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "client-cert-auth": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "two-factor-filter": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "account-key-upn-san": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "othername",
                            "rfc822name",
                            "dnsname"
                        ],
                        "type": "str"
                    },
                    "account-key-cert-field": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "othername",
                            "rfc822name",
                            "dnsname"
                        ],
                        "type": "str"
                    },
                    "max-connections": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "group-filter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "group-member-check": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "user-attr",
                    "group-object",
                    "posix-group-object"
                ],
                "type": "str"
            },
            "group-object-filter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "group-search-base": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "member-attr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "password": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "password-expiry-warning": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "password-renewal": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "secondary-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "secure": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "starttls",
                    "ldaps"
                ],
                "type": "str"
            },
            "server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "server-identity-check": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "source-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ssl-min-proto-version": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "default",
                    "TLSv1",
                    "TLSv1-1",
                    "TLSv1-2",
                    "SSLv3",
                    "TLSv1-3"
                ],
                "type": "str"
            },
            "tertiary-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "simple",
                    "anonymous",
                    "regular"
                ],
                "type": "str"
            },
            "username": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "obtain-user-info": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "search-type": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "nested",
                    "recursive"
                ],
                "elements": "str"
            },
            "user-info-exchange-server": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "account-key-name": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "no_log": true,
                "type": "str"
            },
            "group-object-search-base": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "two-factor": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "fortitoken-cloud"
                ],
                "type": "str"
            },
            "interface": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "interface-select-method": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auto",
                    "sdwan",
                    "specify"
                ],
                "type": "str"
            },
            "two-factor-authentication": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "fortitoken",
                    "email",
                    "sms"
                ],
                "type": "str"
            },
            "two-factor-notification": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "email",
                    "sms"
                ],
                "type": "str"
            },
            "antiphish": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "password-attr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "str"
            },
            "source-port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "client-cert": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "client-cert-auth": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "two-factor-filter": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "account-key-upn-san": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "othername",
                    "rfc822name",
                    "dnsname"
                ],
                "type": "str"
            },
            "account-key-cert-field": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "othername",
                    "rfc822name",
                    "dnsname"
                ],
                "type": "str"
            }
        }
    },
    "user_ldap_dynamicmapping": {
        "stated": true,
        "options": {
            "_scope": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "account-key-filter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "str"
            },
            "account-key-name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "str"
            },
            "account-key-processing": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "same",
                    "strip"
                ],
                "type": "str"
            },
            "ca-cert": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cnid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "filter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "group-filter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "group-member-check": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "user-attr",
                    "group-object",
                    "posix-group-object"
                ],
                "type": "str"
            },
            "group-object-filter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "group-object-search-base": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "group-search-base": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "member-attr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "obtain-user-info": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "password": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "password-expiry-warning": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "password-renewal": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "retrieve-protection-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "search-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "nested",
                    "recursive"
                ],
                "elements": "str"
            },
            "secondary-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "secure": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "starttls",
                    "ldaps"
                ],
                "type": "str"
            },
            "server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "server-identity-check": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "source-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ssl-min-proto-version": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "default",
                    "TLSv1",
                    "TLSv1-1",
                    "TLSv1-2",
                    "SSLv3",
                    "TLSv1-3"
                ],
                "type": "str"
            },
            "tertiary-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "simple",
                    "anonymous",
                    "regular"
                ],
                "type": "str"
            },
            "user-info-exchange-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "username": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "two-factor": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "fortitoken-cloud"
                ],
                "type": "str"
            },
            "interface": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "interface-select-method": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auto",
                    "sdwan",
                    "specify"
                ],
                "type": "str"
            },
            "two-factor-authentication": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "fortitoken",
                    "email",
                    "sms"
                ],
                "type": "str"
            },
            "two-factor-notification": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "email",
                    "sms"
                ],
                "type": "str"
            },
            "antiphish": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "password-attr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "str"
            },
            "source-port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "client-cert": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "client-cert-auth": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "two-factor-filter": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "account-key-upn-san": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "othername",
                    "rfc822name",
                    "dnsname"
                ],
                "type": "str"
            },
            "account-key-cert-field": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "othername",
                    "rfc822name",
                    "dnsname"
                ],
                "type": "str"
            },
            "max-connections": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "user_local": {
        "stated": true,
        "options": {
            "auth-concurrent-override": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "auth-concurrent-value": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "authtimeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "email-to": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "fortitoken": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "str"
            },
            "id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ldap-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "passwd": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "passwd-policy": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "str"
            },
            "ppk-identity": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ppk-secret": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "radius-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sms-custom-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sms-phone": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sms-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "fortiguard",
                    "custom"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tacacs+-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "two-factor": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "fortitoken",
                    "email",
                    "sms",
                    "fortitoken-cloud"
                ],
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "password",
                    "radius",
                    "tacacs+",
                    "ldap"
                ],
                "type": "str"
            },
            "workstation": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "two-factor-authentication": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "fortitoken",
                    "email",
                    "sms"
                ],
                "type": "str"
            },
            "two-factor-notification": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "email",
                    "sms"
                ],
                "type": "str"
            },
            "username-case-sensitivity": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "username-case-insensitivity": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "username-sensitivity": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "history0": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "raw"
            },
            "history1": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "user_nsx": {
        "stated": true,
        "options": {
            "fmgip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "fmguser": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "password": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "server": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "user": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "fmgpasswd": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "service-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "if-allgroup": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "service": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "integration": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "east-west",
                            "north-south"
                        ],
                        "type": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ref-id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "service-manager-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "service-manager-rev": {
                "required": false,
                "revision": {
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "user_nsx_service": {
        "stated": true,
        "options": {
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "integration": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "east-west",
                    "north-south"
                ],
                "type": "str"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ref-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "user_passwordpolicy": {
        "stated": true,
        "options": {
            "expire-days": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "warn-days": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "expired-password-renewal": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "expire-status": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "min-change-characters": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "min-lower-case-letter": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "min-non-alphanumeric": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "min-number": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "min-upper-case-letter": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "minimum-length": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "reuse-password": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "user_peer": {
        "stated": true,
        "options": {
            "ca": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cn-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "string",
                    "email",
                    "FQDN",
                    "ipv4",
                    "ipv6"
                ],
                "type": "str"
            },
            "ldap-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "password",
                    "principal-name"
                ],
                "type": "str"
            },
            "ldap-password": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "ldap-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ldap-username": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "mandatory-ca-verify": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ocsp-override-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "passwd": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "subject": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "two-factor": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mfa-mode": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "password",
                    "subject-identity"
                ],
                "type": "str"
            },
            "mfa-password": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "mfa-server": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "mfa-username": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "user_peergrp": {
        "stated": true,
        "options": {
            "member": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "user_pop3": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "secure": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "starttls",
                    "pop3s"
                ],
                "type": "str"
            },
            "server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ssl-min-proto-version": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "default",
                    "TLSv1",
                    "TLSv1-1",
                    "TLSv1-2",
                    "SSLv3",
                    "TLSv1-3"
                ],
                "type": "str"
            }
        }
    },
    "user_pxgrid": {
        "stated": true,
        "options": {
            "ca-cert": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "client-cert": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "user_radius": {
        "stated": true,
        "options": {
            "accounting-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "port": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "secret": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "server": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "source-ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "interface": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "interface-select-method": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "auto",
                            "sdwan",
                            "specify"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "acct-all-servers": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "acct-interim-interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "all-usergroup": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "auth-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pap",
                    "chap",
                    "ms_chap",
                    "ms_chap_v2",
                    "auto"
                ],
                "type": "str"
            },
            "class": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dynamic_mapping": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "_scope": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "vdom": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "acct-all-servers": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "acct-interim-interval": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "all-usergroup": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "auth-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "pap",
                            "chap",
                            "ms_chap",
                            "ms_chap_v2",
                            "auto"
                        ],
                        "type": "str"
                    },
                    "class": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "dp-carrier-endpoint-attribute": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "User-Name",
                            "User-Password",
                            "CHAP-Password",
                            "NAS-IP-Address",
                            "NAS-Port",
                            "Service-Type",
                            "Framed-Protocol",
                            "Framed-IP-Address",
                            "Framed-IP-Netmask",
                            "Framed-Routing",
                            "Filter-Id",
                            "Framed-MTU",
                            "Framed-Compression",
                            "Login-IP-Host",
                            "Login-Service",
                            "Login-TCP-Port",
                            "Reply-Message",
                            "Callback-Number",
                            "Callback-Id",
                            "Framed-Route",
                            "Framed-IPX-Network",
                            "State",
                            "Class",
                            "Vendor-Specific",
                            "Session-Timeout",
                            "Idle-Timeout",
                            "Termination-Action",
                            "Called-Station-Id",
                            "Calling-Station-Id",
                            "NAS-Identifier",
                            "Proxy-State",
                            "Login-LAT-Service",
                            "Login-LAT-Node",
                            "Login-LAT-Group",
                            "Framed-AppleTalk-Link",
                            "Framed-AppleTalk-Network",
                            "Framed-AppleTalk-Zone",
                            "Acct-Status-Type",
                            "Acct-Delay-Time",
                            "Acct-Input-Octets",
                            "Acct-Output-Octets",
                            "Acct-Session-Id",
                            "Acct-Authentic",
                            "Acct-Session-Time",
                            "Acct-Input-Packets",
                            "Acct-Output-Packets",
                            "Acct-Terminate-Cause",
                            "Acct-Multi-Session-Id",
                            "Acct-Link-Count",
                            "CHAP-Challenge",
                            "NAS-Port-Type",
                            "Port-Limit",
                            "Login-LAT-Port"
                        ],
                        "type": "str"
                    },
                    "dp-carrier-endpoint-block-attribute": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "User-Name",
                            "User-Password",
                            "CHAP-Password",
                            "NAS-IP-Address",
                            "NAS-Port",
                            "Service-Type",
                            "Framed-Protocol",
                            "Framed-IP-Address",
                            "Framed-IP-Netmask",
                            "Framed-Routing",
                            "Filter-Id",
                            "Framed-MTU",
                            "Framed-Compression",
                            "Login-IP-Host",
                            "Login-Service",
                            "Login-TCP-Port",
                            "Reply-Message",
                            "Callback-Number",
                            "Callback-Id",
                            "Framed-Route",
                            "Framed-IPX-Network",
                            "State",
                            "Class",
                            "Vendor-Specific",
                            "Session-Timeout",
                            "Idle-Timeout",
                            "Termination-Action",
                            "Called-Station-Id",
                            "Calling-Station-Id",
                            "NAS-Identifier",
                            "Proxy-State",
                            "Login-LAT-Service",
                            "Login-LAT-Node",
                            "Login-LAT-Group",
                            "Framed-AppleTalk-Link",
                            "Framed-AppleTalk-Network",
                            "Framed-AppleTalk-Zone",
                            "Acct-Status-Type",
                            "Acct-Delay-Time",
                            "Acct-Input-Octets",
                            "Acct-Output-Octets",
                            "Acct-Session-Id",
                            "Acct-Authentic",
                            "Acct-Session-Time",
                            "Acct-Input-Packets",
                            "Acct-Output-Packets",
                            "Acct-Terminate-Cause",
                            "Acct-Multi-Session-Id",
                            "Acct-Link-Count",
                            "CHAP-Challenge",
                            "NAS-Port-Type",
                            "Port-Limit",
                            "Login-LAT-Port"
                        ],
                        "type": "str"
                    },
                    "dp-context-timeout": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "dp-flush-ip-session": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "dp-hold-time": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "dp-http-header": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "dp-http-header-fallback": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ip-header-address",
                            "default-profile"
                        ],
                        "type": "str"
                    },
                    "dp-http-header-status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "dp-http-header-suppress": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "dp-log-dyn_flags": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "none",
                            "protocol-error",
                            "profile-missing",
                            "context-missing",
                            "accounting-stop-missed",
                            "accounting-event",
                            "radiusd-other",
                            "endpoint-block"
                        ],
                        "elements": "str"
                    },
                    "dp-log-period": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "dp-mem-percent": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "dp-profile-attribute": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "User-Name",
                            "User-Password",
                            "CHAP-Password",
                            "NAS-IP-Address",
                            "NAS-Port",
                            "Service-Type",
                            "Framed-Protocol",
                            "Framed-IP-Address",
                            "Framed-IP-Netmask",
                            "Framed-Routing",
                            "Filter-Id",
                            "Framed-MTU",
                            "Framed-Compression",
                            "Login-IP-Host",
                            "Login-Service",
                            "Login-TCP-Port",
                            "Reply-Message",
                            "Callback-Number",
                            "Callback-Id",
                            "Framed-Route",
                            "Framed-IPX-Network",
                            "State",
                            "Class",
                            "Vendor-Specific",
                            "Session-Timeout",
                            "Idle-Timeout",
                            "Termination-Action",
                            "Called-Station-Id",
                            "Calling-Station-Id",
                            "NAS-Identifier",
                            "Proxy-State",
                            "Login-LAT-Service",
                            "Login-LAT-Node",
                            "Login-LAT-Group",
                            "Framed-AppleTalk-Link",
                            "Framed-AppleTalk-Network",
                            "Framed-AppleTalk-Zone",
                            "Acct-Status-Type",
                            "Acct-Delay-Time",
                            "Acct-Input-Octets",
                            "Acct-Output-Octets",
                            "Acct-Session-Id",
                            "Acct-Authentic",
                            "Acct-Session-Time",
                            "Acct-Input-Packets",
                            "Acct-Output-Packets",
                            "Acct-Terminate-Cause",
                            "Acct-Multi-Session-Id",
                            "Acct-Link-Count",
                            "CHAP-Challenge",
                            "NAS-Port-Type",
                            "Port-Limit",
                            "Login-LAT-Port"
                        ],
                        "type": "str"
                    },
                    "dp-profile-attribute-key": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "str"
                    },
                    "dp-radius-response": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "dp-radius-server-port": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "dp-secret": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "dp-validate-request-secret": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "dynamic-profile": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "endpoint-translation": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ep-carrier-endpoint-convert-hex": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ep-carrier-endpoint-header": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ep-carrier-endpoint-header-suppress": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ep-carrier-endpoint-prefix": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ep-carrier-endpoint-prefix-range-max": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ep-carrier-endpoint-prefix-range-min": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ep-carrier-endpoint-prefix-string": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ep-carrier-endpoint-source": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "http-header",
                            "cookie"
                        ],
                        "type": "str"
                    },
                    "ep-ip-header": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ep-ip-header-suppress": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ep-missing-header-fallback": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "session-ip",
                            "policy-profile"
                        ],
                        "type": "str"
                    },
                    "ep-profile-query-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "session-ip",
                            "extract-ip",
                            "extract-carrier-endpoint"
                        ],
                        "type": "str"
                    },
                    "h3c-compatibility": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "nas-ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "password-encoding": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ISO-8859-1",
                            "auto"
                        ],
                        "type": "str"
                    },
                    "password-renewal": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "radius-coa": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "radius-port": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "rsso": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "rsso-context-timeout": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "rsso-endpoint-attribute": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "User-Name",
                            "User-Password",
                            "CHAP-Password",
                            "NAS-IP-Address",
                            "NAS-Port",
                            "Service-Type",
                            "Framed-Protocol",
                            "Framed-IP-Address",
                            "Framed-IP-Netmask",
                            "Framed-Routing",
                            "Filter-Id",
                            "Framed-MTU",
                            "Framed-Compression",
                            "Login-IP-Host",
                            "Login-Service",
                            "Login-TCP-Port",
                            "Reply-Message",
                            "Callback-Number",
                            "Callback-Id",
                            "Framed-Route",
                            "Framed-IPX-Network",
                            "State",
                            "Class",
                            "Session-Timeout",
                            "Idle-Timeout",
                            "Termination-Action",
                            "Called-Station-Id",
                            "Calling-Station-Id",
                            "NAS-Identifier",
                            "Proxy-State",
                            "Login-LAT-Service",
                            "Login-LAT-Node",
                            "Login-LAT-Group",
                            "Framed-AppleTalk-Link",
                            "Framed-AppleTalk-Network",
                            "Framed-AppleTalk-Zone",
                            "Acct-Status-Type",
                            "Acct-Delay-Time",
                            "Acct-Input-Octets",
                            "Acct-Output-Octets",
                            "Acct-Session-Id",
                            "Acct-Authentic",
                            "Acct-Session-Time",
                            "Acct-Input-Packets",
                            "Acct-Output-Packets",
                            "Acct-Terminate-Cause",
                            "Acct-Multi-Session-Id",
                            "Acct-Link-Count",
                            "CHAP-Challenge",
                            "NAS-Port-Type",
                            "Port-Limit",
                            "Login-LAT-Port"
                        ],
                        "type": "str"
                    },
                    "rsso-endpoint-block-attribute": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "User-Name",
                            "User-Password",
                            "CHAP-Password",
                            "NAS-IP-Address",
                            "NAS-Port",
                            "Service-Type",
                            "Framed-Protocol",
                            "Framed-IP-Address",
                            "Framed-IP-Netmask",
                            "Framed-Routing",
                            "Filter-Id",
                            "Framed-MTU",
                            "Framed-Compression",
                            "Login-IP-Host",
                            "Login-Service",
                            "Login-TCP-Port",
                            "Reply-Message",
                            "Callback-Number",
                            "Callback-Id",
                            "Framed-Route",
                            "Framed-IPX-Network",
                            "State",
                            "Class",
                            "Session-Timeout",
                            "Idle-Timeout",
                            "Termination-Action",
                            "Called-Station-Id",
                            "Calling-Station-Id",
                            "NAS-Identifier",
                            "Proxy-State",
                            "Login-LAT-Service",
                            "Login-LAT-Node",
                            "Login-LAT-Group",
                            "Framed-AppleTalk-Link",
                            "Framed-AppleTalk-Network",
                            "Framed-AppleTalk-Zone",
                            "Acct-Status-Type",
                            "Acct-Delay-Time",
                            "Acct-Input-Octets",
                            "Acct-Output-Octets",
                            "Acct-Session-Id",
                            "Acct-Authentic",
                            "Acct-Session-Time",
                            "Acct-Input-Packets",
                            "Acct-Output-Packets",
                            "Acct-Terminate-Cause",
                            "Acct-Multi-Session-Id",
                            "Acct-Link-Count",
                            "CHAP-Challenge",
                            "NAS-Port-Type",
                            "Port-Limit",
                            "Login-LAT-Port"
                        ],
                        "type": "str"
                    },
                    "rsso-ep-one-ip-only": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "rsso-flush-ip-session": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "rsso-log-flags": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "none",
                            "protocol-error",
                            "profile-missing",
                            "context-missing",
                            "accounting-stop-missed",
                            "accounting-event",
                            "radiusd-other",
                            "endpoint-block"
                        ],
                        "elements": "str"
                    },
                    "rsso-log-period": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "rsso-radius-response": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "rsso-radius-server-port": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "rsso-secret": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "rsso-validate-request-secret": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "secondary-secret": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "secondary-server": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "secret": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "server": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "source-ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sso-attribute": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "User-Name",
                            "User-Password",
                            "CHAP-Password",
                            "NAS-IP-Address",
                            "NAS-Port",
                            "Service-Type",
                            "Framed-Protocol",
                            "Framed-IP-Address",
                            "Framed-IP-Netmask",
                            "Framed-Routing",
                            "Filter-Id",
                            "Framed-MTU",
                            "Framed-Compression",
                            "Login-IP-Host",
                            "Login-Service",
                            "Login-TCP-Port",
                            "Reply-Message",
                            "Callback-Number",
                            "Callback-Id",
                            "Framed-Route",
                            "Framed-IPX-Network",
                            "State",
                            "Class",
                            "Session-Timeout",
                            "Idle-Timeout",
                            "Termination-Action",
                            "Called-Station-Id",
                            "Calling-Station-Id",
                            "NAS-Identifier",
                            "Proxy-State",
                            "Login-LAT-Service",
                            "Login-LAT-Node",
                            "Login-LAT-Group",
                            "Framed-AppleTalk-Link",
                            "Framed-AppleTalk-Network",
                            "Framed-AppleTalk-Zone",
                            "Acct-Status-Type",
                            "Acct-Delay-Time",
                            "Acct-Input-Octets",
                            "Acct-Output-Octets",
                            "Acct-Session-Id",
                            "Acct-Authentic",
                            "Acct-Session-Time",
                            "Acct-Input-Packets",
                            "Acct-Output-Packets",
                            "Acct-Terminate-Cause",
                            "Acct-Multi-Session-Id",
                            "Acct-Link-Count",
                            "CHAP-Challenge",
                            "NAS-Port-Type",
                            "Port-Limit",
                            "Login-LAT-Port"
                        ],
                        "type": "str"
                    },
                    "sso-attribute-key": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "str"
                    },
                    "sso-attribute-value-override": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "tertiary-secret": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "tertiary-server": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "timeout": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "use-group-for-profile": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "use-management-vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "username-case-sensitive": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "interface": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "interface-select-method": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "auto",
                            "sdwan",
                            "specify"
                        ],
                        "type": "str"
                    },
                    "group-override-attr-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "filter-Id",
                            "class"
                        ],
                        "type": "str"
                    },
                    "switch-controller-acct-fast-framedip-detect": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "accounting-server": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "interface": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "interface-select-method": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "auto",
                                    "sdwan",
                                    "specify"
                                ],
                                "type": "str"
                            },
                            "port": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "secret": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "no_log": true,
                                "type": "raw"
                            },
                            "server": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "source-ip": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "status": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "switch-controller-service-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "login",
                            "framed",
                            "callback-login",
                            "callback-framed",
                            "outbound",
                            "administrative",
                            "nas-prompt",
                            "authenticate-only",
                            "callback-nas-prompt",
                            "call-check",
                            "callback-administrative"
                        ],
                        "elements": "str"
                    },
                    "delimiter": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "plus",
                            "comma"
                        ],
                        "type": "str"
                    },
                    "mac-case": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "uppercase",
                            "lowercase"
                        ],
                        "type": "str"
                    },
                    "mac-password-delimiter": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "hyphen",
                            "single-hyphen",
                            "colon",
                            "none"
                        ],
                        "type": "str"
                    },
                    "mac-username-delimiter": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "hyphen",
                            "single-hyphen",
                            "colon",
                            "none"
                        ],
                        "type": "str"
                    },
                    "nas-id": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "nas-id-type": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "legacy",
                            "custom",
                            "hostname"
                        ],
                        "type": "str"
                    },
                    "ca-cert": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "client-cert": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "server-identity-check": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "status-ttl": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "tls-min-proto-version": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "default",
                            "TLSv1",
                            "TLSv1-1",
                            "TLSv1-2",
                            "SSLv3",
                            "TLSv1-3"
                        ],
                        "type": "str"
                    },
                    "transport-protocol": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "udp",
                            "tcp",
                            "tls"
                        ],
                        "type": "str"
                    },
                    "account-key-cert-field": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "othername",
                            "rfc822name",
                            "dnsname"
                        ],
                        "type": "str"
                    },
                    "account-key-processing": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "same",
                            "strip"
                        ],
                        "type": "str"
                    },
                    "call-station-id-type": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "legacy",
                            "IP",
                            "MAC"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "h3c-compatibility": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "nas-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "password-encoding": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ISO-8859-1",
                    "auto"
                ],
                "type": "str"
            },
            "password-renewal": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "radius-coa": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "radius-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "rsso": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "rsso-context-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "rsso-endpoint-attribute": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "User-Name",
                    "User-Password",
                    "CHAP-Password",
                    "NAS-IP-Address",
                    "NAS-Port",
                    "Service-Type",
                    "Framed-Protocol",
                    "Framed-IP-Address",
                    "Framed-IP-Netmask",
                    "Framed-Routing",
                    "Filter-Id",
                    "Framed-MTU",
                    "Framed-Compression",
                    "Login-IP-Host",
                    "Login-Service",
                    "Login-TCP-Port",
                    "Reply-Message",
                    "Callback-Number",
                    "Callback-Id",
                    "Framed-Route",
                    "Framed-IPX-Network",
                    "State",
                    "Class",
                    "Session-Timeout",
                    "Idle-Timeout",
                    "Termination-Action",
                    "Called-Station-Id",
                    "Calling-Station-Id",
                    "NAS-Identifier",
                    "Proxy-State",
                    "Login-LAT-Service",
                    "Login-LAT-Node",
                    "Login-LAT-Group",
                    "Framed-AppleTalk-Link",
                    "Framed-AppleTalk-Network",
                    "Framed-AppleTalk-Zone",
                    "Acct-Status-Type",
                    "Acct-Delay-Time",
                    "Acct-Input-Octets",
                    "Acct-Output-Octets",
                    "Acct-Session-Id",
                    "Acct-Authentic",
                    "Acct-Session-Time",
                    "Acct-Input-Packets",
                    "Acct-Output-Packets",
                    "Acct-Terminate-Cause",
                    "Acct-Multi-Session-Id",
                    "Acct-Link-Count",
                    "CHAP-Challenge",
                    "NAS-Port-Type",
                    "Port-Limit",
                    "Login-LAT-Port"
                ],
                "type": "str"
            },
            "rsso-endpoint-block-attribute": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "User-Name",
                    "User-Password",
                    "CHAP-Password",
                    "NAS-IP-Address",
                    "NAS-Port",
                    "Service-Type",
                    "Framed-Protocol",
                    "Framed-IP-Address",
                    "Framed-IP-Netmask",
                    "Framed-Routing",
                    "Filter-Id",
                    "Framed-MTU",
                    "Framed-Compression",
                    "Login-IP-Host",
                    "Login-Service",
                    "Login-TCP-Port",
                    "Reply-Message",
                    "Callback-Number",
                    "Callback-Id",
                    "Framed-Route",
                    "Framed-IPX-Network",
                    "State",
                    "Class",
                    "Session-Timeout",
                    "Idle-Timeout",
                    "Termination-Action",
                    "Called-Station-Id",
                    "Calling-Station-Id",
                    "NAS-Identifier",
                    "Proxy-State",
                    "Login-LAT-Service",
                    "Login-LAT-Node",
                    "Login-LAT-Group",
                    "Framed-AppleTalk-Link",
                    "Framed-AppleTalk-Network",
                    "Framed-AppleTalk-Zone",
                    "Acct-Status-Type",
                    "Acct-Delay-Time",
                    "Acct-Input-Octets",
                    "Acct-Output-Octets",
                    "Acct-Session-Id",
                    "Acct-Authentic",
                    "Acct-Session-Time",
                    "Acct-Input-Packets",
                    "Acct-Output-Packets",
                    "Acct-Terminate-Cause",
                    "Acct-Multi-Session-Id",
                    "Acct-Link-Count",
                    "CHAP-Challenge",
                    "NAS-Port-Type",
                    "Port-Limit",
                    "Login-LAT-Port"
                ],
                "type": "str"
            },
            "rsso-ep-one-ip-only": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "rsso-flush-ip-session": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "rsso-log-flags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "none",
                    "protocol-error",
                    "profile-missing",
                    "context-missing",
                    "accounting-stop-missed",
                    "accounting-event",
                    "radiusd-other",
                    "endpoint-block"
                ],
                "elements": "str"
            },
            "rsso-log-period": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "rsso-radius-response": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "rsso-radius-server-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "rsso-secret": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "rsso-validate-request-secret": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "secondary-secret": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "secondary-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "secret": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "source-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sso-attribute": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "User-Name",
                    "User-Password",
                    "CHAP-Password",
                    "NAS-IP-Address",
                    "NAS-Port",
                    "Service-Type",
                    "Framed-Protocol",
                    "Framed-IP-Address",
                    "Framed-IP-Netmask",
                    "Framed-Routing",
                    "Filter-Id",
                    "Framed-MTU",
                    "Framed-Compression",
                    "Login-IP-Host",
                    "Login-Service",
                    "Login-TCP-Port",
                    "Reply-Message",
                    "Callback-Number",
                    "Callback-Id",
                    "Framed-Route",
                    "Framed-IPX-Network",
                    "State",
                    "Class",
                    "Session-Timeout",
                    "Idle-Timeout",
                    "Termination-Action",
                    "Called-Station-Id",
                    "Calling-Station-Id",
                    "NAS-Identifier",
                    "Proxy-State",
                    "Login-LAT-Service",
                    "Login-LAT-Node",
                    "Login-LAT-Group",
                    "Framed-AppleTalk-Link",
                    "Framed-AppleTalk-Network",
                    "Framed-AppleTalk-Zone",
                    "Acct-Status-Type",
                    "Acct-Delay-Time",
                    "Acct-Input-Octets",
                    "Acct-Output-Octets",
                    "Acct-Session-Id",
                    "Acct-Authentic",
                    "Acct-Session-Time",
                    "Acct-Input-Packets",
                    "Acct-Output-Packets",
                    "Acct-Terminate-Cause",
                    "Acct-Multi-Session-Id",
                    "Acct-Link-Count",
                    "CHAP-Challenge",
                    "NAS-Port-Type",
                    "Port-Limit",
                    "Login-LAT-Port"
                ],
                "type": "str"
            },
            "sso-attribute-key": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "str"
            },
            "sso-attribute-value-override": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tertiary-secret": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "tertiary-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "use-management-vdom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "username-case-sensitive": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "interface": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "interface-select-method": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auto",
                    "sdwan",
                    "specify"
                ],
                "type": "str"
            },
            "group-override-attr-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "filter-Id",
                    "class"
                ],
                "type": "str"
            },
            "switch-controller-acct-fast-framedip-detect": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "switch-controller-service-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "login",
                    "framed",
                    "callback-login",
                    "callback-framed",
                    "outbound",
                    "administrative",
                    "nas-prompt",
                    "authenticate-only",
                    "callback-nas-prompt",
                    "call-check",
                    "callback-administrative"
                ],
                "elements": "str"
            },
            "delimiter": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "plus",
                    "comma"
                ],
                "type": "str"
            },
            "mac-case": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "uppercase",
                    "lowercase"
                ],
                "type": "str"
            },
            "mac-password-delimiter": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "hyphen",
                    "single-hyphen",
                    "colon",
                    "none"
                ],
                "type": "str"
            },
            "mac-username-delimiter": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "hyphen",
                    "single-hyphen",
                    "colon",
                    "none"
                ],
                "type": "str"
            },
            "nas-id": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "nas-id-type": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "legacy",
                    "custom",
                    "hostname"
                ],
                "type": "str"
            },
            "ca-cert": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "client-cert": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "server-identity-check": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "status-ttl": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tls-min-proto-version": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "default",
                    "TLSv1",
                    "TLSv1-1",
                    "TLSv1-2",
                    "SSLv3",
                    "TLSv1-3"
                ],
                "type": "str"
            },
            "transport-protocol": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "udp",
                    "tcp",
                    "tls"
                ],
                "type": "str"
            },
            "account-key-cert-field": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "othername",
                    "rfc822name",
                    "dnsname"
                ],
                "type": "str"
            },
            "account-key-processing": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "same",
                    "strip"
                ],
                "type": "str"
            },
            "call-station-id-type": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "legacy",
                    "IP",
                    "MAC"
                ],
                "type": "str"
            }
        }
    },
    "user_radius_accountingserver": {
        "stated": true,
        "options": {
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "secret": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "source-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "interface": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "interface-select-method": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auto",
                    "sdwan",
                    "specify"
                ],
                "type": "str"
            }
        }
    },
    "user_radius_dynamicmapping": {
        "stated": true,
        "options": {
            "_scope": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "acct-all-servers": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "acct-interim-interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "all-usergroup": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "auth-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pap",
                    "chap",
                    "ms_chap",
                    "ms_chap_v2",
                    "auto"
                ],
                "type": "str"
            },
            "class": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dp-carrier-endpoint-attribute": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "User-Name",
                    "User-Password",
                    "CHAP-Password",
                    "NAS-IP-Address",
                    "NAS-Port",
                    "Service-Type",
                    "Framed-Protocol",
                    "Framed-IP-Address",
                    "Framed-IP-Netmask",
                    "Framed-Routing",
                    "Filter-Id",
                    "Framed-MTU",
                    "Framed-Compression",
                    "Login-IP-Host",
                    "Login-Service",
                    "Login-TCP-Port",
                    "Reply-Message",
                    "Callback-Number",
                    "Callback-Id",
                    "Framed-Route",
                    "Framed-IPX-Network",
                    "State",
                    "Class",
                    "Vendor-Specific",
                    "Session-Timeout",
                    "Idle-Timeout",
                    "Termination-Action",
                    "Called-Station-Id",
                    "Calling-Station-Id",
                    "NAS-Identifier",
                    "Proxy-State",
                    "Login-LAT-Service",
                    "Login-LAT-Node",
                    "Login-LAT-Group",
                    "Framed-AppleTalk-Link",
                    "Framed-AppleTalk-Network",
                    "Framed-AppleTalk-Zone",
                    "Acct-Status-Type",
                    "Acct-Delay-Time",
                    "Acct-Input-Octets",
                    "Acct-Output-Octets",
                    "Acct-Session-Id",
                    "Acct-Authentic",
                    "Acct-Session-Time",
                    "Acct-Input-Packets",
                    "Acct-Output-Packets",
                    "Acct-Terminate-Cause",
                    "Acct-Multi-Session-Id",
                    "Acct-Link-Count",
                    "CHAP-Challenge",
                    "NAS-Port-Type",
                    "Port-Limit",
                    "Login-LAT-Port"
                ],
                "type": "str"
            },
            "dp-carrier-endpoint-block-attribute": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "User-Name",
                    "User-Password",
                    "CHAP-Password",
                    "NAS-IP-Address",
                    "NAS-Port",
                    "Service-Type",
                    "Framed-Protocol",
                    "Framed-IP-Address",
                    "Framed-IP-Netmask",
                    "Framed-Routing",
                    "Filter-Id",
                    "Framed-MTU",
                    "Framed-Compression",
                    "Login-IP-Host",
                    "Login-Service",
                    "Login-TCP-Port",
                    "Reply-Message",
                    "Callback-Number",
                    "Callback-Id",
                    "Framed-Route",
                    "Framed-IPX-Network",
                    "State",
                    "Class",
                    "Vendor-Specific",
                    "Session-Timeout",
                    "Idle-Timeout",
                    "Termination-Action",
                    "Called-Station-Id",
                    "Calling-Station-Id",
                    "NAS-Identifier",
                    "Proxy-State",
                    "Login-LAT-Service",
                    "Login-LAT-Node",
                    "Login-LAT-Group",
                    "Framed-AppleTalk-Link",
                    "Framed-AppleTalk-Network",
                    "Framed-AppleTalk-Zone",
                    "Acct-Status-Type",
                    "Acct-Delay-Time",
                    "Acct-Input-Octets",
                    "Acct-Output-Octets",
                    "Acct-Session-Id",
                    "Acct-Authentic",
                    "Acct-Session-Time",
                    "Acct-Input-Packets",
                    "Acct-Output-Packets",
                    "Acct-Terminate-Cause",
                    "Acct-Multi-Session-Id",
                    "Acct-Link-Count",
                    "CHAP-Challenge",
                    "NAS-Port-Type",
                    "Port-Limit",
                    "Login-LAT-Port"
                ],
                "type": "str"
            },
            "dp-context-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "dp-flush-ip-session": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dp-hold-time": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "dp-http-header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dp-http-header-fallback": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ip-header-address",
                    "default-profile"
                ],
                "type": "str"
            },
            "dp-http-header-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dp-http-header-suppress": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dp-log-dyn_flags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "none",
                    "protocol-error",
                    "profile-missing",
                    "context-missing",
                    "accounting-stop-missed",
                    "accounting-event",
                    "radiusd-other",
                    "endpoint-block"
                ],
                "elements": "str"
            },
            "dp-log-period": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "dp-mem-percent": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "dp-profile-attribute": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "User-Name",
                    "User-Password",
                    "CHAP-Password",
                    "NAS-IP-Address",
                    "NAS-Port",
                    "Service-Type",
                    "Framed-Protocol",
                    "Framed-IP-Address",
                    "Framed-IP-Netmask",
                    "Framed-Routing",
                    "Filter-Id",
                    "Framed-MTU",
                    "Framed-Compression",
                    "Login-IP-Host",
                    "Login-Service",
                    "Login-TCP-Port",
                    "Reply-Message",
                    "Callback-Number",
                    "Callback-Id",
                    "Framed-Route",
                    "Framed-IPX-Network",
                    "State",
                    "Class",
                    "Vendor-Specific",
                    "Session-Timeout",
                    "Idle-Timeout",
                    "Termination-Action",
                    "Called-Station-Id",
                    "Calling-Station-Id",
                    "NAS-Identifier",
                    "Proxy-State",
                    "Login-LAT-Service",
                    "Login-LAT-Node",
                    "Login-LAT-Group",
                    "Framed-AppleTalk-Link",
                    "Framed-AppleTalk-Network",
                    "Framed-AppleTalk-Zone",
                    "Acct-Status-Type",
                    "Acct-Delay-Time",
                    "Acct-Input-Octets",
                    "Acct-Output-Octets",
                    "Acct-Session-Id",
                    "Acct-Authentic",
                    "Acct-Session-Time",
                    "Acct-Input-Packets",
                    "Acct-Output-Packets",
                    "Acct-Terminate-Cause",
                    "Acct-Multi-Session-Id",
                    "Acct-Link-Count",
                    "CHAP-Challenge",
                    "NAS-Port-Type",
                    "Port-Limit",
                    "Login-LAT-Port"
                ],
                "type": "str"
            },
            "dp-profile-attribute-key": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "str"
            },
            "dp-radius-response": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dp-radius-server-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "dp-secret": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "dp-validate-request-secret": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dynamic-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "endpoint-translation": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ep-carrier-endpoint-convert-hex": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ep-carrier-endpoint-header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ep-carrier-endpoint-header-suppress": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ep-carrier-endpoint-prefix": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ep-carrier-endpoint-prefix-range-max": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ep-carrier-endpoint-prefix-range-min": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ep-carrier-endpoint-prefix-string": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ep-carrier-endpoint-source": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "http-header",
                    "cookie"
                ],
                "type": "str"
            },
            "ep-ip-header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ep-ip-header-suppress": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ep-missing-header-fallback": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "session-ip",
                    "policy-profile"
                ],
                "type": "str"
            },
            "ep-profile-query-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "session-ip",
                    "extract-ip",
                    "extract-carrier-endpoint"
                ],
                "type": "str"
            },
            "h3c-compatibility": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "nas-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "password-encoding": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ISO-8859-1",
                    "auto"
                ],
                "type": "str"
            },
            "password-renewal": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "radius-coa": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "radius-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "rsso": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "rsso-context-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "rsso-endpoint-attribute": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "User-Name",
                    "User-Password",
                    "CHAP-Password",
                    "NAS-IP-Address",
                    "NAS-Port",
                    "Service-Type",
                    "Framed-Protocol",
                    "Framed-IP-Address",
                    "Framed-IP-Netmask",
                    "Framed-Routing",
                    "Filter-Id",
                    "Framed-MTU",
                    "Framed-Compression",
                    "Login-IP-Host",
                    "Login-Service",
                    "Login-TCP-Port",
                    "Reply-Message",
                    "Callback-Number",
                    "Callback-Id",
                    "Framed-Route",
                    "Framed-IPX-Network",
                    "State",
                    "Class",
                    "Session-Timeout",
                    "Idle-Timeout",
                    "Termination-Action",
                    "Called-Station-Id",
                    "Calling-Station-Id",
                    "NAS-Identifier",
                    "Proxy-State",
                    "Login-LAT-Service",
                    "Login-LAT-Node",
                    "Login-LAT-Group",
                    "Framed-AppleTalk-Link",
                    "Framed-AppleTalk-Network",
                    "Framed-AppleTalk-Zone",
                    "Acct-Status-Type",
                    "Acct-Delay-Time",
                    "Acct-Input-Octets",
                    "Acct-Output-Octets",
                    "Acct-Session-Id",
                    "Acct-Authentic",
                    "Acct-Session-Time",
                    "Acct-Input-Packets",
                    "Acct-Output-Packets",
                    "Acct-Terminate-Cause",
                    "Acct-Multi-Session-Id",
                    "Acct-Link-Count",
                    "CHAP-Challenge",
                    "NAS-Port-Type",
                    "Port-Limit",
                    "Login-LAT-Port"
                ],
                "type": "str"
            },
            "rsso-endpoint-block-attribute": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "User-Name",
                    "User-Password",
                    "CHAP-Password",
                    "NAS-IP-Address",
                    "NAS-Port",
                    "Service-Type",
                    "Framed-Protocol",
                    "Framed-IP-Address",
                    "Framed-IP-Netmask",
                    "Framed-Routing",
                    "Filter-Id",
                    "Framed-MTU",
                    "Framed-Compression",
                    "Login-IP-Host",
                    "Login-Service",
                    "Login-TCP-Port",
                    "Reply-Message",
                    "Callback-Number",
                    "Callback-Id",
                    "Framed-Route",
                    "Framed-IPX-Network",
                    "State",
                    "Class",
                    "Session-Timeout",
                    "Idle-Timeout",
                    "Termination-Action",
                    "Called-Station-Id",
                    "Calling-Station-Id",
                    "NAS-Identifier",
                    "Proxy-State",
                    "Login-LAT-Service",
                    "Login-LAT-Node",
                    "Login-LAT-Group",
                    "Framed-AppleTalk-Link",
                    "Framed-AppleTalk-Network",
                    "Framed-AppleTalk-Zone",
                    "Acct-Status-Type",
                    "Acct-Delay-Time",
                    "Acct-Input-Octets",
                    "Acct-Output-Octets",
                    "Acct-Session-Id",
                    "Acct-Authentic",
                    "Acct-Session-Time",
                    "Acct-Input-Packets",
                    "Acct-Output-Packets",
                    "Acct-Terminate-Cause",
                    "Acct-Multi-Session-Id",
                    "Acct-Link-Count",
                    "CHAP-Challenge",
                    "NAS-Port-Type",
                    "Port-Limit",
                    "Login-LAT-Port"
                ],
                "type": "str"
            },
            "rsso-ep-one-ip-only": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "rsso-flush-ip-session": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "rsso-log-flags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "none",
                    "protocol-error",
                    "profile-missing",
                    "context-missing",
                    "accounting-stop-missed",
                    "accounting-event",
                    "radiusd-other",
                    "endpoint-block"
                ],
                "elements": "str"
            },
            "rsso-log-period": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "rsso-radius-response": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "rsso-radius-server-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "rsso-secret": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "rsso-validate-request-secret": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "secondary-secret": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "secondary-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "secret": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "source-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sso-attribute": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "User-Name",
                    "User-Password",
                    "CHAP-Password",
                    "NAS-IP-Address",
                    "NAS-Port",
                    "Service-Type",
                    "Framed-Protocol",
                    "Framed-IP-Address",
                    "Framed-IP-Netmask",
                    "Framed-Routing",
                    "Filter-Id",
                    "Framed-MTU",
                    "Framed-Compression",
                    "Login-IP-Host",
                    "Login-Service",
                    "Login-TCP-Port",
                    "Reply-Message",
                    "Callback-Number",
                    "Callback-Id",
                    "Framed-Route",
                    "Framed-IPX-Network",
                    "State",
                    "Class",
                    "Session-Timeout",
                    "Idle-Timeout",
                    "Termination-Action",
                    "Called-Station-Id",
                    "Calling-Station-Id",
                    "NAS-Identifier",
                    "Proxy-State",
                    "Login-LAT-Service",
                    "Login-LAT-Node",
                    "Login-LAT-Group",
                    "Framed-AppleTalk-Link",
                    "Framed-AppleTalk-Network",
                    "Framed-AppleTalk-Zone",
                    "Acct-Status-Type",
                    "Acct-Delay-Time",
                    "Acct-Input-Octets",
                    "Acct-Output-Octets",
                    "Acct-Session-Id",
                    "Acct-Authentic",
                    "Acct-Session-Time",
                    "Acct-Input-Packets",
                    "Acct-Output-Packets",
                    "Acct-Terminate-Cause",
                    "Acct-Multi-Session-Id",
                    "Acct-Link-Count",
                    "CHAP-Challenge",
                    "NAS-Port-Type",
                    "Port-Limit",
                    "Login-LAT-Port"
                ],
                "type": "str"
            },
            "sso-attribute-key": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "str"
            },
            "sso-attribute-value-override": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tertiary-secret": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "tertiary-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "use-group-for-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "use-management-vdom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "username-case-sensitive": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "interface": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "interface-select-method": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auto",
                    "sdwan",
                    "specify"
                ],
                "type": "str"
            },
            "group-override-attr-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "filter-Id",
                    "class"
                ],
                "type": "str"
            },
            "switch-controller-acct-fast-framedip-detect": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "accounting-server": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "interface": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "interface-select-method": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "auto",
                            "sdwan",
                            "specify"
                        ],
                        "type": "str"
                    },
                    "port": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "secret": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "server": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "source-ip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "switch-controller-service-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "login",
                    "framed",
                    "callback-login",
                    "callback-framed",
                    "outbound",
                    "administrative",
                    "nas-prompt",
                    "authenticate-only",
                    "callback-nas-prompt",
                    "call-check",
                    "callback-administrative"
                ],
                "elements": "str"
            },
            "delimiter": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "plus",
                    "comma"
                ],
                "type": "str"
            },
            "mac-case": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "uppercase",
                    "lowercase"
                ],
                "type": "str"
            },
            "mac-password-delimiter": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "hyphen",
                    "single-hyphen",
                    "colon",
                    "none"
                ],
                "type": "str"
            },
            "mac-username-delimiter": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "hyphen",
                    "single-hyphen",
                    "colon",
                    "none"
                ],
                "type": "str"
            },
            "nas-id": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "nas-id-type": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "legacy",
                    "custom",
                    "hostname"
                ],
                "type": "str"
            },
            "ca-cert": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "client-cert": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "server-identity-check": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "status-ttl": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tls-min-proto-version": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "default",
                    "TLSv1",
                    "TLSv1-1",
                    "TLSv1-2",
                    "SSLv3",
                    "TLSv1-3"
                ],
                "type": "str"
            },
            "transport-protocol": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "udp",
                    "tcp",
                    "tls"
                ],
                "type": "str"
            },
            "account-key-cert-field": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "othername",
                    "rfc822name",
                    "dnsname"
                ],
                "type": "str"
            },
            "account-key-processing": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "same",
                    "strip"
                ],
                "type": "str"
            },
            "call-station-id-type": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "legacy",
                    "IP",
                    "MAC"
                ],
                "type": "str"
            }
        }
    },
    "user_radius_dynamicmapping_accountingserver": {
        "stated": true,
        "options": {
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "interface": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "interface-select-method": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "auto",
                    "sdwan",
                    "specify"
                ],
                "type": "str"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "int"
            },
            "secret": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "no_log": true,
                "type": "raw"
            },
            "server": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "source-ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "user_saml": {
        "stated": true,
        "options": {
            "cert": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "entity-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "group-name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "idp-cert": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "idp-entity-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "idp-single-logout-url": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "idp-single-sign-on-url": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "single-logout-url": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "single-sign-on-url": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "user-name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "adfs-claim": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "digest-method": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "sha1",
                    "sha256"
                ],
                "type": "str"
            },
            "group-claim-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "email",
                    "given-name",
                    "name",
                    "upn",
                    "common-name",
                    "email-adfs-1x",
                    "group",
                    "upn-adfs-1x",
                    "role",
                    "sur-name",
                    "ppid",
                    "name-identifier",
                    "authentication-method",
                    "deny-only-group-sid",
                    "deny-only-primary-sid",
                    "deny-only-primary-group-sid",
                    "group-sid",
                    "primary-group-sid",
                    "primary-sid",
                    "windows-account-name"
                ],
                "type": "str"
            },
            "limit-relaystate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "user-claim-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "email",
                    "given-name",
                    "name",
                    "upn",
                    "common-name",
                    "email-adfs-1x",
                    "group",
                    "upn-adfs-1x",
                    "role",
                    "sur-name",
                    "ppid",
                    "name-identifier",
                    "authentication-method",
                    "deny-only-group-sid",
                    "deny-only-primary-sid",
                    "deny-only-primary-group-sid",
                    "group-sid",
                    "primary-group-sid",
                    "primary-sid",
                    "windows-account-name"
                ],
                "type": "str"
            },
            "clock-tolerance": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "dynamic_mapping": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "_scope": {
                        "required": false,
                        "revision": {
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "name": {
                                "required": false,
                                "revision": {
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "vdom": {
                                "required": false,
                                "revision": {
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "adfs-claim": {
                        "required": false,
                        "revision": {
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "cert": {
                        "required": false,
                        "revision": {
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "clock-tolerance": {
                        "required": false,
                        "revision": {
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "digest-method": {
                        "required": false,
                        "revision": {
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "sha1",
                            "sha256"
                        ],
                        "type": "str"
                    },
                    "entity-id": {
                        "required": false,
                        "revision": {
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "group-claim-type": {
                        "required": false,
                        "revision": {
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "email",
                            "given-name",
                            "name",
                            "upn",
                            "common-name",
                            "email-adfs-1x",
                            "group",
                            "upn-adfs-1x",
                            "role",
                            "sur-name",
                            "ppid",
                            "name-identifier",
                            "authentication-method",
                            "deny-only-group-sid",
                            "deny-only-primary-sid",
                            "deny-only-primary-group-sid",
                            "group-sid",
                            "primary-group-sid",
                            "primary-sid",
                            "windows-account-name"
                        ],
                        "type": "str"
                    },
                    "group-name": {
                        "required": false,
                        "revision": {
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "idp-cert": {
                        "required": false,
                        "revision": {
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "idp-entity-id": {
                        "required": false,
                        "revision": {
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "idp-single-logout-url": {
                        "required": false,
                        "revision": {
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "idp-single-sign-on-url": {
                        "required": false,
                        "revision": {
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "limit-relaystate": {
                        "required": false,
                        "revision": {
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "single-logout-url": {
                        "required": false,
                        "revision": {
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "single-sign-on-url": {
                        "required": false,
                        "revision": {
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "user-claim-type": {
                        "required": false,
                        "revision": {
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "email",
                            "given-name",
                            "name",
                            "upn",
                            "common-name",
                            "email-adfs-1x",
                            "group",
                            "upn-adfs-1x",
                            "role",
                            "sur-name",
                            "ppid",
                            "name-identifier",
                            "authentication-method",
                            "deny-only-group-sid",
                            "deny-only-primary-sid",
                            "deny-only-primary-group-sid",
                            "group-sid",
                            "primary-group-sid",
                            "primary-sid",
                            "windows-account-name"
                        ],
                        "type": "str"
                    },
                    "user-name": {
                        "required": false,
                        "revision": {
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "auth-url": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "reauth": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "auth-url": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "reauth": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "user_saml_dynamicmapping": {
        "stated": true,
        "options": {
            "_scope": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "adfs-claim": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "cert": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "clock-tolerance": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "digest-method": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "sha1",
                    "sha256"
                ],
                "type": "str"
            },
            "entity-id": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "group-claim-type": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "email",
                    "given-name",
                    "name",
                    "upn",
                    "common-name",
                    "email-adfs-1x",
                    "group",
                    "upn-adfs-1x",
                    "role",
                    "sur-name",
                    "ppid",
                    "name-identifier",
                    "authentication-method",
                    "deny-only-group-sid",
                    "deny-only-primary-sid",
                    "deny-only-primary-group-sid",
                    "group-sid",
                    "primary-group-sid",
                    "primary-sid",
                    "windows-account-name"
                ],
                "type": "str"
            },
            "group-name": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "idp-cert": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "idp-entity-id": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "idp-single-logout-url": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "idp-single-sign-on-url": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "limit-relaystate": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "single-logout-url": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "single-sign-on-url": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "user-claim-type": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "email",
                    "given-name",
                    "name",
                    "upn",
                    "common-name",
                    "email-adfs-1x",
                    "group",
                    "upn-adfs-1x",
                    "role",
                    "sur-name",
                    "ppid",
                    "name-identifier",
                    "authentication-method",
                    "deny-only-group-sid",
                    "deny-only-primary-sid",
                    "deny-only-primary-group-sid",
                    "group-sid",
                    "primary-group-sid",
                    "primary-sid",
                    "windows-account-name"
                ],
                "type": "str"
            },
            "user-name": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "auth-url": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "reauth": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "user_securityexemptlist": {
        "stated": true,
        "options": {
            "description": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "rule": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "devices": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "raw"
                    },
                    "dstaddr": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "service": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "srcaddr": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "user_securityexemptlist_rule": {
        "stated": true,
        "options": {
            "devices": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "dstaddr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "service": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcaddr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "user_tacacs": {
        "stated": true,
        "options": {
            "authen-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auto",
                    "ascii",
                    "pap",
                    "chap",
                    "mschap"
                ],
                "type": "str"
            },
            "authorization": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dynamic_mapping": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "_scope": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "vdom": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "authen-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "auto",
                            "ascii",
                            "pap",
                            "chap",
                            "mschap"
                        ],
                        "type": "str"
                    },
                    "authorization": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "key": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "port": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "secondary-key": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "secondary-server": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "server": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "source-ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "tertiary-key": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "tertiary-server": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "interface": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "interface-select-method": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "auto",
                            "sdwan",
                            "specify"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "key": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "secondary-key": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "secondary-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "source-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tertiary-key": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "tertiary-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "interface": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "interface-select-method": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auto",
                    "sdwan",
                    "specify"
                ],
                "type": "str"
            }
        }
    },
    "user_tacacs_dynamicmapping": {
        "stated": true,
        "options": {
            "_scope": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "authen-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auto",
                    "ascii",
                    "pap",
                    "chap",
                    "mschap"
                ],
                "type": "str"
            },
            "authorization": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "key": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "secondary-key": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "secondary-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "source-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tertiary-key": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "tertiary-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "interface": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "interface-select-method": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auto",
                    "sdwan",
                    "specify"
                ],
                "type": "str"
            }
        }
    },
    "user_vcenter": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "password": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "rule": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "rule": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "server": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "upd_interval": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "user": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "user_vcenter_rule": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "rule": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "utmprofile": {
        "stated": true,
        "options": {
            "antivirus-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "application-list": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ips-sensor": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "scan-botnet-connections": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "block",
                    "monitor"
                ],
                "type": "str"
            },
            "utm-log": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "webfilter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "vap": {
        "stated": true,
        "options": {
            "_centmgmt": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "_dhcp_svr_id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "_intf_allowaccess": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "https",
                    "ping",
                    "ssh",
                    "snmp",
                    "http",
                    "telnet",
                    "fgfm",
                    "auto-ipsec",
                    "radius-acct",
                    "probe-response",
                    "capwap",
                    "dnp",
                    "ftm",
                    "fabric",
                    "speed-test"
                ],
                "elements": "str"
            },
            "_intf_device-identification": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "_intf_device-netscan": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "_intf_dhcp-relay-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "_intf_dhcp-relay-service": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "_intf_dhcp-relay-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "regular",
                    "ipsec"
                ],
                "type": "str"
            },
            "_intf_dhcp6-relay-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "_intf_dhcp6-relay-service": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "_intf_dhcp6-relay-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "regular"
                ],
                "type": "str"
            },
            "_intf_ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "_intf_ip6-address": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "_intf_ip6-allowaccess": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "https",
                    "ping",
                    "ssh",
                    "snmp",
                    "http",
                    "telnet",
                    "any",
                    "fgfm",
                    "capwap"
                ],
                "elements": "str"
            },
            "_intf_listen-forticlient-connection": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "acct-interim-interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "alias": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "auth": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "PSK",
                    "psk",
                    "RADIUS",
                    "radius",
                    "usergroup"
                ],
                "type": "str"
            },
            "broadcast-ssid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "broadcast-suppression": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "dhcp",
                    "arp",
                    "dhcp2",
                    "arp2",
                    "netbios-ns",
                    "netbios-ds",
                    "arp3",
                    "dhcp-up",
                    "dhcp-down",
                    "arp-known",
                    "arp-unknown",
                    "arp-reply",
                    "ipv6",
                    "dhcp-starvation",
                    "arp-poison",
                    "all-other-mc",
                    "all-other-bc",
                    "arp-proxy",
                    "dhcp-ucast"
                ],
                "elements": "str"
            },
            "captive-portal-ac-name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "captive-portal-macauth-radius-secret": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "captive-portal-macauth-radius-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "captive-portal-radius-secret": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "captive-portal-radius-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "captive-portal-session-timeout-interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "dhcp-lease-time": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "dhcp-option82-circuit-id-insertion": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "style-1",
                    "style-2",
                    "style-3"
                ],
                "type": "str"
            },
            "dhcp-option82-insertion": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dhcp-option82-remote-id-insertion": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "style-1"
                ],
                "type": "str"
            },
            "dynamic-vlan": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dynamic_mapping": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "_centmgmt": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "_dhcp_svr_id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "_intf_allowaccess": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "https",
                            "ping",
                            "ssh",
                            "snmp",
                            "http",
                            "telnet",
                            "fgfm",
                            "auto-ipsec",
                            "radius-acct",
                            "probe-response",
                            "capwap",
                            "dnp",
                            "ftm",
                            "fabric",
                            "speed-test"
                        ],
                        "elements": "str"
                    },
                    "_intf_device-identification": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "_intf_device-netscan": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "_intf_dhcp-relay-ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "_intf_dhcp-relay-service": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "_intf_dhcp-relay-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "regular",
                            "ipsec"
                        ],
                        "type": "str"
                    },
                    "_intf_dhcp6-relay-ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "_intf_dhcp6-relay-service": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "_intf_dhcp6-relay-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "regular"
                        ],
                        "type": "str"
                    },
                    "_intf_ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "_intf_ip6-address": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "_intf_ip6-allowaccess": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "https",
                            "ping",
                            "ssh",
                            "snmp",
                            "http",
                            "telnet",
                            "any",
                            "fgfm",
                            "capwap"
                        ],
                        "elements": "str"
                    },
                    "_intf_listen-forticlient-connection": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "_scope": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "vdom": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "acct-interim-interval": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "address-group": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "alias": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "atf-weight": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "auth": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "PSK",
                            "psk",
                            "RADIUS",
                            "radius",
                            "usergroup"
                        ],
                        "type": "str"
                    },
                    "broadcast-ssid": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "broadcast-suppression": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "dhcp",
                            "arp",
                            "dhcp2",
                            "arp2",
                            "netbios-ns",
                            "netbios-ds",
                            "arp3",
                            "dhcp-up",
                            "dhcp-down",
                            "arp-known",
                            "arp-unknown",
                            "arp-reply",
                            "ipv6",
                            "dhcp-starvation",
                            "arp-poison",
                            "all-other-mc",
                            "all-other-bc",
                            "arp-proxy",
                            "dhcp-ucast"
                        ],
                        "elements": "str"
                    },
                    "captive-portal-ac-name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "captive-portal-macauth-radius-secret": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "captive-portal-macauth-radius-server": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "captive-portal-radius-secret": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "captive-portal-radius-server": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "captive-portal-session-timeout-interval": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "client-count": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "dhcp-lease-time": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "dhcp-option82-circuit-id-insertion": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "style-1",
                            "style-2",
                            "style-3"
                        ],
                        "type": "str"
                    },
                    "dhcp-option82-insertion": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "dhcp-option82-remote-id-insertion": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "style-1"
                        ],
                        "type": "str"
                    },
                    "dynamic-vlan": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "eap-reauth": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "eap-reauth-intv": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "eapol-key-retries": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "encrypt": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "TKIP",
                            "AES",
                            "TKIP-AES"
                        ],
                        "type": "str"
                    },
                    "external-fast-roaming": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "external-logout": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "external-web": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "fast-bss-transition": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "fast-roaming": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ft-mobility-domain": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ft-over-ds": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ft-r0-key-lifetime": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "int"
                    },
                    "gtk-rekey": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "gtk-rekey-intv": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "int"
                    },
                    "hotspot20-profile": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "intra-vap-privacy": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "key": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "keyindex": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "int"
                    },
                    "ldpc": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "tx",
                            "rx",
                            "rxtx"
                        ],
                        "type": "str"
                    },
                    "local-authentication": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "local-bridging": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "local-lan": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "deny",
                            "allow"
                        ],
                        "type": "str"
                    },
                    "local-standalone": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "local-standalone-nat": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "local-switching": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "mac-auth-bypass": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "mac-filter": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "mac-filter-policy-other": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "deny",
                            "allow"
                        ],
                        "type": "str"
                    },
                    "max-clients": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "max-clients-ap": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "me-disable-thresh": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "mesh-backhaul": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "mpsk": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "mpsk-concurrent-clients": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "multicast-enhance": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "multicast-rate": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "0",
                            "6000",
                            "12000",
                            "24000"
                        ],
                        "type": "str"
                    },
                    "okc": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "owe-groups": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "19",
                            "20",
                            "21"
                        ],
                        "elements": "str"
                    },
                    "owe-transition": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "owe-transition-ssid": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "passphrase": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "pmf": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable",
                            "optional"
                        ],
                        "type": "str"
                    },
                    "pmf-assoc-comeback-timeout": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "pmf-sa-query-retry-timeout": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "portal-message-override-group": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "portal-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "auth",
                            "auth+disclaimer",
                            "disclaimer",
                            "email-collect",
                            "cmcc",
                            "cmcc-macauth",
                            "auth-mac",
                            "external-auth",
                            "external-macauth"
                        ],
                        "type": "str"
                    },
                    "probe-resp-suppression": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "probe-resp-threshold": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ptk-rekey": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ptk-rekey-intv": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "int"
                    },
                    "qos-profile": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "quarantine": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "radio-2g-threshold": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "radio-5g-threshold": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "radio-sensitivity": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "radius-mac-auth": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "radius-mac-auth-server": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "radius-mac-auth-usergroups": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "radius-server": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "rates-11a": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "1",
                            "1-basic",
                            "2",
                            "2-basic",
                            "5.5",
                            "5.5-basic",
                            "6",
                            "6-basic",
                            "9",
                            "9-basic",
                            "12",
                            "12-basic",
                            "18",
                            "18-basic",
                            "24",
                            "24-basic",
                            "36",
                            "36-basic",
                            "48",
                            "48-basic",
                            "54",
                            "54-basic",
                            "11",
                            "11-basic"
                        ],
                        "elements": "str"
                    },
                    "rates-11ac-ss12": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "mcs0/1",
                            "mcs1/1",
                            "mcs2/1",
                            "mcs3/1",
                            "mcs4/1",
                            "mcs5/1",
                            "mcs6/1",
                            "mcs7/1",
                            "mcs8/1",
                            "mcs9/1",
                            "mcs0/2",
                            "mcs1/2",
                            "mcs2/2",
                            "mcs3/2",
                            "mcs4/2",
                            "mcs5/2",
                            "mcs6/2",
                            "mcs7/2",
                            "mcs8/2",
                            "mcs9/2",
                            "mcs10/1",
                            "mcs11/1",
                            "mcs10/2",
                            "mcs11/2"
                        ],
                        "elements": "str"
                    },
                    "rates-11ac-ss34": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "mcs0/3",
                            "mcs1/3",
                            "mcs2/3",
                            "mcs3/3",
                            "mcs4/3",
                            "mcs5/3",
                            "mcs6/3",
                            "mcs7/3",
                            "mcs8/3",
                            "mcs9/3",
                            "mcs0/4",
                            "mcs1/4",
                            "mcs2/4",
                            "mcs3/4",
                            "mcs4/4",
                            "mcs5/4",
                            "mcs6/4",
                            "mcs7/4",
                            "mcs8/4",
                            "mcs9/4",
                            "mcs10/3",
                            "mcs11/3",
                            "mcs10/4",
                            "mcs11/4"
                        ],
                        "elements": "str"
                    },
                    "rates-11bg": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "1",
                            "1-basic",
                            "2",
                            "2-basic",
                            "5.5",
                            "5.5-basic",
                            "6",
                            "6-basic",
                            "9",
                            "9-basic",
                            "12",
                            "12-basic",
                            "18",
                            "18-basic",
                            "24",
                            "24-basic",
                            "36",
                            "36-basic",
                            "48",
                            "48-basic",
                            "54",
                            "54-basic",
                            "11",
                            "11-basic"
                        ],
                        "elements": "str"
                    },
                    "rates-11n-ss12": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "mcs0/1",
                            "mcs1/1",
                            "mcs2/1",
                            "mcs3/1",
                            "mcs4/1",
                            "mcs5/1",
                            "mcs6/1",
                            "mcs7/1",
                            "mcs8/2",
                            "mcs9/2",
                            "mcs10/2",
                            "mcs11/2",
                            "mcs12/2",
                            "mcs13/2",
                            "mcs14/2",
                            "mcs15/2"
                        ],
                        "elements": "str"
                    },
                    "rates-11n-ss34": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "mcs16/3",
                            "mcs17/3",
                            "mcs18/3",
                            "mcs19/3",
                            "mcs20/3",
                            "mcs21/3",
                            "mcs22/3",
                            "mcs23/3",
                            "mcs24/4",
                            "mcs25/4",
                            "mcs26/4",
                            "mcs27/4",
                            "mcs28/4",
                            "mcs29/4",
                            "mcs30/4",
                            "mcs31/4"
                        ],
                        "elements": "str"
                    },
                    "sae-groups": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "1",
                            "2",
                            "5",
                            "14",
                            "15",
                            "16",
                            "17",
                            "18",
                            "19",
                            "20",
                            "21",
                            "27",
                            "28",
                            "29",
                            "30",
                            "31"
                        ],
                        "elements": "str"
                    },
                    "sae-password": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "schedule": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "security": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "None",
                            "WEP64",
                            "wep64",
                            "WEP128",
                            "wep128",
                            "WPA_PSK",
                            "WPA_RADIUS",
                            "WPA",
                            "WPA2",
                            "WPA2_AUTO",
                            "open",
                            "wpa-personal",
                            "wpa-enterprise",
                            "captive-portal",
                            "wpa-only-personal",
                            "wpa-only-enterprise",
                            "wpa2-only-personal",
                            "wpa2-only-enterprise",
                            "wpa-personal+captive-portal",
                            "wpa-only-personal+captive-portal",
                            "wpa2-only-personal+captive-portal",
                            "osen",
                            "wpa3-enterprise",
                            "sae",
                            "sae-transition",
                            "owe",
                            "wpa3-sae",
                            "wpa3-sae-transition",
                            "wpa3-only-enterprise",
                            "wpa3-enterprise-transition"
                        ],
                        "type": "str"
                    },
                    "security-exempt-list": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "security-obsolete-option": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "security-redirect-url": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "selected-usergroups": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "split-tunneling": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ssid": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "tkip-counter-measure": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "usergroup": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "utm-profile": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "vlan-auto": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "vlan-pooling": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "wtp-group",
                            "round-robin",
                            "hash",
                            "disable"
                        ],
                        "type": "str"
                    },
                    "vlanid": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "voice-enterprise": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "mu-mimo": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "_intf_device-access-list": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "external-web-format": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "auto-detect",
                            "no-query-string",
                            "partial-query-string"
                        ],
                        "type": "str"
                    },
                    "high-efficiency": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "primary-wag-profile": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "secondary-wag-profile": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "target-wake-time": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "tunnel-echo-interval": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "tunnel-fallback-interval": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "access-control-list": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "captive-portal-auth-timeout": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ipv6-rules": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "drop-icmp6ra",
                            "drop-icmp6rs",
                            "drop-llmnr6",
                            "drop-icmp6mld2",
                            "drop-dhcp6s",
                            "drop-dhcp6c",
                            "ndp-proxy",
                            "drop-ns-dad",
                            "drop-ns-nondad"
                        ],
                        "elements": "str"
                    },
                    "sticky-client-remove": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "sticky-client-threshold-2g": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sticky-client-threshold-5g": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "bss-color-partial": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "dhcp-option43-insertion": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "mpsk-profile": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "igmp-snooping": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "port-macauth": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "radius",
                            "address-group"
                        ],
                        "type": "str"
                    },
                    "port-macauth-reauth-timeout": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "port-macauth-timeout": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "additional-akms": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "akm6"
                        ],
                        "elements": "str"
                    },
                    "bstm-disassociation-imminent": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "bstm-load-balancing-disassoc-timer": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "bstm-rssi-disassoc-timer": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "dhcp-address-enforcement": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "gas-comeback-delay": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "gas-fragmentation-limit": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "mac-called-station-delimiter": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "hyphen",
                            "single-hyphen",
                            "colon",
                            "none"
                        ],
                        "type": "str"
                    },
                    "mac-calling-station-delimiter": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "hyphen",
                            "single-hyphen",
                            "colon",
                            "none"
                        ],
                        "type": "str"
                    },
                    "mac-case": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "uppercase",
                            "lowercase"
                        ],
                        "type": "str"
                    },
                    "mac-password-delimiter": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "hyphen",
                            "single-hyphen",
                            "colon",
                            "none"
                        ],
                        "type": "str"
                    },
                    "mac-username-delimiter": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "hyphen",
                            "single-hyphen",
                            "colon",
                            "none"
                        ],
                        "type": "str"
                    },
                    "mbo": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "mbo-cell-data-conn-pref": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "excluded",
                            "prefer-not",
                            "prefer-use"
                        ],
                        "type": "str"
                    },
                    "nac": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "nac-profile": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "neighbor-report-dual-band": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "address-group-policy": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "allow",
                            "deny"
                        ],
                        "type": "str"
                    },
                    "antivirus-profile": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "application-detection-engine": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "application-list": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "application-report-intv": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "auth-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "auth-portal-addr": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "beacon-advertising": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "name",
                            "model",
                            "serial-number"
                        ],
                        "elements": "str"
                    },
                    "ips-sensor": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "l3-roaming": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "local-standalone-dns": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "local-standalone-dns-ip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "osen": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "radius-mac-mpsk-auth": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "radius-mac-mpsk-timeout": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "rates-11ax-ss12": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "mcs0/1",
                            "mcs1/1",
                            "mcs2/1",
                            "mcs3/1",
                            "mcs4/1",
                            "mcs5/1",
                            "mcs6/1",
                            "mcs7/1",
                            "mcs8/1",
                            "mcs9/1",
                            "mcs10/1",
                            "mcs11/1",
                            "mcs0/2",
                            "mcs1/2",
                            "mcs2/2",
                            "mcs3/2",
                            "mcs4/2",
                            "mcs5/2",
                            "mcs6/2",
                            "mcs7/2",
                            "mcs8/2",
                            "mcs9/2",
                            "mcs10/2",
                            "mcs11/2"
                        ],
                        "elements": "str"
                    },
                    "rates-11ax-ss34": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "mcs0/3",
                            "mcs1/3",
                            "mcs2/3",
                            "mcs3/3",
                            "mcs4/3",
                            "mcs5/3",
                            "mcs6/3",
                            "mcs7/3",
                            "mcs8/3",
                            "mcs9/3",
                            "mcs10/3",
                            "mcs11/3",
                            "mcs0/4",
                            "mcs1/4",
                            "mcs2/4",
                            "mcs3/4",
                            "mcs4/4",
                            "mcs5/4",
                            "mcs6/4",
                            "mcs7/4",
                            "mcs8/4",
                            "mcs9/4",
                            "mcs10/4",
                            "mcs11/4"
                        ],
                        "elements": "str"
                    },
                    "scan-botnet-connections": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "block",
                            "monitor"
                        ],
                        "type": "str"
                    },
                    "utm-log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "utm-status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "webfilter-profile": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sae-h2e-only": {
                        "required": false,
                        "revision": {
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "sae-pk": {
                        "required": false,
                        "revision": {
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "sae-private-key": {
                        "required": false,
                        "revision": {
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "str"
                    },
                    "sticky-client-threshold-6g": {
                        "required": false,
                        "revision": {
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "application-dscp-marking": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "l3-roaming-mode": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "direct",
                            "indirect"
                        ],
                        "type": "str"
                    },
                    "rates-11ac-mcs-map": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "rates-11ax-mcs-map": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "captive-portal-fw-accounting": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "radius-mac-auth-block-interval": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "_is_factory_setting": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable",
                            "ext"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "eap-reauth": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "eap-reauth-intv": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "eapol-key-retries": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "encrypt": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "TKIP",
                    "AES",
                    "TKIP-AES"
                ],
                "type": "str"
            },
            "external-fast-roaming": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "external-logout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "external-web": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "fast-bss-transition": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fast-roaming": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ft-mobility-domain": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ft-over-ds": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ft-r0-key-lifetime": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "int"
            },
            "gtk-rekey": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "gtk-rekey-intv": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "int"
            },
            "hotspot20-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "intra-vap-privacy": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "key": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "keyindex": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "int"
            },
            "ldpc": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "tx",
                    "rx",
                    "rxtx"
                ],
                "type": "str"
            },
            "local-authentication": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "local-bridging": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "local-lan": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "deny",
                    "allow"
                ],
                "type": "str"
            },
            "local-standalone": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "local-standalone-nat": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mac-auth-bypass": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mac-filter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mac-filter-list": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "mac": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "mac-filter-policy": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "deny",
                            "allow"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "mac-filter-policy-other": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "deny",
                    "allow"
                ],
                "type": "str"
            },
            "max-clients": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "max-clients-ap": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "me-disable-thresh": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mesh-backhaul": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mpsk": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mpsk-concurrent-clients": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mpsk-key": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "list",
                "options": {
                    "comment": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "concurrent-clients": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "key-name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "str"
                    },
                    "passphrase": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "mpsk-schedules": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    }
                },
                "elements": "dict"
            },
            "multicast-enhance": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "multicast-rate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "0",
                    "6000",
                    "12000",
                    "24000"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "okc": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "passphrase": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "pmf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "optional"
                ],
                "type": "str"
            },
            "pmf-assoc-comeback-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "pmf-sa-query-retry-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "portal-message-override-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "portal-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auth",
                    "auth+disclaimer",
                    "disclaimer",
                    "email-collect",
                    "cmcc",
                    "cmcc-macauth",
                    "auth-mac",
                    "external-auth",
                    "external-macauth"
                ],
                "type": "str"
            },
            "probe-resp-suppression": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "probe-resp-threshold": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ptk-rekey": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ptk-rekey-intv": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "int"
            },
            "qos-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "quarantine": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "radio-2g-threshold": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "radio-5g-threshold": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "radio-sensitivity": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "radius-mac-auth": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "radius-mac-auth-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "radius-mac-auth-usergroups": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "radius-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "rates-11a": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "1",
                    "1-basic",
                    "2",
                    "2-basic",
                    "5.5",
                    "5.5-basic",
                    "6",
                    "6-basic",
                    "9",
                    "9-basic",
                    "12",
                    "12-basic",
                    "18",
                    "18-basic",
                    "24",
                    "24-basic",
                    "36",
                    "36-basic",
                    "48",
                    "48-basic",
                    "54",
                    "54-basic",
                    "11",
                    "11-basic"
                ],
                "elements": "str"
            },
            "rates-11ac-ss12": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "mcs0/1",
                    "mcs1/1",
                    "mcs2/1",
                    "mcs3/1",
                    "mcs4/1",
                    "mcs5/1",
                    "mcs6/1",
                    "mcs7/1",
                    "mcs8/1",
                    "mcs9/1",
                    "mcs0/2",
                    "mcs1/2",
                    "mcs2/2",
                    "mcs3/2",
                    "mcs4/2",
                    "mcs5/2",
                    "mcs6/2",
                    "mcs7/2",
                    "mcs8/2",
                    "mcs9/2",
                    "mcs10/1",
                    "mcs11/1",
                    "mcs10/2",
                    "mcs11/2"
                ],
                "elements": "str"
            },
            "rates-11ac-ss34": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "mcs0/3",
                    "mcs1/3",
                    "mcs2/3",
                    "mcs3/3",
                    "mcs4/3",
                    "mcs5/3",
                    "mcs6/3",
                    "mcs7/3",
                    "mcs8/3",
                    "mcs9/3",
                    "mcs0/4",
                    "mcs1/4",
                    "mcs2/4",
                    "mcs3/4",
                    "mcs4/4",
                    "mcs5/4",
                    "mcs6/4",
                    "mcs7/4",
                    "mcs8/4",
                    "mcs9/4",
                    "mcs10/3",
                    "mcs11/3",
                    "mcs10/4",
                    "mcs11/4"
                ],
                "elements": "str"
            },
            "rates-11bg": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "1",
                    "1-basic",
                    "2",
                    "2-basic",
                    "5.5",
                    "5.5-basic",
                    "6",
                    "6-basic",
                    "9",
                    "9-basic",
                    "12",
                    "12-basic",
                    "18",
                    "18-basic",
                    "24",
                    "24-basic",
                    "36",
                    "36-basic",
                    "48",
                    "48-basic",
                    "54",
                    "54-basic",
                    "11",
                    "11-basic"
                ],
                "elements": "str"
            },
            "rates-11n-ss12": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "mcs0/1",
                    "mcs1/1",
                    "mcs2/1",
                    "mcs3/1",
                    "mcs4/1",
                    "mcs5/1",
                    "mcs6/1",
                    "mcs7/1",
                    "mcs8/2",
                    "mcs9/2",
                    "mcs10/2",
                    "mcs11/2",
                    "mcs12/2",
                    "mcs13/2",
                    "mcs14/2",
                    "mcs15/2"
                ],
                "elements": "str"
            },
            "rates-11n-ss34": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "mcs16/3",
                    "mcs17/3",
                    "mcs18/3",
                    "mcs19/3",
                    "mcs20/3",
                    "mcs21/3",
                    "mcs22/3",
                    "mcs23/3",
                    "mcs24/4",
                    "mcs25/4",
                    "mcs26/4",
                    "mcs27/4",
                    "mcs28/4",
                    "mcs29/4",
                    "mcs30/4",
                    "mcs31/4"
                ],
                "elements": "str"
            },
            "schedule": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "security": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "None",
                    "WEP64",
                    "wep64",
                    "WEP128",
                    "wep128",
                    "WPA_PSK",
                    "WPA_RADIUS",
                    "WPA",
                    "WPA2",
                    "WPA2_AUTO",
                    "open",
                    "wpa-personal",
                    "wpa-enterprise",
                    "captive-portal",
                    "wpa-only-personal",
                    "wpa-only-enterprise",
                    "wpa2-only-personal",
                    "wpa2-only-enterprise",
                    "wpa-personal+captive-portal",
                    "wpa-only-personal+captive-portal",
                    "wpa2-only-personal+captive-portal",
                    "osen",
                    "wpa3-enterprise",
                    "sae",
                    "sae-transition",
                    "owe",
                    "wpa3-sae",
                    "wpa3-sae-transition",
                    "wpa3-only-enterprise",
                    "wpa3-enterprise-transition"
                ],
                "type": "str"
            },
            "security-exempt-list": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "security-obsolete-option": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "security-redirect-url": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "selected-usergroups": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "split-tunneling": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tkip-counter-measure": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "usergroup": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "utm-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vdom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "vlan-auto": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "vlan-pool": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "_wtp-group": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "wtp-group": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": false,
                            "6.2.2": false,
                            "6.2.3": false,
                            "6.2.5": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "vlan-pooling": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "wtp-group",
                    "round-robin",
                    "hash",
                    "disable"
                ],
                "type": "str"
            },
            "vlanid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "voice-enterprise": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "address-group": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "atf-weight": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mu-mimo": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "owe-groups": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "19",
                    "20",
                    "21"
                ],
                "elements": "str"
            },
            "owe-transition": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "owe-transition-ssid": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sae-groups": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "1",
                    "2",
                    "5",
                    "14",
                    "15",
                    "16",
                    "17",
                    "18",
                    "19",
                    "20",
                    "21",
                    "27",
                    "28",
                    "29",
                    "30",
                    "31"
                ],
                "elements": "str"
            },
            "sae-password": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "_intf_device-access-list": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "external-web-format": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auto-detect",
                    "no-query-string",
                    "partial-query-string"
                ],
                "type": "str"
            },
            "high-efficiency": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "primary-wag-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "secondary-wag-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "target-wake-time": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tunnel-echo-interval": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tunnel-fallback-interval": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "access-control-list": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "captive-portal-auth-timeout": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ipv6-rules": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "drop-icmp6ra",
                    "drop-icmp6rs",
                    "drop-llmnr6",
                    "drop-icmp6mld2",
                    "drop-dhcp6s",
                    "drop-dhcp6c",
                    "ndp-proxy",
                    "drop-ns-dad",
                    "drop-ns-nondad"
                ],
                "elements": "str"
            },
            "sticky-client-remove": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sticky-client-threshold-2g": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sticky-client-threshold-5g": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "bss-color-partial": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dhcp-option43-insertion": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mpsk-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "igmp-snooping": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "port-macauth": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "radius",
                    "address-group"
                ],
                "type": "str"
            },
            "port-macauth-reauth-timeout": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "port-macauth-timeout": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "portal-message-overrides": {
                "required": false,
                "type": "dict",
                "options": {
                    "auth-disclaimer-page": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "auth-login-failed-page": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "auth-login-page": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "auth-reject-page": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                }
            },
            "additional-akms": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "akm6"
                ],
                "elements": "str"
            },
            "bstm-disassociation-imminent": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "bstm-load-balancing-disassoc-timer": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "bstm-rssi-disassoc-timer": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "dhcp-address-enforcement": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "gas-comeback-delay": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "gas-fragmentation-limit": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mac-called-station-delimiter": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "hyphen",
                    "single-hyphen",
                    "colon",
                    "none"
                ],
                "type": "str"
            },
            "mac-calling-station-delimiter": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "hyphen",
                    "single-hyphen",
                    "colon",
                    "none"
                ],
                "type": "str"
            },
            "mac-case": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "uppercase",
                    "lowercase"
                ],
                "type": "str"
            },
            "mac-password-delimiter": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "hyphen",
                    "single-hyphen",
                    "colon",
                    "none"
                ],
                "type": "str"
            },
            "mac-username-delimiter": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "hyphen",
                    "single-hyphen",
                    "colon",
                    "none"
                ],
                "type": "str"
            },
            "mbo": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mbo-cell-data-conn-pref": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "excluded",
                    "prefer-not",
                    "prefer-use"
                ],
                "type": "str"
            },
            "nac": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "nac-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "neighbor-report-dual-band": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "address-group-policy": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "antivirus-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "application-detection-engine": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "application-list": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "application-report-intv": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "auth-cert": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "auth-portal-addr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "beacon-advertising": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "name",
                    "model",
                    "serial-number"
                ],
                "elements": "str"
            },
            "ips-sensor": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "l3-roaming": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "local-standalone-dns": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "local-standalone-dns-ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "osen": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "radius-mac-mpsk-auth": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "radius-mac-mpsk-timeout": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "rates-11ax-ss12": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "mcs0/1",
                    "mcs1/1",
                    "mcs2/1",
                    "mcs3/1",
                    "mcs4/1",
                    "mcs5/1",
                    "mcs6/1",
                    "mcs7/1",
                    "mcs8/1",
                    "mcs9/1",
                    "mcs10/1",
                    "mcs11/1",
                    "mcs0/2",
                    "mcs1/2",
                    "mcs2/2",
                    "mcs3/2",
                    "mcs4/2",
                    "mcs5/2",
                    "mcs6/2",
                    "mcs7/2",
                    "mcs8/2",
                    "mcs9/2",
                    "mcs10/2",
                    "mcs11/2"
                ],
                "elements": "str"
            },
            "rates-11ax-ss34": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "mcs0/3",
                    "mcs1/3",
                    "mcs2/3",
                    "mcs3/3",
                    "mcs4/3",
                    "mcs5/3",
                    "mcs6/3",
                    "mcs7/3",
                    "mcs8/3",
                    "mcs9/3",
                    "mcs10/3",
                    "mcs11/3",
                    "mcs0/4",
                    "mcs1/4",
                    "mcs2/4",
                    "mcs3/4",
                    "mcs4/4",
                    "mcs5/4",
                    "mcs6/4",
                    "mcs7/4",
                    "mcs8/4",
                    "mcs9/4",
                    "mcs10/4",
                    "mcs11/4"
                ],
                "elements": "str"
            },
            "scan-botnet-connections": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "block",
                    "monitor"
                ],
                "type": "str"
            },
            "utm-log": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "utm-status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "vlan-name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vlan-id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "webfilter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sae-h2e-only": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sae-pk": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sae-private-key": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "str"
            },
            "sticky-client-threshold-6g": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "application-dscp-marking": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "l3-roaming-mode": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "direct",
                    "indirect"
                ],
                "type": "str"
            },
            "rates-11ac-mcs-map": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "rates-11ax-mcs-map": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "captive-portal-fw-accounting": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "radius-mac-auth-block-interval": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "_is_factory_setting": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "ext"
                ],
                "type": "str"
            }
        }
    },
    "vap_dynamicmapping": {
        "stated": true,
        "options": {
            "_centmgmt": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "_dhcp_svr_id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "_intf_allowaccess": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "https",
                    "ping",
                    "ssh",
                    "snmp",
                    "http",
                    "telnet",
                    "fgfm",
                    "auto-ipsec",
                    "radius-acct",
                    "probe-response",
                    "capwap",
                    "dnp",
                    "ftm",
                    "fabric",
                    "speed-test"
                ],
                "elements": "str"
            },
            "_intf_device-identification": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "_intf_device-netscan": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "_intf_dhcp-relay-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "_intf_dhcp-relay-service": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "_intf_dhcp-relay-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "regular",
                    "ipsec"
                ],
                "type": "str"
            },
            "_intf_dhcp6-relay-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "_intf_dhcp6-relay-service": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "_intf_dhcp6-relay-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "regular"
                ],
                "type": "str"
            },
            "_intf_ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "_intf_ip6-address": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "_intf_ip6-allowaccess": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "https",
                    "ping",
                    "ssh",
                    "snmp",
                    "http",
                    "telnet",
                    "any",
                    "fgfm",
                    "capwap"
                ],
                "elements": "str"
            },
            "_intf_listen-forticlient-connection": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "_scope": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "acct-interim-interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "address-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "alias": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "atf-weight": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "auth": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "PSK",
                    "psk",
                    "RADIUS",
                    "radius",
                    "usergroup"
                ],
                "type": "str"
            },
            "broadcast-ssid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "broadcast-suppression": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "dhcp",
                    "arp",
                    "dhcp2",
                    "arp2",
                    "netbios-ns",
                    "netbios-ds",
                    "arp3",
                    "dhcp-up",
                    "dhcp-down",
                    "arp-known",
                    "arp-unknown",
                    "arp-reply",
                    "ipv6",
                    "dhcp-starvation",
                    "arp-poison",
                    "all-other-mc",
                    "all-other-bc",
                    "arp-proxy",
                    "dhcp-ucast"
                ],
                "elements": "str"
            },
            "captive-portal-ac-name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "captive-portal-macauth-radius-secret": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "captive-portal-macauth-radius-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "captive-portal-radius-secret": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "captive-portal-radius-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "captive-portal-session-timeout-interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "client-count": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "dhcp-lease-time": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "dhcp-option82-circuit-id-insertion": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "style-1",
                    "style-2",
                    "style-3"
                ],
                "type": "str"
            },
            "dhcp-option82-insertion": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dhcp-option82-remote-id-insertion": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "style-1"
                ],
                "type": "str"
            },
            "dynamic-vlan": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "eap-reauth": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "eap-reauth-intv": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "eapol-key-retries": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "encrypt": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "TKIP",
                    "AES",
                    "TKIP-AES"
                ],
                "type": "str"
            },
            "external-fast-roaming": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "external-logout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "external-web": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "fast-bss-transition": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fast-roaming": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ft-mobility-domain": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ft-over-ds": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ft-r0-key-lifetime": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "int"
            },
            "gtk-rekey": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "gtk-rekey-intv": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "int"
            },
            "hotspot20-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "intra-vap-privacy": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "key": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "keyindex": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "int"
            },
            "ldpc": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "tx",
                    "rx",
                    "rxtx"
                ],
                "type": "str"
            },
            "local-authentication": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "local-bridging": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "local-lan": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "deny",
                    "allow"
                ],
                "type": "str"
            },
            "local-standalone": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "local-standalone-nat": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "local-switching": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mac-auth-bypass": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mac-filter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mac-filter-policy-other": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "deny",
                    "allow"
                ],
                "type": "str"
            },
            "max-clients": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "max-clients-ap": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "me-disable-thresh": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mesh-backhaul": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mpsk": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mpsk-concurrent-clients": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "multicast-enhance": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "multicast-rate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "0",
                    "6000",
                    "12000",
                    "24000"
                ],
                "type": "str"
            },
            "okc": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "owe-groups": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "19",
                    "20",
                    "21"
                ],
                "elements": "str"
            },
            "owe-transition": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "owe-transition-ssid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "passphrase": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "pmf": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "optional"
                ],
                "type": "str"
            },
            "pmf-assoc-comeback-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "pmf-sa-query-retry-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "portal-message-override-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "portal-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auth",
                    "auth+disclaimer",
                    "disclaimer",
                    "email-collect",
                    "cmcc",
                    "cmcc-macauth",
                    "auth-mac",
                    "external-auth",
                    "external-macauth"
                ],
                "type": "str"
            },
            "probe-resp-suppression": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "probe-resp-threshold": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ptk-rekey": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ptk-rekey-intv": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "int"
            },
            "qos-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "quarantine": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "radio-2g-threshold": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "radio-5g-threshold": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "radio-sensitivity": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "radius-mac-auth": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "radius-mac-auth-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "radius-mac-auth-usergroups": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "radius-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "rates-11a": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "1",
                    "1-basic",
                    "2",
                    "2-basic",
                    "5.5",
                    "5.5-basic",
                    "6",
                    "6-basic",
                    "9",
                    "9-basic",
                    "12",
                    "12-basic",
                    "18",
                    "18-basic",
                    "24",
                    "24-basic",
                    "36",
                    "36-basic",
                    "48",
                    "48-basic",
                    "54",
                    "54-basic",
                    "11",
                    "11-basic"
                ],
                "elements": "str"
            },
            "rates-11ac-ss12": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "mcs0/1",
                    "mcs1/1",
                    "mcs2/1",
                    "mcs3/1",
                    "mcs4/1",
                    "mcs5/1",
                    "mcs6/1",
                    "mcs7/1",
                    "mcs8/1",
                    "mcs9/1",
                    "mcs0/2",
                    "mcs1/2",
                    "mcs2/2",
                    "mcs3/2",
                    "mcs4/2",
                    "mcs5/2",
                    "mcs6/2",
                    "mcs7/2",
                    "mcs8/2",
                    "mcs9/2",
                    "mcs10/1",
                    "mcs11/1",
                    "mcs10/2",
                    "mcs11/2"
                ],
                "elements": "str"
            },
            "rates-11ac-ss34": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "mcs0/3",
                    "mcs1/3",
                    "mcs2/3",
                    "mcs3/3",
                    "mcs4/3",
                    "mcs5/3",
                    "mcs6/3",
                    "mcs7/3",
                    "mcs8/3",
                    "mcs9/3",
                    "mcs0/4",
                    "mcs1/4",
                    "mcs2/4",
                    "mcs3/4",
                    "mcs4/4",
                    "mcs5/4",
                    "mcs6/4",
                    "mcs7/4",
                    "mcs8/4",
                    "mcs9/4",
                    "mcs10/3",
                    "mcs11/3",
                    "mcs10/4",
                    "mcs11/4"
                ],
                "elements": "str"
            },
            "rates-11bg": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "1",
                    "1-basic",
                    "2",
                    "2-basic",
                    "5.5",
                    "5.5-basic",
                    "6",
                    "6-basic",
                    "9",
                    "9-basic",
                    "12",
                    "12-basic",
                    "18",
                    "18-basic",
                    "24",
                    "24-basic",
                    "36",
                    "36-basic",
                    "48",
                    "48-basic",
                    "54",
                    "54-basic",
                    "11",
                    "11-basic"
                ],
                "elements": "str"
            },
            "rates-11n-ss12": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "mcs0/1",
                    "mcs1/1",
                    "mcs2/1",
                    "mcs3/1",
                    "mcs4/1",
                    "mcs5/1",
                    "mcs6/1",
                    "mcs7/1",
                    "mcs8/2",
                    "mcs9/2",
                    "mcs10/2",
                    "mcs11/2",
                    "mcs12/2",
                    "mcs13/2",
                    "mcs14/2",
                    "mcs15/2"
                ],
                "elements": "str"
            },
            "rates-11n-ss34": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "mcs16/3",
                    "mcs17/3",
                    "mcs18/3",
                    "mcs19/3",
                    "mcs20/3",
                    "mcs21/3",
                    "mcs22/3",
                    "mcs23/3",
                    "mcs24/4",
                    "mcs25/4",
                    "mcs26/4",
                    "mcs27/4",
                    "mcs28/4",
                    "mcs29/4",
                    "mcs30/4",
                    "mcs31/4"
                ],
                "elements": "str"
            },
            "sae-groups": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "1",
                    "2",
                    "5",
                    "14",
                    "15",
                    "16",
                    "17",
                    "18",
                    "19",
                    "20",
                    "21",
                    "27",
                    "28",
                    "29",
                    "30",
                    "31"
                ],
                "elements": "str"
            },
            "sae-password": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "schedule": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "security": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "None",
                    "WEP64",
                    "wep64",
                    "WEP128",
                    "wep128",
                    "WPA_PSK",
                    "WPA_RADIUS",
                    "WPA",
                    "WPA2",
                    "WPA2_AUTO",
                    "open",
                    "wpa-personal",
                    "wpa-enterprise",
                    "captive-portal",
                    "wpa-only-personal",
                    "wpa-only-enterprise",
                    "wpa2-only-personal",
                    "wpa2-only-enterprise",
                    "wpa-personal+captive-portal",
                    "wpa-only-personal+captive-portal",
                    "wpa2-only-personal+captive-portal",
                    "osen",
                    "wpa3-enterprise",
                    "sae",
                    "sae-transition",
                    "owe",
                    "wpa3-sae",
                    "wpa3-sae-transition",
                    "wpa3-only-enterprise",
                    "wpa3-enterprise-transition"
                ],
                "type": "str"
            },
            "security-exempt-list": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "security-obsolete-option": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "security-redirect-url": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "selected-usergroups": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "split-tunneling": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tkip-counter-measure": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "usergroup": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "utm-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vdom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "vlan-auto": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "vlan-pooling": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "wtp-group",
                    "round-robin",
                    "hash",
                    "disable"
                ],
                "type": "str"
            },
            "vlanid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "voice-enterprise": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mu-mimo": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "_intf_device-access-list": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "external-web-format": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auto-detect",
                    "no-query-string",
                    "partial-query-string"
                ],
                "type": "str"
            },
            "high-efficiency": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "primary-wag-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "secondary-wag-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "target-wake-time": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tunnel-echo-interval": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tunnel-fallback-interval": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "access-control-list": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "captive-portal-auth-timeout": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ipv6-rules": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "drop-icmp6ra",
                    "drop-icmp6rs",
                    "drop-llmnr6",
                    "drop-icmp6mld2",
                    "drop-dhcp6s",
                    "drop-dhcp6c",
                    "ndp-proxy",
                    "drop-ns-dad",
                    "drop-ns-nondad"
                ],
                "elements": "str"
            },
            "sticky-client-remove": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sticky-client-threshold-2g": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sticky-client-threshold-5g": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "bss-color-partial": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dhcp-option43-insertion": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mpsk-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "igmp-snooping": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "port-macauth": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "radius",
                    "address-group"
                ],
                "type": "str"
            },
            "port-macauth-reauth-timeout": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "port-macauth-timeout": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "additional-akms": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "akm6"
                ],
                "elements": "str"
            },
            "bstm-disassociation-imminent": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "bstm-load-balancing-disassoc-timer": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "bstm-rssi-disassoc-timer": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "dhcp-address-enforcement": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "gas-comeback-delay": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "gas-fragmentation-limit": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mac-called-station-delimiter": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "hyphen",
                    "single-hyphen",
                    "colon",
                    "none"
                ],
                "type": "str"
            },
            "mac-calling-station-delimiter": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "hyphen",
                    "single-hyphen",
                    "colon",
                    "none"
                ],
                "type": "str"
            },
            "mac-case": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "uppercase",
                    "lowercase"
                ],
                "type": "str"
            },
            "mac-password-delimiter": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "hyphen",
                    "single-hyphen",
                    "colon",
                    "none"
                ],
                "type": "str"
            },
            "mac-username-delimiter": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "hyphen",
                    "single-hyphen",
                    "colon",
                    "none"
                ],
                "type": "str"
            },
            "mbo": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mbo-cell-data-conn-pref": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "excluded",
                    "prefer-not",
                    "prefer-use"
                ],
                "type": "str"
            },
            "nac": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "nac-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "neighbor-report-dual-band": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "address-group-policy": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "antivirus-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "application-detection-engine": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "application-list": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "application-report-intv": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "auth-cert": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "auth-portal-addr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "beacon-advertising": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "name",
                    "model",
                    "serial-number"
                ],
                "elements": "str"
            },
            "ips-sensor": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "l3-roaming": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "local-standalone-dns": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "local-standalone-dns-ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "osen": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "radius-mac-mpsk-auth": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "radius-mac-mpsk-timeout": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "rates-11ax-ss12": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "mcs0/1",
                    "mcs1/1",
                    "mcs2/1",
                    "mcs3/1",
                    "mcs4/1",
                    "mcs5/1",
                    "mcs6/1",
                    "mcs7/1",
                    "mcs8/1",
                    "mcs9/1",
                    "mcs10/1",
                    "mcs11/1",
                    "mcs0/2",
                    "mcs1/2",
                    "mcs2/2",
                    "mcs3/2",
                    "mcs4/2",
                    "mcs5/2",
                    "mcs6/2",
                    "mcs7/2",
                    "mcs8/2",
                    "mcs9/2",
                    "mcs10/2",
                    "mcs11/2"
                ],
                "elements": "str"
            },
            "rates-11ax-ss34": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "mcs0/3",
                    "mcs1/3",
                    "mcs2/3",
                    "mcs3/3",
                    "mcs4/3",
                    "mcs5/3",
                    "mcs6/3",
                    "mcs7/3",
                    "mcs8/3",
                    "mcs9/3",
                    "mcs10/3",
                    "mcs11/3",
                    "mcs0/4",
                    "mcs1/4",
                    "mcs2/4",
                    "mcs3/4",
                    "mcs4/4",
                    "mcs5/4",
                    "mcs6/4",
                    "mcs7/4",
                    "mcs8/4",
                    "mcs9/4",
                    "mcs10/4",
                    "mcs11/4"
                ],
                "elements": "str"
            },
            "scan-botnet-connections": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "block",
                    "monitor"
                ],
                "type": "str"
            },
            "utm-log": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "utm-status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "webfilter-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sae-h2e-only": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sae-pk": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sae-private-key": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "str"
            },
            "sticky-client-threshold-6g": {
                "required": false,
                "revision": {
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "application-dscp-marking": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "l3-roaming-mode": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "direct",
                    "indirect"
                ],
                "type": "str"
            },
            "rates-11ac-mcs-map": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "rates-11ax-mcs-map": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "captive-portal-fw-accounting": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "radius-mac-auth-block-interval": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "_is_factory_setting": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "ext"
                ],
                "type": "str"
            }
        }
    },
    "vap_macfilterlist": {
        "stated": true,
        "options": {
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mac": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "mac-filter-policy": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "deny",
                    "allow"
                ],
                "type": "str"
            }
        }
    },
    "vap_mpskkey": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "concurrent-clients": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "key-name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "str"
            },
            "passphrase": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "mpsk-schedules": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "vap_portalmessageoverrides": {
        "stated": false,
        "options": {
            "auth-disclaimer-page": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "auth-login-failed-page": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "auth-login-page": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "auth-reject-page": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "vap_vlanname": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vlan-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "vap_vlanpool": {
        "stated": true,
        "options": {
            "_wtp-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "wtp-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": false,
                    "6.2.2": false,
                    "6.2.3": false,
                    "6.2.5": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "vapgroup": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vaps": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "videofilter_profile": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dailymotion": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fortiguard-category": {
                "required": false,
                "type": "dict",
                "options": {
                    "filters": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "action": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "block",
                                    "bypass",
                                    "monitor",
                                    "allow"
                                ],
                                "type": "str"
                            },
                            "category-id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "log": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    }
                }
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vimeo": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "vimeo-restrict": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "youtube": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "youtube-channel-filter": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "youtube-restrict": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "strict",
                    "none",
                    "moderate"
                ],
                "type": "str"
            },
            "replacemsg-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "default-action": {
                "required": false,
                "revision": {
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "block",
                    "monitor",
                    "allow"
                ],
                "type": "str"
            },
            "log": {
                "required": false,
                "revision": {
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "videofilter_profile_fortiguardcategory": {
        "stated": false,
        "options": {
            "filters": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "block",
                            "bypass",
                            "monitor",
                            "allow"
                        ],
                        "type": "str"
                    },
                    "category-id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "videofilter_profile_fortiguardcategory_filters": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "block",
                    "bypass",
                    "monitor",
                    "allow"
                ],
                "type": "str"
            },
            "category-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "videofilter_youtubechannelfilter": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "entries": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "block",
                            "bypass",
                            "monitor",
                            "allow"
                        ],
                        "type": "str"
                    },
                    "channel-id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "comment": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "default-action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "monitor",
                    "block",
                    "allow"
                ],
                "type": "str"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "override-category": {
                "required": false,
                "revision": {
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "videofilter_youtubechannelfilter_entries": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "block",
                    "bypass",
                    "monitor",
                    "allow"
                ],
                "type": "str"
            },
            "channel-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "virtualpatch_profile": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "block"
                ],
                "type": "str"
            },
            "comment": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "exemption": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "device": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "list",
                        "elements": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "rule": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "list",
                        "elements": "int"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "log": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "severity": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "low",
                    "medium",
                    "high",
                    "critical"
                ],
                "elements": "str"
            }
        }
    },
    "virtualpatch_profile_exemption": {
        "stated": true,
        "options": {
            "device": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "list",
                "elements": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "rule": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "list",
                "elements": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "voip_profile": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sccp": {
                "required": false,
                "type": "dict",
                "options": {
                    "block-mcast": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "log-call-summary": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "log-violations": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "max-calls": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "verify-header": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "sip": {
                "required": false,
                "type": "dict",
                "options": {
                    "ack-rate": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "block-ack": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "block-bye": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "block-cancel": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "block-geo-red-options": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "block-info": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "block-invite": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "block-long-lines": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "block-message": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "block-notify": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "block-options": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "block-prack": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "block-publish": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "block-refer": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "block-register": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "block-subscribe": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "block-unknown": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "block-update": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "bye-rate": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "call-keepalive": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "cancel-rate": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "contact-fixup": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "hnt-restrict-source-ip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "hosted-nat-traversal": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "info-rate": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "invite-rate": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ips-rtp": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "log-call-summary": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "log-violations": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "malformed-header-allow": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "pass",
                            "discard",
                            "respond"
                        ],
                        "type": "str"
                    },
                    "malformed-header-call-id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "pass",
                            "discard",
                            "respond"
                        ],
                        "type": "str"
                    },
                    "malformed-header-contact": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "pass",
                            "discard",
                            "respond"
                        ],
                        "type": "str"
                    },
                    "malformed-header-content-length": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "pass",
                            "discard",
                            "respond"
                        ],
                        "type": "str"
                    },
                    "malformed-header-content-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "pass",
                            "discard",
                            "respond"
                        ],
                        "type": "str"
                    },
                    "malformed-header-cseq": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "pass",
                            "discard",
                            "respond"
                        ],
                        "type": "str"
                    },
                    "malformed-header-expires": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "pass",
                            "discard",
                            "respond"
                        ],
                        "type": "str"
                    },
                    "malformed-header-from": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "pass",
                            "discard",
                            "respond"
                        ],
                        "type": "str"
                    },
                    "malformed-header-max-forwards": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "pass",
                            "discard",
                            "respond"
                        ],
                        "type": "str"
                    },
                    "malformed-header-p-asserted-identity": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "pass",
                            "discard",
                            "respond"
                        ],
                        "type": "str"
                    },
                    "malformed-header-rack": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "pass",
                            "discard",
                            "respond"
                        ],
                        "type": "str"
                    },
                    "malformed-header-record-route": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "pass",
                            "discard",
                            "respond"
                        ],
                        "type": "str"
                    },
                    "malformed-header-route": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "pass",
                            "discard",
                            "respond"
                        ],
                        "type": "str"
                    },
                    "malformed-header-rseq": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "pass",
                            "discard",
                            "respond"
                        ],
                        "type": "str"
                    },
                    "malformed-header-sdp-a": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "pass",
                            "discard",
                            "respond"
                        ],
                        "type": "str"
                    },
                    "malformed-header-sdp-b": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "pass",
                            "discard",
                            "respond"
                        ],
                        "type": "str"
                    },
                    "malformed-header-sdp-c": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "pass",
                            "discard",
                            "respond"
                        ],
                        "type": "str"
                    },
                    "malformed-header-sdp-i": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "pass",
                            "discard",
                            "respond"
                        ],
                        "type": "str"
                    },
                    "malformed-header-sdp-k": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "pass",
                            "discard",
                            "respond"
                        ],
                        "type": "str"
                    },
                    "malformed-header-sdp-m": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "pass",
                            "discard",
                            "respond"
                        ],
                        "type": "str"
                    },
                    "malformed-header-sdp-o": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "pass",
                            "discard",
                            "respond"
                        ],
                        "type": "str"
                    },
                    "malformed-header-sdp-r": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "pass",
                            "discard",
                            "respond"
                        ],
                        "type": "str"
                    },
                    "malformed-header-sdp-s": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "pass",
                            "discard",
                            "respond"
                        ],
                        "type": "str"
                    },
                    "malformed-header-sdp-t": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "pass",
                            "discard",
                            "respond"
                        ],
                        "type": "str"
                    },
                    "malformed-header-sdp-v": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "pass",
                            "discard",
                            "respond"
                        ],
                        "type": "str"
                    },
                    "malformed-header-sdp-z": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "pass",
                            "discard",
                            "respond"
                        ],
                        "type": "str"
                    },
                    "malformed-header-to": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "pass",
                            "discard",
                            "respond"
                        ],
                        "type": "str"
                    },
                    "malformed-header-via": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "pass",
                            "discard",
                            "respond"
                        ],
                        "type": "str"
                    },
                    "malformed-request-line": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "pass",
                            "discard",
                            "respond"
                        ],
                        "type": "str"
                    },
                    "max-body-length": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "max-dialogs": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "max-idle-dialogs": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "max-line-length": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "message-rate": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "nat-port-range": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "nat-trace": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "no-sdp-fixup": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "notify-rate": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "open-contact-pinhole": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "open-record-route-pinhole": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "open-register-pinhole": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "open-via-pinhole": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "options-rate": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "prack-rate": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "preserve-override": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "provisional-invite-expiry-time": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "publish-rate": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "refer-rate": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "register-contact-trace": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "register-rate": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "rfc2543-branch": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "rtp": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ssl-algorithm": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "high",
                            "medium",
                            "low"
                        ],
                        "type": "str"
                    },
                    "ssl-auth-client": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ssl-auth-server": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ssl-client-certificate": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ssl-client-renegotiation": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "deny",
                            "secure"
                        ],
                        "type": "str"
                    },
                    "ssl-max-version": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ssl-3.0",
                            "tls-1.0",
                            "tls-1.1",
                            "tls-1.2",
                            "tls-1.3"
                        ],
                        "type": "str"
                    },
                    "ssl-min-version": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ssl-3.0",
                            "tls-1.0",
                            "tls-1.1",
                            "tls-1.2",
                            "tls-1.3"
                        ],
                        "type": "str"
                    },
                    "ssl-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "off",
                            "full"
                        ],
                        "type": "str"
                    },
                    "ssl-pfs": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "require",
                            "deny",
                            "allow"
                        ],
                        "type": "str"
                    },
                    "ssl-send-empty-frags": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ssl-server-certificate": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "strict-register": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "subscribe-rate": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "unknown-header": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "pass",
                            "discard",
                            "respond"
                        ],
                        "type": "str"
                    },
                    "update-rate": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ack-rate-track": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "src-ip",
                            "dest-ip"
                        ],
                        "type": "str"
                    },
                    "bye-rate-track": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "src-ip",
                            "dest-ip"
                        ],
                        "type": "str"
                    },
                    "cancel-rate-track": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "src-ip",
                            "dest-ip"
                        ],
                        "type": "str"
                    },
                    "info-rate-track": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "src-ip",
                            "dest-ip"
                        ],
                        "type": "str"
                    },
                    "invite-rate-track": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "src-ip",
                            "dest-ip"
                        ],
                        "type": "str"
                    },
                    "malformed-header-no-proxy-require": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "pass",
                            "discard",
                            "respond"
                        ],
                        "type": "str"
                    },
                    "malformed-header-no-require": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "pass",
                            "discard",
                            "respond"
                        ],
                        "type": "str"
                    },
                    "message-rate-track": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "src-ip",
                            "dest-ip"
                        ],
                        "type": "str"
                    },
                    "notify-rate-track": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "src-ip",
                            "dest-ip"
                        ],
                        "type": "str"
                    },
                    "options-rate-track": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "src-ip",
                            "dest-ip"
                        ],
                        "type": "str"
                    },
                    "prack-rate-track": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "src-ip",
                            "dest-ip"
                        ],
                        "type": "str"
                    },
                    "publish-rate-track": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "src-ip",
                            "dest-ip"
                        ],
                        "type": "str"
                    },
                    "refer-rate-track": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "src-ip",
                            "dest-ip"
                        ],
                        "type": "str"
                    },
                    "register-rate-track": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "src-ip",
                            "dest-ip"
                        ],
                        "type": "str"
                    },
                    "subscribe-rate-track": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "src-ip",
                            "dest-ip"
                        ],
                        "type": "str"
                    },
                    "update-rate-track": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "src-ip",
                            "dest-ip"
                        ],
                        "type": "str"
                    },
                    "call-id-regex": {
                        "required": false,
                        "revision": {
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "content-type-regex": {
                        "required": false,
                        "revision": {
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                }
            },
            "feature-set": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "flow",
                    "proxy",
                    "ips",
                    "voipd"
                ],
                "type": "str"
            },
            "msrp": {
                "required": false,
                "type": "dict",
                "options": {
                    "log-violations": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "max-msg-size": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "max-msg-size-action": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "pass",
                            "block",
                            "reset",
                            "monitor"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            }
        }
    },
    "voip_profile_msrp": {
        "stated": false,
        "options": {
            "log-violations": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "max-msg-size": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "max-msg-size-action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "block",
                    "reset",
                    "monitor"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "voip_profile_sccp": {
        "stated": false,
        "options": {
            "block-mcast": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "log-call-summary": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "log-violations": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "max-calls": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "verify-header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "voip_profile_sip": {
        "stated": false,
        "options": {
            "ack-rate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "block-ack": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "block-bye": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "block-cancel": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "block-geo-red-options": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "block-info": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "block-invite": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "block-long-lines": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "block-message": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "block-notify": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "block-options": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "block-prack": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "block-publish": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "block-refer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "block-register": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "block-subscribe": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "block-unknown": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "block-update": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "bye-rate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "call-keepalive": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "cancel-rate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "contact-fixup": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "hnt-restrict-source-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "hosted-nat-traversal": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "info-rate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "invite-rate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ips-rtp": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "log-call-summary": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "log-violations": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "malformed-header-allow": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "discard",
                    "respond"
                ],
                "type": "str"
            },
            "malformed-header-call-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "discard",
                    "respond"
                ],
                "type": "str"
            },
            "malformed-header-contact": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "discard",
                    "respond"
                ],
                "type": "str"
            },
            "malformed-header-content-length": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "discard",
                    "respond"
                ],
                "type": "str"
            },
            "malformed-header-content-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "discard",
                    "respond"
                ],
                "type": "str"
            },
            "malformed-header-cseq": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "discard",
                    "respond"
                ],
                "type": "str"
            },
            "malformed-header-expires": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "discard",
                    "respond"
                ],
                "type": "str"
            },
            "malformed-header-from": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "discard",
                    "respond"
                ],
                "type": "str"
            },
            "malformed-header-max-forwards": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "discard",
                    "respond"
                ],
                "type": "str"
            },
            "malformed-header-p-asserted-identity": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "discard",
                    "respond"
                ],
                "type": "str"
            },
            "malformed-header-rack": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "discard",
                    "respond"
                ],
                "type": "str"
            },
            "malformed-header-record-route": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "discard",
                    "respond"
                ],
                "type": "str"
            },
            "malformed-header-route": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "discard",
                    "respond"
                ],
                "type": "str"
            },
            "malformed-header-rseq": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "discard",
                    "respond"
                ],
                "type": "str"
            },
            "malformed-header-sdp-a": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "discard",
                    "respond"
                ],
                "type": "str"
            },
            "malformed-header-sdp-b": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "discard",
                    "respond"
                ],
                "type": "str"
            },
            "malformed-header-sdp-c": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "discard",
                    "respond"
                ],
                "type": "str"
            },
            "malformed-header-sdp-i": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "discard",
                    "respond"
                ],
                "type": "str"
            },
            "malformed-header-sdp-k": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "discard",
                    "respond"
                ],
                "type": "str"
            },
            "malformed-header-sdp-m": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "discard",
                    "respond"
                ],
                "type": "str"
            },
            "malformed-header-sdp-o": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "discard",
                    "respond"
                ],
                "type": "str"
            },
            "malformed-header-sdp-r": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "discard",
                    "respond"
                ],
                "type": "str"
            },
            "malformed-header-sdp-s": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "discard",
                    "respond"
                ],
                "type": "str"
            },
            "malformed-header-sdp-t": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "discard",
                    "respond"
                ],
                "type": "str"
            },
            "malformed-header-sdp-v": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "discard",
                    "respond"
                ],
                "type": "str"
            },
            "malformed-header-sdp-z": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "discard",
                    "respond"
                ],
                "type": "str"
            },
            "malformed-header-to": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "discard",
                    "respond"
                ],
                "type": "str"
            },
            "malformed-header-via": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "discard",
                    "respond"
                ],
                "type": "str"
            },
            "malformed-request-line": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "discard",
                    "respond"
                ],
                "type": "str"
            },
            "max-body-length": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "max-dialogs": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "max-idle-dialogs": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "max-line-length": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "message-rate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "nat-trace": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "no-sdp-fixup": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "notify-rate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "open-contact-pinhole": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "open-record-route-pinhole": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "open-register-pinhole": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "open-via-pinhole": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "options-rate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "prack-rate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "preserve-override": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "provisional-invite-expiry-time": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "publish-rate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "refer-rate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "register-contact-trace": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "register-rate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "rfc2543-branch": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "rtp": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-algorithm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "high",
                    "medium",
                    "low"
                ],
                "type": "str"
            },
            "ssl-auth-client": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ssl-auth-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ssl-client-certificate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ssl-client-renegotiation": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny",
                    "secure"
                ],
                "type": "str"
            },
            "ssl-max-version": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ssl-3.0",
                    "tls-1.0",
                    "tls-1.1",
                    "tls-1.2",
                    "tls-1.3"
                ],
                "type": "str"
            },
            "ssl-min-version": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ssl-3.0",
                    "tls-1.0",
                    "tls-1.1",
                    "tls-1.2",
                    "tls-1.3"
                ],
                "type": "str"
            },
            "ssl-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "off",
                    "full"
                ],
                "type": "str"
            },
            "ssl-pfs": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "require",
                    "deny",
                    "allow"
                ],
                "type": "str"
            },
            "ssl-send-empty-frags": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-server-certificate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "strict-register": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "subscribe-rate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "unknown-header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "discard",
                    "respond"
                ],
                "type": "str"
            },
            "update-rate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "nat-port-range": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ack-rate-track": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "src-ip",
                    "dest-ip"
                ],
                "type": "str"
            },
            "bye-rate-track": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "src-ip",
                    "dest-ip"
                ],
                "type": "str"
            },
            "cancel-rate-track": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "src-ip",
                    "dest-ip"
                ],
                "type": "str"
            },
            "info-rate-track": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "src-ip",
                    "dest-ip"
                ],
                "type": "str"
            },
            "invite-rate-track": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "src-ip",
                    "dest-ip"
                ],
                "type": "str"
            },
            "malformed-header-no-proxy-require": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "discard",
                    "respond"
                ],
                "type": "str"
            },
            "malformed-header-no-require": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "discard",
                    "respond"
                ],
                "type": "str"
            },
            "message-rate-track": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "src-ip",
                    "dest-ip"
                ],
                "type": "str"
            },
            "notify-rate-track": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "src-ip",
                    "dest-ip"
                ],
                "type": "str"
            },
            "options-rate-track": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "src-ip",
                    "dest-ip"
                ],
                "type": "str"
            },
            "prack-rate-track": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "src-ip",
                    "dest-ip"
                ],
                "type": "str"
            },
            "publish-rate-track": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "src-ip",
                    "dest-ip"
                ],
                "type": "str"
            },
            "refer-rate-track": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "src-ip",
                    "dest-ip"
                ],
                "type": "str"
            },
            "register-rate-track": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "src-ip",
                    "dest-ip"
                ],
                "type": "str"
            },
            "subscribe-rate-track": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "src-ip",
                    "dest-ip"
                ],
                "type": "str"
            },
            "update-rate-track": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "src-ip",
                    "dest-ip"
                ],
                "type": "str"
            },
            "call-id-regex": {
                "required": false,
                "revision": {
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "content-type-regex": {
                "required": false,
                "revision": {
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "vpn_certificate_ca": {
        "stated": true,
        "options": {
            "_private_key": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "str"
            },
            "auto-update-days": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "auto-update-days-warning": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ca": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "last-updated": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "range": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "global",
                    "vdom"
                ],
                "type": "str"
            },
            "scep-url": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "source": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "factory",
                    "user",
                    "bundle",
                    "fortiguard"
                ],
                "type": "str"
            },
            "source-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "trusted": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-inspection-trusted": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ca-identifier": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "obsolete": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "est-url": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "vpn_certificate_ocspserver": {
        "stated": true,
        "options": {
            "cert": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "secondary-cert": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "secondary-url": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "source-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "unavail-action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "revoke",
                    "ignore"
                ],
                "type": "str"
            },
            "url": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "vpn_certificate_remote": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "range": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "global",
                    "vdom"
                ],
                "type": "str"
            },
            "remote": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "source": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "factory",
                    "user",
                    "bundle",
                    "fortiguard"
                ],
                "type": "str"
            }
        }
    },
    "vpn_ipsec_fec": {
        "stated": true,
        "options": {
            "mappings": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "bandwidth-bi-threshold": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "bandwidth-down-threshold": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "bandwidth-up-threshold": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "base": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "latency-threshold": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "packet-loss-threshold": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "redundant": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "seqno": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "vpn_ipsec_fec_mappings": {
        "stated": true,
        "options": {
            "bandwidth-bi-threshold": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "bandwidth-down-threshold": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "bandwidth-up-threshold": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "base": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "latency-threshold": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "packet-loss-threshold": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "redundant": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "seqno": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "vpn_ssl_settings": {
        "stated": false,
        "options": {
            "algorithm": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "default",
                    "high",
                    "low",
                    "medium"
                ],
                "type": "str"
            },
            "auth-session-check-source-ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "auth-timeout": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "authentication-rule": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "auth": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "any",
                            "local",
                            "radius",
                            "ldap",
                            "tacacs+",
                            "peer"
                        ],
                        "type": "str"
                    },
                    "cipher": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "any",
                            "high",
                            "medium"
                        ],
                        "type": "str"
                    },
                    "client-cert": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "groups": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "portal": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "realm": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "source-address": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "source-address-negate": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "source-address6": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "source-address6-negate": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "source-interface": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "user-peer": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "users": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    }
                },
                "elements": "dict"
            },
            "auto-tunnel-static-route": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "banned-cipher": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "RSA",
                    "DH",
                    "DHE",
                    "ECDH",
                    "ECDHE",
                    "DSS",
                    "ECDSA",
                    "AES",
                    "AESGCM",
                    "CAMELLIA",
                    "3DES",
                    "SHA1",
                    "SHA256",
                    "SHA384",
                    "STATIC",
                    "CHACHA20",
                    "ARIA",
                    "AESCCM"
                ],
                "elements": "str"
            },
            "check-referer": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "default-portal": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "deflate-compression-level": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "deflate-min-data-size": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "dns-server1": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dns-server2": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dns-suffix": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dtls-hello-timeout": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "dtls-max-proto-ver": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "dtls1-0",
                    "dtls1-2"
                ],
                "type": "str"
            },
            "dtls-min-proto-ver": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "dtls1-0",
                    "dtls1-2"
                ],
                "type": "str"
            },
            "dtls-tunnel": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "encode-2f-sequence": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "encrypt-and-store-password": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "force-two-factor-auth": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "header-x-forwarded-for": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "add",
                    "remove"
                ],
                "type": "str"
            },
            "hsts-include-subdomains": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "http-compression": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "http-only-cookie": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "http-request-body-timeout": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "http-request-header-timeout": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "https-redirect": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "idle-timeout": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ipv6-dns-server1": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipv6-dns-server2": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipv6-wins-server1": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipv6-wins-server2": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "login-attempt-limit": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "login-block-time": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "login-timeout": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "port-precedence": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "reqclientcert": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "route-source-interface": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "servercert": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "source-address": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "source-address-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "source-address6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "source-address6-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "source-interface": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ssl-client-renegotiation": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-insert-empty-fragment": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-max-proto-ver": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "tls1-0",
                    "tls1-1",
                    "tls1-2",
                    "tls1-3"
                ],
                "type": "str"
            },
            "ssl-min-proto-ver": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "tls1-0",
                    "tls1-1",
                    "tls1-2",
                    "tls1-3"
                ],
                "type": "str"
            },
            "tlsv1-0": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tlsv1-1": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tlsv1-2": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tlsv1-3": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "transform-backward-slashes": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tunnel-connect-without-reauth": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tunnel-ip-pools": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "tunnel-ipv6-pools": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "tunnel-user-session-timeout": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "unsafe-legacy-renegotiation": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "url-obscuration": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "user-peer": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "wins-server1": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "wins-server2": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "x-content-type-options": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sslv3": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-big-buffer": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "client-sigalgs": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "no-rsa-pss",
                    "all"
                ],
                "type": "str"
            },
            "ciphersuite": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "TLS-AES-128-GCM-SHA256",
                    "TLS-AES-256-GCM-SHA384",
                    "TLS-CHACHA20-POLY1305-SHA256",
                    "TLS-AES-128-CCM-SHA256",
                    "TLS-AES-128-CCM-8-SHA256"
                ],
                "elements": "str"
            },
            "dual-stack-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tunnel-addr-assigned-method": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "first-available",
                    "round-robin"
                ],
                "type": "str"
            },
            "browser-language-detection": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "saml-redirect-port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "web-mode-snat": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": false,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ztna-trusted-client": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dtls-heartbeat-fail-count": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "dtls-heartbeat-idle-timeout": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "dtls-heartbeat-interval": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "server-hostname": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "vpn_ssl_settings_authenticationrule": {
        "stated": true,
        "options": {
            "auth": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "any",
                    "local",
                    "radius",
                    "ldap",
                    "tacacs+",
                    "peer"
                ],
                "type": "str"
            },
            "cipher": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "any",
                    "high",
                    "medium"
                ],
                "type": "str"
            },
            "client-cert": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "groups": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "portal": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "realm": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "source-address": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "source-address-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "source-address6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "source-address6-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "source-interface": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "user-peer": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "users": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "vpnmgr_node": {
        "stated": true,
        "options": {
            "add-route": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "assign-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "assign-ip-from": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "range",
                    "usrgrp",
                    "dhcp",
                    "name"
                ],
                "type": "str"
            },
            "authpasswd": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "authusr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "authusrgrp": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "auto-configuration": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "automatic_routing": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "banner": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "default-gateway": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dhcp-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dns-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auto",
                    "manual"
                ],
                "type": "str"
            },
            "dns-service": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "default",
                    "specify",
                    "local"
                ],
                "type": "str"
            },
            "domain": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "extgw": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "extgw_hubip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "extgw_p2_per_net": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "extgwip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "hub_iface": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "iface": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ip-range": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "end-ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "start-ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "ipsec-lease-hold": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ipv4-dns-server1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipv4-dns-server2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipv4-dns-server3": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipv4-end-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipv4-exclude-range": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "end-ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "start-ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "ipv4-netmask": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipv4-split-include": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipv4-start-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipv4-wins-server1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipv4-wins-server2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "local-gw": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "localid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "mode-cfg": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mode-cfg-ip-version": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "4",
                    "6"
                ],
                "type": "str"
            },
            "net-device": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "peer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "peergrp": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "peerid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "peertype": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "any",
                    "one",
                    "dialup",
                    "peer",
                    "peergrp"
                ],
                "type": "str"
            },
            "protected_subnet": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "addr": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "seq": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "public-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "role": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "hub",
                    "spoke"
                ],
                "type": "str"
            },
            "route-overlap": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "use-old",
                    "use-new",
                    "allow"
                ],
                "type": "str"
            },
            "spoke-zone": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "summary_addr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "addr": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "priority": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "seq": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "tunnel-search": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "selectors",
                    "nexthop"
                ],
                "type": "str"
            },
            "unity-support": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "usrgrp": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vpn-interface-priority": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "vpn-zone": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "vpntable": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "xauthtype": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "client",
                    "pap",
                    "chap",
                    "auto"
                ],
                "type": "str"
            },
            "exchange-interface-ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "hub-public-ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipv4-split-exclude": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "scope member": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vdom": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "dhcp-ra-giaddr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "encapsulation": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "tunnel-mode",
                    "transport-mode"
                ],
                "type": "str"
            },
            "ipv4-name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "l2tp": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "auto-discovery-receiver": {
                "required": false,
                "revision": {
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "auto-discovery-sender": {
                "required": false,
                "revision": {
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "network-id": {
                "required": false,
                "revision": {
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "network-overlay": {
                "required": false,
                "revision": {
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "enable",
                    "disable"
                ],
                "type": "str"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "vpnmgr_node_iprange": {
        "stated": true,
        "options": {
            "end-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "start-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "vpnmgr_node_ipv4excluderange": {
        "stated": true,
        "options": {
            "end-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "start-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "vpnmgr_node_protectedsubnet": {
        "stated": true,
        "options": {
            "addr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "seq": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "vpnmgr_node_summaryaddr": {
        "stated": true,
        "options": {
            "addr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "priority": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "seq": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "vpnmgr_vpntable": {
        "stated": true,
        "options": {
            "authmethod": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "psk",
                    "rsa-signature",
                    "signature"
                ],
                "type": "str"
            },
            "auto-zone-policy": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "certificate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "description": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dpd": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "on-idle",
                    "on-demand"
                ],
                "type": "str"
            },
            "dpd-retrycount": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "dpd-retryinterval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "fcc-enforcement": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "hub2spoke-zone": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ike-version": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "1",
                    "2"
                ],
                "type": "str"
            },
            "ike1dhgroup": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "1",
                    "2",
                    "5",
                    "14",
                    "15",
                    "16",
                    "17",
                    "18",
                    "19",
                    "20",
                    "21",
                    "27",
                    "28",
                    "29",
                    "30",
                    "31",
                    "32"
                ],
                "elements": "str"
            },
            "ike1dpd": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ike1keylifesec": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "int"
            },
            "ike1localid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ike1mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "main",
                    "aggressive"
                ],
                "type": "str"
            },
            "ike1natkeepalive": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ike1nattraversal": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "forced"
                ],
                "type": "str"
            },
            "ike1proposal": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "des-md5",
                    "des-sha1",
                    "3des-md5",
                    "3des-sha1",
                    "aes128-md5",
                    "aes128-sha1",
                    "aes192-md5",
                    "aes192-sha1",
                    "aes256-md5",
                    "aes256-sha1",
                    "des-sha256",
                    "3des-sha256",
                    "aes128-sha256",
                    "aes192-sha256",
                    "aes256-sha256",
                    "des-sha384",
                    "des-sha512",
                    "3des-sha384",
                    "3des-sha512",
                    "aes128-sha384",
                    "aes128-sha512",
                    "aes192-sha384",
                    "aes192-sha512",
                    "aes256-sha384",
                    "aes256-sha512",
                    "aria128-md5",
                    "aria128-sha1",
                    "aria128-sha256",
                    "aria128-sha384",
                    "aria128-sha512",
                    "aria192-md5",
                    "aria192-sha1",
                    "aria192-sha256",
                    "aria192-sha384",
                    "aria192-sha512",
                    "aria256-md5",
                    "aria256-sha1",
                    "aria256-sha256",
                    "aria256-sha384",
                    "aria256-sha512",
                    "seed-md5",
                    "seed-sha1",
                    "seed-sha256",
                    "seed-sha384",
                    "seed-sha512",
                    "aes128gcm-prfsha1",
                    "aes128gcm-prfsha256",
                    "aes128gcm-prfsha384",
                    "aes128gcm-prfsha512",
                    "aes256gcm-prfsha1",
                    "aes256gcm-prfsha256",
                    "aes256gcm-prfsha384",
                    "aes256gcm-prfsha512",
                    "chacha20poly1305-prfsha1",
                    "chacha20poly1305-prfsha256",
                    "chacha20poly1305-prfsha384",
                    "chacha20poly1305-prfsha512"
                ],
                "type": "str"
            },
            "ike2autonego": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ike2dhgroup": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "1",
                    "2",
                    "5",
                    "14",
                    "15",
                    "16",
                    "17",
                    "18",
                    "19",
                    "20",
                    "21",
                    "27",
                    "28",
                    "29",
                    "30",
                    "31",
                    "32"
                ],
                "elements": "str"
            },
            "ike2keepalive": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ike2keylifekbs": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "int"
            },
            "ike2keylifesec": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "int"
            },
            "ike2keylifetype": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "seconds",
                    "kbs",
                    "both"
                ],
                "type": "str"
            },
            "ike2proposal": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "null-md5",
                    "null-sha1",
                    "des-null",
                    "3des-null",
                    "des-md5",
                    "des-sha1",
                    "3des-md5",
                    "3des-sha1",
                    "aes128-md5",
                    "aes128-sha1",
                    "aes192-md5",
                    "aes192-sha1",
                    "aes256-md5",
                    "aes256-sha1",
                    "aes128-null",
                    "aes192-null",
                    "aes256-null",
                    "null-sha256",
                    "des-sha256",
                    "3des-sha256",
                    "aes128-sha256",
                    "aes192-sha256",
                    "aes256-sha256",
                    "des-sha384",
                    "des-sha512",
                    "3des-sha384",
                    "3des-sha512",
                    "aes128-sha384",
                    "aes128-sha512",
                    "aes192-sha384",
                    "aes192-sha512",
                    "aes256-sha384",
                    "aes256-sha512",
                    "null-sha384",
                    "null-sha512",
                    "aria128-null",
                    "aria128-md5",
                    "aria128-sha1",
                    "aria128-sha256",
                    "aria128-sha384",
                    "aria128-sha512",
                    "aria192-null",
                    "aria192-md5",
                    "aria192-sha1",
                    "aria192-sha256",
                    "aria192-sha384",
                    "aria192-sha512",
                    "aria256-null",
                    "aria256-md5",
                    "aria256-sha1",
                    "aria256-sha256",
                    "aria256-sha384",
                    "aria256-sha512",
                    "seed-null",
                    "seed-md5",
                    "seed-sha1",
                    "seed-sha256",
                    "seed-sha384",
                    "seed-sha512",
                    "aes128gcm",
                    "aes256gcm",
                    "chacha20poly1305"
                ],
                "type": "str"
            },
            "inter-vdom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "intf-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "off",
                    "on"
                ],
                "type": "str"
            },
            "localid-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auto",
                    "fqdn",
                    "user-fqdn",
                    "keyid",
                    "address",
                    "asn1dn"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "negotiate-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "npu-offload": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "pfs": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "psk-auto-generate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "psksecret": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "replay": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "rsa-certificate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "spoke2hub-zone": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "topology": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "meshed",
                    "star",
                    "dialup"
                ],
                "type": "str"
            },
            "vpn-zone": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "network-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "network-overlay": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "vpnsslweb_hostchecksoftware": {
        "stated": true,
        "options": {
            "check-item-list": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "deny",
                            "require"
                        ],
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "md5s": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "target": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "file",
                            "registry",
                            "process"
                        ],
                        "type": "str"
                    },
                    "version": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "guid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "os-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "macos",
                    "windows"
                ],
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "av",
                    "fw"
                ],
                "type": "str"
            },
            "version": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "vpnsslweb_hostchecksoftware_checkitemlist": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "deny",
                    "require"
                ],
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "md5s": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "target": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "file",
                    "registry",
                    "process"
                ],
                "type": "str"
            },
            "version": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "vpnsslweb_portal": {
        "stated": true,
        "options": {
            "allow-user-access": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "web",
                    "ftp",
                    "telnet",
                    "smb",
                    "vnc",
                    "rdp",
                    "ssh",
                    "ping",
                    "citrix",
                    "portforward",
                    "sftp"
                ],
                "elements": "str"
            },
            "auto-connect": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "bookmark-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "bookmarks": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "additional-params": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "apptype": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "web",
                                    "telnet",
                                    "ssh",
                                    "ftp",
                                    "smb",
                                    "vnc",
                                    "rdp",
                                    "citrix",
                                    "rdpnative",
                                    "portforward",
                                    "sftp"
                                ],
                                "type": "str"
                            },
                            "description": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "folder": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "form-data": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "options": {
                                    "name": {
                                        "required": false,
                                        "revision": {
                                            "6.0.0": true,
                                            "6.2.0": true,
                                            "6.2.1": true,
                                            "6.2.2": true,
                                            "6.2.3": true,
                                            "6.2.5": true,
                                            "6.2.6": true,
                                            "6.2.7": true,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.0": true,
                                            "6.4.1": true,
                                            "6.4.2": true,
                                            "6.4.3": true,
                                            "6.4.4": true,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    },
                                    "value": {
                                        "required": false,
                                        "revision": {
                                            "6.0.0": true,
                                            "6.2.0": true,
                                            "6.2.1": true,
                                            "6.2.2": true,
                                            "6.2.3": true,
                                            "6.2.5": true,
                                            "6.2.6": true,
                                            "6.2.7": true,
                                            "6.2.8": true,
                                            "6.2.9": true,
                                            "6.2.10": true,
                                            "6.2.11": true,
                                            "6.2.12": true,
                                            "6.4.0": true,
                                            "6.4.1": true,
                                            "6.4.2": true,
                                            "6.4.3": true,
                                            "6.4.4": true,
                                            "6.4.5": true,
                                            "6.4.6": true,
                                            "6.4.7": true,
                                            "6.4.8": true,
                                            "6.4.9": true,
                                            "6.4.10": true,
                                            "6.4.11": true,
                                            "6.4.12": true,
                                            "6.4.13": true,
                                            "7.0.0": true,
                                            "7.0.1": true,
                                            "7.0.2": true,
                                            "7.0.3": true,
                                            "7.0.4": true,
                                            "7.0.5": true,
                                            "7.0.6": true,
                                            "7.0.7": true,
                                            "7.0.8": true,
                                            "7.0.9": true,
                                            "7.2.0": true,
                                            "7.2.1": true,
                                            "7.2.2": true,
                                            "7.2.3": true,
                                            "7.2.4": true,
                                            "7.4.0": true,
                                            "7.4.1": true
                                        },
                                        "type": "str"
                                    }
                                },
                                "elements": "dict"
                            },
                            "host": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "listening-port": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "load-balancing-info": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "logon-password": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "no_log": true,
                                "type": "raw"
                            },
                            "logon-user": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "port": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "preconnection-blob": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "preconnection-id": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "remote-port": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "security": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "rdp",
                                    "nla",
                                    "tls",
                                    "any"
                                ],
                                "type": "str"
                            },
                            "server-layout": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "en-us-qwerty",
                                    "de-de-qwertz",
                                    "fr-fr-azerty",
                                    "it-it-qwerty",
                                    "sv-se-qwerty",
                                    "failsafe",
                                    "en-gb-qwerty",
                                    "es-es-qwerty",
                                    "fr-ch-qwertz",
                                    "ja-jp-qwerty",
                                    "pt-br-qwerty",
                                    "tr-tr-qwerty",
                                    "fr-ca-qwerty"
                                ],
                                "type": "str"
                            },
                            "show-status-window": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "sso": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "static",
                                    "auto"
                                ],
                                "type": "str"
                            },
                            "sso-credential": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "sslvpn-login",
                                    "alternative"
                                ],
                                "type": "str"
                            },
                            "sso-credential-sent-once": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "sso-password": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "no_log": true,
                                "type": "raw"
                            },
                            "sso-username": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "url": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "domain": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "color-depth": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "8",
                                    "16",
                                    "32"
                                ],
                                "type": "str"
                            },
                            "height": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": false,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "keyboard-layout": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "ar",
                                    "da",
                                    "de",
                                    "de-ch",
                                    "en-gb",
                                    "en-uk",
                                    "en-us",
                                    "es",
                                    "fi",
                                    "fr",
                                    "fr-be",
                                    "fr-ca",
                                    "fr-ch",
                                    "hr",
                                    "hu",
                                    "it",
                                    "ja",
                                    "lt",
                                    "lv",
                                    "mk",
                                    "no",
                                    "pl",
                                    "pt",
                                    "pt-br",
                                    "ru",
                                    "sl",
                                    "sv",
                                    "tk",
                                    "tr",
                                    "fr-ca-m",
                                    "wg",
                                    "ar-101",
                                    "ar-102",
                                    "ar-102-azerty",
                                    "can-mul",
                                    "cz",
                                    "cz-qwerty",
                                    "cz-pr",
                                    "nl",
                                    "de-ibm",
                                    "en-uk-ext",
                                    "en-us-dvorak",
                                    "es-var",
                                    "fi-sami",
                                    "hu-101",
                                    "it-142",
                                    "ko",
                                    "lt-ibm",
                                    "lt-std",
                                    "lav-std",
                                    "lav-leg",
                                    "mk-std",
                                    "no-sami",
                                    "pol-214",
                                    "pol-pr",
                                    "pt-br-abnt2",
                                    "ru-mne",
                                    "ru-t",
                                    "sv-sami",
                                    "tuk",
                                    "tur-f",
                                    "tur-q",
                                    "zh-sym-sg-us",
                                    "zh-sym-us",
                                    "zh-tr-hk",
                                    "zh-tr-mo",
                                    "zh-tr-us",
                                    "fr-apple",
                                    "la-am"
                                ],
                                "type": "str"
                            },
                            "restricted-admin": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "send-preconnection-id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "width": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": false,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "vnc-keyboard-layout": {
                                "required": false,
                                "revision": {
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "da",
                                    "de",
                                    "de-ch",
                                    "en-uk",
                                    "es",
                                    "fi",
                                    "fr",
                                    "fr-be",
                                    "it",
                                    "no",
                                    "pt",
                                    "sv",
                                    "nl",
                                    "en-uk-ext",
                                    "it-142",
                                    "pt-br-abnt2",
                                    "default",
                                    "fr-ca-mul",
                                    "gd",
                                    "us-intl"
                                ],
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "custom-lang": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "customize-forticlient-download-url": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "display-bookmark": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "display-connection-tools": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "display-history": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "display-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dns-server1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dns-server2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dns-suffix": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "exclusive-routing": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "forticlient-download": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "forticlient-download-method": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "direct",
                    "ssl-vpn"
                ],
                "type": "str"
            },
            "heading": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "hide-sso-credential": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "host-check": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "av",
                    "fw",
                    "av-fw",
                    "custom"
                ],
                "type": "str"
            },
            "host-check-interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "host-check-policy": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ip-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "range",
                    "user-group",
                    "dhcp",
                    "no-ip"
                ],
                "type": "str"
            },
            "ip-pools": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ipv6-dns-server1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipv6-dns-server2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipv6-exclusive-routing": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ipv6-pools": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ipv6-service-restriction": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ipv6-split-tunneling": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ipv6-split-tunneling-routing-address": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ipv6-tunnel-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ipv6-wins-server1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipv6-wins-server2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "keep-alive": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "limit-user-logins": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mac-addr-action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "deny",
                    "allow"
                ],
                "type": "str"
            },
            "mac-addr-check": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "mac-addr-check-rule": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "mac-addr-list": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "mac-addr-mask": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "macos-forticlient-download-url": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "os-check": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "redir-url": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "save-password": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "service-restriction": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "skip-check-for-unsupported-browser": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "skip-check-for-unsupported-os": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "smb-ntlmv1-auth": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "smbv1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "split-dns": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "dns-server1": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "dns-server2": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "domains": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ipv6-dns-server1": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ipv6-dns-server2": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "split-tunneling": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "split-tunneling-routing-address": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "theme": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "gray",
                    "blue",
                    "orange",
                    "crimson",
                    "steelblue",
                    "darkgrey",
                    "green",
                    "melongene",
                    "red",
                    "mariner",
                    "neutrino",
                    "jade",
                    "graphite",
                    "dark-matter",
                    "onyx",
                    "eclipse",
                    "jet-stream",
                    "security-fabric"
                ],
                "type": "str"
            },
            "tunnel-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "user-bookmark": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "user-group-bookmark": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "web-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "windows-forticlient-download-url": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "wins-server1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "wins-server2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "skip-check-for-browser": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "smb-max-version": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "smbv1",
                    "smbv2",
                    "smbv3"
                ],
                "type": "str"
            },
            "smb-min-version": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "smbv1",
                    "smbv2",
                    "smbv3"
                ],
                "type": "str"
            },
            "virtual-desktop-logout-when-browser-close": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "virtual-desktop-clipboard-share": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "virtual-desktop-desktop-switch": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "virtual-desktop": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "virtual-desktop-network-share-access": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "virtual-desktop-printing": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "virtual-desktop-app-list": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "virtual-desktop-removable-media-access": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "transform-backward-slashes": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ipv6-split-tunneling-routing-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "split-tunneling-routing-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "os-check-list": {
                "required": false,
                "type": "dict",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "check-up-to-date",
                            "deny"
                        ],
                        "type": "str"
                    },
                    "latest-patch-level": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "tolerance": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                }
            },
            "use-sdwan": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "prefer-ipv6-dns": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "rewrite-ip-uri-ui": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "clipboard": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "default-window-height": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "default-window-width": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "dhcp-ip-overlap": {
                "required": false,
                "revision": {
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "use-old",
                    "use-new"
                ],
                "type": "str"
            },
            "client-src-range": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dhcp-ra-giaddr": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dhcp6-ra-linkaddr": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "landing-page": {
                "required": false,
                "type": "dict",
                "options": {
                    "form-data": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "name": {
                                "required": false,
                                "revision": {
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "value": {
                                "required": false,
                                "revision": {
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "logout-url": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sso": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "static",
                            "auto"
                        ],
                        "type": "str"
                    },
                    "sso-credential": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "sslvpn-login",
                            "alternative"
                        ],
                        "type": "str"
                    },
                    "sso-password": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "sso-username": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "url": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                }
            },
            "landing-page-mode": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "default-protocol": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "web",
                    "ftp",
                    "telnet",
                    "smb",
                    "vnc",
                    "rdp",
                    "ssh",
                    "sftp"
                ],
                "type": "str"
            },
            "focus-bookmark": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "vpnsslweb_portal_bookmarkgroup": {
        "stated": true,
        "options": {
            "bookmarks": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "additional-params": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "apptype": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "web",
                            "telnet",
                            "ssh",
                            "ftp",
                            "smb",
                            "vnc",
                            "rdp",
                            "citrix",
                            "rdpnative",
                            "portforward",
                            "sftp"
                        ],
                        "type": "str"
                    },
                    "description": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "folder": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "form-data": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "value": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "host": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "listening-port": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "load-balancing-info": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "logon-password": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "logon-user": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "port": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "preconnection-blob": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "preconnection-id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "remote-port": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "security": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "rdp",
                            "nla",
                            "tls",
                            "any"
                        ],
                        "type": "str"
                    },
                    "server-layout": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "en-us-qwerty",
                            "de-de-qwertz",
                            "fr-fr-azerty",
                            "it-it-qwerty",
                            "sv-se-qwerty",
                            "failsafe",
                            "en-gb-qwerty",
                            "es-es-qwerty",
                            "fr-ch-qwertz",
                            "ja-jp-qwerty",
                            "pt-br-qwerty",
                            "tr-tr-qwerty",
                            "fr-ca-qwerty"
                        ],
                        "type": "str"
                    },
                    "show-status-window": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "sso": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "static",
                            "auto"
                        ],
                        "type": "str"
                    },
                    "sso-credential": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "sslvpn-login",
                            "alternative"
                        ],
                        "type": "str"
                    },
                    "sso-credential-sent-once": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "sso-password": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "sso-username": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "url": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "domain": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "color-depth": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "8",
                            "16",
                            "32"
                        ],
                        "type": "str"
                    },
                    "height": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "keyboard-layout": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ar",
                            "da",
                            "de",
                            "de-ch",
                            "en-gb",
                            "en-uk",
                            "en-us",
                            "es",
                            "fi",
                            "fr",
                            "fr-be",
                            "fr-ca",
                            "fr-ch",
                            "hr",
                            "hu",
                            "it",
                            "ja",
                            "lt",
                            "lv",
                            "mk",
                            "no",
                            "pl",
                            "pt",
                            "pt-br",
                            "ru",
                            "sl",
                            "sv",
                            "tk",
                            "tr",
                            "fr-ca-m",
                            "wg",
                            "ar-101",
                            "ar-102",
                            "ar-102-azerty",
                            "can-mul",
                            "cz",
                            "cz-qwerty",
                            "cz-pr",
                            "nl",
                            "de-ibm",
                            "en-uk-ext",
                            "en-us-dvorak",
                            "es-var",
                            "fi-sami",
                            "hu-101",
                            "it-142",
                            "ko",
                            "lt-ibm",
                            "lt-std",
                            "lav-std",
                            "lav-leg",
                            "mk-std",
                            "no-sami",
                            "pol-214",
                            "pol-pr",
                            "pt-br-abnt2",
                            "ru-mne",
                            "ru-t",
                            "sv-sami",
                            "tuk",
                            "tur-f",
                            "tur-q",
                            "zh-sym-sg-us",
                            "zh-sym-us",
                            "zh-tr-hk",
                            "zh-tr-mo",
                            "zh-tr-us",
                            "fr-apple",
                            "la-am"
                        ],
                        "type": "str"
                    },
                    "restricted-admin": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "send-preconnection-id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "width": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "vnc-keyboard-layout": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "da",
                            "de",
                            "de-ch",
                            "en-uk",
                            "es",
                            "fi",
                            "fr",
                            "fr-be",
                            "it",
                            "no",
                            "pt",
                            "sv",
                            "nl",
                            "en-uk-ext",
                            "it-142",
                            "pt-br-abnt2",
                            "default",
                            "fr-ca-mul",
                            "gd",
                            "us-intl"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "vpnsslweb_portal_bookmarkgroup_bookmarks": {
        "stated": true,
        "options": {
            "additional-params": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "apptype": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "web",
                    "telnet",
                    "ssh",
                    "ftp",
                    "smb",
                    "vnc",
                    "rdp",
                    "citrix",
                    "rdpnative",
                    "portforward",
                    "sftp"
                ],
                "type": "str"
            },
            "description": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "folder": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "form-data": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "value": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "host": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "listening-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "load-balancing-info": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "logon-password": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "logon-user": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "preconnection-blob": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "preconnection-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "remote-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "security": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "rdp",
                    "nla",
                    "tls",
                    "any"
                ],
                "type": "str"
            },
            "server-layout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "en-us-qwerty",
                    "de-de-qwertz",
                    "fr-fr-azerty",
                    "it-it-qwerty",
                    "sv-se-qwerty",
                    "failsafe",
                    "en-gb-qwerty",
                    "es-es-qwerty",
                    "fr-ch-qwertz",
                    "ja-jp-qwerty",
                    "pt-br-qwerty",
                    "tr-tr-qwerty",
                    "fr-ca-qwerty"
                ],
                "type": "str"
            },
            "show-status-window": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sso": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "static",
                    "auto"
                ],
                "type": "str"
            },
            "sso-credential": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "sslvpn-login",
                    "alternative"
                ],
                "type": "str"
            },
            "sso-credential-sent-once": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sso-password": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "sso-username": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "url": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "domain": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "color-depth": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "8",
                    "16",
                    "32"
                ],
                "type": "str"
            },
            "height": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "keyboard-layout": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ar",
                    "da",
                    "de",
                    "de-ch",
                    "en-gb",
                    "en-uk",
                    "en-us",
                    "es",
                    "fi",
                    "fr",
                    "fr-be",
                    "fr-ca",
                    "fr-ch",
                    "hr",
                    "hu",
                    "it",
                    "ja",
                    "lt",
                    "lv",
                    "mk",
                    "no",
                    "pl",
                    "pt",
                    "pt-br",
                    "ru",
                    "sl",
                    "sv",
                    "tk",
                    "tr",
                    "fr-ca-m",
                    "wg",
                    "ar-101",
                    "ar-102",
                    "ar-102-azerty",
                    "can-mul",
                    "cz",
                    "cz-qwerty",
                    "cz-pr",
                    "nl",
                    "de-ibm",
                    "en-uk-ext",
                    "en-us-dvorak",
                    "es-var",
                    "fi-sami",
                    "hu-101",
                    "it-142",
                    "ko",
                    "lt-ibm",
                    "lt-std",
                    "lav-std",
                    "lav-leg",
                    "mk-std",
                    "no-sami",
                    "pol-214",
                    "pol-pr",
                    "pt-br-abnt2",
                    "ru-mne",
                    "ru-t",
                    "sv-sami",
                    "tuk",
                    "tur-f",
                    "tur-q",
                    "zh-sym-sg-us",
                    "zh-sym-us",
                    "zh-tr-hk",
                    "zh-tr-mo",
                    "zh-tr-us",
                    "fr-apple",
                    "la-am"
                ],
                "type": "str"
            },
            "restricted-admin": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "send-preconnection-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "width": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "vnc-keyboard-layout": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "da",
                    "de",
                    "de-ch",
                    "en-uk",
                    "es",
                    "fi",
                    "fr",
                    "fr-be",
                    "it",
                    "no",
                    "pt",
                    "sv",
                    "nl",
                    "en-uk-ext",
                    "it-142",
                    "pt-br-abnt2",
                    "default",
                    "fr-ca-mul",
                    "gd",
                    "us-intl"
                ],
                "type": "str"
            }
        }
    },
    "vpnsslweb_portal_bookmarkgroup_bookmarks_formdata": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "value": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "vpnsslweb_portal_landingpage": {
        "stated": false,
        "options": {
            "form-data": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "value": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "logout-url": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sso": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "static",
                    "auto"
                ],
                "type": "str"
            },
            "sso-credential": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "sslvpn-login",
                    "alternative"
                ],
                "type": "str"
            },
            "sso-password": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "sso-username": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "url": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "vpnsslweb_portal_landingpage_formdata": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "value": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "vpnsslweb_portal_macaddrcheckrule": {
        "stated": true,
        "options": {
            "mac-addr-list": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "mac-addr-mask": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "vpnsslweb_portal_oschecklist": {
        "stated": false,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "check-up-to-date",
                    "deny"
                ],
                "type": "str"
            },
            "latest-patch-level": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tolerance": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "vpnsslweb_portal_splitdns": {
        "stated": true,
        "options": {
            "dns-server1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dns-server2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "domains": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ipv6-dns-server1": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipv6-dns-server2": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "vpnsslweb_realm": {
        "stated": true,
        "options": {
            "login-page": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "max-concurrent-user": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "url-path": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "virtual-host": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "nas-ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "radius-server": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "radius-port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "virtual-host-only": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "virtual-host-server-cert": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "vpnsslweb_virtualdesktopapplist": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "block",
                    "allow"
                ],
                "type": "str"
            },
            "apps": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "options": {
                    "md5s": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "raw"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": false,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "vpnsslweb_virtualdesktopapplist_apps": {
        "stated": true,
        "options": {
            "md5s": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "waf_mainclass": {
        "stated": true,
        "options": {
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "waf_profile": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "extended-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "external": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "url-access": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "access-pattern": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "id": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "negate": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "pattern": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "regex": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "srcaddr": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "bypass",
                            "permit",
                            "block"
                        ],
                        "type": "str"
                    },
                    "address": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "severity": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "low",
                            "medium",
                            "high"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "address-list": {
                "required": false,
                "type": "dict",
                "options": {
                    "blocked-address": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "blocked-log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "severity": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "low",
                            "medium",
                            "high"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "trusted-address": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    }
                }
            },
            "constraint": {
                "required": false,
                "type": "dict",
                "options": {
                    "content-length": {
                        "required": false,
                        "type": "dict",
                        "options": {
                            "action": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "allow",
                                    "block"
                                ],
                                "type": "str"
                            },
                            "length": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "log": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "severity": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "low",
                                    "medium",
                                    "high"
                                ],
                                "type": "str"
                            },
                            "status": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            }
                        }
                    },
                    "exception": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "address": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "content-length": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "header-length": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "hostname": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "line-length": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "malformed": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "max-cookie": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "max-header-line": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "max-range-segment": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "max-url-param": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "method": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "param-length": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "pattern": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "regex": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "url-param-length": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "version": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "header-length": {
                        "required": false,
                        "type": "dict",
                        "options": {
                            "action": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "allow",
                                    "block"
                                ],
                                "type": "str"
                            },
                            "length": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "log": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "severity": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "low",
                                    "medium",
                                    "high"
                                ],
                                "type": "str"
                            },
                            "status": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            }
                        }
                    },
                    "hostname": {
                        "required": false,
                        "type": "dict",
                        "options": {
                            "action": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "allow",
                                    "block"
                                ],
                                "type": "str"
                            },
                            "log": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "severity": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "low",
                                    "medium",
                                    "high"
                                ],
                                "type": "str"
                            },
                            "status": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            }
                        }
                    },
                    "line-length": {
                        "required": false,
                        "type": "dict",
                        "options": {
                            "action": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "allow",
                                    "block"
                                ],
                                "type": "str"
                            },
                            "length": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "log": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "severity": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "low",
                                    "medium",
                                    "high"
                                ],
                                "type": "str"
                            },
                            "status": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            }
                        }
                    },
                    "malformed": {
                        "required": false,
                        "type": "dict",
                        "options": {
                            "action": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "allow",
                                    "block"
                                ],
                                "type": "str"
                            },
                            "log": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "severity": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "low",
                                    "medium",
                                    "high"
                                ],
                                "type": "str"
                            },
                            "status": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            }
                        }
                    },
                    "max-cookie": {
                        "required": false,
                        "type": "dict",
                        "options": {
                            "action": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "allow",
                                    "block"
                                ],
                                "type": "str"
                            },
                            "log": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "max-cookie": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "severity": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "low",
                                    "medium",
                                    "high"
                                ],
                                "type": "str"
                            },
                            "status": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            }
                        }
                    },
                    "max-header-line": {
                        "required": false,
                        "type": "dict",
                        "options": {
                            "action": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "allow",
                                    "block"
                                ],
                                "type": "str"
                            },
                            "log": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "max-header-line": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "severity": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "low",
                                    "medium",
                                    "high"
                                ],
                                "type": "str"
                            },
                            "status": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            }
                        }
                    },
                    "max-range-segment": {
                        "required": false,
                        "type": "dict",
                        "options": {
                            "action": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "allow",
                                    "block"
                                ],
                                "type": "str"
                            },
                            "log": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "max-range-segment": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "severity": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "low",
                                    "medium",
                                    "high"
                                ],
                                "type": "str"
                            },
                            "status": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            }
                        }
                    },
                    "max-url-param": {
                        "required": false,
                        "type": "dict",
                        "options": {
                            "action": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "allow",
                                    "block"
                                ],
                                "type": "str"
                            },
                            "log": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "max-url-param": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "severity": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "low",
                                    "medium",
                                    "high"
                                ],
                                "type": "str"
                            },
                            "status": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            }
                        }
                    },
                    "method": {
                        "required": false,
                        "type": "dict",
                        "options": {
                            "action": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "allow",
                                    "block"
                                ],
                                "type": "str"
                            },
                            "log": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "severity": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "low",
                                    "medium",
                                    "high"
                                ],
                                "type": "str"
                            },
                            "status": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            }
                        }
                    },
                    "param-length": {
                        "required": false,
                        "type": "dict",
                        "options": {
                            "action": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "allow",
                                    "block"
                                ],
                                "type": "str"
                            },
                            "length": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "log": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "severity": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "low",
                                    "medium",
                                    "high"
                                ],
                                "type": "str"
                            },
                            "status": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            }
                        }
                    },
                    "url-param-length": {
                        "required": false,
                        "type": "dict",
                        "options": {
                            "action": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "allow",
                                    "block"
                                ],
                                "type": "str"
                            },
                            "length": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "log": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "severity": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "low",
                                    "medium",
                                    "high"
                                ],
                                "type": "str"
                            },
                            "status": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            }
                        }
                    },
                    "version": {
                        "required": false,
                        "type": "dict",
                        "options": {
                            "action": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "allow",
                                    "block"
                                ],
                                "type": "str"
                            },
                            "log": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "severity": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "low",
                                    "medium",
                                    "high"
                                ],
                                "type": "str"
                            },
                            "status": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            }
                        }
                    }
                }
            },
            "method": {
                "required": false,
                "type": "dict",
                "options": {
                    "default-allowed-methods": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "delete",
                            "get",
                            "head",
                            "options",
                            "post",
                            "put",
                            "trace",
                            "others",
                            "connect"
                        ],
                        "elements": "str"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "method-policy": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "address": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "allowed-methods": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "choices": [
                                    "delete",
                                    "get",
                                    "head",
                                    "options",
                                    "post",
                                    "put",
                                    "trace",
                                    "others",
                                    "connect"
                                ],
                                "elements": "str"
                            },
                            "id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "pattern": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "regex": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "severity": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "low",
                            "medium",
                            "high"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "signature": {
                "required": false,
                "type": "dict",
                "options": {
                    "credit-card-detection-threshold": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "custom-signature": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "action": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "allow",
                                    "block",
                                    "erase"
                                ],
                                "type": "str"
                            },
                            "case-sensitivity": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "direction": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "request",
                                    "response"
                                ],
                                "type": "str"
                            },
                            "log": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "pattern": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "severity": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "low",
                                    "medium",
                                    "high"
                                ],
                                "type": "str"
                            },
                            "status": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "target": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "choices": [
                                    "arg",
                                    "arg-name",
                                    "req-body",
                                    "req-cookie",
                                    "req-cookie-name",
                                    "req-filename",
                                    "req-header",
                                    "req-header-name",
                                    "req-raw-uri",
                                    "req-uri",
                                    "resp-body",
                                    "resp-hdr",
                                    "resp-status"
                                ],
                                "elements": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "disabled-signature": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "disabled-sub-class": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "main-class": {
                        "required": false,
                        "type": "dict",
                        "options": {
                            "action": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "allow",
                                    "block",
                                    "erase"
                                ],
                                "type": "str"
                            },
                            "id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "log": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "severity": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "low",
                                    "medium",
                                    "high"
                                ],
                                "type": "str"
                            },
                            "status": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            }
                        }
                    }
                }
            }
        }
    },
    "waf_profile_addresslist": {
        "stated": false,
        "options": {
            "blocked-address": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "blocked-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "severity": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "low",
                    "medium",
                    "high"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "trusted-address": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "waf_profile_constraint": {
        "stated": false,
        "options": {
            "content-length": {
                "required": false,
                "type": "dict",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block"
                        ],
                        "type": "str"
                    },
                    "length": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "severity": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "low",
                            "medium",
                            "high"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "exception": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "address": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "content-length": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "header-length": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "hostname": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "line-length": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "malformed": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "max-cookie": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "max-header-line": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "max-range-segment": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "max-url-param": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "method": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "param-length": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "pattern": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "regex": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "url-param-length": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "version": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "header-length": {
                "required": false,
                "type": "dict",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block"
                        ],
                        "type": "str"
                    },
                    "length": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "severity": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "low",
                            "medium",
                            "high"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "hostname": {
                "required": false,
                "type": "dict",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block"
                        ],
                        "type": "str"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "severity": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "low",
                            "medium",
                            "high"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "line-length": {
                "required": false,
                "type": "dict",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block"
                        ],
                        "type": "str"
                    },
                    "length": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "severity": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "low",
                            "medium",
                            "high"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "malformed": {
                "required": false,
                "type": "dict",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block"
                        ],
                        "type": "str"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "severity": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "low",
                            "medium",
                            "high"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "max-cookie": {
                "required": false,
                "type": "dict",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block"
                        ],
                        "type": "str"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "max-cookie": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "severity": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "low",
                            "medium",
                            "high"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "max-header-line": {
                "required": false,
                "type": "dict",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block"
                        ],
                        "type": "str"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "max-header-line": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "severity": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "low",
                            "medium",
                            "high"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "max-range-segment": {
                "required": false,
                "type": "dict",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block"
                        ],
                        "type": "str"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "max-range-segment": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "severity": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "low",
                            "medium",
                            "high"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "max-url-param": {
                "required": false,
                "type": "dict",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block"
                        ],
                        "type": "str"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "max-url-param": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "severity": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "low",
                            "medium",
                            "high"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "method": {
                "required": false,
                "type": "dict",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block"
                        ],
                        "type": "str"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "severity": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "low",
                            "medium",
                            "high"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "param-length": {
                "required": false,
                "type": "dict",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block"
                        ],
                        "type": "str"
                    },
                    "length": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "severity": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "low",
                            "medium",
                            "high"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "url-param-length": {
                "required": false,
                "type": "dict",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block"
                        ],
                        "type": "str"
                    },
                    "length": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "severity": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "low",
                            "medium",
                            "high"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "version": {
                "required": false,
                "type": "dict",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block"
                        ],
                        "type": "str"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "severity": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "low",
                            "medium",
                            "high"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            }
        }
    },
    "waf_profile_constraint_contentlength": {
        "stated": false,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block"
                ],
                "type": "str"
            },
            "length": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "severity": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "low",
                    "medium",
                    "high"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "waf_profile_constraint_exception": {
        "stated": true,
        "options": {
            "address": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "content-length": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "header-length": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "hostname": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "line-length": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "malformed": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "max-cookie": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "max-header-line": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "max-range-segment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "max-url-param": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "method": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "param-length": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "pattern": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "regex": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "url-param-length": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "version": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "waf_profile_constraint_headerlength": {
        "stated": false,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block"
                ],
                "type": "str"
            },
            "length": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "severity": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "low",
                    "medium",
                    "high"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "waf_profile_constraint_hostname": {
        "stated": false,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block"
                ],
                "type": "str"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "severity": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "low",
                    "medium",
                    "high"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "waf_profile_constraint_linelength": {
        "stated": false,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block"
                ],
                "type": "str"
            },
            "length": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "severity": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "low",
                    "medium",
                    "high"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "waf_profile_constraint_malformed": {
        "stated": false,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block"
                ],
                "type": "str"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "severity": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "low",
                    "medium",
                    "high"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "waf_profile_constraint_maxcookie": {
        "stated": false,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block"
                ],
                "type": "str"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "max-cookie": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "severity": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "low",
                    "medium",
                    "high"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "waf_profile_constraint_maxheaderline": {
        "stated": false,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block"
                ],
                "type": "str"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "max-header-line": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "severity": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "low",
                    "medium",
                    "high"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "waf_profile_constraint_maxrangesegment": {
        "stated": false,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block"
                ],
                "type": "str"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "max-range-segment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "severity": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "low",
                    "medium",
                    "high"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "waf_profile_constraint_maxurlparam": {
        "stated": false,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block"
                ],
                "type": "str"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "max-url-param": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "severity": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "low",
                    "medium",
                    "high"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "waf_profile_constraint_method": {
        "stated": false,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block"
                ],
                "type": "str"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "severity": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "low",
                    "medium",
                    "high"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "waf_profile_constraint_paramlength": {
        "stated": false,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block"
                ],
                "type": "str"
            },
            "length": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "severity": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "low",
                    "medium",
                    "high"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "waf_profile_constraint_urlparamlength": {
        "stated": false,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block"
                ],
                "type": "str"
            },
            "length": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "severity": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "low",
                    "medium",
                    "high"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "waf_profile_constraint_version": {
        "stated": false,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block"
                ],
                "type": "str"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "severity": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "low",
                    "medium",
                    "high"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "waf_profile_method": {
        "stated": false,
        "options": {
            "default-allowed-methods": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "delete",
                    "get",
                    "head",
                    "options",
                    "post",
                    "put",
                    "trace",
                    "others",
                    "connect"
                ],
                "elements": "str"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "method-policy": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "address": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "allowed-methods": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "delete",
                            "get",
                            "head",
                            "options",
                            "post",
                            "put",
                            "trace",
                            "others",
                            "connect"
                        ],
                        "elements": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "pattern": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "regex": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "severity": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "low",
                    "medium",
                    "high"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "waf_profile_method_methodpolicy": {
        "stated": true,
        "options": {
            "address": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "allowed-methods": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "delete",
                    "get",
                    "head",
                    "options",
                    "post",
                    "put",
                    "trace",
                    "others",
                    "connect"
                ],
                "elements": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "pattern": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "regex": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "waf_profile_signature": {
        "stated": false,
        "options": {
            "credit-card-detection-threshold": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "custom-signature": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block",
                            "erase"
                        ],
                        "type": "str"
                    },
                    "case-sensitivity": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "direction": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "request",
                            "response"
                        ],
                        "type": "str"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "pattern": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "severity": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "low",
                            "medium",
                            "high"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "target": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "arg",
                            "arg-name",
                            "req-body",
                            "req-cookie",
                            "req-cookie-name",
                            "req-filename",
                            "req-header",
                            "req-header-name",
                            "req-raw-uri",
                            "req-uri",
                            "resp-body",
                            "resp-hdr",
                            "resp-status"
                        ],
                        "elements": "str"
                    }
                },
                "elements": "dict"
            },
            "disabled-signature": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "disabled-sub-class": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "main-class": {
                "required": false,
                "type": "dict",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "block",
                            "erase"
                        ],
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "severity": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "low",
                            "medium",
                            "high"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            }
        }
    },
    "waf_profile_signature_customsignature": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block",
                    "erase"
                ],
                "type": "str"
            },
            "case-sensitivity": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "direction": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "request",
                    "response"
                ],
                "type": "str"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "pattern": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "severity": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "low",
                    "medium",
                    "high"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "target": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "arg",
                    "arg-name",
                    "req-body",
                    "req-cookie",
                    "req-cookie-name",
                    "req-filename",
                    "req-header",
                    "req-header-name",
                    "req-raw-uri",
                    "req-uri",
                    "resp-body",
                    "resp-hdr",
                    "resp-status"
                ],
                "elements": "str"
            }
        }
    },
    "waf_profile_signature_mainclass": {
        "stated": false,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "block",
                    "erase"
                ],
                "type": "str"
            },
            "id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "severity": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "low",
                    "medium",
                    "high"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "waf_profile_urlaccess": {
        "stated": true,
        "options": {
            "access-pattern": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "negate": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "pattern": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "regex": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "srcaddr": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "bypass",
                    "permit",
                    "block"
                ],
                "type": "str"
            },
            "address": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "severity": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "low",
                    "medium",
                    "high"
                ],
                "type": "str"
            }
        }
    },
    "waf_profile_urlaccess_accesspattern": {
        "stated": true,
        "options": {
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "negate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "pattern": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "regex": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "srcaddr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "waf_signature": {
        "stated": true,
        "options": {
            "desc": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "waf_subclass": {
        "stated": true,
        "options": {
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "wagprofile": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dhcp-ip-addr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ping-interval": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ping-number": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "return-packet-timeout": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tunnel-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "gre",
                    "l2tpv3"
                ],
                "type": "str"
            },
            "wag-ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "wag-port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "wanopt_authgroup": {
        "stated": true,
        "options": {
            "auth-method": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "cert",
                    "psk"
                ],
                "type": "str"
            },
            "cert": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "peer": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "peer-accept": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "any",
                    "defined",
                    "one"
                ],
                "type": "str"
            },
            "psk": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "wanopt_peer": {
        "stated": true,
        "options": {
            "ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "peer-host-id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "wanopt_profile": {
        "stated": true,
        "options": {
            "auth-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "comments": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "transparent": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "cifs": {
                "required": false,
                "type": "dict",
                "options": {
                    "byte-caching": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "log-traffic": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "prefer-chunking": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "dynamic",
                            "fix"
                        ],
                        "type": "str"
                    },
                    "protocol-opt": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "protocol",
                            "tcp"
                        ],
                        "type": "str"
                    },
                    "secure-tunnel": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "tunnel-sharing": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "private",
                            "shared",
                            "express-shared"
                        ],
                        "type": "str"
                    },
                    "port": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    }
                }
            },
            "ftp": {
                "required": false,
                "type": "dict",
                "options": {
                    "byte-caching": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "log-traffic": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "prefer-chunking": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "dynamic",
                            "fix"
                        ],
                        "type": "str"
                    },
                    "protocol-opt": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "protocol",
                            "tcp"
                        ],
                        "type": "str"
                    },
                    "secure-tunnel": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ssl": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "tunnel-sharing": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "private",
                            "shared",
                            "express-shared"
                        ],
                        "type": "str"
                    },
                    "port": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    }
                }
            },
            "http": {
                "required": false,
                "type": "dict",
                "options": {
                    "byte-caching": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "log-traffic": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "prefer-chunking": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "dynamic",
                            "fix"
                        ],
                        "type": "str"
                    },
                    "protocol-opt": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "protocol",
                            "tcp"
                        ],
                        "type": "str"
                    },
                    "secure-tunnel": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ssl": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "tunnel-sharing": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "private",
                            "shared",
                            "express-shared"
                        ],
                        "type": "str"
                    },
                    "tunnel-non-http": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "unknown-http-version": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "best-effort",
                            "reject",
                            "tunnel"
                        ],
                        "type": "str"
                    },
                    "port": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "ssl-port": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    }
                }
            },
            "mapi": {
                "required": false,
                "type": "dict",
                "options": {
                    "byte-caching": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "log-traffic": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "secure-tunnel": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "tunnel-sharing": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "private",
                            "shared",
                            "express-shared"
                        ],
                        "type": "str"
                    },
                    "port": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    }
                }
            },
            "tcp": {
                "required": false,
                "type": "dict",
                "options": {
                    "byte-caching": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "byte-caching-opt": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "mem-only",
                            "mem-disk"
                        ],
                        "type": "str"
                    },
                    "log-traffic": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "port": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "secure-tunnel": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ssl": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ssl-port": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "tunnel-sharing": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "private",
                            "shared",
                            "express-shared"
                        ],
                        "type": "str"
                    }
                }
            }
        }
    },
    "wanopt_profile_cifs": {
        "stated": false,
        "options": {
            "byte-caching": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "log-traffic": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "prefer-chunking": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "dynamic",
                    "fix"
                ],
                "type": "str"
            },
            "secure-tunnel": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tunnel-sharing": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "private",
                    "shared",
                    "express-shared"
                ],
                "type": "str"
            },
            "protocol-opt": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "protocol",
                    "tcp"
                ],
                "type": "str"
            }
        }
    },
    "wanopt_profile_ftp": {
        "stated": false,
        "options": {
            "byte-caching": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "log-traffic": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "prefer-chunking": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "dynamic",
                    "fix"
                ],
                "type": "str"
            },
            "secure-tunnel": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tunnel-sharing": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "private",
                    "shared",
                    "express-shared"
                ],
                "type": "str"
            },
            "protocol-opt": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "protocol",
                    "tcp"
                ],
                "type": "str"
            },
            "ssl": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "wanopt_profile_http": {
        "stated": false,
        "options": {
            "byte-caching": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "log-traffic": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "prefer-chunking": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "dynamic",
                    "fix"
                ],
                "type": "str"
            },
            "secure-tunnel": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tunnel-non-http": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tunnel-sharing": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "private",
                    "shared",
                    "express-shared"
                ],
                "type": "str"
            },
            "unknown-http-version": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "best-effort",
                    "reject",
                    "tunnel"
                ],
                "type": "str"
            },
            "protocol-opt": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "protocol",
                    "tcp"
                ],
                "type": "str"
            }
        }
    },
    "wanopt_profile_mapi": {
        "stated": false,
        "options": {
            "byte-caching": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "log-traffic": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "secure-tunnel": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tunnel-sharing": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "private",
                    "shared",
                    "express-shared"
                ],
                "type": "str"
            }
        }
    },
    "wanopt_profile_tcp": {
        "stated": false,
        "options": {
            "byte-caching": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "byte-caching-opt": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "mem-only",
                    "mem-disk"
                ],
                "type": "str"
            },
            "log-traffic": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "secure-tunnel": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ssl-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tunnel-sharing": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "private",
                    "shared",
                    "express-shared"
                ],
                "type": "str"
            }
        }
    },
    "wanprof_system_sdwan": {
        "stated": false,
        "options": {
            "duplication": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "dstaddr": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "dstaddr6": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "dstintf": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "packet-de-duplication": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "packet-duplication": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "force",
                            "on-demand"
                        ],
                        "type": "str"
                    },
                    "service": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "srcaddr": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "srcaddr6": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "srcintf": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "service-id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "sla-match-service": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "duplication-max-num": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fail-detect": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "health-check": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "_dynamic-server": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "addr-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ipv4",
                            "ipv6"
                        ],
                        "type": "str"
                    },
                    "diffservcode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "dns-match-ip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "dns-request-domain": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "failtime": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ftp-file": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ftp-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "passive",
                            "port"
                        ],
                        "type": "str"
                    },
                    "ha-priority": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "http-agent": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "http-get": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "http-match": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "interval": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "members": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "packet-size": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "password": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "port": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "probe-count": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "probe-packets": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "probe-timeout": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "protocol": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ping",
                            "tcp-echo",
                            "udp-echo",
                            "http",
                            "twamp",
                            "ping6",
                            "dns",
                            "tcp-connect",
                            "ftp",
                            "https"
                        ],
                        "type": "str"
                    },
                    "quality-measured-method": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "half-close",
                            "half-open"
                        ],
                        "type": "str"
                    },
                    "recoverytime": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "security-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "authentication"
                        ],
                        "type": "str"
                    },
                    "server": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "sla": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "jitter-threshold": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "latency-threshold": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "link-cost-factor": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "choices": [
                                    "latency",
                                    "jitter",
                                    "packet-loss",
                                    "mos"
                                ],
                                "elements": "str"
                            },
                            "packetloss-threshold": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "mos-threshold": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.1": false,
                                    "7.0.2": false,
                                    "7.0.3": false,
                                    "7.0.4": false,
                                    "7.0.5": false,
                                    "7.0.6": false,
                                    "7.0.7": false,
                                    "7.0.8": false,
                                    "7.0.9": false,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "priority-in-sla": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "priority-out-sla": {
                                "required": false,
                                "revision": {
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            }
                        },
                        "elements": "dict"
                    },
                    "sla-fail-log-period": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "sla-pass-log-period": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "int"
                    },
                    "system-dns": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "threshold-alert-jitter": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "threshold-alert-latency": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "threshold-alert-packetloss": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "threshold-warning-jitter": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "threshold-warning-latency": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "threshold-warning-packetloss": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "update-cascade-interface": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "update-static-route": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "user": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "detect-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "active",
                            "passive",
                            "prefer-passive",
                            "remote",
                            "agent-based"
                        ],
                        "type": "str"
                    },
                    "mos-codec": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "g711",
                            "g722",
                            "g729"
                        ],
                        "type": "str"
                    },
                    "source": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vrf": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "embed-measured-health": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "sla-id-redistribute": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "class-id": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "source6": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "load-balance-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "source-ip-based",
                    "weight-based",
                    "usage-based",
                    "source-dest-ip-based",
                    "measured-volume-based"
                ],
                "type": "str"
            },
            "members": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "_dynamic-member": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "comment": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "cost": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "gateway": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "gateway6": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ingress-spillover-threshold": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "interface": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "priority": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "seq-num": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "source": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "source6": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "spillover-threshold": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "volume-ratio": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "weight": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "zone": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "priority6": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "preferred-source": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "neighbor": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "health-check": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "member": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "role": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "primary",
                            "secondary",
                            "standalone"
                        ],
                        "type": "str"
                    },
                    "sla-id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "minimum-sla-meet-members": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "sla",
                            "speedtest"
                        ],
                        "type": "str"
                    },
                    "service-id": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "neighbor-hold-boot-time": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "neighbor-hold-down": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "neighbor-hold-down-time": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "service": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "addr-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ipv4",
                            "ipv6"
                        ],
                        "type": "str"
                    },
                    "bandwidth-weight": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "default": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "dscp-forward": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "dscp-forward-tag": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "dscp-reverse": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "dscp-reverse-tag": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "dst": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "dst-negate": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "dst6": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "end-port": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "gateway": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "groups": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "hash-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "round-robin",
                            "source-ip-based",
                            "source-dest-ip-based",
                            "inbandwidth",
                            "outbandwidth",
                            "bibandwidth"
                        ],
                        "type": "str"
                    },
                    "health-check": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "hold-down-time": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "input-device": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "input-device-negate": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "internet-service": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "internet-service-app-ctrl": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "internet-service-app-ctrl-group": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "internet-service-custom": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "internet-service-custom-group": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "internet-service-group": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "internet-service-name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "jitter-weight": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "latency-weight": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "link-cost-factor": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "latency",
                            "jitter",
                            "packet-loss",
                            "inbandwidth",
                            "outbandwidth",
                            "bibandwidth",
                            "custom-profile-1"
                        ],
                        "type": "str"
                    },
                    "link-cost-threshold": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "minimum-sla-meet-members": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "auto",
                            "manual",
                            "priority",
                            "sla",
                            "load-balance"
                        ],
                        "type": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "packet-loss-weight": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "priority-members": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "protocol": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "quality-link": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "role": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "primary",
                            "secondary",
                            "standalone"
                        ],
                        "type": "str"
                    },
                    "route-tag": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "sla": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "health-check": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            }
                        },
                        "elements": "dict"
                    },
                    "sla-compare-method": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "order",
                            "number"
                        ],
                        "type": "str"
                    },
                    "src": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "src-negate": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "src6": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "standalone-action": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "start-port": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "tos": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "tos-mask": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "users": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "tie-break": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "zone",
                            "cfg-order",
                            "fib-best-match",
                            "input-device"
                        ],
                        "type": "str"
                    },
                    "use-shortcut-sla": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "input-zone": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "internet-service-app-ctrl-category": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "passive-measurement": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "priority-zone": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "agent-exclusive": {
                        "required": false,
                        "revision": {
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "shortcut": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "shortcut-stickiness": {
                        "required": false,
                        "revision": {
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "end-src-port": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "load-balance": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "sla-stickiness": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "start-src-port": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "zone-mode": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "zone": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "service-sla-tie-break": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "cfg-order",
                            "fib-best-match",
                            "input-device"
                        ],
                        "type": "str"
                    },
                    "minimum-sla-meet-members": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "speedtest-bypass-routing": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fail-alert-interfaces": {
                "required": false,
                "revision": {
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "app-perf-log-period": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "wanprof_system_sdwan_duplication": {
        "stated": true,
        "options": {
            "dstaddr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dstaddr6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dstintf": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "packet-de-duplication": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "packet-duplication": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "force",
                    "on-demand"
                ],
                "type": "str"
            },
            "service": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcaddr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcaddr6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "srcintf": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "service-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "sla-match-service": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "wanprof_system_sdwan_healthcheck": {
        "stated": true,
        "options": {
            "_dynamic-server": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "addr-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ipv4",
                    "ipv6"
                ],
                "type": "str"
            },
            "diffservcode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dns-match-ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dns-request-domain": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "failtime": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ftp-file": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ftp-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "passive",
                    "port"
                ],
                "type": "str"
            },
            "ha-priority": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "http-agent": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "http-get": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "http-match": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "interval": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "members": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "packet-size": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "password": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "probe-count": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "probe-packets": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "probe-timeout": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ping",
                    "tcp-echo",
                    "udp-echo",
                    "http",
                    "twamp",
                    "ping6",
                    "dns",
                    "tcp-connect",
                    "ftp",
                    "https"
                ],
                "type": "str"
            },
            "quality-measured-method": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "half-close",
                    "half-open"
                ],
                "type": "str"
            },
            "recoverytime": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "security-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "authentication"
                ],
                "type": "str"
            },
            "server": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "sla": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "jitter-threshold": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "latency-threshold": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "link-cost-factor": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "latency",
                            "jitter",
                            "packet-loss",
                            "mos"
                        ],
                        "elements": "str"
                    },
                    "packetloss-threshold": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "mos-threshold": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "priority-in-sla": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "priority-out-sla": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "sla-fail-log-period": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "sla-pass-log-period": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "int"
            },
            "system-dns": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "threshold-alert-jitter": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "threshold-alert-latency": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "threshold-alert-packetloss": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "threshold-warning-jitter": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "threshold-warning-latency": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "threshold-warning-packetloss": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "update-cascade-interface": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "update-static-route": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "user": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "detect-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "active",
                    "passive",
                    "prefer-passive",
                    "remote",
                    "agent-based"
                ],
                "type": "str"
            },
            "mos-codec": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "g711",
                    "g722",
                    "g729"
                ],
                "type": "str"
            },
            "source": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vrf": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "embed-measured-health": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sla-id-redistribute": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "class-id": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "source6": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "wanprof_system_sdwan_healthcheck_sla": {
        "stated": true,
        "options": {
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "jitter-threshold": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "latency-threshold": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "link-cost-factor": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "latency",
                    "jitter",
                    "packet-loss",
                    "mos"
                ],
                "elements": "str"
            },
            "packetloss-threshold": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mos-threshold": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "priority-in-sla": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "priority-out-sla": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "wanprof_system_sdwan_members": {
        "stated": true,
        "options": {
            "_dynamic-member": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "cost": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "gateway": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "gateway6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ingress-spillover-threshold": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "interface": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "priority": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "seq-num": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "source": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "source6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "spillover-threshold": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "volume-ratio": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "weight": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "zone": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "priority6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "preferred-source": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "wanprof_system_sdwan_neighbor": {
        "stated": true,
        "options": {
            "health-check": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "member": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "role": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "primary",
                    "secondary",
                    "standalone"
                ],
                "type": "str"
            },
            "sla-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "minimum-sla-meet-members": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "sla",
                    "speedtest"
                ],
                "type": "str"
            },
            "service-id": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "wanprof_system_sdwan_service": {
        "stated": true,
        "options": {
            "addr-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ipv4",
                    "ipv6"
                ],
                "type": "str"
            },
            "bandwidth-weight": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "default": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dscp-forward": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dscp-forward-tag": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dscp-reverse": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dscp-reverse-tag": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dst": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dst-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dst6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "end-port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "gateway": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "groups": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "hash-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "round-robin",
                    "source-ip-based",
                    "source-dest-ip-based",
                    "inbandwidth",
                    "outbandwidth",
                    "bibandwidth"
                ],
                "type": "str"
            },
            "health-check": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "hold-down-time": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "input-device": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "input-device-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service-app-ctrl": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-app-ctrl-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-custom": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-custom-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-group": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "jitter-weight": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "latency-weight": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "link-cost-factor": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "latency",
                    "jitter",
                    "packet-loss",
                    "inbandwidth",
                    "outbandwidth",
                    "bibandwidth",
                    "custom-profile-1"
                ],
                "type": "str"
            },
            "link-cost-threshold": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "minimum-sla-meet-members": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auto",
                    "manual",
                    "priority",
                    "sla",
                    "load-balance"
                ],
                "type": "str"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "packet-loss-weight": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "priority-members": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "quality-link": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "role": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "primary",
                    "secondary",
                    "standalone"
                ],
                "type": "str"
            },
            "route-tag": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "sla": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "health-check": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "sla-compare-method": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "order",
                    "number"
                ],
                "type": "str"
            },
            "src": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "src-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "src6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "standalone-action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "start-port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tos": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tos-mask": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "users": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "tie-break": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "zone",
                    "cfg-order",
                    "fib-best-match",
                    "input-device"
                ],
                "type": "str"
            },
            "use-shortcut-sla": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "input-zone": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-app-ctrl-category": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "passive-measurement": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "priority-zone": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "agent-exclusive": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "shortcut": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "shortcut-stickiness": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "end-src-port": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "load-balance": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sla-stickiness": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "start-src-port": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "zone-mode": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "wanprof_system_sdwan_service_sla": {
        "stated": true,
        "options": {
            "health-check": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "wanprof_system_sdwan_zone": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "service-sla-tie-break": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "cfg-order",
                    "fib-best-match",
                    "input-device"
                ],
                "type": "str"
            },
            "minimum-sla-meet-members": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "wanprof_system_virtualwanlink": {
        "stated": false,
        "options": {
            "fail-detect": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "health-check": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "_dynamic-server": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "addr-mode": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ipv4",
                            "ipv6"
                        ],
                        "type": "str"
                    },
                    "failtime": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "http-agent": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "http-get": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "http-match": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "interval": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "members": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "packet-size": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "password": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "port": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "protocol": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ping",
                            "tcp-echo",
                            "udp-echo",
                            "http",
                            "twamp",
                            "ping6",
                            "dns"
                        ],
                        "type": "str"
                    },
                    "recoverytime": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "security-mode": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "authentication"
                        ],
                        "type": "str"
                    },
                    "server": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "sla": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "id": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "jitter-threshold": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "latency-threshold": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "link-cost-factor": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "choices": [
                                    "latency",
                                    "jitter",
                                    "packet-loss"
                                ],
                                "elements": "str"
                            },
                            "packetloss-threshold": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            }
                        },
                        "elements": "dict"
                    },
                    "threshold-alert-jitter": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "threshold-alert-latency": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "threshold-alert-packetloss": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "threshold-warning-jitter": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "threshold-warning-latency": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "threshold-warning-packetloss": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "update-cascade-interface": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "update-static-route": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "internet-service-id": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "probe-packets": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "sla-fail-log-period": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "sla-pass-log-period": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "int"
                    },
                    "timeout": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "ha-priority": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "diffservcode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "probe-timeout": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "dns-request-domain": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "probe-count": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "int"
                    },
                    "system-dns": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "load-balance-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "source-ip-based",
                    "weight-based",
                    "usage-based",
                    "source-dest-ip-based",
                    "measured-volume-based"
                ],
                "type": "str"
            },
            "members": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "_dynamic-member": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "comment": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "gateway": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "gateway6": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ingress-spillover-threshold": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "interface": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "priority": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "seq-num": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "source": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "source6": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "spillover-threshold": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "volume-ratio": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "weight": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "cost": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "service": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "addr-mode": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ipv4",
                            "ipv6"
                        ],
                        "type": "str"
                    },
                    "bandwidth-weight": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "default": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "dscp-forward": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "dscp-forward-tag": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "dscp-reverse": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "dscp-reverse-tag": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "dst": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "dst-negate": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "dst6": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "end-port": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "gateway": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "groups": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "health-check": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "hold-down-time": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "internet-service": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "internet-service-ctrl": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "raw"
                    },
                    "internet-service-ctrl-group": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "raw"
                    },
                    "internet-service-custom": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "internet-service-custom-group": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "internet-service-group": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "internet-service-id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "jitter-weight": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "latency-weight": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "link-cost-factor": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "latency",
                            "jitter",
                            "packet-loss",
                            "inbandwidth",
                            "outbandwidth",
                            "bibandwidth",
                            "custom-profile-1"
                        ],
                        "type": "str"
                    },
                    "link-cost-threshold": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "member": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "mode": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "auto",
                            "manual",
                            "priority",
                            "sla",
                            "load-balance"
                        ],
                        "type": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "packet-loss-weight": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "priority-members": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "protocol": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "quality-link": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "route-tag": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "sla": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "health-check": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "id": {
                                "required": false,
                                "revision": {
                                    "6.0.0": true,
                                    "6.2.0": true,
                                    "6.2.1": true,
                                    "6.2.2": true,
                                    "6.2.3": true,
                                    "6.2.5": true,
                                    "6.2.6": true,
                                    "6.2.7": true,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.0": true,
                                    "6.4.1": true,
                                    "6.4.2": true,
                                    "6.4.3": true,
                                    "6.4.4": true,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            }
                        },
                        "elements": "dict"
                    },
                    "src": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "src-negate": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "src6": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "start-port": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "tos": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "tos-mask": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "users": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "internet-service-app-ctrl": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "internet-service-app-ctrl-group": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "role": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "primary",
                            "secondary",
                            "standalone"
                        ],
                        "type": "str"
                    },
                    "sla-compare-method": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "order",
                            "number"
                        ],
                        "type": "str"
                    },
                    "standalone-action": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "input-device": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "internet-service-name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": false,
                            "6.4.2": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    },
                    "input-device-negate": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "neighbor": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "health-check": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "member": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "role": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "primary",
                            "secondary",
                            "standalone"
                        ],
                        "type": "str"
                    },
                    "sla-id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "neighbor-hold-boot-time": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "neighbor-hold-down": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "neighbor-hold-down-time": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fail-alert-interfaces": {
                "required": false,
                "revision": {
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "wanprof_system_virtualwanlink_healthcheck": {
        "stated": true,
        "options": {
            "_dynamic-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "addr-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ipv4",
                    "ipv6"
                ],
                "type": "str"
            },
            "failtime": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "http-agent": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "http-get": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "http-match": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "members": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "packet-size": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "password": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ping",
                    "tcp-echo",
                    "udp-echo",
                    "http",
                    "twamp",
                    "ping6",
                    "dns"
                ],
                "type": "str"
            },
            "recoverytime": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "security-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "authentication"
                ],
                "type": "str"
            },
            "server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "sla": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "jitter-threshold": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "latency-threshold": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "link-cost-factor": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "latency",
                            "jitter",
                            "packet-loss"
                        ],
                        "elements": "str"
                    },
                    "packetloss-threshold": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "threshold-alert-jitter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "threshold-alert-latency": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "threshold-alert-packetloss": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "threshold-warning-jitter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "threshold-warning-latency": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "threshold-warning-packetloss": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "update-cascade-interface": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "update-static-route": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service-id": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "probe-packets": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sla-fail-log-period": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "sla-pass-log-period": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "int"
            },
            "timeout": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "ha-priority": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "diffservcode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "probe-timeout": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "dns-request-domain": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "probe-count": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "int"
            },
            "system-dns": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "wanprof_system_virtualwanlink_healthcheck_sla": {
        "stated": true,
        "options": {
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "jitter-threshold": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "latency-threshold": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "link-cost-factor": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "latency",
                    "jitter",
                    "packet-loss"
                ],
                "elements": "str"
            },
            "packetloss-threshold": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "wanprof_system_virtualwanlink_members": {
        "stated": true,
        "options": {
            "_dynamic-member": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "gateway": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "gateway6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ingress-spillover-threshold": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "interface": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "priority": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "seq-num": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "source": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "source6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "spillover-threshold": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "volume-ratio": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "weight": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "cost": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "wanprof_system_virtualwanlink_neighbor": {
        "stated": true,
        "options": {
            "health-check": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "member": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "role": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "primary",
                    "secondary",
                    "standalone"
                ],
                "type": "str"
            },
            "sla-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "wanprof_system_virtualwanlink_service": {
        "stated": true,
        "options": {
            "addr-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ipv4",
                    "ipv6"
                ],
                "type": "str"
            },
            "bandwidth-weight": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "default": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dscp-forward": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dscp-forward-tag": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dscp-reverse": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dscp-reverse-tag": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dst": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dst-negate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dst6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "end-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "gateway": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "groups": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "health-check": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "hold-down-time": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "internet-service": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "internet-service-ctrl": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "internet-service-ctrl-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "raw"
            },
            "internet-service-custom": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-custom-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "jitter-weight": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "latency-weight": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "link-cost-factor": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "latency",
                    "jitter",
                    "packet-loss",
                    "inbandwidth",
                    "outbandwidth",
                    "bibandwidth",
                    "custom-profile-1"
                ],
                "type": "str"
            },
            "link-cost-threshold": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "member": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auto",
                    "manual",
                    "priority",
                    "sla",
                    "load-balance"
                ],
                "type": "str"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "packet-loss-weight": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "priority-members": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "quality-link": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "route-tag": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "sla": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "health-check": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "src": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "src-negate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "src6": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "start-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tos": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "tos-mask": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "users": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-app-ctrl": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-app-ctrl-group": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "role": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "primary",
                    "secondary",
                    "standalone"
                ],
                "type": "str"
            },
            "sla-compare-method": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "order",
                    "number"
                ],
                "type": "str"
            },
            "standalone-action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "input-device": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "internet-service-name": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "input-device-negate": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "wanprof_system_virtualwanlink_service_sla": {
        "stated": true,
        "options": {
            "health-check": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "webfilter_categories": {
        "stated": true,
        "options": {
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "webfilter_content": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "entries": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "exempt",
                            "block"
                        ],
                        "type": "str"
                    },
                    "lang": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "western",
                            "simch",
                            "trach",
                            "japanese",
                            "korean",
                            "french",
                            "thai",
                            "spanish",
                            "cyrillic"
                        ],
                        "type": "str"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "pattern-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "wildcard",
                            "regexp"
                        ],
                        "type": "str"
                    },
                    "score": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "webfilter_content_entries": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "exempt",
                    "block"
                ],
                "type": "str"
            },
            "lang": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "western",
                    "simch",
                    "trach",
                    "japanese",
                    "korean",
                    "french",
                    "thai",
                    "spanish",
                    "cyrillic"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "pattern-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "wildcard",
                    "regexp"
                ],
                "type": "str"
            },
            "score": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "webfilter_contentheader": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "entries": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "exempt",
                            "block",
                            "allow"
                        ],
                        "type": "str"
                    },
                    "category": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "pattern": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "webfilter_contentheader_entries": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "exempt",
                    "block",
                    "allow"
                ],
                "type": "str"
            },
            "category": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "pattern": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "webfilter_ftgdlocalcat": {
        "stated": true,
        "options": {
            "desc": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "webfilter_ftgdlocalrating": {
        "stated": true,
        "options": {
            "rating": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "url": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "webfilter_profile": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "extended-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "https-replacemsg": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "inspection-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "proxy",
                    "flow-based",
                    "dns"
                ],
                "type": "str"
            },
            "log-all-url": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "options": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "block-invalid-url",
                    "jscript",
                    "js",
                    "vbs",
                    "unknown",
                    "wf-referer",
                    "https-scan",
                    "intrinsic",
                    "wf-cookie",
                    "per-user-bwl",
                    "activexfilter",
                    "cookiefilter",
                    "https-url-scan",
                    "javafilter",
                    "rangeblock",
                    "contenttype-check",
                    "per-user-bal"
                ],
                "elements": "str"
            },
            "ovrd-perm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "bannedword-override",
                    "urlfilter-override",
                    "fortiguard-wf-override",
                    "contenttype-check-override"
                ],
                "elements": "str"
            },
            "post-action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "normal",
                    "comfort",
                    "block"
                ],
                "type": "str"
            },
            "replacemsg-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "web-content-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "web-extended-all-action-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "web-filter-activex-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "web-filter-applet-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "web-filter-command-block-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "web-filter-cookie-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "web-filter-cookie-removal-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "web-filter-js-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "web-filter-jscript-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "web-filter-referer-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "web-filter-unknown-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "web-filter-vbs-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "web-ftgd-err-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "web-ftgd-quota-usage": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "web-invalid-domain-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "web-url-log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "wisp": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "wisp-algorithm": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auto-learning",
                    "primary-secondary",
                    "round-robin"
                ],
                "type": "str"
            },
            "wisp-servers": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "youtube-channel-filter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "channel-id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "comment": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "youtube-channel-status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "blacklist",
                    "whitelist"
                ],
                "type": "str"
            },
            "feature-set": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "proxy",
                    "flow"
                ],
                "type": "str"
            },
            "web-antiphishing-log": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "antiphish": {
                "required": false,
                "type": "dict",
                "options": {
                    "check-basic-auth": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "check-uri": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "check-username-only": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "custom-patterns": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "category": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "username",
                                    "password"
                                ],
                                "type": "str"
                            },
                            "pattern": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "type": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.6": false,
                                    "6.4.7": false,
                                    "6.4.8": false,
                                    "6.4.9": false,
                                    "6.4.10": false,
                                    "6.4.11": false,
                                    "6.4.12": false,
                                    "6.4.13": false,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "regex",
                                    "literal"
                                ],
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "default-action": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "log",
                            "block",
                            "exempt"
                        ],
                        "type": "str"
                    },
                    "domain-controller": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "inspection-entries": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "action": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "log",
                                    "block",
                                    "exempt"
                                ],
                                "type": "str"
                            },
                            "fortiguard-category": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            },
                            "name": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": false,
                                    "6.2.9": false,
                                    "6.2.10": false,
                                    "6.2.11": false,
                                    "6.2.12": false,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "max-body-len": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "authentication": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "domain-controller",
                            "ldap"
                        ],
                        "type": "str"
                    },
                    "ldap": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                }
            },
            "ftgd-wf": {
                "required": false,
                "type": "dict",
                "options": {
                    "exempt-quota": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "filters": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "action": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "block",
                                    "monitor",
                                    "warning",
                                    "authenticate"
                                ],
                                "type": "str"
                            },
                            "auth-usr-grp": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            },
                            "category": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "log": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "disable",
                                    "enable"
                                ],
                                "type": "str"
                            },
                            "override-replacemsg": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "warn-duration": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "warning-duration-type": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "session",
                                    "timeout"
                                ],
                                "type": "str"
                            },
                            "warning-prompt": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "per-domain",
                                    "per-category"
                                ],
                                "type": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "max-quota-timeout": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "options": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "error-allow",
                            "http-err-detail",
                            "rate-image-urls",
                            "strict-blocking",
                            "rate-server-ip",
                            "redir-block",
                            "connect-request-bypass",
                            "log-all-url",
                            "ftgd-disable"
                        ],
                        "elements": "str"
                    },
                    "ovrd": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "quota": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "category": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            },
                            "duration": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "id": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            },
                            "override-replacemsg": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "type": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "time",
                                    "traffic"
                                ],
                                "type": "str"
                            },
                            "unit": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "B",
                                    "KB",
                                    "MB",
                                    "GB"
                                ],
                                "type": "str"
                            },
                            "value": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "int"
                            }
                        },
                        "elements": "dict"
                    },
                    "rate-crl-urls": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "rate-css-urls": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "rate-image-urls": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "rate-javascript-urls": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "category-override": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": false,
                            "7.0.4": false,
                            "7.0.5": false,
                            "7.0.6": false,
                            "7.0.7": false,
                            "7.0.8": false,
                            "7.0.9": false,
                            "7.2.0": false,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "type": "str"
                    }
                }
            },
            "override": {
                "required": false,
                "type": "dict",
                "options": {
                    "ovrd-cookie": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "deny",
                            "allow"
                        ],
                        "type": "str"
                    },
                    "ovrd-dur": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ovrd-dur-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "constant",
                            "ask"
                        ],
                        "type": "str"
                    },
                    "ovrd-scope": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "user",
                            "user-group",
                            "ip",
                            "ask",
                            "browser"
                        ],
                        "type": "str"
                    },
                    "ovrd-user-group": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "profile": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "profile-attribute": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "User-Name",
                            "User-Password",
                            "CHAP-Password",
                            "NAS-IP-Address",
                            "NAS-Port",
                            "Service-Type",
                            "Framed-Protocol",
                            "Framed-IP-Address",
                            "Framed-IP-Netmask",
                            "Framed-Routing",
                            "Filter-Id",
                            "Framed-MTU",
                            "Framed-Compression",
                            "Login-IP-Host",
                            "Login-Service",
                            "Login-TCP-Port",
                            "Reply-Message",
                            "Callback-Number",
                            "Callback-Id",
                            "Framed-Route",
                            "Framed-IPX-Network",
                            "State",
                            "Class",
                            "Vendor-Specific",
                            "Session-Timeout",
                            "Idle-Timeout",
                            "Termination-Action",
                            "Called-Station-Id",
                            "Calling-Station-Id",
                            "NAS-Identifier",
                            "Proxy-State",
                            "Login-LAT-Service",
                            "Login-LAT-Node",
                            "Login-LAT-Group",
                            "Framed-AppleTalk-Link",
                            "Framed-AppleTalk-Network",
                            "Framed-AppleTalk-Zone",
                            "Acct-Status-Type",
                            "Acct-Delay-Time",
                            "Acct-Input-Octets",
                            "Acct-Output-Octets",
                            "Acct-Session-Id",
                            "Acct-Authentic",
                            "Acct-Session-Time",
                            "Acct-Input-Packets",
                            "Acct-Output-Packets",
                            "Acct-Terminate-Cause",
                            "Acct-Multi-Session-Id",
                            "Acct-Link-Count",
                            "CHAP-Challenge",
                            "NAS-Port-Type",
                            "Port-Limit",
                            "Login-LAT-Port"
                        ],
                        "type": "str"
                    },
                    "profile-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "list",
                            "radius"
                        ],
                        "type": "str"
                    }
                }
            },
            "url-extraction": {
                "required": false,
                "type": "dict",
                "options": {
                    "redirect-header": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "redirect-no-content": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "redirect-url": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "server-fqdn": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "web": {
                "required": false,
                "type": "dict",
                "options": {
                    "blacklist": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "bword-table": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "bword-threshold": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "content-header-list": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "keyword-match": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "log-search": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "safe-search": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "google",
                            "yahoo",
                            "bing",
                            "url",
                            "header"
                        ],
                        "elements": "str"
                    },
                    "urlfilter-table": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "whitelist": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "exempt-av",
                            "exempt-webcontent",
                            "exempt-activex-java-cookie",
                            "exempt-dlp",
                            "exempt-rangeblock",
                            "extended-log-others"
                        ],
                        "elements": "str"
                    },
                    "youtube-restrict": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "strict",
                            "none",
                            "moderate"
                        ],
                        "type": "str"
                    },
                    "allowlist": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "exempt-av",
                            "exempt-webcontent",
                            "exempt-activex-java-cookie",
                            "exempt-dlp",
                            "exempt-rangeblock",
                            "extended-log-others"
                        ],
                        "elements": "str"
                    },
                    "blocklist": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "vimeo-restrict": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                }
            },
            "file-filter": {
                "required": false,
                "type": "dict",
                "options": {
                    "entries": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "options": {
                            "action": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "log",
                                    "block"
                                ],
                                "type": "str"
                            },
                            "comment": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "direction": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "any",
                                    "incoming",
                                    "outgoing"
                                ],
                                "type": "str"
                            },
                            "encryption": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": false,
                                    "7.2.2": false,
                                    "7.2.3": false,
                                    "7.2.4": false,
                                    "7.4.0": false,
                                    "7.4.1": false
                                },
                                "choices": [
                                    "any",
                                    "yes"
                                ],
                                "type": "str"
                            },
                            "file-type": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "raw"
                            },
                            "filter": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "str"
                            },
                            "password-protected": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "choices": [
                                    "any",
                                    "yes"
                                ],
                                "type": "str"
                            },
                            "protocol": {
                                "required": false,
                                "revision": {
                                    "6.2.0": false,
                                    "6.2.2": false,
                                    "6.2.6": false,
                                    "6.2.7": false,
                                    "6.2.8": true,
                                    "6.2.9": true,
                                    "6.2.10": true,
                                    "6.2.11": true,
                                    "6.2.12": true,
                                    "6.4.1": false,
                                    "6.4.3": false,
                                    "6.4.4": false,
                                    "6.4.5": true,
                                    "6.4.6": true,
                                    "6.4.7": true,
                                    "6.4.8": true,
                                    "6.4.9": true,
                                    "6.4.10": true,
                                    "6.4.11": true,
                                    "6.4.12": true,
                                    "6.4.13": true,
                                    "7.0.0": true,
                                    "7.0.1": true,
                                    "7.0.2": true,
                                    "7.0.3": true,
                                    "7.0.4": true,
                                    "7.0.5": true,
                                    "7.0.6": true,
                                    "7.0.7": true,
                                    "7.0.8": true,
                                    "7.0.9": true,
                                    "7.2.0": true,
                                    "7.2.1": true,
                                    "7.2.2": true,
                                    "7.2.3": true,
                                    "7.2.4": true,
                                    "7.4.0": true,
                                    "7.4.1": true
                                },
                                "type": "list",
                                "choices": [
                                    "http",
                                    "ftp"
                                ],
                                "elements": "str"
                            }
                        },
                        "elements": "dict"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "scan-archive-contents": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            }
        }
    },
    "webfilter_profile_antiphish": {
        "stated": false,
        "options": {
            "check-basic-auth": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "check-uri": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "custom-patterns": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "category": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "username",
                            "password"
                        ],
                        "type": "str"
                    },
                    "pattern": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "regex",
                            "literal"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "default-action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "log",
                    "block",
                    "exempt"
                ],
                "type": "str"
            },
            "domain-controller": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "inspection-entries": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "log",
                            "block",
                            "exempt"
                        ],
                        "type": "str"
                    },
                    "fortiguard-category": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "max-body-len": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "check-username-only": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "authentication": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "domain-controller",
                    "ldap"
                ],
                "type": "str"
            },
            "ldap": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "webfilter_profile_antiphish_custompatterns": {
        "stated": true,
        "options": {
            "category": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "username",
                    "password"
                ],
                "type": "str"
            },
            "pattern": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "regex",
                    "literal"
                ],
                "type": "str"
            }
        }
    },
    "webfilter_profile_antiphish_inspectionentries": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "log",
                    "block",
                    "exempt"
                ],
                "type": "str"
            },
            "fortiguard-category": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "webfilter_profile_filefilter": {
        "stated": false,
        "options": {
            "entries": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "log",
                            "block"
                        ],
                        "type": "str"
                    },
                    "comment": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "direction": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "any",
                            "incoming",
                            "outgoing"
                        ],
                        "type": "str"
                    },
                    "encryption": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": false,
                            "7.2.2": false,
                            "7.2.3": false,
                            "7.2.4": false,
                            "7.4.0": false,
                            "7.4.1": false
                        },
                        "choices": [
                            "any",
                            "yes"
                        ],
                        "type": "str"
                    },
                    "file-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "filter": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "password-protected": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "any",
                            "yes"
                        ],
                        "type": "str"
                    },
                    "protocol": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "http",
                            "ftp"
                        ],
                        "elements": "str"
                    }
                },
                "elements": "dict"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "scan-archive-contents": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "webfilter_profile_filefilter_entries": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "log",
                    "block"
                ],
                "type": "str"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "direction": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "any",
                    "incoming",
                    "outgoing"
                ],
                "type": "str"
            },
            "encryption": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "any",
                    "yes"
                ],
                "type": "str"
            },
            "file-type": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "filter": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "password-protected": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "any",
                    "yes"
                ],
                "type": "str"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "http",
                    "ftp"
                ],
                "elements": "str"
            }
        }
    },
    "webfilter_profile_ftgdwf": {
        "stated": false,
        "options": {
            "exempt-quota": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "filters": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "block",
                            "monitor",
                            "warning",
                            "authenticate"
                        ],
                        "type": "str"
                    },
                    "auth-usr-grp": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "category": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "log": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "override-replacemsg": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "warn-duration": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "warning-duration-type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "session",
                            "timeout"
                        ],
                        "type": "str"
                    },
                    "warning-prompt": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "per-domain",
                            "per-category"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "max-quota-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "options": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "error-allow",
                    "http-err-detail",
                    "rate-image-urls",
                    "strict-blocking",
                    "rate-server-ip",
                    "redir-block",
                    "connect-request-bypass",
                    "log-all-url",
                    "ftgd-disable"
                ],
                "elements": "str"
            },
            "ovrd": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "quota": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "category": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "duration": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "override-replacemsg": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "time",
                            "traffic"
                        ],
                        "type": "str"
                    },
                    "unit": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "B",
                            "KB",
                            "MB",
                            "GB"
                        ],
                        "type": "str"
                    },
                    "value": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "rate-crl-urls": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "rate-css-urls": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "rate-image-urls": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "rate-javascript-urls": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "category-override": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            }
        }
    },
    "webfilter_profile_ftgdwf_filters": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "block",
                    "monitor",
                    "warning",
                    "authenticate"
                ],
                "type": "str"
            },
            "auth-usr-grp": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "category": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "log": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "override-replacemsg": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "warn-duration": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "warning-duration-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "session",
                    "timeout"
                ],
                "type": "str"
            },
            "warning-prompt": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "per-domain",
                    "per-category"
                ],
                "type": "str"
            }
        }
    },
    "webfilter_profile_ftgdwf_quota": {
        "stated": true,
        "options": {
            "category": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "duration": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "override-replacemsg": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "time",
                    "traffic"
                ],
                "type": "str"
            },
            "unit": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "B",
                    "KB",
                    "MB",
                    "GB"
                ],
                "type": "str"
            },
            "value": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "webfilter_profile_override": {
        "stated": false,
        "options": {
            "ovrd-cookie": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "deny",
                    "allow"
                ],
                "type": "str"
            },
            "ovrd-dur": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ovrd-dur-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "constant",
                    "ask"
                ],
                "type": "str"
            },
            "ovrd-scope": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "user",
                    "user-group",
                    "ip",
                    "ask",
                    "browser"
                ],
                "type": "str"
            },
            "ovrd-user-group": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "profile-attribute": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "User-Name",
                    "User-Password",
                    "CHAP-Password",
                    "NAS-IP-Address",
                    "NAS-Port",
                    "Service-Type",
                    "Framed-Protocol",
                    "Framed-IP-Address",
                    "Framed-IP-Netmask",
                    "Framed-Routing",
                    "Filter-Id",
                    "Framed-MTU",
                    "Framed-Compression",
                    "Login-IP-Host",
                    "Login-Service",
                    "Login-TCP-Port",
                    "Reply-Message",
                    "Callback-Number",
                    "Callback-Id",
                    "Framed-Route",
                    "Framed-IPX-Network",
                    "State",
                    "Class",
                    "Vendor-Specific",
                    "Session-Timeout",
                    "Idle-Timeout",
                    "Termination-Action",
                    "Called-Station-Id",
                    "Calling-Station-Id",
                    "NAS-Identifier",
                    "Proxy-State",
                    "Login-LAT-Service",
                    "Login-LAT-Node",
                    "Login-LAT-Group",
                    "Framed-AppleTalk-Link",
                    "Framed-AppleTalk-Network",
                    "Framed-AppleTalk-Zone",
                    "Acct-Status-Type",
                    "Acct-Delay-Time",
                    "Acct-Input-Octets",
                    "Acct-Output-Octets",
                    "Acct-Session-Id",
                    "Acct-Authentic",
                    "Acct-Session-Time",
                    "Acct-Input-Packets",
                    "Acct-Output-Packets",
                    "Acct-Terminate-Cause",
                    "Acct-Multi-Session-Id",
                    "Acct-Link-Count",
                    "CHAP-Challenge",
                    "NAS-Port-Type",
                    "Port-Limit",
                    "Login-LAT-Port"
                ],
                "type": "str"
            },
            "profile-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "list",
                    "radius"
                ],
                "type": "str"
            }
        }
    },
    "webfilter_profile_urlextraction": {
        "stated": false,
        "options": {
            "redirect-header": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "redirect-no-content": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "redirect-url": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "server-fqdn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "webfilter_profile_web": {
        "stated": false,
        "options": {
            "blacklist": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "bword-table": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "bword-threshold": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "content-header-list": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "keyword-match": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "log-search": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "safe-search": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "google",
                    "yahoo",
                    "bing",
                    "url",
                    "header"
                ],
                "elements": "str"
            },
            "urlfilter-table": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "whitelist": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "exempt-av",
                    "exempt-webcontent",
                    "exempt-activex-java-cookie",
                    "exempt-dlp",
                    "exempt-rangeblock",
                    "extended-log-others"
                ],
                "elements": "str"
            },
            "youtube-restrict": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "strict",
                    "none",
                    "moderate"
                ],
                "type": "str"
            },
            "allowlist": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "exempt-av",
                    "exempt-webcontent",
                    "exempt-activex-java-cookie",
                    "exempt-dlp",
                    "exempt-rangeblock",
                    "extended-log-others"
                ],
                "elements": "str"
            },
            "blocklist": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "vimeo-restrict": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "webfilter_profile_youtubechannelfilter": {
        "stated": true,
        "options": {
            "channel-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "webfilter_urlfilter": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "entries": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "exempt",
                            "block",
                            "allow",
                            "monitor",
                            "pass"
                        ],
                        "type": "str"
                    },
                    "dns-address-family": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ipv4",
                            "ipv6",
                            "both"
                        ],
                        "type": "str"
                    },
                    "exempt": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "av",
                            "web-content",
                            "activex-java-cookie",
                            "dlp",
                            "fortiguard",
                            "all",
                            "filepattern",
                            "pass",
                            "range-block",
                            "antiphish"
                        ],
                        "elements": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "referrer-host": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "status": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "simple",
                            "regex",
                            "wildcard"
                        ],
                        "type": "str"
                    },
                    "url": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "web-proxy-profile": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "antiphish-action": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "block",
                            "log"
                        ],
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip-addr-block": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "one-arm-ips-urlfilter": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ip4-mapped-ip6": {
                "required": false,
                "revision": {
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "webfilter_urlfilter_entries": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "exempt",
                    "block",
                    "allow",
                    "monitor",
                    "pass"
                ],
                "type": "str"
            },
            "dns-address-family": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ipv4",
                    "ipv6",
                    "both"
                ],
                "type": "str"
            },
            "exempt": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "av",
                    "web-content",
                    "activex-java-cookie",
                    "dlp",
                    "fortiguard",
                    "all",
                    "filepattern",
                    "pass",
                    "range-block",
                    "antiphish"
                ],
                "elements": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "referrer-host": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "status": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "simple",
                    "regex",
                    "wildcard"
                ],
                "type": "str"
            },
            "url": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "web-proxy-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "antiphish-action": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "block",
                    "log"
                ],
                "type": "str"
            }
        }
    },
    "webproxy_forwardserver": {
        "stated": true,
        "options": {
            "addr-type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "fqdn",
                    "ip",
                    "ipv6"
                ],
                "type": "str"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "fqdn": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "healthcheck": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "monitor": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "server-down-option": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "block",
                    "pass"
                ],
                "type": "str"
            },
            "password": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "username": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ipv6": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "webproxy_forwardservergroup": {
        "stated": true,
        "options": {
            "affinity": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "group-down-option": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "block",
                    "pass"
                ],
                "type": "str"
            },
            "ldb-method": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "weighted",
                    "least-session",
                    "active-passive"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "server-list": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "weight": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            }
        }
    },
    "webproxy_forwardservergroup_serverlist": {
        "stated": true,
        "options": {
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "weight": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "webproxy_profile": {
        "stated": true,
        "options": {
            "header-client-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "add",
                    "remove"
                ],
                "type": "str"
            },
            "header-front-end-https": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "add",
                    "remove"
                ],
                "type": "str"
            },
            "header-via-request": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "add",
                    "remove"
                ],
                "type": "str"
            },
            "header-via-response": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "add",
                    "remove"
                ],
                "type": "str"
            },
            "header-x-authenticated-groups": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "add",
                    "remove"
                ],
                "type": "str"
            },
            "header-x-authenticated-user": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "add",
                    "remove"
                ],
                "type": "str"
            },
            "header-x-forwarded-for": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "add",
                    "remove"
                ],
                "type": "str"
            },
            "headers": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "add-to-request",
                            "add-to-response",
                            "remove-from-request",
                            "remove-from-response",
                            "monitor-request",
                            "monitor-response"
                        ],
                        "type": "str"
                    },
                    "content": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "name": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "add-option": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "append",
                            "new-on-not-found",
                            "new"
                        ],
                        "type": "str"
                    },
                    "base64-encoding": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "dstaddr": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "dstaddr6": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "protocol": {
                        "required": false,
                        "revision": {
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "https",
                            "http"
                        ],
                        "elements": "str"
                    }
                },
                "elements": "dict"
            },
            "log-header-change": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "strip-encoding": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "header-x-forwarded-client-cert": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "pass",
                    "add",
                    "remove"
                ],
                "type": "str"
            }
        }
    },
    "webproxy_profile_headers": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "add-to-request",
                    "add-to-response",
                    "remove-from-request",
                    "remove-from-response",
                    "monitor-request",
                    "monitor-response"
                ],
                "type": "str"
            },
            "content": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "add-option": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "append",
                    "new-on-not-found",
                    "new"
                ],
                "type": "str"
            },
            "base64-encoding": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dstaddr": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "dstaddr6": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "https",
                    "http"
                ],
                "elements": "str"
            }
        }
    },
    "webproxy_wisp": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "max-connections": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "outgoing-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "server-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "server-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "widsprofile": {
        "stated": true,
        "options": {
            "ap-auto-suppress": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ap-bgscan-disable-day": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "list",
                "choices": [
                    "sunday",
                    "monday",
                    "tuesday",
                    "wednesday",
                    "thursday",
                    "friday",
                    "saturday"
                ],
                "elements": "str"
            },
            "ap-bgscan-disable-end": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "ap-bgscan-disable-start": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "type": "str"
            },
            "ap-bgscan-duration": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ap-bgscan-idle": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ap-bgscan-intv": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ap-bgscan-period": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ap-bgscan-report-intv": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ap-fgscan-report-intv": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ap-scan": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ap-scan-passive": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "asleap-attack": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "assoc-flood-thresh": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "assoc-flood-time": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "assoc-frame-flood": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "auth-flood-thresh": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "auth-flood-time": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "auth-frame-flood": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "deauth-broadcast": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "deauth-unknown-src-thresh": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "eapol-fail-flood": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "eapol-fail-intv": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "eapol-fail-thresh": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "eapol-logoff-flood": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "eapol-logoff-intv": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "eapol-logoff-thresh": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "eapol-pre-fail-flood": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "eapol-pre-fail-intv": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "eapol-pre-fail-thresh": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "eapol-pre-succ-flood": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "eapol-pre-succ-intv": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "eapol-pre-succ-thresh": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "eapol-start-flood": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "eapol-start-intv": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "eapol-start-thresh": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "eapol-succ-flood": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "eapol-succ-intv": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "eapol-succ-thresh": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "invalid-mac-oui": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "long-duration-attack": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "long-duration-thresh": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "null-ssid-probe-resp": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sensor-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "foreign",
                    "both"
                ],
                "type": "str"
            },
            "spoofed-deauth": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "weak-wep-iv": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "wireless-bridge": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ap-bgscan-disable-schedules": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "rogue-scan": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": false,
                    "6.4.2": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.5": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": false,
                    "7.0.4": false,
                    "7.0.5": false,
                    "7.0.6": false,
                    "7.0.7": false,
                    "7.0.8": false,
                    "7.0.9": false,
                    "7.2.0": false,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ap-scan-threshold": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ap-scan-channel-list-2G-5G": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "raw"
            },
            "ap-scan-channel-list-6G": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "raw"
            }
        }
    },
    "wireless_accesscontrollist": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "layer3-ipv4-rules": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "deny"
                        ],
                        "type": "str"
                    },
                    "comment": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "dstaddr": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "dstport": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "protocol": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "rule-id": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "srcaddr": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "srcport": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "layer3-ipv6-rules": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "action": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "allow",
                            "deny"
                        ],
                        "type": "str"
                    },
                    "comment": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "dstaddr": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "dstport": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "protocol": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "rule-id": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "srcaddr": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "srcport": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "name": {
                "required": true,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "wireless_accesscontrollist_layer3ipv4rules": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "comment": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dstaddr": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dstport": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "rule-id": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "srcaddr": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "srcport": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "wireless_accesscontrollist_layer3ipv6rules": {
        "stated": true,
        "options": {
            "action": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "allow",
                    "deny"
                ],
                "type": "str"
            },
            "comment": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dstaddr": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "dstport": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "protocol": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "rule-id": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "srcaddr": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "srcport": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    },
    "wireless_address": {
        "stated": true,
        "options": {
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "mac": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "policy": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "deny",
                    "allow"
                ],
                "type": "str"
            }
        }
    },
    "wireless_addrgrp": {
        "stated": true,
        "options": {
            "addresses": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "default-policy": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "deny",
                    "allow"
                ],
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "wireless_ssidpolicy": {
        "stated": true,
        "options": {
            "description": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vlan": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "wireless_syslogprofile": {
        "stated": true,
        "options": {
            "comment": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "log-level": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "emergency",
                    "alert",
                    "critical",
                    "error",
                    "warning",
                    "notification",
                    "information",
                    "debugging"
                ],
                "type": "str"
            },
            "name": {
                "required": true,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "server-addr-type": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "fqdn",
                    "ip"
                ],
                "type": "str"
            },
            "server-fqdn": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "server-ip": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "server-port": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "server-status": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "wtpprofile": {
        "stated": true,
        "options": {
            "allowaccess": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "https",
                    "ssh",
                    "snmp",
                    "http",
                    "telnet"
                ],
                "elements": "str"
            },
            "ap-country": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "AL",
                    "DZ",
                    "AR",
                    "AM",
                    "AU",
                    "AT",
                    "AZ",
                    "BH",
                    "BD",
                    "BY",
                    "BE",
                    "BZ",
                    "BO",
                    "BA",
                    "BR",
                    "BN",
                    "BG",
                    "CA",
                    "CL",
                    "CN",
                    "CO",
                    "CR",
                    "HR",
                    "CY",
                    "CZ",
                    "DK",
                    "DO",
                    "EC",
                    "EG",
                    "SV",
                    "EE",
                    "FI",
                    "FR",
                    "GE",
                    "DE",
                    "GR",
                    "GT",
                    "HN",
                    "HK",
                    "HU",
                    "IS",
                    "IN",
                    "ID",
                    "IR",
                    "IE",
                    "IL",
                    "IT",
                    "JM",
                    "JP",
                    "JO",
                    "KZ",
                    "KE",
                    "KP",
                    "KR",
                    "KW",
                    "LV",
                    "LB",
                    "LI",
                    "LT",
                    "LU",
                    "MO",
                    "MK",
                    "MY",
                    "MT",
                    "MX",
                    "MC",
                    "MA",
                    "NP",
                    "NL",
                    "AN",
                    "NZ",
                    "NO",
                    "OM",
                    "PK",
                    "PA",
                    "PG",
                    "PE",
                    "PH",
                    "PL",
                    "PT",
                    "PR",
                    "QA",
                    "RO",
                    "RU",
                    "SA",
                    "SG",
                    "SK",
                    "SI",
                    "ZA",
                    "ES",
                    "LK",
                    "SE",
                    "CH",
                    "SY",
                    "TW",
                    "TH",
                    "TT",
                    "TN",
                    "TR",
                    "AE",
                    "UA",
                    "GB",
                    "US",
                    "PS",
                    "UY",
                    "UZ",
                    "VE",
                    "VN",
                    "YE",
                    "ZW",
                    "NA",
                    "KH",
                    "TZ",
                    "SD",
                    "AO",
                    "RW",
                    "MZ",
                    "RS",
                    "ME",
                    "BB",
                    "GD",
                    "GL",
                    "GU",
                    "PY",
                    "HT",
                    "AW",
                    "MM",
                    "ZB",
                    "CF",
                    "BS",
                    "VC",
                    "MV",
                    "SN",
                    "CI",
                    "GH",
                    "MW",
                    "UG",
                    "BF",
                    "KY",
                    "TC",
                    "TM",
                    "VU",
                    "FM",
                    "GY",
                    "KN",
                    "LC",
                    "CX",
                    "AF",
                    "CM",
                    "ML",
                    "BJ",
                    "MG",
                    "TD",
                    "BW",
                    "LY",
                    "LS",
                    "MU",
                    "SL",
                    "NE",
                    "TG",
                    "RE",
                    "MD",
                    "BM",
                    "VI",
                    "PM",
                    "MF",
                    "IM",
                    "FO",
                    "GI",
                    "LA",
                    "WF",
                    "MH",
                    "BT",
                    "PF",
                    "NI",
                    "GF",
                    "AS",
                    "MP",
                    "PW",
                    "GP",
                    "ET",
                    "SR",
                    "DM",
                    "MQ",
                    "YT",
                    "BL",
                    "ZM",
                    "CG",
                    "CD",
                    "MR",
                    "IQ",
                    "FJ",
                    "--",
                    "MN",
                    "NG",
                    "GA",
                    "GM",
                    "SO",
                    "SZ",
                    "LR",
                    "DJ"
                ],
                "type": "str"
            },
            "ble-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "comment": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "control-message-offload": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "ebp-frame",
                    "aeroscout-tag",
                    "ap-list",
                    "sta-list",
                    "sta-cap-list",
                    "stats",
                    "aeroscout-mu",
                    "sta-health",
                    "spectral-analysis"
                ],
                "elements": "str"
            },
            "deny-mac-list": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "mac": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                },
                "elements": "dict"
            },
            "dtls-in-kernel": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dtls-policy": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "clear-text",
                    "dtls-enabled",
                    "ipsec-vpn",
                    "ipsec-sn-vpn"
                ],
                "elements": "str"
            },
            "energy-efficient-ethernet": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ext-info-enable": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "handoff-roaming": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "handoff-rssi": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "handoff-sta-thresh": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ip-fragment-preventing": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "tcp-mss-adjust",
                    "icmp-unreachable"
                ],
                "elements": "str"
            },
            "led-schedules": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "led-state": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "lldp": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "login-passwd": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "login-passwd-change": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "no",
                    "yes",
                    "default"
                ],
                "type": "str"
            },
            "max-clients": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "name": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "poe-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auto",
                    "8023af",
                    "8023at",
                    "power-adapter",
                    "full",
                    "high",
                    "low"
                ],
                "type": "str"
            },
            "split-tunneling-acl": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "options": {
                    "dest-ip": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "id": {
                        "required": false,
                        "revision": {
                            "6.0.0": true,
                            "6.2.0": true,
                            "6.2.1": true,
                            "6.2.2": true,
                            "6.2.3": true,
                            "6.2.5": true,
                            "6.2.6": true,
                            "6.2.7": true,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.0": true,
                            "6.4.1": true,
                            "6.4.2": true,
                            "6.4.3": true,
                            "6.4.4": true,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    }
                },
                "elements": "dict"
            },
            "split-tunneling-acl-local-ap-subnet": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "split-tunneling-acl-path": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "tunnel",
                    "local"
                ],
                "type": "str"
            },
            "tun-mtu-downlink": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "tun-mtu-uplink": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "wan-port-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "wan-lan",
                    "wan-only"
                ],
                "type": "str"
            },
            "snmp": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": false,
                    "7.2.2": false,
                    "7.2.3": false,
                    "7.2.4": false,
                    "7.4.0": false,
                    "7.4.1": false
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ap-handoff": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "apcfg-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "frequency-handoff": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "lan": {
                "required": false,
                "type": "dict",
                "options": {
                    "port-esl-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "offline",
                            "bridge-to-wan",
                            "bridge-to-ssid",
                            "nat-to-wan"
                        ],
                        "type": "str"
                    },
                    "port-esl-ssid": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "port-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "offline",
                            "bridge-to-wan",
                            "bridge-to-ssid",
                            "nat-to-wan"
                        ],
                        "type": "str"
                    },
                    "port-ssid": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "port1-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "offline",
                            "bridge-to-wan",
                            "bridge-to-ssid",
                            "nat-to-wan"
                        ],
                        "type": "str"
                    },
                    "port1-ssid": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "port2-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "offline",
                            "bridge-to-wan",
                            "bridge-to-ssid",
                            "nat-to-wan"
                        ],
                        "type": "str"
                    },
                    "port2-ssid": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "port3-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "offline",
                            "bridge-to-wan",
                            "bridge-to-ssid",
                            "nat-to-wan"
                        ],
                        "type": "str"
                    },
                    "port3-ssid": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "port4-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "offline",
                            "bridge-to-wan",
                            "bridge-to-ssid",
                            "nat-to-wan"
                        ],
                        "type": "str"
                    },
                    "port4-ssid": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "port5-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "offline",
                            "bridge-to-wan",
                            "bridge-to-ssid",
                            "nat-to-wan"
                        ],
                        "type": "str"
                    },
                    "port5-ssid": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "port6-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "offline",
                            "bridge-to-wan",
                            "bridge-to-ssid",
                            "nat-to-wan"
                        ],
                        "type": "str"
                    },
                    "port6-ssid": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "port7-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "offline",
                            "bridge-to-wan",
                            "bridge-to-ssid",
                            "nat-to-wan"
                        ],
                        "type": "str"
                    },
                    "port7-ssid": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "port8-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "offline",
                            "bridge-to-wan",
                            "bridge-to-ssid",
                            "nat-to-wan"
                        ],
                        "type": "str"
                    },
                    "port8-ssid": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                }
            },
            "lbs": {
                "required": false,
                "type": "dict",
                "options": {
                    "aeroscout": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "aeroscout-ap-mac": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "bssid",
                            "board-mac"
                        ],
                        "type": "str"
                    },
                    "aeroscout-mmu-report": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "aeroscout-mu": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "aeroscout-mu-factor": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "aeroscout-mu-timeout": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "aeroscout-server-ip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "aeroscout-server-port": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ekahau-blink-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ekahau-tag": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "erc-server-ip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "erc-server-port": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "fortipresence": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable",
                            "enable2",
                            "foreign",
                            "both"
                        ],
                        "type": "str"
                    },
                    "fortipresence-ble": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "fortipresence-frequency": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "fortipresence-port": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "fortipresence-project": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "fortipresence-rogue": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "fortipresence-secret": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "fortipresence-server": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "fortipresence-unassoc": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "station-locate": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "fortipresence-server-addr-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "fqdn",
                            "ipv4"
                        ],
                        "type": "str"
                    },
                    "fortipresence-server-fqdn": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "polestar": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "polestar-accumulation-interval": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "polestar-asset-addrgrp-list": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "polestar-asset-uuid-list1": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "polestar-asset-uuid-list2": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "polestar-asset-uuid-list3": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "polestar-asset-uuid-list4": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "polestar-protocol": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "WSS"
                        ],
                        "type": "str"
                    },
                    "polestar-reporting-interval": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "polestar-server-fqdn": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "polestar-server-path": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "polestar-server-port": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "polestar-server-token": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "str"
                    }
                }
            },
            "platform": {
                "required": false,
                "type": "dict",
                "options": {
                    "ddscan": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "dual-5G",
                            "single-5G"
                        ],
                        "type": "str"
                    },
                    "type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "30B-50B",
                            "60B",
                            "80CM-81CM",
                            "220A",
                            "220B",
                            "210B",
                            "60C",
                            "222B",
                            "112B",
                            "320B",
                            "11C",
                            "14C",
                            "223B",
                            "28C",
                            "320C",
                            "221C",
                            "25D",
                            "222C",
                            "224D",
                            "214B",
                            "21D",
                            "24D",
                            "112D",
                            "223C",
                            "321C",
                            "C220C",
                            "C225C",
                            "S321C",
                            "S323C",
                            "FWF",
                            "S311C",
                            "S313C",
                            "AP-11N",
                            "S322C",
                            "S321CR",
                            "S322CR",
                            "S323CR",
                            "S421E",
                            "S422E",
                            "S423E",
                            "421E",
                            "423E",
                            "C221E",
                            "C226E",
                            "C23JD",
                            "C24JE",
                            "C21D",
                            "U421E",
                            "U423E",
                            "221E",
                            "222E",
                            "223E",
                            "S221E",
                            "S223E",
                            "U221EV",
                            "U223EV",
                            "U321EV",
                            "U323EV",
                            "224E",
                            "U422EV",
                            "U24JEV",
                            "321E",
                            "U431F",
                            "U433F",
                            "231E",
                            "431F",
                            "433F",
                            "231F",
                            "432F",
                            "234F",
                            "23JF",
                            "U231F",
                            "831F",
                            "U234F",
                            "U432F",
                            "431FL",
                            "432FR",
                            "433FL",
                            "231FL",
                            "231G",
                            "233G",
                            "431G",
                            "433G",
                            "U231G",
                            "U441G",
                            "234G"
                        ],
                        "type": "str"
                    },
                    "_local_platform_str": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    }
                }
            },
            "radio-1": {
                "required": false,
                "type": "dict",
                "options": {
                    "airtime-fairness": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "amsdu": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ap-sniffer-addr": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ap-sniffer-bufsize": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ap-sniffer-chan": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ap-sniffer-ctl": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ap-sniffer-data": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ap-sniffer-mgmt-beacon": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ap-sniffer-mgmt-other": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ap-sniffer-mgmt-probe": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "auto-power-high": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "auto-power-level": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "auto-power-low": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "auto-power-target": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "band": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "802.11b",
                            "802.11a",
                            "802.11g",
                            "802.11n",
                            "802.11ac",
                            "802.11n-5G",
                            "802.11ax-5G",
                            "802.11ax",
                            "802.11ac-2G",
                            "802.11g-only",
                            "802.11n-only",
                            "802.11n,g-only",
                            "802.11ac-only",
                            "802.11ac,n-only",
                            "802.11n-5G-only",
                            "802.11ax-5G-only",
                            "802.11ax,ac-only",
                            "802.11ax,ac,n-only",
                            "802.11ax-only",
                            "802.11ax,n-only",
                            "802.11ax,n,g-only",
                            "802.11ax-6G"
                        ],
                        "type": "str"
                    },
                    "band-5g-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "5g-full",
                            "5g-high",
                            "5g-low"
                        ],
                        "type": "str"
                    },
                    "bandwidth-admission-control": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "bandwidth-capacity": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "beacon-interval": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "bss-color": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "call-admission-control": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "call-capacity": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "channel": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "channel-bonding": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable",
                            "80MHz",
                            "40MHz",
                            "20MHz",
                            "160MHz"
                        ],
                        "type": "str"
                    },
                    "channel-utilization": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "coexistence": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "darrp": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "drma": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "drma-sensitivity": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "low",
                            "medium",
                            "high"
                        ],
                        "type": "str"
                    },
                    "dtim": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "frag-threshold": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "max-clients": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "max-distance": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disabled",
                            "ap",
                            "monitor",
                            "sniffer",
                            "sam"
                        ],
                        "type": "str"
                    },
                    "power-level": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "powersave-optimize": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "tim",
                            "ac-vo",
                            "no-obss-scan",
                            "no-11b-rate",
                            "client-rate-follow"
                        ],
                        "elements": "str"
                    },
                    "protection-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "rtscts",
                            "ctsonly",
                            "disable"
                        ],
                        "type": "str"
                    },
                    "radio-id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "rts-threshold": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "short-guard-interval": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "spectrum-analysis": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable",
                            "scan-only"
                        ],
                        "type": "str"
                    },
                    "transmit-optimize": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "disable",
                            "power-save",
                            "aggr-limit",
                            "retry-limit",
                            "send-bar"
                        ],
                        "elements": "str"
                    },
                    "vap-all": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable",
                            "tunnel",
                            "bridge",
                            "manual"
                        ],
                        "type": "str"
                    },
                    "vap1": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vap2": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vap3": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vap4": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vap5": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vap6": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vap7": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vap8": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vaps": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "wids-profile": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "zero-wait-dfs": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "frequency-handoff": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ap-handoff": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "iperf-protocol": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "udp",
                            "tcp"
                        ],
                        "type": "str"
                    },
                    "iperf-server-port": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "power-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "dBm",
                            "percentage"
                        ],
                        "type": "str"
                    },
                    "power-value": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "sam-bssid": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sam-captive-portal": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "sam-password": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "sam-report-intv": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "sam-security-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "open",
                            "wpa-personal",
                            "wpa-enterprise"
                        ],
                        "type": "str"
                    },
                    "sam-server": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sam-ssid": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sam-test": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ping",
                            "iperf"
                        ],
                        "type": "str"
                    },
                    "sam-username": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "arrp-profile": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "bss-color-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "auto",
                            "static"
                        ],
                        "type": "str"
                    },
                    "sam-cwp-failure-string": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sam-cwp-match-string": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sam-cwp-password": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "sam-cwp-success-string": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sam-cwp-test-url": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sam-cwp-username": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sam-server-fqdn": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sam-server-ip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sam-server-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ip",
                            "fqdn"
                        ],
                        "type": "str"
                    },
                    "80211d": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "optional-antenna": {
                        "required": false,
                        "revision": {
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "FANT-04ABGN-0606-O-N",
                            "FANT-04ABGN-1414-P-N",
                            "FANT-04ABGN-8065-P-N",
                            "FANT-04ABGN-0606-O-R",
                            "FANT-04ABGN-0606-P-R",
                            "FANT-10ACAX-1213-D-N",
                            "FANT-08ABGN-1213-D-R"
                        ],
                        "type": "str"
                    },
                    "mimo-mode": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "default",
                            "1x1",
                            "2x2",
                            "3x3",
                            "4x4",
                            "8x8"
                        ],
                        "type": "str"
                    }
                }
            },
            "radio-2": {
                "required": false,
                "type": "dict",
                "options": {
                    "airtime-fairness": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "amsdu": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ap-sniffer-addr": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ap-sniffer-bufsize": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ap-sniffer-chan": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ap-sniffer-ctl": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ap-sniffer-data": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ap-sniffer-mgmt-beacon": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ap-sniffer-mgmt-other": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ap-sniffer-mgmt-probe": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "auto-power-high": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "auto-power-level": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "auto-power-low": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "auto-power-target": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "band": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "802.11b",
                            "802.11a",
                            "802.11g",
                            "802.11n",
                            "802.11ac",
                            "802.11n-5G",
                            "802.11ax-5G",
                            "802.11ax",
                            "802.11ac-2G",
                            "802.11g-only",
                            "802.11n-only",
                            "802.11n,g-only",
                            "802.11ac-only",
                            "802.11ac,n-only",
                            "802.11n-5G-only",
                            "802.11ax-5G-only",
                            "802.11ax,ac-only",
                            "802.11ax,ac,n-only",
                            "802.11ax-only",
                            "802.11ax,n-only",
                            "802.11ax,n,g-only",
                            "802.11ax-6G"
                        ],
                        "type": "str"
                    },
                    "band-5g-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "5g-full",
                            "5g-high",
                            "5g-low"
                        ],
                        "type": "str"
                    },
                    "bandwidth-admission-control": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "bandwidth-capacity": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "beacon-interval": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "bss-color": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "call-admission-control": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "call-capacity": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "channel": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "channel-bonding": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable",
                            "80MHz",
                            "40MHz",
                            "20MHz",
                            "160MHz"
                        ],
                        "type": "str"
                    },
                    "channel-utilization": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "coexistence": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "darrp": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "drma": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "drma-sensitivity": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "low",
                            "medium",
                            "high"
                        ],
                        "type": "str"
                    },
                    "dtim": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "frag-threshold": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "max-clients": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "max-distance": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disabled",
                            "ap",
                            "monitor",
                            "sniffer",
                            "sam"
                        ],
                        "type": "str"
                    },
                    "power-level": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "powersave-optimize": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "tim",
                            "ac-vo",
                            "no-obss-scan",
                            "no-11b-rate",
                            "client-rate-follow"
                        ],
                        "elements": "str"
                    },
                    "protection-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "rtscts",
                            "ctsonly",
                            "disable"
                        ],
                        "type": "str"
                    },
                    "radio-id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "rts-threshold": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "short-guard-interval": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "spectrum-analysis": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable",
                            "scan-only"
                        ],
                        "type": "str"
                    },
                    "transmit-optimize": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "disable",
                            "power-save",
                            "aggr-limit",
                            "retry-limit",
                            "send-bar"
                        ],
                        "elements": "str"
                    },
                    "vap-all": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable",
                            "tunnel",
                            "bridge",
                            "manual"
                        ],
                        "type": "str"
                    },
                    "vap1": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vap2": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vap3": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vap4": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vap5": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vap6": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vap7": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vap8": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vaps": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "wids-profile": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "zero-wait-dfs": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "frequency-handoff": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ap-handoff": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "iperf-protocol": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "udp",
                            "tcp"
                        ],
                        "type": "str"
                    },
                    "iperf-server-port": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "power-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "dBm",
                            "percentage"
                        ],
                        "type": "str"
                    },
                    "power-value": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "sam-bssid": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sam-captive-portal": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "sam-password": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "sam-report-intv": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "sam-security-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "open",
                            "wpa-personal",
                            "wpa-enterprise"
                        ],
                        "type": "str"
                    },
                    "sam-server": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sam-ssid": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sam-test": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ping",
                            "iperf"
                        ],
                        "type": "str"
                    },
                    "sam-username": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "arrp-profile": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "bss-color-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "auto",
                            "static"
                        ],
                        "type": "str"
                    },
                    "sam-cwp-failure-string": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sam-cwp-match-string": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sam-cwp-password": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "sam-cwp-success-string": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sam-cwp-test-url": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sam-cwp-username": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sam-server-fqdn": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sam-server-ip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sam-server-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ip",
                            "fqdn"
                        ],
                        "type": "str"
                    },
                    "80211d": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "optional-antenna": {
                        "required": false,
                        "revision": {
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "FANT-04ABGN-0606-O-N",
                            "FANT-04ABGN-1414-P-N",
                            "FANT-04ABGN-8065-P-N",
                            "FANT-04ABGN-0606-O-R",
                            "FANT-04ABGN-0606-P-R",
                            "FANT-10ACAX-1213-D-N",
                            "FANT-08ABGN-1213-D-R"
                        ],
                        "type": "str"
                    },
                    "mimo-mode": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "default",
                            "1x1",
                            "2x2",
                            "3x3",
                            "4x4",
                            "8x8"
                        ],
                        "type": "str"
                    }
                }
            },
            "radio-3": {
                "required": false,
                "type": "dict",
                "options": {
                    "airtime-fairness": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "amsdu": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ap-sniffer-addr": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ap-sniffer-bufsize": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ap-sniffer-chan": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ap-sniffer-ctl": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ap-sniffer-data": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ap-sniffer-mgmt-beacon": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ap-sniffer-mgmt-other": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ap-sniffer-mgmt-probe": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "auto-power-high": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "auto-power-level": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "auto-power-low": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "auto-power-target": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "band": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "802.11b",
                            "802.11a",
                            "802.11g",
                            "802.11n",
                            "802.11ac",
                            "802.11n-5G",
                            "802.11ax-5G",
                            "802.11ax",
                            "802.11ac-2G",
                            "802.11g-only",
                            "802.11n-only",
                            "802.11n,g-only",
                            "802.11ac-only",
                            "802.11ac,n-only",
                            "802.11n-5G-only",
                            "802.11ax-5G-only",
                            "802.11ax,ac-only",
                            "802.11ax,ac,n-only",
                            "802.11ax-only",
                            "802.11ax,n-only",
                            "802.11ax,n,g-only",
                            "802.11ax-6G"
                        ],
                        "type": "str"
                    },
                    "band-5g-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "5g-full",
                            "5g-high",
                            "5g-low"
                        ],
                        "type": "str"
                    },
                    "bandwidth-admission-control": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "bandwidth-capacity": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "beacon-interval": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "bss-color": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "call-admission-control": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "call-capacity": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "channel": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "channel-bonding": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "80MHz",
                            "40MHz",
                            "20MHz",
                            "160MHz"
                        ],
                        "type": "str"
                    },
                    "channel-utilization": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "coexistence": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "darrp": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "drma": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "drma-sensitivity": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "low",
                            "medium",
                            "high"
                        ],
                        "type": "str"
                    },
                    "dtim": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "frag-threshold": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "max-clients": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "max-distance": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disabled",
                            "ap",
                            "monitor",
                            "sniffer",
                            "sam"
                        ],
                        "type": "str"
                    },
                    "power-level": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "powersave-optimize": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "tim",
                            "ac-vo",
                            "no-obss-scan",
                            "no-11b-rate",
                            "client-rate-follow"
                        ],
                        "elements": "str"
                    },
                    "protection-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "rtscts",
                            "ctsonly",
                            "disable"
                        ],
                        "type": "str"
                    },
                    "radio-id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "rts-threshold": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "short-guard-interval": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "spectrum-analysis": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable",
                            "scan-only"
                        ],
                        "type": "str"
                    },
                    "transmit-optimize": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "disable",
                            "power-save",
                            "aggr-limit",
                            "retry-limit",
                            "send-bar"
                        ],
                        "elements": "str"
                    },
                    "vap-all": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable",
                            "tunnel",
                            "bridge",
                            "manual"
                        ],
                        "type": "str"
                    },
                    "vap1": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vap2": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vap3": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vap4": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vap5": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vap6": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vap7": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vap8": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vaps": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "wids-profile": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "zero-wait-dfs": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "frequency-handoff": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ap-handoff": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "iperf-protocol": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "udp",
                            "tcp"
                        ],
                        "type": "str"
                    },
                    "iperf-server-port": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "power-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "dBm",
                            "percentage"
                        ],
                        "type": "str"
                    },
                    "power-value": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "sam-bssid": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sam-captive-portal": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "sam-password": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "sam-report-intv": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "sam-security-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "open",
                            "wpa-personal",
                            "wpa-enterprise"
                        ],
                        "type": "str"
                    },
                    "sam-server": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sam-ssid": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sam-test": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ping",
                            "iperf"
                        ],
                        "type": "str"
                    },
                    "sam-username": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "arrp-profile": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "bss-color-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "auto",
                            "static"
                        ],
                        "type": "str"
                    },
                    "sam-cwp-failure-string": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sam-cwp-match-string": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sam-cwp-password": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "sam-cwp-success-string": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sam-cwp-test-url": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sam-cwp-username": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sam-server-fqdn": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sam-server-ip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sam-server-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ip",
                            "fqdn"
                        ],
                        "type": "str"
                    },
                    "80211d": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "optional-antenna": {
                        "required": false,
                        "revision": {
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "FANT-04ABGN-0606-O-N",
                            "FANT-04ABGN-1414-P-N",
                            "FANT-04ABGN-8065-P-N",
                            "FANT-04ABGN-0606-O-R",
                            "FANT-04ABGN-0606-P-R",
                            "FANT-10ACAX-1213-D-N",
                            "FANT-08ABGN-1213-D-R"
                        ],
                        "type": "str"
                    },
                    "mimo-mode": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "default",
                            "1x1",
                            "2x2",
                            "3x3",
                            "4x4",
                            "8x8"
                        ],
                        "type": "str"
                    }
                }
            },
            "radio-4": {
                "required": false,
                "type": "dict",
                "options": {
                    "airtime-fairness": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "amsdu": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ap-sniffer-addr": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "ap-sniffer-bufsize": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ap-sniffer-chan": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "ap-sniffer-ctl": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ap-sniffer-data": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ap-sniffer-mgmt-beacon": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ap-sniffer-mgmt-other": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ap-sniffer-mgmt-probe": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "auto-power-high": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "auto-power-level": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "auto-power-low": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "auto-power-target": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "band": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "802.11b",
                            "802.11a",
                            "802.11g",
                            "802.11n",
                            "802.11ac",
                            "802.11n-5G",
                            "802.11ax-5G",
                            "802.11ax",
                            "802.11ac-2G",
                            "802.11g-only",
                            "802.11n-only",
                            "802.11n,g-only",
                            "802.11ac-only",
                            "802.11ac,n-only",
                            "802.11n-5G-only",
                            "802.11ax-5G-only",
                            "802.11ax,ac-only",
                            "802.11ax,ac,n-only",
                            "802.11ax-only",
                            "802.11ax,n-only",
                            "802.11ax,n,g-only",
                            "802.11ax-6G"
                        ],
                        "type": "str"
                    },
                    "band-5g-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "5g-full",
                            "5g-high",
                            "5g-low"
                        ],
                        "type": "str"
                    },
                    "bandwidth-admission-control": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "bandwidth-capacity": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "beacon-interval": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "bss-color": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "call-admission-control": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "call-capacity": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "channel": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "channel-bonding": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "80MHz",
                            "40MHz",
                            "20MHz",
                            "160MHz"
                        ],
                        "type": "str"
                    },
                    "channel-utilization": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "coexistence": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "darrp": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "drma": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "drma-sensitivity": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "low",
                            "medium",
                            "high"
                        ],
                        "type": "str"
                    },
                    "dtim": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "frag-threshold": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "max-clients": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "max-distance": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ap",
                            "monitor",
                            "sniffer",
                            "disabled",
                            "sam"
                        ],
                        "type": "str"
                    },
                    "power-level": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "powersave-optimize": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "tim",
                            "ac-vo",
                            "no-obss-scan",
                            "no-11b-rate",
                            "client-rate-follow"
                        ],
                        "elements": "str"
                    },
                    "protection-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "rtscts",
                            "ctsonly",
                            "disable"
                        ],
                        "type": "str"
                    },
                    "radio-id": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "rts-threshold": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "short-guard-interval": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "spectrum-analysis": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable",
                            "scan-only"
                        ],
                        "type": "str"
                    },
                    "transmit-optimize": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "list",
                        "choices": [
                            "disable",
                            "power-save",
                            "aggr-limit",
                            "retry-limit",
                            "send-bar"
                        ],
                        "elements": "str"
                    },
                    "vap-all": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable",
                            "tunnel",
                            "bridge",
                            "manual"
                        ],
                        "type": "str"
                    },
                    "vap1": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vap2": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vap3": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vap4": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vap5": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vap6": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vap7": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vap8": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "vaps": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "raw"
                    },
                    "wids-profile": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "zero-wait-dfs": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "frequency-handoff": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "ap-handoff": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": true,
                            "6.2.9": true,
                            "6.2.10": true,
                            "6.2.11": true,
                            "6.2.12": true,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.5": true,
                            "6.4.6": true,
                            "6.4.7": true,
                            "6.4.8": true,
                            "6.4.9": true,
                            "6.4.10": true,
                            "6.4.11": true,
                            "6.4.12": true,
                            "6.4.13": true,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "iperf-protocol": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "udp",
                            "tcp"
                        ],
                        "type": "str"
                    },
                    "iperf-server-port": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "power-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "dBm",
                            "percentage"
                        ],
                        "type": "str"
                    },
                    "power-value": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "sam-bssid": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sam-captive-portal": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "sam-password": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "sam-report-intv": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "sam-security-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "open",
                            "wpa-personal",
                            "wpa-enterprise"
                        ],
                        "type": "str"
                    },
                    "sam-server": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sam-ssid": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sam-test": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ping",
                            "iperf"
                        ],
                        "type": "str"
                    },
                    "sam-username": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.0": true,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "arrp-profile": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": false,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "bss-color-mode": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": false,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "auto",
                            "static"
                        ],
                        "type": "str"
                    },
                    "sam-cwp-failure-string": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sam-cwp-match-string": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sam-cwp-password": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "no_log": true,
                        "type": "raw"
                    },
                    "sam-cwp-success-string": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sam-cwp-test-url": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sam-cwp-username": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sam-server-fqdn": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sam-server-ip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "sam-server-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "ip",
                            "fqdn"
                        ],
                        "type": "str"
                    },
                    "80211d": {
                        "required": false,
                        "revision": {
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "optional-antenna": {
                        "required": false,
                        "revision": {
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none",
                            "FANT-04ABGN-0606-O-N",
                            "FANT-04ABGN-1414-P-N",
                            "FANT-04ABGN-8065-P-N",
                            "FANT-04ABGN-0606-O-R",
                            "FANT-04ABGN-0606-P-R",
                            "FANT-10ACAX-1213-D-N",
                            "FANT-08ABGN-1213-D-R"
                        ],
                        "type": "str"
                    },
                    "mimo-mode": {
                        "required": false,
                        "revision": {
                            "7.4.1": true
                        },
                        "choices": [
                            "default",
                            "1x1",
                            "2x2",
                            "3x3",
                            "4x4",
                            "8x8"
                        ],
                        "type": "str"
                    }
                }
            },
            "console-login": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "esl-ses-dongle": {
                "required": false,
                "type": "dict",
                "options": {
                    "apc-addr-type": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "fqdn",
                            "ip"
                        ],
                        "type": "str"
                    },
                    "apc-fqdn": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "apc-ip": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "str"
                    },
                    "apc-port": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "type": "int"
                    },
                    "coex-level": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "none"
                        ],
                        "type": "str"
                    },
                    "compliance-level": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "compliance-level-2"
                        ],
                        "type": "str"
                    },
                    "esl-channel": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "0",
                            "1",
                            "2",
                            "3",
                            "4",
                            "5",
                            "6",
                            "7",
                            "8",
                            "9",
                            "10",
                            "127",
                            "-1"
                        ],
                        "type": "str"
                    },
                    "output-power": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "a",
                            "b",
                            "c",
                            "d",
                            "e",
                            "f",
                            "g",
                            "h"
                        ],
                        "type": "str"
                    },
                    "scd-enable": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "tls-cert-verification": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    },
                    "tls-fqdn-verification": {
                        "required": false,
                        "revision": {
                            "6.2.0": false,
                            "6.2.2": false,
                            "6.2.6": false,
                            "6.2.7": false,
                            "6.2.8": false,
                            "6.2.9": false,
                            "6.2.10": false,
                            "6.2.11": false,
                            "6.2.12": false,
                            "6.4.1": false,
                            "6.4.3": false,
                            "6.4.4": false,
                            "6.4.6": false,
                            "6.4.7": false,
                            "6.4.8": false,
                            "6.4.9": false,
                            "6.4.10": false,
                            "6.4.11": false,
                            "6.4.12": false,
                            "6.4.13": false,
                            "7.0.1": true,
                            "7.0.2": true,
                            "7.0.3": true,
                            "7.0.4": true,
                            "7.0.5": true,
                            "7.0.6": true,
                            "7.0.7": true,
                            "7.0.8": true,
                            "7.0.9": true,
                            "7.2.0": true,
                            "7.2.1": true,
                            "7.2.2": true,
                            "7.2.3": true,
                            "7.2.4": true,
                            "7.4.0": true,
                            "7.4.1": true
                        },
                        "choices": [
                            "disable",
                            "enable"
                        ],
                        "type": "str"
                    }
                }
            },
            "indoor-outdoor-deployment": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "platform-determined",
                    "outdoor",
                    "indoor"
                ],
                "type": "str"
            },
            "syslog-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "wan-port-auth": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "802.1x"
                ],
                "type": "str"
            },
            "wan-port-auth-methods": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "all",
                    "EAP-FAST",
                    "EAP-TLS",
                    "EAP-PEAP"
                ],
                "type": "str"
            },
            "wan-port-auth-password": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "wan-port-auth-usrname": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "_is_factory_setting": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "ext"
                ],
                "type": "str"
            },
            "unii-4-5ghz-band": {
                "required": false,
                "revision": {
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "wtpprofile_denymaclist": {
        "stated": true,
        "options": {
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mac": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "wtpprofile_eslsesdongle": {
        "stated": false,
        "options": {
            "apc-addr-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "fqdn",
                    "ip"
                ],
                "type": "str"
            },
            "apc-fqdn": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "apc-ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "apc-port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "coex-level": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none"
                ],
                "type": "str"
            },
            "compliance-level": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "compliance-level-2"
                ],
                "type": "str"
            },
            "esl-channel": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "0",
                    "1",
                    "2",
                    "3",
                    "4",
                    "5",
                    "6",
                    "7",
                    "8",
                    "9",
                    "10",
                    "127",
                    "-1"
                ],
                "type": "str"
            },
            "output-power": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "a",
                    "b",
                    "c",
                    "d",
                    "e",
                    "f",
                    "g",
                    "h"
                ],
                "type": "str"
            },
            "scd-enable": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tls-cert-verification": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "tls-fqdn-verification": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            }
        }
    },
    "wtpprofile_lan": {
        "stated": false,
        "options": {
            "port-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "offline",
                    "bridge-to-wan",
                    "bridge-to-ssid",
                    "nat-to-wan"
                ],
                "type": "str"
            },
            "port-ssid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "port1-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "offline",
                    "bridge-to-wan",
                    "bridge-to-ssid",
                    "nat-to-wan"
                ],
                "type": "str"
            },
            "port1-ssid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "port2-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "offline",
                    "bridge-to-wan",
                    "bridge-to-ssid",
                    "nat-to-wan"
                ],
                "type": "str"
            },
            "port2-ssid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "port3-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "offline",
                    "bridge-to-wan",
                    "bridge-to-ssid",
                    "nat-to-wan"
                ],
                "type": "str"
            },
            "port3-ssid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "port4-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "offline",
                    "bridge-to-wan",
                    "bridge-to-ssid",
                    "nat-to-wan"
                ],
                "type": "str"
            },
            "port4-ssid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "port5-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "offline",
                    "bridge-to-wan",
                    "bridge-to-ssid",
                    "nat-to-wan"
                ],
                "type": "str"
            },
            "port5-ssid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "port6-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "offline",
                    "bridge-to-wan",
                    "bridge-to-ssid",
                    "nat-to-wan"
                ],
                "type": "str"
            },
            "port6-ssid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "port7-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "offline",
                    "bridge-to-wan",
                    "bridge-to-ssid",
                    "nat-to-wan"
                ],
                "type": "str"
            },
            "port7-ssid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "port8-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "offline",
                    "bridge-to-wan",
                    "bridge-to-ssid",
                    "nat-to-wan"
                ],
                "type": "str"
            },
            "port8-ssid": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "port-esl-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "offline",
                    "bridge-to-wan",
                    "bridge-to-ssid",
                    "nat-to-wan"
                ],
                "type": "str"
            },
            "port-esl-ssid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "wtpprofile_lbs": {
        "stated": false,
        "options": {
            "aeroscout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "aeroscout-ap-mac": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "bssid",
                    "board-mac"
                ],
                "type": "str"
            },
            "aeroscout-mmu-report": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "aeroscout-mu": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "aeroscout-mu-factor": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "aeroscout-mu-timeout": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "aeroscout-server-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "aeroscout-server-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ekahau-blink-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ekahau-tag": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "erc-server-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "erc-server-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fortipresence": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "enable2",
                    "foreign",
                    "both"
                ],
                "type": "str"
            },
            "fortipresence-frequency": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fortipresence-port": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "fortipresence-project": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "fortipresence-rogue": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fortipresence-secret": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "fortipresence-server": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "fortipresence-unassoc": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "station-locate": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fortipresence-ble": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "fortipresence-server-addr-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "fqdn",
                    "ipv4"
                ],
                "type": "str"
            },
            "fortipresence-server-fqdn": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "polestar": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "polestar-accumulation-interval": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "polestar-asset-addrgrp-list": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "polestar-asset-uuid-list1": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "polestar-asset-uuid-list2": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "polestar-asset-uuid-list3": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "polestar-asset-uuid-list4": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "polestar-protocol": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "WSS"
                ],
                "type": "str"
            },
            "polestar-reporting-interval": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "polestar-server-fqdn": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "polestar-server-path": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "str"
            },
            "polestar-server-port": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "type": "int"
            },
            "polestar-server-token": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "no_log": true,
                "type": "str"
            }
        }
    },
    "wtpprofile_platform": {
        "stated": false,
        "options": {
            "type": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "30B-50B",
                    "60B",
                    "80CM-81CM",
                    "220A",
                    "220B",
                    "210B",
                    "60C",
                    "222B",
                    "112B",
                    "320B",
                    "11C",
                    "14C",
                    "223B",
                    "28C",
                    "320C",
                    "221C",
                    "25D",
                    "222C",
                    "224D",
                    "214B",
                    "21D",
                    "24D",
                    "112D",
                    "223C",
                    "321C",
                    "C220C",
                    "C225C",
                    "S321C",
                    "S323C",
                    "FWF",
                    "S311C",
                    "S313C",
                    "AP-11N",
                    "S322C",
                    "S321CR",
                    "S322CR",
                    "S323CR",
                    "S421E",
                    "S422E",
                    "S423E",
                    "421E",
                    "423E",
                    "C221E",
                    "C226E",
                    "C23JD",
                    "C24JE",
                    "C21D",
                    "U421E",
                    "U423E",
                    "221E",
                    "222E",
                    "223E",
                    "S221E",
                    "S223E",
                    "U221EV",
                    "U223EV",
                    "U321EV",
                    "U323EV",
                    "224E",
                    "U422EV",
                    "U24JEV",
                    "321E",
                    "U431F",
                    "U433F",
                    "231E",
                    "431F",
                    "433F",
                    "231F",
                    "432F",
                    "234F",
                    "23JF",
                    "U231F",
                    "831F",
                    "U234F",
                    "U432F",
                    "431FL",
                    "432FR",
                    "433FL",
                    "231FL",
                    "231G",
                    "233G",
                    "431G",
                    "433G",
                    "U231G",
                    "U441G",
                    "234G"
                ],
                "type": "str"
            },
            "mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "dual-5G",
                    "single-5G"
                ],
                "type": "str"
            },
            "ddscan": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "_local_platform_str": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            }
        }
    },
    "wtpprofile_radio1": {
        "stated": false,
        "options": {
            "amsdu": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ap-handoff": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ap-sniffer-addr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ap-sniffer-bufsize": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ap-sniffer-chan": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ap-sniffer-ctl": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ap-sniffer-data": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ap-sniffer-mgmt-beacon": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ap-sniffer-mgmt-other": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ap-sniffer-mgmt-probe": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "auto-power-high": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "auto-power-level": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "auto-power-low": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "band": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "802.11b",
                    "802.11a",
                    "802.11g",
                    "802.11n",
                    "802.11ac",
                    "802.11n-5G",
                    "802.11g-only",
                    "802.11n-only",
                    "802.11n,g-only",
                    "802.11ac-only",
                    "802.11ac,n-only",
                    "802.11n-5G-only",
                    "802.11ax-5G",
                    "802.11ax",
                    "802.11ax-5G-only",
                    "802.11ax,ac-only",
                    "802.11ax,ac,n-only",
                    "802.11ax-only",
                    "802.11ax,n-only",
                    "802.11ax,n,g-only",
                    "802.11ac-2G",
                    "802.11ax-6G"
                ],
                "type": "str"
            },
            "bandwidth-admission-control": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "bandwidth-capacity": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "beacon-interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "call-admission-control": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "call-capacity": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "channel": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "channel-bonding": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "80MHz",
                    "40MHz",
                    "20MHz",
                    "160MHz"
                ],
                "type": "str"
            },
            "channel-utilization": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "coexistence": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "darrp": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dtim": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "frag-threshold": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "frequency-handoff": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "max-clients": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "max-distance": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disabled",
                    "ap",
                    "monitor",
                    "sniffer",
                    "sam"
                ],
                "type": "str"
            },
            "power-level": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "powersave-optimize": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "tim",
                    "ac-vo",
                    "no-obss-scan",
                    "no-11b-rate",
                    "client-rate-follow"
                ],
                "elements": "str"
            },
            "protection-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "rtscts",
                    "ctsonly",
                    "disable"
                ],
                "type": "str"
            },
            "radio-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "rts-threshold": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "short-guard-interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "spectrum-analysis": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "scan-only"
                ],
                "type": "str"
            },
            "transmit-optimize": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "disable",
                    "power-save",
                    "aggr-limit",
                    "retry-limit",
                    "send-bar"
                ],
                "elements": "str"
            },
            "vap-all": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "tunnel",
                    "bridge",
                    "manual"
                ],
                "type": "str"
            },
            "vaps": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "wids-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "airtime-fairness": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "band-5g-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "5g-full",
                    "5g-high",
                    "5g-low"
                ],
                "type": "str"
            },
            "zero-wait-dfs": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "vap1": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vap2": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vap3": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vap4": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vap5": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vap6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vap7": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vap8": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "bss-color": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "auto-power-target": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "drma": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "drma-sensitivity": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "low",
                    "medium",
                    "high"
                ],
                "type": "str"
            },
            "iperf-protocol": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "udp",
                    "tcp"
                ],
                "type": "str"
            },
            "iperf-server-port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "power-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "dBm",
                    "percentage"
                ],
                "type": "str"
            },
            "power-value": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "sam-bssid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sam-captive-portal": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sam-password": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "sam-report-intv": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "sam-security-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "open",
                    "wpa-personal",
                    "wpa-enterprise"
                ],
                "type": "str"
            },
            "sam-server": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sam-ssid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sam-test": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ping",
                    "iperf"
                ],
                "type": "str"
            },
            "sam-username": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "arrp-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "bss-color-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auto",
                    "static"
                ],
                "type": "str"
            },
            "sam-cwp-failure-string": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sam-cwp-match-string": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sam-cwp-password": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "sam-cwp-success-string": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sam-cwp-test-url": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sam-cwp-username": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sam-server-fqdn": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sam-server-ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sam-server-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ip",
                    "fqdn"
                ],
                "type": "str"
            },
            "80211d": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "optional-antenna": {
                "required": false,
                "revision": {
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "FANT-04ABGN-0606-O-N",
                    "FANT-04ABGN-1414-P-N",
                    "FANT-04ABGN-8065-P-N",
                    "FANT-04ABGN-0606-O-R",
                    "FANT-04ABGN-0606-P-R",
                    "FANT-10ACAX-1213-D-N",
                    "FANT-08ABGN-1213-D-R"
                ],
                "type": "str"
            },
            "mimo-mode": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "default",
                    "1x1",
                    "2x2",
                    "3x3",
                    "4x4",
                    "8x8"
                ],
                "type": "str"
            }
        }
    },
    "wtpprofile_radio2": {
        "stated": false,
        "options": {
            "amsdu": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ap-handoff": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ap-sniffer-addr": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ap-sniffer-bufsize": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ap-sniffer-chan": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ap-sniffer-ctl": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ap-sniffer-data": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ap-sniffer-mgmt-beacon": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ap-sniffer-mgmt-other": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ap-sniffer-mgmt-probe": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "auto-power-high": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "auto-power-level": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "auto-power-low": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "band": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "802.11b",
                    "802.11a",
                    "802.11g",
                    "802.11n",
                    "802.11ac",
                    "802.11n-5G",
                    "802.11g-only",
                    "802.11n-only",
                    "802.11n,g-only",
                    "802.11ac-only",
                    "802.11ac,n-only",
                    "802.11n-5G-only",
                    "802.11ax-5G",
                    "802.11ax",
                    "802.11ax-5G-only",
                    "802.11ax,ac-only",
                    "802.11ax,ac,n-only",
                    "802.11ax-only",
                    "802.11ax,n-only",
                    "802.11ax,n,g-only",
                    "802.11ac-2G",
                    "802.11ax-6G"
                ],
                "type": "str"
            },
            "bandwidth-admission-control": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "bandwidth-capacity": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "beacon-interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "call-admission-control": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "call-capacity": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "channel": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "channel-bonding": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "80MHz",
                    "40MHz",
                    "20MHz",
                    "160MHz"
                ],
                "type": "str"
            },
            "channel-utilization": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "coexistence": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "darrp": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dtim": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "frag-threshold": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "frequency-handoff": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "max-clients": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "max-distance": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disabled",
                    "ap",
                    "monitor",
                    "sniffer",
                    "sam"
                ],
                "type": "str"
            },
            "power-level": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "powersave-optimize": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "tim",
                    "ac-vo",
                    "no-obss-scan",
                    "no-11b-rate",
                    "client-rate-follow"
                ],
                "elements": "str"
            },
            "protection-mode": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "rtscts",
                    "ctsonly",
                    "disable"
                ],
                "type": "str"
            },
            "radio-id": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "rts-threshold": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "short-guard-interval": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "spectrum-analysis": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "scan-only"
                ],
                "type": "str"
            },
            "transmit-optimize": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "disable",
                    "power-save",
                    "aggr-limit",
                    "retry-limit",
                    "send-bar"
                ],
                "elements": "str"
            },
            "vap-all": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "tunnel",
                    "bridge",
                    "manual"
                ],
                "type": "str"
            },
            "vaps": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "wids-profile": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "airtime-fairness": {
                "required": false,
                "revision": {
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "band-5g-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "5g-full",
                    "5g-high",
                    "5g-low"
                ],
                "type": "str"
            },
            "zero-wait-dfs": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "vap1": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vap2": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vap3": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vap4": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vap5": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vap6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vap7": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vap8": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "bss-color": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "auto-power-target": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "drma": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "drma-sensitivity": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "low",
                    "medium",
                    "high"
                ],
                "type": "str"
            },
            "iperf-protocol": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "udp",
                    "tcp"
                ],
                "type": "str"
            },
            "iperf-server-port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "power-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "dBm",
                    "percentage"
                ],
                "type": "str"
            },
            "power-value": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "sam-bssid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sam-captive-portal": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sam-password": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "sam-report-intv": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "sam-security-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "open",
                    "wpa-personal",
                    "wpa-enterprise"
                ],
                "type": "str"
            },
            "sam-server": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sam-ssid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sam-test": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ping",
                    "iperf"
                ],
                "type": "str"
            },
            "sam-username": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "arrp-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "bss-color-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auto",
                    "static"
                ],
                "type": "str"
            },
            "sam-cwp-failure-string": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sam-cwp-match-string": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sam-cwp-password": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "sam-cwp-success-string": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sam-cwp-test-url": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sam-cwp-username": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sam-server-fqdn": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sam-server-ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sam-server-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ip",
                    "fqdn"
                ],
                "type": "str"
            },
            "80211d": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "optional-antenna": {
                "required": false,
                "revision": {
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "FANT-04ABGN-0606-O-N",
                    "FANT-04ABGN-1414-P-N",
                    "FANT-04ABGN-8065-P-N",
                    "FANT-04ABGN-0606-O-R",
                    "FANT-04ABGN-0606-P-R",
                    "FANT-10ACAX-1213-D-N",
                    "FANT-08ABGN-1213-D-R"
                ],
                "type": "str"
            },
            "mimo-mode": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "default",
                    "1x1",
                    "2x2",
                    "3x3",
                    "4x4",
                    "8x8"
                ],
                "type": "str"
            }
        }
    },
    "wtpprofile_radio3": {
        "stated": false,
        "options": {
            "airtime-fairness": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "amsdu": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ap-handoff": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ap-sniffer-addr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ap-sniffer-bufsize": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ap-sniffer-chan": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ap-sniffer-ctl": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ap-sniffer-data": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ap-sniffer-mgmt-beacon": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ap-sniffer-mgmt-other": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ap-sniffer-mgmt-probe": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "auto-power-high": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "auto-power-level": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "auto-power-low": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "band": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "802.11b",
                    "802.11a",
                    "802.11g",
                    "802.11n",
                    "802.11ac",
                    "802.11n-5G",
                    "802.11ax-5G",
                    "802.11ax",
                    "802.11g-only",
                    "802.11n-only",
                    "802.11n,g-only",
                    "802.11ac-only",
                    "802.11ac,n-only",
                    "802.11n-5G-only",
                    "802.11ax-5G-only",
                    "802.11ax,ac-only",
                    "802.11ax,ac,n-only",
                    "802.11ax-only",
                    "802.11ax,n-only",
                    "802.11ax,n,g-only",
                    "802.11ac-2G",
                    "802.11ax-6G"
                ],
                "type": "str"
            },
            "bandwidth-admission-control": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "bandwidth-capacity": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "beacon-interval": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "call-admission-control": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "call-capacity": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "channel": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "channel-bonding": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "80MHz",
                    "40MHz",
                    "20MHz",
                    "160MHz"
                ],
                "type": "str"
            },
            "channel-utilization": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "coexistence": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "darrp": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dtim": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "frag-threshold": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "frequency-handoff": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "max-clients": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "max-distance": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disabled",
                    "ap",
                    "monitor",
                    "sniffer",
                    "sam"
                ],
                "type": "str"
            },
            "power-level": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "powersave-optimize": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "tim",
                    "ac-vo",
                    "no-obss-scan",
                    "no-11b-rate",
                    "client-rate-follow"
                ],
                "elements": "str"
            },
            "protection-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "rtscts",
                    "ctsonly",
                    "disable"
                ],
                "type": "str"
            },
            "radio-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "rts-threshold": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "short-guard-interval": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "spectrum-analysis": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "scan-only"
                ],
                "type": "str"
            },
            "transmit-optimize": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "disable",
                    "power-save",
                    "aggr-limit",
                    "retry-limit",
                    "send-bar"
                ],
                "elements": "str"
            },
            "vap-all": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "tunnel",
                    "bridge",
                    "manual"
                ],
                "type": "str"
            },
            "vaps": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "wids-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "band-5g-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "5g-full",
                    "5g-high",
                    "5g-low"
                ],
                "type": "str"
            },
            "zero-wait-dfs": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "vap1": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vap2": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vap3": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vap4": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vap5": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vap6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vap7": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vap8": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "bss-color": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "auto-power-target": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "drma": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "drma-sensitivity": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "low",
                    "medium",
                    "high"
                ],
                "type": "str"
            },
            "iperf-protocol": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "udp",
                    "tcp"
                ],
                "type": "str"
            },
            "iperf-server-port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "power-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "dBm",
                    "percentage"
                ],
                "type": "str"
            },
            "power-value": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "sam-bssid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sam-captive-portal": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sam-password": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "sam-report-intv": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "sam-security-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "open",
                    "wpa-personal",
                    "wpa-enterprise"
                ],
                "type": "str"
            },
            "sam-server": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sam-ssid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sam-test": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ping",
                    "iperf"
                ],
                "type": "str"
            },
            "sam-username": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "arrp-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "bss-color-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auto",
                    "static"
                ],
                "type": "str"
            },
            "sam-cwp-failure-string": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sam-cwp-match-string": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sam-cwp-password": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "sam-cwp-success-string": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sam-cwp-test-url": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sam-cwp-username": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sam-server-fqdn": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sam-server-ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sam-server-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ip",
                    "fqdn"
                ],
                "type": "str"
            },
            "80211d": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "optional-antenna": {
                "required": false,
                "revision": {
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "FANT-04ABGN-0606-O-N",
                    "FANT-04ABGN-1414-P-N",
                    "FANT-04ABGN-8065-P-N",
                    "FANT-04ABGN-0606-O-R",
                    "FANT-04ABGN-0606-P-R",
                    "FANT-10ACAX-1213-D-N",
                    "FANT-08ABGN-1213-D-R"
                ],
                "type": "str"
            },
            "mimo-mode": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "default",
                    "1x1",
                    "2x2",
                    "3x3",
                    "4x4",
                    "8x8"
                ],
                "type": "str"
            }
        }
    },
    "wtpprofile_radio4": {
        "stated": false,
        "options": {
            "airtime-fairness": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "amsdu": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ap-handoff": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ap-sniffer-addr": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "ap-sniffer-bufsize": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ap-sniffer-chan": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "ap-sniffer-ctl": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ap-sniffer-data": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ap-sniffer-mgmt-beacon": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ap-sniffer-mgmt-other": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "ap-sniffer-mgmt-probe": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "auto-power-high": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "auto-power-level": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "auto-power-low": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "band": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "802.11b",
                    "802.11a",
                    "802.11g",
                    "802.11n",
                    "802.11ac",
                    "802.11n-5G",
                    "802.11ax-5G",
                    "802.11ax",
                    "802.11g-only",
                    "802.11n-only",
                    "802.11n,g-only",
                    "802.11ac-only",
                    "802.11ac,n-only",
                    "802.11n-5G-only",
                    "802.11ax-5G-only",
                    "802.11ax,ac-only",
                    "802.11ax,ac,n-only",
                    "802.11ax-only",
                    "802.11ax,n-only",
                    "802.11ax,n,g-only",
                    "802.11ac-2G",
                    "802.11ax-6G"
                ],
                "type": "str"
            },
            "band-5g-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "5g-full",
                    "5g-high",
                    "5g-low"
                ],
                "type": "str"
            },
            "bandwidth-admission-control": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "bandwidth-capacity": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "beacon-interval": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "call-admission-control": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "call-capacity": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "channel": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "channel-bonding": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "80MHz",
                    "40MHz",
                    "20MHz",
                    "160MHz"
                ],
                "type": "str"
            },
            "channel-utilization": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "coexistence": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "darrp": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "dtim": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "frag-threshold": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "frequency-handoff": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": false,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "max-clients": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "max-distance": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ap",
                    "monitor",
                    "sniffer",
                    "disabled",
                    "sam"
                ],
                "type": "str"
            },
            "power-level": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "powersave-optimize": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "tim",
                    "ac-vo",
                    "no-obss-scan",
                    "no-11b-rate",
                    "client-rate-follow"
                ],
                "elements": "str"
            },
            "protection-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "rtscts",
                    "ctsonly",
                    "disable"
                ],
                "type": "str"
            },
            "radio-id": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "rts-threshold": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "short-guard-interval": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "spectrum-analysis": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "scan-only"
                ],
                "type": "str"
            },
            "transmit-optimize": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "list",
                "choices": [
                    "disable",
                    "power-save",
                    "aggr-limit",
                    "retry-limit",
                    "send-bar"
                ],
                "elements": "str"
            },
            "vap-all": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable",
                    "tunnel",
                    "bridge",
                    "manual"
                ],
                "type": "str"
            },
            "vaps": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "raw"
            },
            "wids-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "zero-wait-dfs": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "vap1": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vap2": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vap3": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vap4": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vap5": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vap6": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vap7": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "vap8": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "bss-color": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "auto-power-target": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "drma": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "drma-sensitivity": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "low",
                    "medium",
                    "high"
                ],
                "type": "str"
            },
            "iperf-protocol": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "udp",
                    "tcp"
                ],
                "type": "str"
            },
            "iperf-server-port": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "power-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "dBm",
                    "percentage"
                ],
                "type": "str"
            },
            "power-value": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "sam-bssid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sam-captive-portal": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "sam-password": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "sam-report-intv": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            },
            "sam-security-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "open",
                    "wpa-personal",
                    "wpa-enterprise"
                ],
                "type": "str"
            },
            "sam-server": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sam-ssid": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sam-test": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ping",
                    "iperf"
                ],
                "type": "str"
            },
            "sam-username": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "arrp-profile": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": false,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "bss-color-mode": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": false,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "auto",
                    "static"
                ],
                "type": "str"
            },
            "sam-cwp-failure-string": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sam-cwp-match-string": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sam-cwp-password": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "no_log": true,
                "type": "raw"
            },
            "sam-cwp-success-string": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sam-cwp-test-url": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sam-cwp-username": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sam-server-fqdn": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sam-server-ip": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "sam-server-type": {
                "required": false,
                "revision": {
                    "6.2.0": false,
                    "6.2.2": false,
                    "6.2.6": false,
                    "6.2.7": false,
                    "6.2.8": false,
                    "6.2.9": false,
                    "6.2.10": false,
                    "6.2.11": false,
                    "6.2.12": false,
                    "6.4.1": false,
                    "6.4.3": false,
                    "6.4.4": false,
                    "6.4.6": false,
                    "6.4.7": false,
                    "6.4.8": false,
                    "6.4.9": false,
                    "6.4.10": false,
                    "6.4.11": false,
                    "6.4.12": false,
                    "6.4.13": false,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "ip",
                    "fqdn"
                ],
                "type": "str"
            },
            "80211d": {
                "required": false,
                "revision": {
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "disable",
                    "enable"
                ],
                "type": "str"
            },
            "optional-antenna": {
                "required": false,
                "revision": {
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "choices": [
                    "none",
                    "FANT-04ABGN-0606-O-N",
                    "FANT-04ABGN-1414-P-N",
                    "FANT-04ABGN-8065-P-N",
                    "FANT-04ABGN-0606-O-R",
                    "FANT-04ABGN-0606-P-R",
                    "FANT-10ACAX-1213-D-N",
                    "FANT-08ABGN-1213-D-R"
                ],
                "type": "str"
            },
            "mimo-mode": {
                "required": false,
                "revision": {
                    "7.4.1": true
                },
                "choices": [
                    "default",
                    "1x1",
                    "2x2",
                    "3x3",
                    "4x4",
                    "8x8"
                ],
                "type": "str"
            }
        }
    },
    "wtpprofile_splittunnelingacl": {
        "stated": true,
        "options": {
            "dest-ip": {
                "required": false,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "str"
            },
            "id": {
                "required": true,
                "revision": {
                    "6.0.0": true,
                    "6.2.0": true,
                    "6.2.1": true,
                    "6.2.2": true,
                    "6.2.3": true,
                    "6.2.5": true,
                    "6.2.6": true,
                    "6.2.7": true,
                    "6.2.8": true,
                    "6.2.9": true,
                    "6.2.10": true,
                    "6.2.11": true,
                    "6.2.12": true,
                    "6.4.0": true,
                    "6.4.1": true,
                    "6.4.2": true,
                    "6.4.3": true,
                    "6.4.4": true,
                    "6.4.5": true,
                    "6.4.6": true,
                    "6.4.7": true,
                    "6.4.8": true,
                    "6.4.9": true,
                    "6.4.10": true,
                    "6.4.11": true,
                    "6.4.12": true,
                    "6.4.13": true,
                    "7.0.0": true,
                    "7.0.1": true,
                    "7.0.2": true,
                    "7.0.3": true,
                    "7.0.4": true,
                    "7.0.5": true,
                    "7.0.6": true,
                    "7.0.7": true,
                    "7.0.8": true,
                    "7.0.9": true,
                    "7.2.0": true,
                    "7.2.1": true,
                    "7.2.2": true,
                    "7.2.3": true,
                    "7.2.4": true,
                    "7.4.0": true,
                    "7.4.1": true
                },
                "type": "int"
            }
        }
    }
}
'''

schemas = json.loads(SCHEMA_DATA)
